@@ -1,7 +1,19 @@
 use crate::config::Config;
 use crate::lint_context::LintContext;
 use crate::rule::{LintWarning, Rule};
+use std::collections::hash_map::DefaultHasher;
 use std::collections::{HashMap, HashSet};
+use std::hash::{Hash, Hasher};
+
+/// Maximum number of fix iterations before stopping (same as Ruff)
+const MAX_ITERATIONS: usize = 100;
+
+/// Calculate hash of content for convergence detection
+fn hash_content(content: &str) -> u64 {
+    let mut hasher = DefaultHasher::new();
+    content.hash(&mut hasher);
+    hasher.finish()
+}
 
 /// Coordinates rule fixing to minimize the number of passes needed
 pub struct FixCoordinator {
@@ -28,8 +40,9 @@ impl FixCoordinator {
         dependencies.insert("MD010", vec!["MD007", "MD005"]);
 
         // MD013 (line length) MUST run before:
-        // - MD009 (trailing spaces) - line wrapping might add/remove trailing spaces
+        // - MD009 (trailing spaces) - line wrapping might add trailing spaces that need cleanup
         // - MD012 (multiple blanks) - reflowing can affect blank lines
+        // Note: MD013 now trims trailing whitespace during reflow to prevent mid-line spaces
         dependencies.insert("MD013", vec!["MD009", "MD012"]);
 
         // MD004 (list style) should run before:
@@ -122,7 +135,7 @@ impl FixCoordinator {
     }
 
     /// Apply fixes iteratively until no more fixes are needed or max iterations reached
-    /// Returns (rules_fixed_count, iterations, context_creations, fixed_rule_names)
+    /// Returns (rules_fixed_count, iterations, context_creations, fixed_rule_names, converged)
     pub fn apply_fixes_iterative(
         &self,
         rules: &[Box<dyn Rule>],
@@ -130,21 +143,25 @@ impl FixCoordinator {
         content: &mut String,
         config: &Config,
         max_iterations: usize,
-    ) -> Result<(usize, usize, usize, HashSet<String>), String> {
+    ) -> Result<(usize, usize, usize, HashSet<String>, bool), String> {
+        // Use the minimum of max_iterations parameter and MAX_ITERATIONS constant
+        let max_iterations = max_iterations.min(MAX_ITERATIONS);
+
         // Get optimal rule order
         let ordered_rules = self.get_optimal_order(rules);
 
         // Group warnings by rule for quick lookup
         let mut warnings_by_rule: HashMap<&str, Vec<&LintWarning>> = HashMap::new();
         for warning in all_warnings {
-            if let Some(rule_name) = warning.rule_name {
-                warnings_by_rule.entry(rule_name).or_default().push(warning);
+            if let Some(ref rule_name) = warning.rule_name {
+                warnings_by_rule.entry(rule_name.as_str()).or_default().push(warning);
             }
         }
 
         let mut total_fixed = 0;
         let mut total_ctx_creations = 0;
         let mut iterations = 0;
+        let mut previous_hash = hash_content(content);
 
         // Keep track of which rules have been processed successfully
         let mut processed_rules = HashSet::new();
@@ -227,6 +244,14 @@ impl FixCoordinator {
 
             total_fixed += fixes_in_iteration;
 
+            // Check if content has stabilized (hash-based convergence)
+            let current_hash = hash_content(content);
+            if current_hash == previous_hash {
+                // Content unchanged - converged!
+                return Ok((total_fixed, iterations, total_ctx_creations, fixed_rule_names, true));
+            }
+            previous_hash = current_hash;
+
             // If no fixes were made in this iteration, we're done
             if !any_fix_applied {
                 break;
@@ -238,7 +263,15 @@ impl FixCoordinator {
             }
         }
 
-        Ok((total_fixed, iterations, total_ctx_creations, fixed_rule_names))
+        // If we reached here, either we hit max iterations or all rules processed
+        let converged = iterations < max_iterations;
+        Ok((
+            total_fixed,
+            iterations,
+            total_ctx_creations,
+            fixed_rule_names,
+            converged,
+        ))
     }
 }
 
@@ -335,7 +368,7 @@ mod tests {
                 end_line: 1,
                 end_column: 10,
                 message: "Test warning".to_string(),
-                rule_name: Some("MD001"),
+                rule_name: Some("MD001".to_string()),
                 severity: crate::rule::Severity::Error,
                 fix: None,
             }],
@@ -348,7 +381,7 @@ mod tests {
             end_line: 1,
             end_column: 10,
             message: "Test warning".to_string(),
-            rule_name: Some("MD001"),
+            rule_name: Some("MD001".to_string()),
             severity: crate::rule::Severity::Error,
             fix: None,
         }];
@@ -356,16 +389,18 @@ mod tests {
         let mut content = "original content".to_string();
         let config = Config {
             global: GlobalConfig::default(),
+            per_file_ignores: HashMap::new(),
             rules: Default::default(),
         };
 
         let result = coordinator.apply_fixes_iterative(&rules, &warnings, &mut content, &config, 5);
 
         assert!(result.is_ok());
-        let (total_fixed, iterations, ctx_creations, _) = result.unwrap();
+        let (total_fixed, iterations, ctx_creations, _, converged) = result.unwrap();
         assert_eq!(total_fixed, 1);
         assert_eq!(iterations, 1);
         assert_eq!(ctx_creations, 1);
+        assert!(converged);
         assert_eq!(content, "fixed content");
     }
 
@@ -382,7 +417,7 @@ mod tests {
                     end_line: 1,
                     end_column: 10,
                     message: "Tabs".to_string(),
-                    rule_name: Some("MD010"),
+                    rule_name: Some("MD010".to_string()),
                     severity: crate::rule::Severity::Error,
                     fix: None,
                 }],
@@ -396,7 +431,7 @@ mod tests {
                     end_line: 1,
                     end_column: 10,
                     message: "Indentation".to_string(),
-                    rule_name: Some("MD007"),
+                    rule_name: Some("MD007".to_string()),
                     severity: crate::rule::Severity::Error,
                     fix: None,
                 }],
@@ -411,7 +446,7 @@ mod tests {
                 end_line: 1,
                 end_column: 10,
                 message: "Tabs".to_string(),
-                rule_name: Some("MD010"),
+                rule_name: Some("MD010".to_string()),
                 severity: crate::rule::Severity::Error,
                 fix: None,
             },
@@ -421,7 +456,7 @@ mod tests {
                 end_line: 1,
                 end_column: 10,
                 message: "Indentation".to_string(),
-                rule_name: Some("MD007"),
+                rule_name: Some("MD007".to_string()),
                 severity: crate::rule::Severity::Error,
                 fix: None,
             },
@@ -430,16 +465,18 @@ mod tests {
         let mut content = "content with tabs".to_string();
         let config = Config {
             global: GlobalConfig::default(),
+            per_file_ignores: HashMap::new(),
             rules: Default::default(),
         };
 
         let result = coordinator.apply_fixes_iterative(&rules, &warnings, &mut content, &config, 5);
 
         assert!(result.is_ok());
-        let (total_fixed, iterations, ctx_creations, _) = result.unwrap();
+        let (total_fixed, iterations, ctx_creations, _, converged) = result.unwrap();
         assert_eq!(total_fixed, 2);
         assert_eq!(iterations, 2); // Should take 2 iterations due to dependency
         assert!(ctx_creations >= 2);
+        assert!(converged);
     }
 
     #[test]
@@ -454,7 +491,7 @@ mod tests {
                 end_line: 1,
                 end_column: 10,
                 message: "Test".to_string(),
-                rule_name: Some("MD001"),
+                rule_name: Some("MD001".to_string()),
                 severity: crate::rule::Severity::Error,
                 fix: None,
             }],
@@ -467,7 +504,7 @@ mod tests {
             end_line: 1,
             end_column: 10,
             message: "Test".to_string(),
-            rule_name: Some("MD001"),
+            rule_name: Some("MD001".to_string()),
             severity: crate::rule::Severity::Error,
             fix: None,
         }];
@@ -475,6 +512,7 @@ mod tests {
         let mut content = "original".to_string();
         let mut config = Config {
             global: GlobalConfig::default(),
+            per_file_ignores: HashMap::new(),
             rules: Default::default(),
         };
         config.global.unfixable = vec!["MD001".to_string()];
@@ -482,8 +520,9 @@ mod tests {
         let result = coordinator.apply_fixes_iterative(&rules, &warnings, &mut content, &config, 5);
 
         assert!(result.is_ok());
-        let (total_fixed, _, _, _) = result.unwrap();
+        let (total_fixed, _, _, _, converged) = result.unwrap();
         assert_eq!(total_fixed, 0);
+        assert!(converged);
         assert_eq!(content, "original"); // Should not be changed
     }
 
@@ -506,7 +545,7 @@ mod tests {
                     end_line: 1,
                     end_column: 10,
                     message: "Always warns".to_string(),
-                    rule_name: Some("MD999"),
+                    rule_name: Some("MD999".to_string()),
                     severity: crate::rule::Severity::Error,
                     fix: None,
                 }])
@@ -532,7 +571,7 @@ mod tests {
             end_line: 1,
             end_column: 10,
             message: "Always warns".to_string(),
-            rule_name: Some("MD999"),
+            rule_name: Some("MD999".to_string()),
             severity: crate::rule::Severity::Error,
             fix: None,
         }];
@@ -540,14 +579,16 @@ mod tests {
         let mut content = "test".to_string();
         let config = Config {
             global: GlobalConfig::default(),
+            per_file_ignores: HashMap::new(),
             rules: Default::default(),
         };
 
         let result = coordinator.apply_fixes_iterative(&rules, &warnings, &mut content, &config, 3);
 
         assert!(result.is_ok());
-        let (_, iterations, _, _) = result.unwrap();
+        let (_, iterations, _, _, converged) = result.unwrap();
         assert_eq!(iterations, 1); // Should stop after first successful fix
+        assert!(converged);
     }
 
     #[test]
@@ -559,16 +600,18 @@ mod tests {
         let mut content = "unchanged".to_string();
         let config = Config {
             global: GlobalConfig::default(),
+            per_file_ignores: HashMap::new(),
             rules: Default::default(),
         };
 
         let result = coordinator.apply_fixes_iterative(&rules, &warnings, &mut content, &config, 5);
 
         assert!(result.is_ok());
-        let (total_fixed, iterations, ctx_creations, _) = result.unwrap();
+        let (total_fixed, iterations, ctx_creations, _, converged) = result.unwrap();
         assert_eq!(total_fixed, 0);
         assert_eq!(iterations, 1);
         assert_eq!(ctx_creations, 0);
+        assert!(converged);
         assert_eq!(content, "unchanged");
     }
 
