@@ -1,5 +1,6 @@
 pub mod config;
 pub mod exit_codes;
+pub mod filtered_lines;
 pub mod fix_coordinator;
 pub mod inline_config;
 pub mod lint_context;
@@ -16,11 +17,9 @@ pub mod rule_config;
 #[macro_use]
 pub mod rule_config_serde;
 pub mod rules;
+pub mod types;
 pub mod utils;
 
-#[cfg(feature = "python")]
-pub mod python;
-
 pub use rules::heading_utils::{Heading, HeadingStyle};
 pub use rules::*;
 
@@ -151,35 +150,15 @@ pub fn lint(
     let _total_rules = rules.len();
     let _applicable_count = applicable_rules.len();
 
-    // Parse AST once for rules that can benefit from it
-    let ast_rules_count = applicable_rules.iter().filter(|rule| rule.uses_ast()).count();
-    let ast = if ast_rules_count > 0 {
-        Some(crate::utils::ast_utils::get_cached_ast(content))
-    } else {
-        None
-    };
-
-    // Parse LintContext once (migration step) with the provided flavor
+    // Parse LintContext once with the provided flavor
     let lint_ctx = crate::lint_context::LintContext::new(content, flavor);
 
+    let profile_rules = std::env::var("RUMDL_PROFILE_RULES").is_ok();
+
     for rule in applicable_rules {
         let _rule_start = Instant::now();
 
-        // Try optimized paths in order of preference
-        let result = if rule.uses_ast() {
-            if let Some(ref ast_ref) = ast {
-                // 1. AST-based path
-                rule.as_maybe_ast()
-                    .and_then(|ext| ext.check_with_ast_opt(&lint_ctx, ast_ref))
-                    .unwrap_or_else(|| rule.check_with_ast(&lint_ctx, ast_ref))
-            } else {
-                // Fallback to regular check if no AST
-                rule.check(&lint_ctx)
-            }
-        } else {
-            // 2. Regular check path
-            rule.check(&lint_ctx)
-        };
+        let result = rule.check(&lint_ctx);
 
         match result {
             Ok(rule_warnings) => {
@@ -188,7 +167,7 @@ pub fn lint(
                     .into_iter()
                     .filter(|warning| {
                         // Use the warning's rule_name if available, otherwise use the rule's name
-                        let rule_name_to_check = warning.rule_name.unwrap_or(rule.name());
+                        let rule_name_to_check = warning.rule_name.as_deref().unwrap_or(rule.name());
 
                         // Extract the base rule name for sub-rules like "MD029-style" -> "MD029"
                         let base_rule_name = if let Some(dash_pos) = rule_name_to_check.find('-') {
@@ -211,12 +190,14 @@ pub fn lint(
             }
         }
 
+        let rule_duration = _rule_start.elapsed();
+        if profile_rules {
+            eprintln!("[RULE] {:6} {:?}", rule.name(), rule_duration);
+        }
+
         #[cfg(not(test))]
-        if _verbose {
-            let rule_duration = _rule_start.elapsed();
-            if rule_duration.as_millis() > 500 {
-                log::debug!("Rule {} took {:?}", rule.name(), rule_duration);
-            }
+        if _verbose && rule_duration.as_millis() > 500 {
+            log::debug!("Rule {} took {:?}", rule.name(), rule_duration);
         }
     }
 
@@ -226,9 +207,6 @@ pub fn lint(
         if skipped_rules > 0 {
             log::debug!("Skipped {skipped_rules} of {_total_rules} rules based on content analysis");
         }
-        if ast.is_some() {
-            log::debug!("Used shared AST for {ast_rules_count} rules");
-        }
     }
 
     Ok(warnings)
@@ -249,80 +227,11 @@ pub fn get_regex_cache_stats() -> std::collections::HashMap<String, u64> {
     crate::utils::regex_cache::get_cache_stats()
 }
 
-/// Get AST cache statistics for performance monitoring
-pub fn get_ast_cache_stats() -> std::collections::HashMap<u64, u64> {
-    crate::utils::ast_utils::get_ast_cache_stats()
-}
-
-/// Clear all caches (useful for testing and memory management)
-pub fn clear_all_caches() {
-    crate::utils::ast_utils::clear_ast_cache();
-    // Note: Regex cache is intentionally not cleared as it's global and shared
-}
-
-/// Get comprehensive cache performance report
-pub fn get_cache_performance_report() -> String {
-    let regex_stats = get_regex_cache_stats();
-    let ast_stats = get_ast_cache_stats();
-
-    let mut report = String::new();
-
-    report.push_str("=== Cache Performance Report ===\n\n");
-
-    // Regex cache statistics
-    report.push_str("Regex Cache:\n");
-    if regex_stats.is_empty() {
-        report.push_str("  No regex patterns cached\n");
-    } else {
-        let total_usage: u64 = regex_stats.values().sum();
-        report.push_str(&format!("  Total patterns: {}\n", regex_stats.len()));
-        report.push_str(&format!("  Total usage: {total_usage}\n"));
-
-        // Show top 5 most used patterns
-        let mut sorted_patterns: Vec<_> = regex_stats.iter().collect();
-        sorted_patterns.sort_by(|a, b| b.1.cmp(a.1));
-
-        report.push_str("  Top patterns by usage:\n");
-        for (pattern, count) in sorted_patterns.iter().take(5) {
-            let truncated_pattern = if pattern.len() > 50 {
-                format!("{}...", &pattern[..47])
-            } else {
-                pattern.to_string()
-            };
-            report.push_str(&format!(
-                "    {} ({}x): {}\n",
-                count,
-                pattern.len().min(50),
-                truncated_pattern
-            ));
-        }
-    }
-
-    report.push('\n');
-
-    // AST cache statistics
-    report.push_str("AST Cache:\n");
-    if ast_stats.is_empty() {
-        report.push_str("  No AST nodes cached\n");
-    } else {
-        let total_usage: u64 = ast_stats.values().sum();
-        report.push_str(&format!("  Total ASTs: {}\n", ast_stats.len()));
-        report.push_str(&format!("  Total usage: {total_usage}\n"));
-
-        if total_usage > ast_stats.len() as u64 {
-            let cache_hit_rate = ((total_usage - ast_stats.len() as u64) as f64 / total_usage as f64) * 100.0;
-            report.push_str(&format!("  Cache hit rate: {cache_hit_rate:.1}%\n"));
-        }
-    }
-
-    report
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
     use crate::rule::Rule;
-    use crate::rules::{MD001HeadingIncrement, MD009TrailingSpaces, MD012NoMultipleBlanks};
+    use crate::rules::{MD001HeadingIncrement, MD009TrailingSpaces};
 
     #[test]
     fn test_content_characteristics_analyze() {
@@ -451,7 +360,7 @@ mod tests {
         let warnings = result.unwrap();
         assert!(!warnings.is_empty());
         // Check the rule field of LintWarning struct
-        assert_eq!(warnings[0].rule_name, Some("MD001"));
+        assert_eq!(warnings[0].rule_name.as_deref(), Some("MD001"));
     }
 
     #[test]
@@ -508,53 +417,6 @@ mod tests {
         }
     }
 
-    #[test]
-    fn test_get_ast_cache_stats() {
-        let stats = get_ast_cache_stats();
-        // Stats should be a valid HashMap (might be empty)
-        assert!(stats.is_empty() || !stats.is_empty());
-
-        // If not empty, all values should be positive
-        for count in stats.values() {
-            assert!(*count > 0);
-        }
-    }
-
-    #[test]
-    fn test_clear_all_caches() {
-        // Test that clear_all_caches doesn't panic
-        clear_all_caches();
-
-        // After clearing, AST cache should be empty
-        let ast_stats = get_ast_cache_stats();
-        assert!(ast_stats.is_empty());
-    }
-
-    #[test]
-    fn test_get_cache_performance_report() {
-        let report = get_cache_performance_report();
-
-        // Report should contain expected sections
-        assert!(report.contains("Cache Performance Report"));
-        assert!(report.contains("Regex Cache:"));
-        assert!(report.contains("AST Cache:"));
-
-        // Test with empty caches
-        clear_all_caches();
-        let report_empty = get_cache_performance_report();
-        assert!(report_empty.contains("No AST nodes cached"));
-    }
-
-    #[test]
-    fn test_lint_with_ast_rules() {
-        // Create content that would benefit from AST parsing
-        let content = "# Heading\n\nParagraph with **bold** text.";
-        let rules: Vec<Box<dyn Rule>> = vec![Box::new(MD012NoMultipleBlanks::new(1))];
-
-        let result = lint(content, &rules, false, crate::config::MarkdownFlavor::Standard);
-        assert!(result.is_ok());
-    }
-
     #[test]
     fn test_content_characteristics_edge_cases() {
         // Test setext heading edge case
@@ -575,18 +437,4 @@ mod tests {
         let chars = ContentCharacteristics::analyze("text > not a quote");
         assert!(!chars.has_blockquotes);
     }
-
-    #[test]
-    fn test_cache_performance_report_formatting() {
-        // Add some data to caches to test formatting
-        // (Would require actual usage of the caches, which happens during linting)
-
-        let report = get_cache_performance_report();
-
-        // Test truncation of long patterns
-        // Since we can't easily add a long pattern to the cache in this test,
-        // we'll just verify the report structure is correct
-        assert!(!report.is_empty());
-        assert!(report.lines().count() > 3); // Should have multiple lines
-    }
 }
