@@ -32,11 +32,9 @@ fn markdownlint_to_rumdl_rule_key(key: &str) -> Option<&'static str> {
     let normalized_key = key.to_ascii_uppercase().replace('_', "-");
     match normalized_key.as_str() {
         "MD001" | "HEADING-INCREMENT" => Some("MD001"),
-        "MD002" | "FIRST-HEADING-H1" => Some("MD002"),
         "MD003" | "HEADING-STYLE" => Some("MD003"),
         "MD004" | "UL-STYLE" => Some("MD004"),
         "MD005" | "LIST-INDENT" => Some("MD005"),
-        "MD006" | "UL-START-LEFT" => Some("MD006"),
         "MD007" | "UL-INDENT" => Some("MD007"),
         "MD008" => Some("MD008"),
         "MD009" | "NO-TRAILING-SPACES" => Some("MD009"),
@@ -106,6 +104,72 @@ fn normalize_toml_table_keys(val: toml::Value) -> toml::Value {
     }
 }
 
+/// Map markdownlint-specific option names to rumdl option names for a given rule.
+/// This handles incompatibilities between markdownlint and rumdl config schemas.
+/// Returns a new table with mapped options, or None if the entire config should be dropped.
+fn map_markdownlint_options_to_rumdl(
+    rule_key: &str,
+    table: toml::map::Map<String, toml::Value>,
+) -> Option<toml::map::Map<String, toml::Value>> {
+    let mut mapped = toml::map::Map::new();
+
+    match rule_key {
+        "MD013" => {
+            // MD013 (line-length) has different option names in markdownlint vs rumdl
+            for (k, v) in table {
+                match k.as_str() {
+                    // Markdownlint uses separate line length limits for different content types
+                    // rumdl uses boolean flags to enable/disable checking for content types
+                    "code-block-line-length" | "code_block_line_length" => {
+                        // Ignore: rumdl doesn't support per-content-type line length limits
+                        // Instead, users should use code-blocks = false to disable entirely
+                        log::warn!(
+                            "Ignoring markdownlint option 'code_block_line_length' for MD013. Use 'code-blocks = false' in rumdl to disable line length checking in code blocks."
+                        );
+                    }
+                    "heading-line-length" | "heading_line_length" => {
+                        // Ignore: rumdl doesn't support per-content-type line length limits
+                        log::warn!(
+                            "Ignoring markdownlint option 'heading_line_length' for MD013. Use 'headings = false' in rumdl to disable line length checking in headings."
+                        );
+                    }
+                    "stern" => {
+                        // Markdownlint uses "stern", rumdl uses "strict"
+                        mapped.insert("strict".to_string(), v);
+                    }
+                    // Pass through all other options
+                    _ => {
+                        mapped.insert(k, v);
+                    }
+                }
+            }
+            Some(mapped)
+        }
+        "MD054" => {
+            // MD054 (link-image-style) has fundamentally different config models
+            // Markdownlint uses style/styles strings, rumdl uses individual boolean flags
+            for (k, v) in table {
+                match k.as_str() {
+                    "style" | "styles" => {
+                        // Ignore: rumdl uses individual boolean flags (autolink, inline, full, etc.)
+                        // Cannot automatically map string style names to boolean flags
+                        log::warn!(
+                            "Ignoring markdownlint option '{k}' for MD054. rumdl uses individual boolean flags (autolink, inline, full, collapsed, shortcut, url-inline) instead. Please configure these directly."
+                        );
+                    }
+                    // Pass through all other options (autolink, inline, full, collapsed, shortcut, url-inline)
+                    _ => {
+                        mapped.insert(k, v);
+                    }
+                }
+            }
+            Some(mapped)
+        }
+        // All other rules: pass through unchanged
+        _ => Some(table),
+    }
+}
+
 /// Map a MarkdownlintConfig to rumdl's internal Config format
 impl MarkdownlintConfig {
     /// Map to a SourcedConfig, tracking provenance as Markdownlint for all values.
@@ -121,6 +185,12 @@ impl MarkdownlintConfig {
                 let rule_config = sourced_config.rules.entry(norm_rule_key.clone()).or_default();
                 if let Some(tv) = toml_value {
                     if let toml::Value::Table(mut table) = tv {
+                        // Apply markdownlint-to-rumdl option mapping
+                        table = match map_markdownlint_options_to_rumdl(&norm_rule_key, table) {
+                            Some(mapped) => mapped,
+                            None => continue, // Skip this rule entirely if mapping returns None
+                        };
+
                         // Special handling for MD007: Add style = "fixed" for markdownlint compatibility
                         if norm_rule_key == "MD007" && !table.contains_key("style") {
                             table.insert("style".to_string(), toml::Value::String("fixed".to_string()));
@@ -133,20 +203,20 @@ impl MarkdownlintConfig {
                                 .entry(norm_config_key.clone())
                                 .and_modify(|sv| {
                                     sv.value = v.clone();
-                                    sv.source = ConfigSource::Markdownlint;
+                                    sv.source = ConfigSource::ProjectConfig;
                                     sv.overrides.push(crate::config::ConfigOverride {
                                         value: v.clone(),
-                                        source: ConfigSource::Markdownlint,
+                                        source: ConfigSource::ProjectConfig,
                                         file: file.clone(),
                                         line: None,
                                     });
                                 })
                                 .or_insert_with(|| SourcedValue {
                                     value: v.clone(),
-                                    source: ConfigSource::Markdownlint,
+                                    source: ConfigSource::ProjectConfig,
                                     overrides: vec![crate::config::ConfigOverride {
                                         value: v,
-                                        source: ConfigSource::Markdownlint,
+                                        source: ConfigSource::ProjectConfig,
                                         file: file.clone(),
                                         line: None,
                                     }],
@@ -158,20 +228,20 @@ impl MarkdownlintConfig {
                             .entry("value".to_string())
                             .and_modify(|sv| {
                                 sv.value = tv.clone();
-                                sv.source = ConfigSource::Markdownlint;
+                                sv.source = ConfigSource::ProjectConfig;
                                 sv.overrides.push(crate::config::ConfigOverride {
                                     value: tv.clone(),
-                                    source: ConfigSource::Markdownlint,
+                                    source: ConfigSource::ProjectConfig,
                                     file: file.clone(),
                                     line: None,
                                 });
                             })
                             .or_insert_with(|| SourcedValue {
                                 value: tv.clone(),
-                                source: ConfigSource::Markdownlint,
+                                source: ConfigSource::ProjectConfig,
                                 overrides: vec![crate::config::ConfigOverride {
                                     value: tv,
-                                    source: ConfigSource::Markdownlint,
+                                    source: ConfigSource::ProjectConfig,
                                     file: file.clone(),
                                     line: None,
                                 }],
@@ -183,10 +253,10 @@ impl MarkdownlintConfig {
                                 "style".to_string(),
                                 SourcedValue {
                                     value: toml::Value::String("fixed".to_string()),
-                                    source: ConfigSource::Markdownlint,
+                                    source: ConfigSource::ProjectConfig,
                                     overrides: vec![crate::config::ConfigOverride {
                                         value: toml::Value::String("fixed".to_string()),
-                                        source: ConfigSource::Markdownlint,
+                                        source: ConfigSource::ProjectConfig,
                                         file: file.clone(),
                                         line: None,
                                     }],
@@ -250,6 +320,12 @@ impl MarkdownlintConfig {
                     };
 
                     if let toml::Value::Table(mut table) = tv {
+                        // Apply markdownlint-to-rumdl option mapping
+                        table = match map_markdownlint_options_to_rumdl(&norm_rule_key, table) {
+                            Some(mapped) => mapped,
+                            None => continue, // Skip this rule entirely if mapping returns None
+                        };
+
                         // Special handling for MD007: Add style = "fixed" for markdownlint compatibility
                         if norm_rule_key == "MD007" && !table.contains_key("style") {
                             table.insert("style".to_string(), toml::Value::String("fixed".to_string()));
@@ -258,9 +334,9 @@ impl MarkdownlintConfig {
                         for (rk, rv) in table {
                             let norm_rk = crate::config::normalize_key(&rk);
                             let sv = rule_config.values.entry(norm_rk.clone()).or_insert_with(|| {
-                                crate::config::SourcedValue::new(rv.clone(), crate::config::ConfigSource::Markdownlint)
+                                crate::config::SourcedValue::new(rv.clone(), crate::config::ConfigSource::ProjectConfig)
                             });
-                            sv.push_override(rv, crate::config::ConfigSource::Markdownlint, file.clone(), None);
+                            sv.push_override(rv, crate::config::ConfigSource::ProjectConfig, file.clone(), None);
                         }
                     } else {
                         rule_config
@@ -268,20 +344,20 @@ impl MarkdownlintConfig {
                             .entry("value".to_string())
                             .and_modify(|sv| {
                                 sv.value = tv.clone();
-                                sv.source = crate::config::ConfigSource::Markdownlint;
+                                sv.source = crate::config::ConfigSource::ProjectConfig;
                                 sv.overrides.push(crate::config::ConfigOverride {
                                     value: tv.clone(),
-                                    source: crate::config::ConfigSource::Markdownlint,
+                                    source: crate::config::ConfigSource::ProjectConfig,
                                     file: file.clone(),
                                     line: None,
                                 });
                             })
                             .or_insert_with(|| crate::config::SourcedValue {
                                 value: tv.clone(),
-                                source: crate::config::ConfigSource::Markdownlint,
+                                source: crate::config::ConfigSource::ProjectConfig,
                                 overrides: vec![crate::config::ConfigOverride {
                                     value: tv,
-                                    source: crate::config::ConfigSource::Markdownlint,
+                                    source: crate::config::ConfigSource::ProjectConfig,
                                     file: file.clone(),
                                     line: None,
                                 }],
@@ -293,10 +369,10 @@ impl MarkdownlintConfig {
                                 "style".to_string(),
                                 crate::config::SourcedValue {
                                     value: toml::Value::String("fixed".to_string()),
-                                    source: crate::config::ConfigSource::Markdownlint,
+                                    source: crate::config::ConfigSource::ProjectConfig,
                                     overrides: vec![crate::config::ConfigOverride {
                                         value: toml::Value::String("fixed".to_string()),
-                                        source: crate::config::ConfigSource::Markdownlint,
+                                        source: crate::config::ConfigSource::ProjectConfig,
                                         file: file.clone(),
                                         line: None,
                                     }],
@@ -312,7 +388,7 @@ impl MarkdownlintConfig {
         if !disabled_rules.is_empty() {
             fragment.global.disable.push_override(
                 disabled_rules,
-                crate::config::ConfigSource::Markdownlint,
+                crate::config::ConfigSource::ProjectConfig,
                 file.clone(),
                 None,
             );
@@ -322,7 +398,7 @@ impl MarkdownlintConfig {
         if !enabled_rules.is_empty() {
             fragment.global.enable.push_override(
                 enabled_rules,
-                crate::config::ConfigSource::Markdownlint,
+                crate::config::ConfigSource::ProjectConfig,
                 file.clone(),
                 None,
             );
@@ -352,7 +428,6 @@ mod tests {
         // Test aliases with hyphens
         assert_eq!(markdownlint_to_rumdl_rule_key("heading-increment"), Some("MD001"));
         assert_eq!(markdownlint_to_rumdl_rule_key("HEADING-INCREMENT"), Some("MD001"));
-        assert_eq!(markdownlint_to_rumdl_rule_key("first-heading-h1"), Some("MD002"));
         assert_eq!(markdownlint_to_rumdl_rule_key("ul-style"), Some("MD004"));
         assert_eq!(markdownlint_to_rumdl_rule_key("no-trailing-spaces"), Some("MD009"));
         assert_eq!(markdownlint_to_rumdl_rule_key("line-length"), Some("MD013"));
@@ -365,7 +440,6 @@ mod tests {
         // Test aliases with underscores (should also work)
         assert_eq!(markdownlint_to_rumdl_rule_key("heading_increment"), Some("MD001"));
         assert_eq!(markdownlint_to_rumdl_rule_key("HEADING_INCREMENT"), Some("MD001"));
-        assert_eq!(markdownlint_to_rumdl_rule_key("first_heading_h1"), Some("MD002"));
         assert_eq!(markdownlint_to_rumdl_rule_key("ul_style"), Some("MD004"));
         assert_eq!(markdownlint_to_rumdl_rule_key("no_trailing_spaces"), Some("MD009"));
         assert_eq!(markdownlint_to_rumdl_rule_key("line_length"), Some("MD013"));
@@ -511,7 +585,7 @@ ul-style:
         let md013_config = &sourced_config.rules["MD013"];
         assert!(md013_config.values.contains_key("line-length"));
         assert_eq!(md013_config.values["line-length"].value, toml::Value::Integer(100));
-        assert_eq!(md013_config.values["line-length"].source, ConfigSource::Markdownlint);
+        assert_eq!(md013_config.values["line-length"].source, ConfigSource::ProjectConfig);
 
         // Check that loaded_files is tracked
         assert_eq!(sourced_config.loaded_files.len(), 1);
@@ -681,11 +755,9 @@ ul-style:
         // Test that all documented aliases map correctly
         let aliases = vec![
             ("heading-increment", "MD001"),
-            ("first-heading-h1", "MD002"),
             ("heading-style", "MD003"),
             ("ul-style", "MD004"),
             ("list-indent", "MD005"),
-            ("ul-start-left", "MD006"),
             ("ul-indent", "MD007"),
             ("no-trailing-spaces", "MD009"),
             ("no-hard-tabs", "MD010"),
