@@ -3,16 +3,13 @@
 //! Includes rule categories, dynamic dispatch helpers, and inline comment handling for rule enable/disable.
 
 use dyn_clone::DynClone;
-use serde::Serialize;
+use serde::{Deserialize, Serialize};
 use std::ops::Range;
 use thiserror::Error;
 
 // Import document structure
 use crate::lint_context::LintContext;
 
-// Import markdown AST for shared parsing
-pub use markdown::mdast::Node as MarkdownAst;
-
 // Macro to implement box_clone for Rule implementors
 #[macro_export]
 macro_rules! impl_rule_clone {
@@ -39,7 +36,7 @@ pub enum LintError {
 
 pub type LintResult = Result<Vec<LintWarning>, LintError>;
 
-#[derive(Debug, PartialEq, Clone, Serialize)]
+#[derive(Debug, PartialEq, Clone, Serialize, Deserialize)]
 pub struct LintWarning {
     pub message: String,
     pub line: usize,       // 1-indexed start line
@@ -48,16 +45,16 @@ pub struct LintWarning {
     pub end_column: usize, // 1-indexed end column
     pub severity: Severity,
     pub fix: Option<Fix>,
-    pub rule_name: Option<&'static str>,
+    pub rule_name: Option<String>,
 }
 
-#[derive(Debug, PartialEq, Clone, Serialize)]
+#[derive(Debug, PartialEq, Clone, Serialize, Deserialize)]
 pub struct Fix {
     pub range: Range<usize>,
     pub replacement: String,
 }
 
-#[derive(Debug, PartialEq, Clone, Copy, Serialize)]
+#[derive(Debug, PartialEq, Clone, Copy, Serialize, Deserialize)]
 pub enum Severity {
     Error,
     Warning,
@@ -98,12 +95,6 @@ pub trait Rule: DynClone + Send + Sync {
     fn check(&self, ctx: &LintContext) -> LintResult;
     fn fix(&self, ctx: &LintContext) -> Result<String, LintError>;
 
-    /// AST-based check method for rules that can benefit from shared AST parsing
-    /// By default, calls the regular check method if not overridden
-    fn check_with_ast(&self, ctx: &LintContext, _ast: &MarkdownAst) -> LintResult {
-        self.check(ctx)
-    }
-
     /// Check if this rule should quickly skip processing based on content
     fn should_skip(&self, _ctx: &LintContext) -> bool {
         false
@@ -114,11 +105,6 @@ pub trait Rule: DynClone + Send + Sync {
         RuleCategory::Other // Default implementation returns Other
     }
 
-    /// Check if this rule can benefit from AST parsing
-    fn uses_ast(&self) -> bool {
-        false
-    }
-
     fn as_any(&self) -> &dyn std::any::Any;
 
     // DocumentStructure has been merged into LintContext - this method is no longer used
@@ -126,10 +112,6 @@ pub trait Rule: DynClone + Send + Sync {
     //     None
     // }
 
-    fn as_maybe_ast(&self) -> Option<&dyn MaybeAst> {
-        None
-    }
-
     /// Returns the rule name and default config table if the rule has config.
     /// If a rule implements this, it MUST be defined on the `impl Rule for ...` block,
     /// not just the inherent impl.
@@ -346,36 +328,6 @@ impl MaybeDocumentStructure for dyn Rule {
 }
 */
 
-// Helper trait for dynamic dispatch to check_with_ast
-pub trait MaybeAst {
-    fn check_with_ast_opt(&self, ctx: &LintContext, ast: &MarkdownAst) -> Option<LintResult>;
-}
-
-impl<T> MaybeAst for T
-where
-    T: Rule + AstExtensions + 'static,
-{
-    fn check_with_ast_opt(&self, ctx: &LintContext, ast: &MarkdownAst) -> Option<LintResult> {
-        if self.has_relevant_ast_elements(ctx, ast) {
-            Some(self.check_with_ast(ctx, ast))
-        } else {
-            None
-        }
-    }
-}
-
-impl MaybeAst for dyn Rule {
-    fn check_with_ast_opt(&self, _ctx: &LintContext, _ast: &MarkdownAst) -> Option<LintResult> {
-        None
-    }
-}
-
-/// Extension trait for rules that use AST
-pub trait AstExtensions {
-    /// Check if the AST contains relevant elements for this rule
-    fn has_relevant_ast_elements(&self, ctx: &LintContext, ast: &MarkdownAst) -> bool;
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -738,7 +690,7 @@ Content here"#;
             end_column: 10,
             severity: Severity::Warning,
             fix: None,
-            rule_name: Some("MD001"),
+            rule_name: Some("MD001".to_string()),
         };
 
         let serialized = serde_json::to_string(&warning).unwrap();
@@ -768,7 +720,7 @@ Content here"#;
             end_column: 10,
             severity: Severity::Warning,
             fix: Some(fix),
-            rule_name: Some("MD001"),
+            rule_name: Some("MD001".to_string()),
         };
 
         let serialized = serde_json::to_string(&warning).unwrap();
