@@ -1,16 +1,16 @@
-use lazy_static::lazy_static;
+use crate::utils::range_utils::LineIndex;
 use regex::Regex;
 use std::fmt;
+use std::sync::LazyLock;
 
-lazy_static! {
-    // Standard code block detection patterns
-    static ref FENCED_CODE_BLOCK_START: Regex = Regex::new(r"^(\s*)```(?:[^`\r\n]*)$").unwrap();
-    static ref FENCED_CODE_BLOCK_END: Regex = Regex::new(r"^(\s*)```\s*$").unwrap();
-    static ref ALTERNATE_FENCED_CODE_BLOCK_START: Regex = Regex::new(r"^(\s*)~~~(?:[^~\r\n]*)$").unwrap();
-    static ref ALTERNATE_FENCED_CODE_BLOCK_END: Regex = Regex::new(r"^(\s*)~~~\s*$").unwrap();
-    static ref INDENTED_CODE_BLOCK: Regex = Regex::new(r"^(\s{4,})").unwrap();
-    static ref LIST_ITEM_RE: Regex = Regex::new(r"^(\s*)([*+-]|\d+[.)])(\s*)(.*)$").unwrap();
-}
+// Standard code block detection patterns
+static FENCED_CODE_BLOCK_START: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^(\s*)```(?:[^`\r\n]*)$").unwrap());
+static FENCED_CODE_BLOCK_END: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^(\s*)```\s*$").unwrap());
+static ALTERNATE_FENCED_CODE_BLOCK_START: LazyLock<Regex> =
+    LazyLock::new(|| Regex::new(r"^(\s*)~~~(?:[^~\r\n]*)$").unwrap());
+static ALTERNATE_FENCED_CODE_BLOCK_END: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^(\s*)~~~\s*$").unwrap());
+static INDENTED_CODE_BLOCK: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^(\s{4,})").unwrap());
+static LIST_ITEM_RE: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^(\s*)([*+-]|\d+[.)])(\s*)(.*)$").unwrap());
 
 /// Utility functions for detecting and handling code blocks in Markdown documents
 pub struct CodeBlockUtils;
@@ -186,11 +186,8 @@ impl CodeBlockUtils {
 }
 
 // Cached regex patterns for better performance
-lazy_static! {
-    static ref FENCED_CODE_BLOCK_PATTERN: Regex = Regex::new(r"^(?:```|~~~)").unwrap();
-    static ref INDENTED_CODE_BLOCK_PATTERN: Regex = Regex::new(r"^(\s{4,})").unwrap();
-    static ref BACKTICK_PATTERN: Regex = Regex::new(r"(`+)").unwrap();
-}
+static FENCED_CODE_BLOCK_PATTERN: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^(?:```|~~~)").unwrap());
+static INDENTED_CODE_BLOCK_PATTERN: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^(\s{4,})").unwrap());
 
 /// Tracks which lines are inside code blocks and their types
 #[derive(Debug, PartialEq, Clone, Copy)]
@@ -202,25 +199,29 @@ pub enum CodeBlockState {
 
 /// Structure to hold pre-computed code block information
 #[derive(Debug)]
-pub struct CodeBlockInfo {
+pub struct CodeBlockInfo<'a> {
     /// Whether each line is in a code block, and which type
     pub block_states: Vec<CodeBlockState>,
     /// Positions of code spans in the text (start, end)
     pub code_spans: Vec<(usize, usize)>,
     /// The original content used to create this info
-    content: String,
+    content: &'a str,
+    /// LineIndex for correct byte position calculations across all line ending types
+    line_index: LineIndex<'a>,
 }
 
-impl CodeBlockInfo {
+impl<'a> CodeBlockInfo<'a> {
     /// Create a new CodeBlockInfo by analyzing the content
-    pub fn new(content: &str) -> Self {
+    pub fn new(content: &'a str) -> Self {
         let block_states = compute_code_blocks(content);
         let code_spans = compute_code_spans(content);
+        let line_index = LineIndex::new(content);
 
         CodeBlockInfo {
             block_states,
             code_spans,
-            content: content.to_string(),
+            content,
+            line_index,
         }
     }
 
@@ -235,28 +236,17 @@ impl CodeBlockInfo {
 
     /// Check if a position is inside a code span
     pub fn is_in_code_span(&self, line_index: usize, column_index: usize) -> bool {
-        // Calculate absolute position (this assumes content is ASCII-only)
-        let mut position = 0;
-        let content_lines: Vec<&str> = self.content.lines().collect();
+        // Calculate absolute position using LineIndex for correct handling of all line ending types
+        let line_start = self
+            .line_index
+            .get_line_start_byte(line_index + 1)
+            .unwrap_or(self.content.len());
+        let position = line_start + column_index;
 
-        for i in 0..line_index {
-            if i < content_lines.len() {
-                position += content_lines[i].len() + 1; // +1 for newline
-            }
-        }
-
-        if line_index < content_lines.len() {
-            // Add column position
-            let line = content_lines[line_index];
-            if column_index < line.len() {
-                position += column_index;
-
-                // Check if position is in any code span
-                for &(start, end) in &self.code_spans {
-                    if position >= start && position <= end {
-                        return true;
-                    }
-                }
+        // Check if position is in any code span
+        for &(start, end) in &self.code_spans {
+            if position >= start && position <= end {
+                return true;
             }
         }
 
