@@ -1,7 +1,7 @@
 use crate::HeadingStyle;
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::rules::heading_utils::HeadingUtils;
-use crate::utils::range_utils::{LineIndex, calculate_heading_range};
+use crate::utils::range_utils::calculate_heading_range;
 
 /// Rule MD001: Heading levels should only increment by one level at a time
 ///
@@ -69,7 +69,6 @@ impl Rule for MD001HeadingIncrement {
     }
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
-        let line_index = LineIndex::new(ctx.content.to_string());
         let mut warnings = Vec::new();
         let mut prev_level: Option<usize> = None;
 
@@ -97,12 +96,12 @@ impl Rule for MD001HeadingIncrement {
                     let replacement = HeadingUtils::convert_heading_style(heading_text, fixed_level as u32, style);
 
                     // Calculate precise range: highlight the entire heading
-                    let line_content = &line_info.content;
+                    let line_content = line_info.content(ctx.content);
                     let (start_line, start_col, end_line, end_col) =
                         calculate_heading_range(line_num + 1, line_content);
 
                     warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         line: start_line,
                         column: start_col,
                         end_line,
@@ -110,7 +109,7 @@ impl Rule for MD001HeadingIncrement {
                         message: format!("Expected heading level {}, but found heading level {}", prev + 1, level),
                         severity: Severity::Warning,
                         fix: Some(Fix {
-                            range: line_index.line_content_range(line_num + 1),
+                            range: ctx.line_index.line_content_range(line_num + 1),
                             replacement: format!("{}{}", " ".repeat(indentation), replacement),
                         }),
                     });
@@ -163,7 +162,7 @@ impl Rule for MD001HeadingIncrement {
 
                 prev_level = Some(fixed_level);
             } else {
-                fixed_lines.push(line_info.content.clone());
+                fixed_lines.push(line_info.content(ctx.content).to_string());
             }
         }
 
@@ -179,8 +178,12 @@ impl Rule for MD001HeadingIncrement {
     }
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        // Skip if content is empty or has no headings
-        ctx.content.is_empty() || !ctx.lines.iter().any(|line| line.heading.is_some())
+        // Fast path: check if document likely has headings
+        if ctx.content.is_empty() || !ctx.likely_has_headings() {
+            return true;
+        }
+        // Verify headings actually exist
+        !ctx.lines.iter().any(|line| line.heading.is_some())
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
