@@ -7,18 +7,11 @@ use crate::rule::{LintError, LintResult, LintWarning, Rule, RuleCategory, Severi
 use crate::rule_config_serde::RuleConfig;
 use crate::rules::heading_utils::HeadingStyle;
 use crate::utils::range_utils::calculate_heading_range;
-use lazy_static::lazy_static;
-use regex::Regex;
 use toml;
 
 mod md003_config;
 use md003_config::MD003Config;
 
-lazy_static! {
-    static ref FRONT_MATTER_DELIMITER: Regex = Regex::new(r"^---\s*$").unwrap();
-    static ref QUICK_HEADING_CHECK: Regex = Regex::new(r"(?m)^(\s*)#|^(\s*)[^\s].*\n(\s*)(=+|-+)\s*$").unwrap();
-}
-
 /// Rule MD003: Heading style
 #[derive(Clone, Default)]
 pub struct MD003HeadingStyle {
@@ -48,26 +41,47 @@ impl MD003HeadingStyle {
             return self.config.style;
         }
 
-        // Find the first heading from cached info
+        // Count all heading styles to determine most prevalent (prevalence-based approach)
+        let mut atx_count = 0;
+        let mut atx_closed_count = 0;
+        let mut setext1_count = 0;
+        let mut setext2_count = 0;
+
         for line_info in &ctx.lines {
             if let Some(heading) = &line_info.heading {
-                // Map from LintContext heading style to rules heading style
-                return match heading.style {
+                // Map from LintContext heading style to rules heading style and count
+                match heading.style {
                     crate::lint_context::HeadingStyle::ATX => {
                         if heading.has_closing_sequence {
-                            HeadingStyle::AtxClosed
+                            atx_closed_count += 1;
                         } else {
-                            HeadingStyle::Atx
+                            atx_count += 1;
                         }
                     }
-                    crate::lint_context::HeadingStyle::Setext1 => HeadingStyle::Setext1,
-                    crate::lint_context::HeadingStyle::Setext2 => HeadingStyle::Setext2,
-                };
+                    crate::lint_context::HeadingStyle::Setext1 => setext1_count += 1,
+                    crate::lint_context::HeadingStyle::Setext2 => setext2_count += 1,
+                }
             }
         }
 
-        // Default to ATX if no headings found
-        HeadingStyle::Atx
+        // Determine most prevalent style
+        // In case of tie, prefer ATX (most common, widely supported)
+        let max_count = atx_count.max(atx_closed_count).max(setext1_count).max(setext2_count);
+
+        if max_count == 0 {
+            // No headings found, default to ATX
+            return HeadingStyle::Atx;
+        }
+
+        if atx_count == max_count {
+            HeadingStyle::Atx
+        } else if atx_closed_count == max_count {
+            HeadingStyle::AtxClosed
+        } else if setext1_count == max_count {
+            HeadingStyle::Setext1
+        } else {
+            HeadingStyle::Setext2
+        }
     }
 }
 
@@ -86,9 +100,6 @@ impl Rule for MD003HeadingStyle {
         // Get the target style using cached heading information
         let target_style = self.get_target_style(ctx);
 
-        // Create LineIndex once outside the loop
-        let line_index = crate::utils::range_utils::LineIndex::new(ctx.content.to_string());
-
         // Process headings using cached heading information
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
             if let Some(heading) = &line_info.heading {
@@ -161,7 +172,7 @@ impl Rule for MD003HeadingStyle {
                         let final_heading = format!("{}{}", " ".repeat(line_info.indent), converted_heading);
 
                         // Calculate the correct range for the heading
-                        let range = line_index.line_content_range(line_num + 1);
+                        let range = ctx.line_index.line_content_range(line_num + 1);
 
                         Some(crate::rule::Fix {
                             range,
@@ -171,10 +182,10 @@ impl Rule for MD003HeadingStyle {
 
                     // Calculate precise character range for the heading marker
                     let (start_line, start_col, end_line, end_col) =
-                        calculate_heading_range(line_num + 1, &line_info.content);
+                        calculate_heading_range(line_num + 1, line_info.content(ctx.content));
 
                     result.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         line: start_line,
                         column: start_col,
                         end_line,
@@ -242,8 +253,12 @@ impl Rule for MD003HeadingStyle {
     }
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        // Skip if content is empty or has no headings
-        ctx.content.is_empty() || !ctx.lines.iter().any(|line| line.heading.is_some())
+        // Fast path: check if document likely has headings using character frequency
+        if ctx.content.is_empty() || !ctx.likely_has_headings() {
+            return true;
+        }
+        // Verify headings actually exist (handles false positives from character frequency)
+        !ctx.lines.iter().any(|line| line.heading.is_some())
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
