@@ -1,6 +1,6 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::rule_config_serde::RuleConfig;
-use crate::utils::range_utils::{LineIndex, calculate_trailing_range};
+use crate::utils::range_utils::calculate_trailing_range;
 use crate::utils::regex_cache::{ORDERED_LIST_MARKER_REGEX, UNORDERED_LIST_MARKER_REGEX, get_cached_regex};
 
 mod md009_config;
@@ -17,14 +17,14 @@ impl MD009TrailingSpaces {
     pub fn new(br_spaces: usize, strict: bool) -> Self {
         Self {
             config: MD009Config {
-                br_spaces,
+                br_spaces: crate::types::BrSpaces::from_const(br_spaces),
                 strict,
                 list_item_empty_lines: false,
             },
         }
     }
 
-    pub fn from_config_struct(config: MD009Config) -> Self {
+    pub const fn from_config_struct(config: MD009Config) -> Self {
         Self { config }
     }
 
@@ -60,7 +60,7 @@ impl Rule for MD009TrailingSpaces {
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
 
         let mut warnings = Vec::new();
 
@@ -87,7 +87,7 @@ impl Rule for MD009TrailingSpaces {
                     let (start_line, start_col, end_line, end_col) = calculate_trailing_range(line_num + 1, line, 0);
 
                     warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         line: start_line,
                         column: start_col,
                         end_line,
@@ -117,7 +117,7 @@ impl Rule for MD009TrailingSpaces {
             // Special handling: if the content ends with a newline, the last line from .lines()
             // is not really the "last line" in terms of trailing spaces rules
             let is_truly_last_line = line_num == lines.len() - 1 && !content.ends_with('\n');
-            if !self.config.strict && !is_truly_last_line && trailing_spaces == self.config.br_spaces {
+            if !self.config.strict && !is_truly_last_line && trailing_spaces == self.config.br_spaces.get() {
                 continue;
             }
 
@@ -136,7 +136,7 @@ impl Rule for MD009TrailingSpaces {
                 calculate_trailing_range(line_num + 1, line, trimmed.len());
 
             warnings.push(LintWarning {
-                rule_name: Some(self.name()),
+                rule_name: Some(self.name().to_string()),
                 line: start_line,
                 column: start_col,
                 end_line,
@@ -155,9 +155,9 @@ impl Rule for MD009TrailingSpaces {
                     ),
                     replacement: if !self.config.strict
                         && !is_truly_last_line
-                        && trailing_spaces == self.config.br_spaces
+                        && trailing_spaces == self.config.br_spaces.get()
                     {
-                        " ".repeat(self.config.br_spaces)
+                        " ".repeat(self.config.br_spaces.get())
                     } else {
                         String::new()
                     },
@@ -243,12 +243,12 @@ impl Rule for MD009TrailingSpaces {
             // BUT: Never preserve trailing spaces in headings or empty blockquotes as they serve no purpose
             if !self.config.strict
                 && !is_truly_last_line
-                && trailing_spaces == self.config.br_spaces
+                && trailing_spaces == self.config.br_spaces.get()
                 && !is_heading
                 && !is_empty_blockquote
             {
                 // Preserve the exact number of spaces for hard line breaks
-                match self.config.br_spaces {
+                match self.config.br_spaces.get() {
                     0 => {}
                     1 => result.push(' '),
                     2 => result.push_str("  "),
@@ -609,10 +609,10 @@ mod tests {
     }
 
     #[test]
-    fn test_windows_line_endings() {
+    fn test_normalized_line_endings() {
         let rule = MD009TrailingSpaces::default();
-        // Note: This test simulates Windows line endings behavior
-        let content = "Line with spaces  \r\nAnother line  ";
+        // In production, content is normalized to LF at I/O boundary
+        let content = "Line with spaces  \nAnother line  ";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Line 1 has 2 spaces (= br_spaces) so it's OK
@@ -657,28 +657,4 @@ mod tests {
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "Line with two spaces  \nNext line");
     }
-
-    #[test]
-    fn test_different_br_spaces_values() {
-        // Test with br_spaces=0 (no trailing spaces allowed)
-        let rule = MD009TrailingSpaces::new(0, false);
-        let content = "Line with one space \nLine with two spaces  ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
-        let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 2); // Both lines should be flagged
-
-        let fixed = rule.fix(&ctx).unwrap();
-        assert_eq!(fixed, "Line with one space\nLine with two spaces");
-
-        // Test with br_spaces=1 (exactly 1 trailing space for line breaks)
-        let rule = MD009TrailingSpaces::new(1, false);
-        let content = "Line with one space \nLine with two spaces  ";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
-        let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1); // Only line 2 should be flagged
-        assert_eq!(result[0].line, 2);
-
-        let fixed = rule.fix(&ctx).unwrap();
-        assert_eq!(fixed, "Line with one space \nLine with two spaces");
-    }
 }
