@@ -3,7 +3,7 @@ use crate::rule_config_serde::RuleConfig;
 /// Rule MD010: No tabs
 ///
 /// See [docs/md010.md](../../docs/md010.md) for full documentation, configuration, and examples.
-use crate::utils::range_utils::{LineIndex, calculate_match_range};
+use crate::utils::range_utils::calculate_match_range;
 use crate::utils::regex_cache::{HTML_COMMENT_END, HTML_COMMENT_START};
 
 mod md010_config;
@@ -20,11 +20,13 @@ pub struct MD010NoHardTabs {
 impl MD010NoHardTabs {
     pub fn new(spaces_per_tab: usize) -> Self {
         Self {
-            config: MD010Config { spaces_per_tab },
+            config: MD010Config {
+                spaces_per_tab: crate::types::PositiveUsize::from_const(spaces_per_tab),
+            },
         }
     }
 
-    pub fn from_config_struct(config: MD010Config) -> Self {
+    pub const fn from_config_struct(config: MD010Config) -> Self {
         Self { config }
     }
 
@@ -117,7 +119,7 @@ impl Rule for MD010NoHardTabs {
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
 
         let mut warnings = Vec::new();
         let lines: Vec<&str> = content.lines().collect();
@@ -163,12 +165,15 @@ impl Rule for MD010NoHardTabs {
                     }
                 } else if is_leading {
                     if tab_count == 1 {
-                        format!("Found leading tab, use {} spaces instead", self.config.spaces_per_tab)
+                        format!(
+                            "Found leading tab, use {} spaces instead",
+                            self.config.spaces_per_tab.get()
+                        )
                     } else {
                         format!(
                             "Found {} leading tabs, use {} spaces instead",
                             tab_count,
-                            tab_count * self.config.spaces_per_tab
+                            tab_count * self.config.spaces_per_tab.get()
                         )
                     }
                 } else if tab_count == 1 {
@@ -178,7 +183,7 @@ impl Rule for MD010NoHardTabs {
                 };
 
                 warnings.push(LintWarning {
-                    rule_name: Some(self.name()),
+                    rule_name: Some(self.name().to_string()),
                     line: start_line,
                     column: start_col,
                     end_line,
@@ -187,7 +192,7 @@ impl Rule for MD010NoHardTabs {
                     severity: Severity::Warning,
                     fix: Some(Fix {
                         range: _line_index.line_col_to_byte_range_with_length(line_num + 1, start_pos + 1, tab_count),
-                        replacement: " ".repeat(tab_count * self.config.spaces_per_tab),
+                        replacement: " ".repeat(tab_count * self.config.spaces_per_tab.get()),
                     }),
                 });
             }
@@ -198,7 +203,7 @@ impl Rule for MD010NoHardTabs {
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let line_index = &ctx.line_index;
 
         let mut result = String::new();
         let lines: Vec<&str> = content.lines().collect();
@@ -208,10 +213,8 @@ impl Rule for MD010NoHardTabs {
 
         // Pre-compute line positions for code block detection
         let mut line_positions = Vec::with_capacity(lines.len());
-        let mut pos = 0;
-        for line in &lines {
-            line_positions.push(pos);
-            pos += line.len() + 1; // +1 for newline
+        for i in 0..lines.len() {
+            line_positions.push(line_index.get_line_start_byte(i + 1).unwrap_or(0));
         }
 
         for (i, line) in lines.iter().enumerate() {
@@ -223,7 +226,7 @@ impl Rule for MD010NoHardTabs {
                 result.push_str(line);
             } else {
                 // Replace tabs with spaces
-                result.push_str(&line.replace('\t', &" ".repeat(self.config.spaces_per_tab)));
+                result.push_str(&line.replace('\t', &" ".repeat(self.config.spaces_per_tab.get())));
             }
 
             // Add newline if not the last line without a newline
@@ -241,7 +244,7 @@ impl Rule for MD010NoHardTabs {
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
         // Skip if content is empty or has no tabs
-        ctx.content.is_empty() || !ctx.content.contains('\t')
+        ctx.content.is_empty() || !ctx.has_char('\t')
     }
 
     fn category(&self) -> RuleCategory {
