@@ -1,4 +1,5 @@
-use crate::utils::range_utils::{LineIndex, calculate_line_range};
+use crate::filtered_lines::FilteredLinesExt;
+use crate::utils::range_utils::calculate_line_range;
 use std::collections::HashSet;
 use toml;
 
@@ -19,12 +20,15 @@ pub struct MD012NoMultipleBlanks {
 
 impl MD012NoMultipleBlanks {
     pub fn new(maximum: usize) -> Self {
+        use crate::types::PositiveUsize;
         Self {
-            config: MD012Config { maximum },
+            config: MD012Config {
+                maximum: PositiveUsize::new(maximum).unwrap_or(PositiveUsize::from_const(1)),
+            },
         }
     }
 
-    pub fn from_config_struct(config: MD012Config) -> Self {
+    pub const fn from_config_struct(config: MD012Config) -> Self {
         Self { config }
     }
 }
@@ -54,13 +58,14 @@ impl Rule for MD012NoMultipleBlanks {
             .any(|pair| pair[0].trim().is_empty() && pair[1].trim().is_empty());
 
         // Also check for blanks at EOF (markdownlint behavior)
-        let ends_with_multiple_newlines = content.ends_with("\n\n") || content.ends_with("\r\n\r\n");
+        // Content is normalized to LF at I/O boundary
+        let ends_with_multiple_newlines = content.ends_with("\n\n");
 
         if !has_potential_blanks && !ends_with_multiple_newlines {
             return Ok(Vec::new());
         }
 
-        let _line_index = LineIndex::new(content.to_string());
+        let line_index = &ctx.line_index;
 
         let mut warnings = Vec::new();
 
@@ -68,73 +73,27 @@ impl Rule for MD012NoMultipleBlanks {
         let mut blank_count = 0;
         let mut blank_start = 0;
         let mut in_code_block = false;
-        let mut in_front_matter = false;
         let mut code_fence_marker = "";
 
         // Use HashSet for O(1) lookups of lines that need to be checked
         let mut lines_to_check: HashSet<usize> = HashSet::new();
 
-        for (line_num, &line) in lines.iter().enumerate() {
+        // Use filtered_lines to automatically skip front-matter lines
+        for filtered_line in ctx.filtered_lines().skip_front_matter() {
+            let line_num = filtered_line.line_num - 1; // Convert 1-based to 0-based for internal tracking
+            let line = filtered_line.content;
             let trimmed = line.trim_start();
 
-            // Check for front matter boundaries (only at start of file)
-            if trimmed == "---" {
-                if line_num == 0 {
-                    in_front_matter = true;
-                } else if in_front_matter {
-                    in_front_matter = false;
-                }
-                // Check for excess blanks before resetting
-                if blank_count > self.config.maximum {
-                    let location = if blank_start == 0 {
-                        "at start of file"
-                    } else {
-                        "between content"
-                    };
-                    for i in self.config.maximum..blank_count {
-                        let excess_line_num = blank_start + i;
-                        if lines_to_check.contains(&excess_line_num) {
-                            let excess_line = excess_line_num + 1;
-                            let excess_line_content = lines.get(excess_line_num).unwrap_or(&"");
-                            let (start_line, start_col, end_line, end_col) =
-                                calculate_line_range(excess_line, excess_line_content);
-                            warnings.push(LintWarning {
-                                rule_name: Some(self.name()),
-                                severity: Severity::Warning,
-                                message: format!("Multiple consecutive blank lines {location}"),
-                                line: start_line,
-                                column: start_col,
-                                end_line,
-                                end_column: end_col,
-                                fix: Some(Fix {
-                                    range: {
-                                        let line_start = _line_index.get_line_start_byte(excess_line).unwrap_or(0);
-                                        let line_end = _line_index
-                                            .get_line_start_byte(excess_line + 1)
-                                            .unwrap_or(line_start + 1);
-                                        line_start..line_end
-                                    },
-                                    replacement: String::new(),
-                                }),
-                            });
-                        }
-                    }
-                }
-                blank_count = 0;
-                lines_to_check.clear();
-                continue;
-            }
-
             // Check for code block boundaries
             if trimmed.starts_with("```") || trimmed.starts_with("~~~") {
                 // Check for excess blanks before entering/exiting code block
-                if blank_count > self.config.maximum {
+                if blank_count > self.config.maximum.get() {
                     let location = if blank_start == 0 {
                         "at start of file"
                     } else {
                         "between content"
                     };
-                    for i in self.config.maximum..blank_count {
+                    for i in self.config.maximum.get()..blank_count {
                         let excess_line_num = blank_start + i;
                         if lines_to_check.contains(&excess_line_num) {
                             let excess_line = excess_line_num + 1;
@@ -142,7 +101,7 @@ impl Rule for MD012NoMultipleBlanks {
                             let (start_line, start_col, end_line, end_col) =
                                 calculate_line_range(excess_line, excess_line_content);
                             warnings.push(LintWarning {
-                                rule_name: Some(self.name()),
+                                rule_name: Some(self.name().to_string()),
                                 severity: Severity::Warning,
                                 message: format!("Multiple consecutive blank lines {location}"),
                                 line: start_line,
@@ -151,8 +110,8 @@ impl Rule for MD012NoMultipleBlanks {
                                 end_column: end_col,
                                 fix: Some(Fix {
                                     range: {
-                                        let line_start = _line_index.get_line_start_byte(excess_line).unwrap_or(0);
-                                        let line_end = _line_index
+                                        let line_start = line_index.get_line_start_byte(excess_line).unwrap_or(0);
+                                        let line_end = line_index
                                             .get_line_start_byte(excess_line + 1)
                                             .unwrap_or(line_start + 1);
                                         line_start..line_end
@@ -178,8 +137,8 @@ impl Rule for MD012NoMultipleBlanks {
                 continue;
             }
 
-            // Skip lines in code blocks or front matter
-            if in_code_block || in_front_matter {
+            // Skip lines in code blocks
+            if in_code_block {
                 // Reset counter to prevent counting across boundaries
                 blank_count = 0;
                 continue;
@@ -189,13 +148,13 @@ impl Rule for MD012NoMultipleBlanks {
             let is_indented_code = line.len() >= 4 && line.starts_with("    ") && !line.trim().is_empty();
             if is_indented_code {
                 // Check for excess blanks before indented code block
-                if blank_count > self.config.maximum {
+                if blank_count > self.config.maximum.get() {
                     let location = if blank_start == 0 {
                         "at start of file"
                     } else {
                         "between content"
                     };
-                    for i in self.config.maximum..blank_count {
+                    for i in self.config.maximum.get()..blank_count {
                         let excess_line_num = blank_start + i;
                         if lines_to_check.contains(&excess_line_num) {
                             let excess_line = excess_line_num + 1;
@@ -203,7 +162,7 @@ impl Rule for MD012NoMultipleBlanks {
                             let (start_line, start_col, end_line, end_col) =
                                 calculate_line_range(excess_line, excess_line_content);
                             warnings.push(LintWarning {
-                                rule_name: Some(self.name()),
+                                rule_name: Some(self.name().to_string()),
                                 severity: Severity::Warning,
                                 message: format!("Multiple consecutive blank lines {location}"),
                                 line: start_line,
@@ -212,8 +171,8 @@ impl Rule for MD012NoMultipleBlanks {
                                 end_column: end_col,
                                 fix: Some(Fix {
                                     range: {
-                                        let line_start = _line_index.get_line_start_byte(excess_line).unwrap_or(0);
-                                        let line_end = _line_index
+                                        let line_start = line_index.get_line_start_byte(excess_line).unwrap_or(0);
+                                        let line_end = line_index
                                             .get_line_start_byte(excess_line + 1)
                                             .unwrap_or(line_start + 1);
                                         line_start..line_end
@@ -235,11 +194,11 @@ impl Rule for MD012NoMultipleBlanks {
                 }
                 blank_count += 1;
                 // Store line numbers that exceed the limit
-                if blank_count > self.config.maximum {
+                if blank_count > self.config.maximum.get() {
                     lines_to_check.insert(line_num);
                 }
             } else {
-                if blank_count > self.config.maximum {
+                if blank_count > self.config.maximum.get() {
                     // Generate warnings for each excess blank line
                     let location = if blank_start == 0 {
                         "at start of file"
@@ -248,7 +207,7 @@ impl Rule for MD012NoMultipleBlanks {
                     };
 
                     // Report warnings starting from the (maximum+1)th blank line
-                    for i in self.config.maximum..blank_count {
+                    for i in self.config.maximum.get()..blank_count {
                         let excess_line_num = blank_start + i;
                         if lines_to_check.contains(&excess_line_num) {
                             let excess_line = excess_line_num + 1; // +1 for 1-indexed lines
@@ -259,7 +218,7 @@ impl Rule for MD012NoMultipleBlanks {
                                 calculate_line_range(excess_line, excess_line_content);
 
                             warnings.push(LintWarning {
-                                rule_name: Some(self.name()),
+                                rule_name: Some(self.name().to_string()),
                                 severity: Severity::Warning,
                                 message: format!("Multiple consecutive blank lines {location}"),
                                 line: start_line,
@@ -269,8 +228,8 @@ impl Rule for MD012NoMultipleBlanks {
                                 fix: Some(Fix {
                                     range: {
                                         // Remove entire line including newline
-                                        let line_start = _line_index.get_line_start_byte(excess_line).unwrap_or(0);
-                                        let line_end = _line_index
+                                        let line_start = line_index.get_line_start_byte(excess_line).unwrap_or(0);
+                                        let line_end = line_index
                                             .get_line_start_byte(excess_line + 1)
                                             .unwrap_or(line_start + 1);
                                         line_start..line_end
@@ -303,23 +262,26 @@ impl Rule for MD012NoMultipleBlanks {
             }
         }
 
-        // Markdownlint treats ANY blank lines at EOF as a violation
-        // A file ending with \n\n has 1 blank line but markdownlint reports it
-        // as "multiple consecutive blank lines" with "Actual: 2"
-        // This suggests it counts blank lines at EOF specially
+        // To have N blank lines at EOF, you need N+1 trailing newlines
+        // For example: "content\n\n" has 1 blank line (2 newlines)
         let blank_lines_at_eof = consecutive_newlines_at_end.saturating_sub(1);
 
-        // At EOF, ANY blank lines violate the rule (markdownlint behavior)
-        // This is different from the middle of the file where 1 blank is allowed
+        // At EOF, blank lines are always enforced to be 0 (POSIX/Prettier standard)
+        // The `maximum` config only applies to in-document blank lines
         if blank_lines_at_eof > 0 {
             let location = "at end of file";
 
             // Report on the last line (which is blank)
             let report_line = lines.len();
 
+            // Calculate how many newlines to remove
+            // Always keep exactly 1 newline at EOF (0 blank lines)
+            let target_newlines = 1;
+            let excess_newlines = consecutive_newlines_at_end - target_newlines;
+
             // Report one warning for the excess blank lines at EOF
             warnings.push(LintWarning {
-                rule_name: Some(self.name()),
+                rule_name: Some(self.name().to_string()),
                 severity: Severity::Warning,
                 message: format!("Multiple consecutive blank lines {location}"),
                 line: report_line,
@@ -329,9 +291,18 @@ impl Rule for MD012NoMultipleBlanks {
                 fix: Some(Fix {
                     range: {
                         // Remove excess trailing newlines
-                        // Keep content up to where excess newlines start
-                        let excess_newlines = blank_lines_at_eof - self.config.maximum;
                         let keep_chars = content.len() - excess_newlines;
+                        log::debug!(
+                            "MD012 EOF: consecutive_newlines_at_end={}, blank_lines_at_eof={}, target_newlines={}, excess_newlines={}, content_len={}, keep_chars={}, range={}..{}",
+                            consecutive_newlines_at_end,
+                            blank_lines_at_eof,
+                            target_newlines,
+                            excess_newlines,
+                            content.len(),
+                            keep_chars,
+                            keep_chars,
+                            content.len()
+                        );
                         keep_chars..content.len()
                     },
                     replacement: String::new(),
@@ -344,26 +315,41 @@ impl Rule for MD012NoMultipleBlanks {
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
 
         let mut result = Vec::new();
-
         let mut blank_count = 0;
 
-        let lines: Vec<&str> = content.lines().collect();
-
         let mut in_code_block = false;
-
+        let mut code_block_blanks = Vec::new();
         let mut in_front_matter = false;
 
-        let mut code_block_blanks = Vec::new();
+        // Process ALL lines (don't skip front-matter in fix mode)
+        for filtered_line in ctx.filtered_lines() {
+            let line = filtered_line.content;
 
-        for &line in lines.iter() {
-            // Track code blocks and front matter
+            // Pass through front-matter lines unchanged
+            if filtered_line.line_info.in_front_matter {
+                if !in_front_matter {
+                    // Entering front-matter: flush any accumulated blanks
+                    let allowed_blanks = blank_count.min(self.config.maximum.get());
+                    if allowed_blanks > 0 {
+                        result.extend(vec![""; allowed_blanks]);
+                    }
+                    blank_count = 0;
+                    in_front_matter = true;
+                }
+                result.push(line);
+                continue;
+            } else if in_front_matter {
+                // Exiting front-matter
+                in_front_matter = false;
+            }
+
+            // Track code blocks
             if line.trim_start().starts_with("```") || line.trim_start().starts_with("~~~") {
                 // Handle accumulated blank lines before code block
                 if !in_code_block {
-                    let allowed_blanks = blank_count.min(self.config.maximum);
+                    let allowed_blanks = blank_count.min(self.config.maximum.get());
                     if allowed_blanks > 0 {
                         result.extend(vec![""; allowed_blanks]);
                     }
@@ -377,16 +363,6 @@ impl Rule for MD012NoMultipleBlanks {
                 continue;
             }
 
-            if line.trim() == "---" {
-                in_front_matter = !in_front_matter;
-                if blank_count > 0 {
-                    result.extend(vec![""; blank_count]);
-                    blank_count = 0;
-                }
-                result.push(line);
-                continue;
-            }
-
             if in_code_block {
                 if line.trim().is_empty() {
                     code_block_blanks.push(line);
@@ -394,17 +370,11 @@ impl Rule for MD012NoMultipleBlanks {
                     result.append(&mut code_block_blanks);
                     result.push(line);
                 }
-            } else if in_front_matter {
-                if blank_count > 0 {
-                    result.extend(vec![""; blank_count]);
-                    blank_count = 0;
-                }
-                result.push(line);
             } else if line.trim().is_empty() {
                 blank_count += 1;
             } else {
                 // Add allowed blank lines before content
-                let allowed_blanks = blank_count.min(self.config.maximum);
+                let allowed_blanks = blank_count.min(self.config.maximum.get());
                 if allowed_blanks > 0 {
                     result.extend(vec![""; allowed_blanks]);
                 }
@@ -414,15 +384,14 @@ impl Rule for MD012NoMultipleBlanks {
         }
 
         // Handle trailing blank lines
-        if !in_code_block {
-            let allowed_blanks = blank_count.min(self.config.maximum);
-            if allowed_blanks > 0 {
-                result.extend(vec![""; allowed_blanks]);
-            }
+        // After the loop, blank_count contains the number of trailing blank lines
+        // Add up to maximum allowed trailing blank lines
+        let allowed_trailing_blanks = blank_count.min(self.config.maximum.get());
+        if allowed_trailing_blanks > 0 {
+            result.extend(vec![""; allowed_trailing_blanks]);
         }
 
         // Join lines and handle final newline
-
         let mut output = result.join("\n");
         if content.ends_with('\n') {
             output.push('\n');
@@ -436,8 +405,8 @@ impl Rule for MD012NoMultipleBlanks {
     }
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        // Skip if content is empty or doesn't have consecutive newlines
-        ctx.content.is_empty() || !ctx.content.contains("\n\n")
+        // Skip if content is empty or doesn't have newlines (single line can't have multiple blanks)
+        ctx.content.is_empty() || !ctx.has_char('\n')
     }
 
     fn default_config_section(&self) -> Option<(String, toml::Value)> {
