@@ -5,19 +5,17 @@
 
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
 use crate::rule_config_serde::RuleConfig;
-use crate::utils::range_utils::{LineIndex, calculate_match_range};
-use lazy_static::lazy_static;
-use regex::Regex;
+use crate::utils::range_utils::calculate_match_range;
+use crate::utils::regex_cache::get_cached_regex;
 use toml;
 
 mod md014_config;
 use md014_config::MD014Config;
 
-lazy_static! {
-    static ref COMMAND_PATTERN: Regex = Regex::new(r"^\s*[$>]\s+\S+").unwrap();
-    static ref SHELL_LANG_PATTERN: Regex = Regex::new(r"^(?i)(bash|sh|shell|console|terminal)").unwrap();
-    static ref DOLLAR_PROMPT_PATTERN: Regex = Regex::new(r"^\s*([$>])").unwrap();
-}
+// Command detection patterns
+const COMMAND_PATTERN: &str = r"^\s*[$>]\s+\S+";
+const SHELL_LANG_PATTERN: &str = r"^(?i)(bash|sh|shell|console|terminal)";
+const DOLLAR_PROMPT_PATTERN: &str = r"^\s*([$>])";
 
 #[derive(Clone, Default)]
 pub struct MD014CommandsShowOutput {
@@ -40,11 +38,15 @@ impl MD014CommandsShowOutput {
     }
 
     fn is_command_line(&self, line: &str) -> bool {
-        COMMAND_PATTERN.is_match(line)
+        get_cached_regex(COMMAND_PATTERN)
+            .map(|re| re.is_match(line))
+            .unwrap_or(false)
     }
 
     fn is_shell_language(&self, lang: &str) -> bool {
-        SHELL_LANG_PATTERN.is_match(lang)
+        get_cached_regex(SHELL_LANG_PATTERN)
+            .map(|re| re.is_match(lang))
+            .unwrap_or(false)
     }
 
     fn is_output_line(&self, line: &str) -> bool {
@@ -171,7 +173,7 @@ impl Rule for MD014CommandsShowOutput {
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
 
         let mut warnings = Vec::new();
 
@@ -193,7 +195,9 @@ impl Rule for MD014CommandsShowOutput {
                             let cmd_line_num = block_start_line + 1 + cmd_line_idx + 1; // +1 for fence, +1 for 1-indexed
 
                             // Find and highlight the dollar sign or prompt
-                            if let Some(cap) = DOLLAR_PROMPT_PATTERN.captures(cmd_line) {
+                            if let Ok(re) = get_cached_regex(DOLLAR_PROMPT_PATTERN)
+                                && let Some(cap) = re.captures(cmd_line)
+                            {
                                 let match_obj = cap.get(1).unwrap(); // The $ or > character
                                 let (start_line, start_col, end_line, end_col) =
                                     calculate_match_range(cmd_line_num, cmd_line, match_obj.start(), match_obj.len());
@@ -209,7 +213,7 @@ impl Rule for MD014CommandsShowOutput {
                                 };
 
                                 warnings.push(LintWarning {
-                                    rule_name: Some(self.name()),
+                                    rule_name: Some(self.name().to_string()),
                                     line: start_line,
                                     column: start_col,
                                     end_line,
@@ -253,7 +257,7 @@ impl Rule for MD014CommandsShowOutput {
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
 
         let mut result = String::new();
 
@@ -305,7 +309,7 @@ impl Rule for MD014CommandsShowOutput {
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
         // Skip if content is empty or has no code blocks
-        ctx.content.is_empty() || !ctx.content.contains("```")
+        ctx.content.is_empty() || !ctx.likely_has_code()
     }
 
     fn default_config_section(&self) -> Option<(String, toml::Value)> {
