@@ -3,16 +3,11 @@
 /// See [docs/md018.md](../../docs/md018.md) for full documentation, configuration, and examples.
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::range_utils::calculate_single_line_range;
-use lazy_static::lazy_static;
-use regex::Regex;
+use crate::utils::regex_cache::get_cached_regex;
 
-lazy_static! {
-    // Pattern to detect emoji hashtags like #️⃣
-    static ref EMOJI_HASHTAG_PATTERN: Regex = Regex::new(r"^#️⃣|^#⃣").unwrap();
-
-    // Pattern to detect Unicode hashtag symbols that shouldn't be treated as headings
-    static ref UNICODE_HASHTAG_PATTERN: Regex = Regex::new(r"^#[\u{FE0F}\u{20E3}]").unwrap();
-}
+// Emoji and Unicode hashtag patterns
+const EMOJI_HASHTAG_PATTERN_STR: &str = r"^#️⃣|^#⃣";
+const UNICODE_HASHTAG_PATTERN_STR: &str = r"^#[\u{FE0F}\u{20E3}]";
 
 #[derive(Clone)]
 pub struct MD018NoMissingSpaceAtx;
@@ -39,7 +34,13 @@ impl MD018NoMissingSpaceAtx {
         }
 
         // Skip emoji hashtags and Unicode hashtag patterns
-        if EMOJI_HASHTAG_PATTERN.is_match(trimmed_line) || UNICODE_HASHTAG_PATTERN.is_match(trimmed_line) {
+        let is_emoji = get_cached_regex(EMOJI_HASHTAG_PATTERN_STR)
+            .map(|re| re.is_match(trimmed_line))
+            .unwrap_or(false);
+        let is_unicode = get_cached_regex(UNICODE_HASHTAG_PATTERN_STR)
+            .map(|re| re.is_match(trimmed_line))
+            .unwrap_or(false);
+        if is_emoji || is_unicode {
             return None;
         }
 
@@ -142,15 +143,26 @@ impl Rule for MD018NoMissingSpaceAtx {
 
         // Check all lines that have ATX headings from cached info
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
+            // Skip lines inside HTML blocks (e.g., CSS selectors like #id)
+            if line_info.in_html_block {
+                continue;
+            }
+
             if let Some(heading) = &line_info.heading {
                 // Only check ATX headings
                 if matches!(heading.style, crate::lint_context::HeadingStyle::ATX) {
                     // Check if there's a space after the marker
-                    let line = &line_info.content;
+                    let line = line_info.content(ctx.content);
                     let trimmed = line.trim_start();
 
                     // Skip emoji hashtags and Unicode hashtag patterns
-                    if EMOJI_HASHTAG_PATTERN.is_match(trimmed) || UNICODE_HASHTAG_PATTERN.is_match(trimmed) {
+                    let is_emoji = get_cached_regex(EMOJI_HASHTAG_PATTERN_STR)
+                        .map(|re| re.is_match(trimmed))
+                        .unwrap_or(false);
+                    let is_unicode = get_cached_regex(UNICODE_HASHTAG_PATTERN_STR)
+                        .map(|re| re.is_match(trimmed))
+                        .unwrap_or(false);
+                    if is_emoji || is_unicode {
                         continue;
                     }
 
@@ -167,7 +179,7 @@ impl Rule for MD018NoMissingSpaceAtx {
                             );
 
                             warnings.push(LintWarning {
-                                rule_name: Some(self.name()),
+                                rule_name: Some(self.name().to_string()),
                                 message: format!("No space after {} in heading", "#".repeat(heading.level as usize)),
                                 line: start_line,
                                 column: start_col,
@@ -189,7 +201,7 @@ impl Rule for MD018NoMissingSpaceAtx {
                 }
             } else if !line_info.in_code_block && !line_info.is_blank {
                 // Check for malformed headings that weren't detected as proper headings
-                if let Some((hash_end_pos, fixed_line)) = self.check_atx_heading_line(&line_info.content) {
+                if let Some((hash_end_pos, fixed_line)) = self.check_atx_heading_line(line_info.content(ctx.content)) {
                     let (start_line, start_col, end_line, end_col) = calculate_single_line_range(
                         line_num + 1,     // Convert to 1-indexed
                         hash_end_pos + 1, // 1-indexed column
@@ -197,7 +209,7 @@ impl Rule for MD018NoMissingSpaceAtx {
                     );
 
                     warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         message: "No space after hash in heading".to_string(),
                         line: start_line,
                         column: start_col,
@@ -225,11 +237,17 @@ impl Rule for MD018NoMissingSpaceAtx {
             if let Some(heading) = &line_info.heading {
                 // Fix ATX headings missing space
                 if matches!(heading.style, crate::lint_context::HeadingStyle::ATX) {
-                    let line = &line_info.content;
+                    let line = line_info.content(ctx.content);
                     let trimmed = line.trim_start();
 
                     // Skip emoji hashtags and Unicode hashtag patterns
-                    if EMOJI_HASHTAG_PATTERN.is_match(trimmed) || UNICODE_HASHTAG_PATTERN.is_match(trimmed) {
+                    let is_emoji = get_cached_regex(EMOJI_HASHTAG_PATTERN_STR)
+                        .map(|re| re.is_match(trimmed))
+                        .unwrap_or(false);
+                    let is_unicode = get_cached_regex(UNICODE_HASHTAG_PATTERN_STR)
+                        .map(|re| re.is_match(trimmed))
+                        .unwrap_or(false);
+                    if is_emoji || is_unicode {
                         continue;
                     }
 
@@ -250,14 +268,14 @@ impl Rule for MD018NoMissingSpaceAtx {
                 }
             } else if !line_info.in_code_block && !line_info.is_blank {
                 // Fix malformed headings
-                if let Some((_, fixed_line)) = self.check_atx_heading_line(&line_info.content) {
+                if let Some((_, fixed_line)) = self.check_atx_heading_line(line_info.content(ctx.content)) {
                     lines.push(fixed_line);
                     fixed = true;
                 }
             }
 
             if !fixed {
-                lines.push(line_info.content.clone());
+                lines.push(line_info.content(ctx.content).to_string());
             }
         }
 
@@ -277,8 +295,8 @@ impl Rule for MD018NoMissingSpaceAtx {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        // Skip if no lines contain hash symbols
-        !ctx.lines.iter().any(|line| line.content.contains('#'))
+        // Fast path: check if document likely has headings
+        !ctx.likely_has_headings()
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -416,4 +434,62 @@ More content."#;
         assert!(detected_lines.contains(&3)); // ##Malformed Heading
         assert!(detected_lines.contains(&7)); // ###Another Malformed
     }
+
+    #[test]
+    fn test_css_selectors_in_html_blocks() {
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        // Test CSS selectors inside <style> tags should not trigger MD018
+        // This is a common pattern in Quarto/RMarkdown files
+        let content = r#"# Proper Heading
+
+<style>
+#slide-1 ol li {
+    margin-top: 0;
+}
+
+#special-slide ol li {
+    margin-top: 2em;
+}
+</style>
+
+## Another Heading
+"#;
+
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should not detect CSS selectors as malformed headings
+        assert_eq!(
+            result.len(),
+            0,
+            "CSS selectors in <style> blocks should not be flagged as malformed headings"
+        );
+    }
+
+    #[test]
+    fn test_js_code_in_script_blocks() {
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        // Test that patterns like #element in <script> tags don't trigger MD018
+        let content = r#"# Heading
+
+<script>
+const element = document.querySelector('#main-content');
+#another-comment
+</script>
+
+## Another Heading
+"#;
+
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should not detect JS code as malformed headings
+        assert_eq!(
+            result.len(),
+            0,
+            "JavaScript code in <script> blocks should not be flagged as malformed headings"
+        );
+    }
 }
