@@ -2,16 +2,13 @@
 ///
 /// See [docs/md020.md](../../docs/md020.md) for full documentation, configuration, and examples.
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
-use crate::utils::range_utils::{LineIndex, calculate_single_line_range};
-use lazy_static::lazy_static;
-use regex::Regex;
+use crate::utils::range_utils::calculate_single_line_range;
+use crate::utils::regex_cache::get_cached_regex;
 
-lazy_static! {
-    // Updated patterns to handle optional custom IDs like {#custom-id} after closing hashes
-    static ref CLOSED_ATX_NO_SPACE_PATTERN: Regex = Regex::new(r"^(\s*)(#+)([^#\s].*?)([^#\s])(#+)(\s*(?:\{#[^}]+\})?\s*)$").unwrap();
-    static ref CLOSED_ATX_NO_SPACE_START_PATTERN: Regex = Regex::new(r"^(\s*)(#+)([^#\s].*?)\s(#+)(\s*(?:\{#[^}]+\})?\s*)$").unwrap();
-    static ref CLOSED_ATX_NO_SPACE_END_PATTERN: Regex = Regex::new(r"^(\s*)(#+)\s(.*?)([^#\s])(#+)(\s*(?:\{#[^}]+\})?\s*)$").unwrap();
-}
+// Closed ATX heading patterns
+const CLOSED_ATX_NO_SPACE_PATTERN_STR: &str = r"^(\s*)(#+)([^#\s].*?)([^#\s])(#+)(\s*(?:\{#[^}]+\})?\s*)$";
+const CLOSED_ATX_NO_SPACE_START_PATTERN_STR: &str = r"^(\s*)(#+)([^#\s].*?)\s(#+)(\s*(?:\{#[^}]+\})?\s*)$";
+const CLOSED_ATX_NO_SPACE_END_PATTERN_STR: &str = r"^(\s*)(#+)\s(.*?)([^#\s])(#+)(\s*(?:\{#[^}]+\})?\s*)$";
 
 #[derive(Clone)]
 pub struct MD020NoMissingSpaceClosedAtx;
@@ -28,13 +25,22 @@ impl MD020NoMissingSpaceClosedAtx {
     }
 
     fn is_closed_atx_heading_without_space(&self, line: &str) -> bool {
-        CLOSED_ATX_NO_SPACE_PATTERN.is_match(line)
-            || CLOSED_ATX_NO_SPACE_START_PATTERN.is_match(line)
-            || CLOSED_ATX_NO_SPACE_END_PATTERN.is_match(line)
+        get_cached_regex(CLOSED_ATX_NO_SPACE_PATTERN_STR)
+            .map(|re| re.is_match(line))
+            .unwrap_or(false)
+            || get_cached_regex(CLOSED_ATX_NO_SPACE_START_PATTERN_STR)
+                .map(|re| re.is_match(line))
+                .unwrap_or(false)
+            || get_cached_regex(CLOSED_ATX_NO_SPACE_END_PATTERN_STR)
+                .map(|re| re.is_match(line))
+                .unwrap_or(false)
     }
 
     fn fix_closed_atx_heading(&self, line: &str) -> String {
-        if let Some(captures) = CLOSED_ATX_NO_SPACE_PATTERN.captures(line) {
+        if let Some(captures) = get_cached_regex(CLOSED_ATX_NO_SPACE_PATTERN_STR)
+            .ok()
+            .and_then(|re| re.captures(line))
+        {
             let indentation = &captures[1];
             let opening_hashes = &captures[2];
             let content = &captures[3];
@@ -42,14 +48,20 @@ impl MD020NoMissingSpaceClosedAtx {
             let closing_hashes = &captures[5];
             let custom_id = &captures[6];
             format!("{indentation}{opening_hashes} {content}{last_char} {closing_hashes}{custom_id}")
-        } else if let Some(captures) = CLOSED_ATX_NO_SPACE_START_PATTERN.captures(line) {
+        } else if let Some(captures) = get_cached_regex(CLOSED_ATX_NO_SPACE_START_PATTERN_STR)
+            .ok()
+            .and_then(|re| re.captures(line))
+        {
             let indentation = &captures[1];
             let opening_hashes = &captures[2];
             let content = &captures[3];
             let closing_hashes = &captures[4];
             let custom_id = &captures[5];
             format!("{indentation}{opening_hashes} {content} {closing_hashes}{custom_id}")
-        } else if let Some(captures) = CLOSED_ATX_NO_SPACE_END_PATTERN.captures(line) {
+        } else if let Some(captures) = get_cached_regex(CLOSED_ATX_NO_SPACE_END_PATTERN_STR)
+            .ok()
+            .and_then(|re| re.captures(line))
+        {
             let indentation = &captures[1];
             let opening_hashes = &captures[2];
             let content = &captures[3];
@@ -85,20 +97,22 @@ impl Rule for MD020NoMissingSpaceClosedAtx {
 
                 // Check all ATX headings (both properly closed and malformed)
                 if matches!(heading.style, crate::lint_context::HeadingStyle::ATX) {
-                    let line = &line_info.content;
+                    let line = line_info.content(ctx.content);
 
                     // Check if line matches closed ATX pattern without space
                     // This will detect both properly closed headings with missing space
                     // and malformed attempts at closed headings like "# Heading#"
                     if self.is_closed_atx_heading_without_space(line) {
-                        let line_index = LineIndex::new(ctx.content.to_string());
-                        let line_range = line_index.line_content_range(line_num + 1);
+                        let line_range = ctx.line_index.line_content_range(line_num + 1);
 
                         let mut start_col = 1;
                         let mut length = 1;
                         let mut message = String::new();
 
-                        if let Some(captures) = CLOSED_ATX_NO_SPACE_PATTERN.captures(line) {
+                        if let Some(captures) = get_cached_regex(CLOSED_ATX_NO_SPACE_PATTERN_STR)
+                            .ok()
+                            .and_then(|re| re.captures(line))
+                        {
                             // Missing space at both start and end: #Heading#
                             let opening_hashes = captures.get(2).unwrap();
                             message = format!(
@@ -108,7 +122,10 @@ impl Rule for MD020NoMissingSpaceClosedAtx {
                             // Highlight the position right after the opening hashes
                             start_col = opening_hashes.end() + 1;
                             length = 1;
-                        } else if let Some(captures) = CLOSED_ATX_NO_SPACE_START_PATTERN.captures(line) {
+                        } else if let Some(captures) = get_cached_regex(CLOSED_ATX_NO_SPACE_START_PATTERN_STR)
+                            .ok()
+                            .and_then(|re| re.captures(line))
+                        {
                             // Missing space at start: #Heading #
                             let opening_hashes = captures.get(2).unwrap();
                             message = format!(
@@ -118,7 +135,10 @@ impl Rule for MD020NoMissingSpaceClosedAtx {
                             // Highlight the position right after the opening hashes
                             start_col = opening_hashes.end() + 1;
                             length = 1;
-                        } else if let Some(captures) = CLOSED_ATX_NO_SPACE_END_PATTERN.captures(line) {
+                        } else if let Some(captures) = get_cached_regex(CLOSED_ATX_NO_SPACE_END_PATTERN_STR)
+                            .ok()
+                            .and_then(|re| re.captures(line))
+                        {
                             // Missing space at end: # Heading#
                             let content = captures.get(3).unwrap();
                             let closing_hashes = captures.get(5).unwrap();
@@ -135,7 +155,7 @@ impl Rule for MD020NoMissingSpaceClosedAtx {
                             calculate_single_line_range(line_num + 1, start_col, length);
 
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             message,
                             line: start_line,
                             column: start_col_calc,
@@ -164,21 +184,21 @@ impl Rule for MD020NoMissingSpaceClosedAtx {
             if let Some(heading) = &line_info.heading {
                 // Skip headings indented 4+ spaces (they're code blocks)
                 if line_info.indent >= 4 {
-                    lines.push(line_info.content.clone());
+                    lines.push(line_info.content(ctx.content).to_string());
                     continue;
                 }
 
                 // Fix ATX headings without space (both properly closed and malformed)
                 if matches!(heading.style, crate::lint_context::HeadingStyle::ATX)
-                    && self.is_closed_atx_heading_without_space(&line_info.content)
+                    && self.is_closed_atx_heading_without_space(line_info.content(ctx.content))
                 {
-                    lines.push(self.fix_closed_atx_heading(&line_info.content));
+                    lines.push(self.fix_closed_atx_heading(line_info.content(ctx.content)));
                     fixed = true;
                 }
             }
 
             if !fixed {
-                lines.push(line_info.content.clone());
+                lines.push(line_info.content(ctx.content).to_string());
             }
         }
 
@@ -198,7 +218,7 @@ impl Rule for MD020NoMissingSpaceClosedAtx {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        ctx.content.is_empty() || !ctx.content.contains('#')
+        ctx.content.is_empty() || !ctx.likely_has_headings()
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
