@@ -96,10 +96,11 @@ impl MD022BlanksAroundHeadings {
 
     /// Create with custom numbers of blank lines
     pub fn with_values(lines_above: usize, lines_below: usize) -> Self {
+        use crate::types::PositiveUsize;
         Self {
             config: MD022Config {
-                lines_above,
-                lines_below,
+                lines_above: PositiveUsize::new(lines_above).unwrap_or(PositiveUsize::from_const(1)),
+                lines_below: PositiveUsize::new(lines_below).unwrap_or(PositiveUsize::from_const(1)),
                 allowed_at_start: true,
             },
         }
@@ -111,37 +112,34 @@ impl MD022BlanksAroundHeadings {
 
     /// Fix a document by adding appropriate blank lines around headings
     fn _fix_content(&self, ctx: &crate::lint_context::LintContext) -> String {
-        let line_ending = crate::utils::detect_line_ending(ctx.content);
-        let had_trailing_newline = ctx.content.ends_with('\n') || ctx.content.ends_with("\r\n");
+        // Content is normalized to LF at I/O boundary
+        let line_ending = "\n";
+        let had_trailing_newline = ctx.content.ends_with('\n');
         let mut result = Vec::new();
-        let mut in_front_matter = false;
-        let mut front_matter_delimiter_count = 0;
         let mut skip_next = false;
 
+        let heading_at_start_idx = {
+            let mut found_non_blank = false;
+            ctx.lines.iter().enumerate().find_map(|(i, line)| {
+                if line.heading.is_some() && !found_non_blank {
+                    Some(i)
+                } else {
+                    if !line.is_blank {
+                        found_non_blank = true;
+                    }
+                    None
+                }
+            })
+        };
+
         for (i, line_info) in ctx.lines.iter().enumerate() {
             if skip_next {
                 skip_next = false;
                 continue;
             }
-            let line = &line_info.content;
+            let line = line_info.content(ctx.content);
 
-            // Handle front matter
-            if line.trim() == "---" {
-                if i == 0 || (i > 0 && ctx.lines[..i].iter().all(|l| l.is_blank)) {
-                    if front_matter_delimiter_count == 0 {
-                        in_front_matter = true;
-                        front_matter_delimiter_count = 1;
-                    }
-                } else if in_front_matter && front_matter_delimiter_count == 1 {
-                    in_front_matter = false;
-                    front_matter_delimiter_count = 2;
-                }
-                result.push(line.to_string());
-                continue;
-            }
-
-            // Inside front matter or code block, preserve content exactly
-            if in_front_matter || line_info.in_code_block {
+            if line_info.in_code_block {
                 result.push(line.to_string());
                 continue;
             }
@@ -149,11 +147,7 @@ impl MD022BlanksAroundHeadings {
             // Check if it's a heading
             if let Some(heading) = &line_info.heading {
                 // This is a heading line (ATX or Setext content)
-                let is_first_heading = (0..i).all(|j| {
-                    ctx.lines[j].is_blank
-                        || (j == 0 && ctx.lines[j].content.trim() == "---")
-                        || (in_front_matter && ctx.lines[j].content.trim() == "---")
-                });
+                let is_first_heading = Some(i) == heading_at_start_idx;
 
                 // Count existing blank lines above in the result
                 let mut blank_lines_above = 0;
@@ -167,7 +161,7 @@ impl MD022BlanksAroundHeadings {
                 let needed_blanks_above = if is_first_heading && self.config.allowed_at_start {
                     0
                 } else {
-                    self.config.lines_above
+                    self.config.lines_above.get()
                 };
 
                 // Add missing blank lines above if needed
@@ -186,7 +180,7 @@ impl MD022BlanksAroundHeadings {
                 ) {
                     // Add the underline (next line)
                     if i + 1 < ctx.lines.len() {
-                        result.push(ctx.lines[i + 1].content.clone());
+                        result.push(ctx.lines[i + 1].content(ctx.content).to_string());
                         skip_next = true; // Skip the underline in the main loop
                     }
 
@@ -206,7 +200,7 @@ impl MD022BlanksAroundHeadings {
                     let next_is_special = if let Some(idx) = next_content_line_idx {
                         let next_line = &ctx.lines[idx];
                         next_line.list_item.is_some() || {
-                            let trimmed = next_line.content.trim();
+                            let trimmed = next_line.content(ctx.content).trim();
                             (trimmed.starts_with("```") || trimmed.starts_with("~~~"))
                                 && (trimmed.len() == 3
                                     || (trimmed.len() > 3
@@ -220,7 +214,11 @@ impl MD022BlanksAroundHeadings {
                     };
 
                     // Add missing blank lines below if needed
-                    let needed_blanks_below = if next_is_special { 0 } else { self.config.lines_below };
+                    let needed_blanks_below = if next_is_special {
+                        0
+                    } else {
+                        self.config.lines_below.get()
+                    };
                     if blank_lines_below < needed_blanks_below {
                         for _ in 0..(needed_blanks_below - blank_lines_below) {
                             result.push(String::new());
@@ -243,7 +241,7 @@ impl MD022BlanksAroundHeadings {
                     let next_is_special = if let Some(idx) = next_content_line_idx {
                         let next_line = &ctx.lines[idx];
                         next_line.list_item.is_some() || {
-                            let trimmed = next_line.content.trim();
+                            let trimmed = next_line.content(ctx.content).trim();
                             (trimmed.starts_with("```") || trimmed.starts_with("~~~"))
                                 && (trimmed.len() == 3
                                     || (trimmed.len() > 3
@@ -257,7 +255,11 @@ impl MD022BlanksAroundHeadings {
                     };
 
                     // Add missing blank lines below if needed
-                    let needed_blanks_below = if next_is_special { 0 } else { self.config.lines_below };
+                    let needed_blanks_below = if next_is_special {
+                        0
+                    } else {
+                        self.config.lines_below.get()
+                    };
                     if blank_lines_below < needed_blanks_below {
                         for _ in 0..(needed_blanks_below - blank_lines_below) {
                             result.push(String::new());
@@ -273,15 +275,12 @@ impl MD022BlanksAroundHeadings {
         let joined = result.join(line_ending);
 
         // Preserve original trailing newline behavior
-        if had_trailing_newline && !joined.ends_with('\n') && !joined.ends_with("\r\n") {
+        // Content is normalized to LF at I/O boundary
+        if had_trailing_newline && !joined.ends_with('\n') {
             format!("{joined}{line_ending}")
-        } else if !had_trailing_newline && (joined.ends_with('\n') || joined.ends_with("\r\n")) {
+        } else if !had_trailing_newline && joined.ends_with('\n') {
             // Remove trailing newline if original didn't have one
-            if joined.ends_with("\r\n") {
-                joined[..joined.len() - 2].to_string()
-            } else {
-                joined[..joined.len() - 1].to_string()
-            }
+            joined[..joined.len() - 1].to_string()
         } else {
             joined
         }
@@ -305,7 +304,22 @@ impl Rule for MD022BlanksAroundHeadings {
             return Ok(result);
         }
 
-        let line_ending = crate::utils::detect_line_ending(ctx.content);
+        // Content is normalized to LF at I/O boundary
+        let line_ending = "\n";
+
+        let heading_at_start_idx = {
+            let mut found_non_blank = false;
+            ctx.lines.iter().enumerate().find_map(|(i, line)| {
+                if line.heading.is_some() && !found_non_blank {
+                    Some(i)
+                } else {
+                    if !line.is_blank {
+                        found_non_blank = true;
+                    }
+                    None
+                }
+            })
+        };
 
         // Collect all headings first to batch process
         let mut heading_violations = Vec::new();
@@ -332,13 +346,8 @@ impl Rule for MD022BlanksAroundHeadings {
 
             processed_headings.insert(line_num);
 
-            // Check if this is the first heading in the document
-            let is_first_heading = (0..line_num).all(|j| {
-                ctx.lines[j].is_blank ||
-                // Check for front matter lines
-                (j == 0 && ctx.lines[j].content.trim() == "---") ||
-                (j > 0 && ctx.lines[0].content.trim() == "---" && ctx.lines[j].content.trim() == "---")
-            });
+            // Check if this heading is at document start
+            let is_first_heading = Some(line_num) == heading_at_start_idx;
 
             // Count blank lines above
             let blank_lines_above = if line_num > 0 && (!is_first_heading || !self.config.allowed_at_start) {
@@ -352,15 +361,15 @@ impl Rule for MD022BlanksAroundHeadings {
                 }
                 count
             } else {
-                self.config.lines_above // Consider it as having enough blanks if it's the first heading
+                self.config.lines_above.get() // Consider it as having enough blanks if it's the first heading
             };
 
             // Check if we need blank lines above
             if line_num > 0
-                && blank_lines_above < self.config.lines_above
+                && blank_lines_above < self.config.lines_above.get()
                 && (!is_first_heading || !self.config.allowed_at_start)
             {
-                let needed_blanks = self.config.lines_above - blank_lines_above;
+                let needed_blanks = self.config.lines_above.get() - blank_lines_above;
                 heading_violations.push((line_num, "above", needed_blanks));
             }
 
@@ -385,7 +394,7 @@ impl Rule for MD022BlanksAroundHeadings {
                 // Check if next line is a code fence or list item
                 let next_line_is_special = next_non_blank_idx < ctx.lines.len() && {
                     let next_line = &ctx.lines[next_non_blank_idx];
-                    let next_trimmed = next_line.content.trim();
+                    let next_trimmed = next_line.content(ctx.content).trim();
 
                     // Check for code fence
                     let is_code_fence = (next_trimmed.starts_with("```") || next_trimmed.starts_with("~~~"))
@@ -407,8 +416,8 @@ impl Rule for MD022BlanksAroundHeadings {
                     // Count blank lines below
                     let blank_lines_below = next_non_blank_idx - effective_last_line - 1;
 
-                    if blank_lines_below < self.config.lines_below {
-                        let needed_blanks = self.config.lines_below - blank_lines_below;
+                    if blank_lines_below < self.config.lines_below.get() {
+                        let needed_blanks = self.config.lines_below.get() - blank_lines_below;
                         heading_violations.push((line_num, "below", needed_blanks));
                     }
                 }
@@ -422,14 +431,18 @@ impl Rule for MD022BlanksAroundHeadings {
 
             // Calculate precise character range for the heading
             let (start_line, start_col, end_line, end_col) =
-                calculate_heading_range(heading_display_line, &line_info.content);
+                calculate_heading_range(heading_display_line, line_info.content(ctx.content));
 
             let (message, insertion_point) = match position {
                 "above" => (
                     format!(
                         "Expected {} blank {} above heading",
-                        self.config.lines_above,
-                        if self.config.lines_above == 1 { "line" } else { "lines" }
+                        self.config.lines_above.get(),
+                        if self.config.lines_above.get() == 1 {
+                            "line"
+                        } else {
+                            "lines"
+                        }
                     ),
                     heading_line, // Insert before the heading line
                 ),
@@ -449,8 +462,12 @@ impl Rule for MD022BlanksAroundHeadings {
                     (
                         format!(
                             "Expected {} blank {} below heading",
-                            self.config.lines_below,
-                            if self.config.lines_below == 1 { "line" } else { "lines" }
+                            self.config.lines_below.get(),
+                            if self.config.lines_below.get() == 1 {
+                                "line"
+                            } else {
+                                "lines"
+                            }
                         ),
                         insert_after,
                     )
@@ -481,7 +498,7 @@ impl Rule for MD022BlanksAroundHeadings {
             };
 
             result.push(LintWarning {
-                rule_name: Some(self.name()),
+                rule_name: Some(self.name().to_string()),
                 message,
                 line: start_line,
                 column: start_col,
@@ -516,7 +533,12 @@ impl Rule for MD022BlanksAroundHeadings {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        ctx.content.is_empty() || ctx.lines.iter().all(|line| line.heading.is_none())
+        // Fast path: check if document likely has headings
+        if ctx.content.is_empty() || !ctx.likely_has_headings() {
+            return true;
+        }
+        // Verify headings actually exist
+        ctx.lines.iter().all(|line| line.heading.is_none())
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
