@@ -2,7 +2,8 @@
 ///
 /// See [docs/md025.md](../../docs/md025.md) for full documentation, configuration, and examples.
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
-use crate::utils::range_utils::{LineIndex, calculate_match_range};
+use crate::types::HeadingLevel;
+use crate::utils::range_utils::calculate_match_range;
 use crate::utils::regex_cache::{
     HR_ASTERISK, HR_DASH, HR_SPACED_ASTERISK, HR_SPACED_DASH, HR_SPACED_UNDERSCORE, HR_UNDERSCORE,
 };
@@ -20,7 +21,7 @@ impl MD025SingleTitle {
     pub fn new(level: usize, front_matter_title: &str) -> Self {
         Self {
             config: MD025Config {
-                level,
+                level: HeadingLevel::new(level as u8).expect("Level must be 1-6"),
                 front_matter_title: front_matter_title.to_string(),
                 allow_document_sections: true,
                 allow_with_separators: true,
@@ -31,7 +32,7 @@ impl MD025SingleTitle {
     pub fn strict() -> Self {
         Self {
             config: MD025Config {
-                level: 1,
+                level: HeadingLevel::new(1).unwrap(),
                 front_matter_title: "title".to_string(),
                 allow_document_sections: false,
                 allow_with_separators: false,
@@ -123,9 +124,9 @@ impl MD025SingleTitle {
             return false;
         }
 
-        let line = ctx.lines[line_num].content.trim();
+        let line = ctx.lines[line_num].content(ctx.content).trim();
         let prev_line = if line_num > 0 {
-            ctx.lines[line_num - 1].content.trim()
+            ctx.lines[line_num - 1].content(ctx.content).trim()
         } else {
             ""
         };
@@ -151,7 +152,7 @@ impl MD025SingleTitle {
                 continue;
             }
 
-            let line = &ctx.lines[line_num].content;
+            let line = &ctx.lines[line_num].content(ctx.content);
             if Self::is_horizontal_rule(line) && !Self::is_potential_setext_heading(ctx, line_num) {
                 // Found a horizontal rule before this heading
                 // Check that there's no other heading between the HR and this heading
@@ -183,7 +184,6 @@ impl Rule for MD025SingleTitle {
             return Ok(Vec::new());
         }
 
-        let line_index = LineIndex::new(ctx.content.to_string());
         let mut warnings = Vec::new();
 
         // Check for front matter title if configured
@@ -212,7 +212,7 @@ impl Rule for MD025SingleTitle {
         let mut target_level_headings = Vec::new();
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
             if let Some(heading) = &line_info.heading
-                && heading.level as usize == self.config.level
+                && heading.level as usize == self.config.level.as_usize()
             {
                 // Ignore if indented 4+ spaces (indented code block) or inside fenced code block
                 if line_info.indent >= 4 || line_info.in_code_block {
@@ -239,7 +239,7 @@ impl Rule for MD025SingleTitle {
                     }
 
                     // Calculate precise character range for the heading text content
-                    let line_content = &ctx.lines[line_num].content;
+                    let line_content = &ctx.lines[line_num].content(ctx.content);
                     let text_start_in_line = if let Some(pos) = line_content.find(heading_text) {
                         pos
                     } else {
@@ -263,10 +263,10 @@ impl Rule for MD025SingleTitle {
                     );
 
                     warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         message: format!(
                             "Multiple top-level headings (level {}) in the same document",
-                            self.config.level
+                            self.config.level.as_usize()
                         ),
                         line: start_line,
                         column: start_col,
@@ -274,14 +274,19 @@ impl Rule for MD025SingleTitle {
                         end_column: end_col,
                         severity: Severity::Warning,
                         fix: Some(Fix {
-                            range: line_index.line_content_range(line_num + 1),
+                            range: ctx.line_index.line_content_range(line_num + 1),
                             replacement: {
                                 let leading_spaces = line_content.len() - line_content.trim_start().len();
                                 let indentation = " ".repeat(leading_spaces);
                                 if heading_text.is_empty() {
-                                    format!("{}{}", indentation, "#".repeat(self.config.level + 1))
+                                    format!("{}{}", indentation, "#".repeat(self.config.level.as_usize() + 1))
                                 } else {
-                                    format!("{}{} {}", indentation, "#".repeat(self.config.level + 1), heading_text)
+                                    format!(
+                                        "{}{} {}",
+                                        indentation,
+                                        "#".repeat(self.config.level.as_usize() + 1),
+                                        heading_text
+                                    )
                                 }
                             },
                         }),
@@ -305,11 +310,11 @@ impl Rule for MD025SingleTitle {
             }
 
             if let Some(heading) = &line_info.heading {
-                if heading.level as usize == self.config.level && !line_info.in_code_block {
+                if heading.level as usize == self.config.level.as_usize() && !line_info.in_code_block {
                     if !found_first {
                         found_first = true;
                         // Keep the first heading as-is
-                        fixed_lines.push(line_info.content.clone());
+                        fixed_lines.push(line_info.content(ctx.content).to_string());
 
                         // For Setext headings, also add the underline
                         if matches!(
@@ -317,7 +322,7 @@ impl Rule for MD025SingleTitle {
                             crate::lint_context::HeadingStyle::Setext1 | crate::lint_context::HeadingStyle::Setext2
                         ) && line_num + 1 < ctx.lines.len()
                         {
-                            fixed_lines.push(ctx.lines[line_num + 1].content.clone());
+                            fixed_lines.push(ctx.lines[line_num + 1].content(ctx.content).to_string());
                             skip_next = true;
                         }
                     } else {
@@ -327,7 +332,7 @@ impl Rule for MD025SingleTitle {
 
                         if should_allow {
                             // Keep the heading as-is
-                            fixed_lines.push(line_info.content.clone());
+                            fixed_lines.push(line_info.content(ctx.content).to_string());
 
                             // For Setext headings, also add the underline
                             if matches!(
@@ -335,7 +340,7 @@ impl Rule for MD025SingleTitle {
                                 crate::lint_context::HeadingStyle::Setext1 | crate::lint_context::HeadingStyle::Setext2
                             ) && line_num + 1 < ctx.lines.len()
                             {
-                                fixed_lines.push(ctx.lines[line_num + 1].content.clone());
+                                fixed_lines.push(ctx.lines[line_num + 1].content(ctx.content).to_string());
                                 skip_next = true;
                             }
                         } else {
@@ -350,7 +355,7 @@ impl Rule for MD025SingleTitle {
                                 }
                                 crate::lint_context::HeadingStyle::Setext1 => {
                                     // When demoting from level 1 to 2, use Setext2
-                                    if self.config.level == 1 {
+                                    if self.config.level.as_usize() == 1 {
                                         crate::rules::heading_utils::HeadingStyle::Setext2
                                     } else {
                                         // For higher levels, use ATX
@@ -368,27 +373,27 @@ impl Rule for MD025SingleTitle {
                                 match style {
                                     crate::rules::heading_utils::HeadingStyle::Atx
                                     | crate::rules::heading_utils::HeadingStyle::SetextWithAtx => {
-                                        "#".repeat(self.config.level + 1)
+                                        "#".repeat(self.config.level.as_usize() + 1)
                                     }
                                     crate::rules::heading_utils::HeadingStyle::AtxClosed
                                     | crate::rules::heading_utils::HeadingStyle::SetextWithAtxClosed => {
                                         format!(
                                             "{} {}",
-                                            "#".repeat(self.config.level + 1),
-                                            "#".repeat(self.config.level + 1)
+                                            "#".repeat(self.config.level.as_usize() + 1),
+                                            "#".repeat(self.config.level.as_usize() + 1)
                                         )
                                     }
                                     crate::rules::heading_utils::HeadingStyle::Setext1
                                     | crate::rules::heading_utils::HeadingStyle::Setext2
                                     | crate::rules::heading_utils::HeadingStyle::Consistent => {
                                         // For empty Setext or Consistent, use ATX style
-                                        "#".repeat(self.config.level + 1)
+                                        "#".repeat(self.config.level.as_usize() + 1)
                                     }
                                 }
                             } else {
                                 crate::rules::heading_utils::HeadingUtils::convert_heading_style(
                                     &heading.text,
-                                    (self.config.level + 1) as u32,
+                                    (self.config.level.as_usize() + 1) as u32,
                                     style,
                                 )
                             };
@@ -409,7 +414,7 @@ impl Rule for MD025SingleTitle {
                     }
                 } else {
                     // Not a target level heading, keep as-is
-                    fixed_lines.push(line_info.content.clone());
+                    fixed_lines.push(line_info.content(ctx.content).to_string());
 
                     // For Setext headings, also add the underline
                     if matches!(
@@ -417,13 +422,13 @@ impl Rule for MD025SingleTitle {
                         crate::lint_context::HeadingStyle::Setext1 | crate::lint_context::HeadingStyle::Setext2
                     ) && line_num + 1 < ctx.lines.len()
                     {
-                        fixed_lines.push(ctx.lines[line_num + 1].content.clone());
+                        fixed_lines.push(ctx.lines[line_num + 1].content(ctx.content).to_string());
                         skip_next = true;
                     }
                 }
             } else {
                 // Not a heading line, keep as-is
-                fixed_lines.push(line_info.content.clone());
+                fixed_lines.push(line_info.content(ctx.content).to_string());
             }
         }
 
@@ -448,7 +453,7 @@ impl Rule for MD025SingleTitle {
         }
 
         // Skip if no heading markers at all
-        if !ctx.content.contains('#') && !ctx.content.contains('=') && !ctx.content.contains('-') {
+        if !ctx.likely_has_headings() {
             return true;
         }
 
@@ -456,7 +461,7 @@ impl Rule for MD025SingleTitle {
         let mut target_level_count = 0;
         for line_info in &ctx.lines {
             if let Some(heading) = &line_info.heading
-                && heading.level as usize == self.config.level
+                && heading.level as usize == self.config.level.as_usize()
             {
                 // Ignore if indented 4+ spaces (indented code block) or inside fenced code block
                 if line_info.indent >= 4 || line_info.in_code_block {
@@ -578,7 +583,7 @@ mod tests {
     #[test]
     fn test_bounds_checking_bug() {
         // Test case that could trigger bounds error in fix generation
-        // When col + self.config.level exceeds line_content.len()
+        // When col + self.config.level.as_usize() exceeds line_content.len()
         let rule = MD025SingleTitle::default();
 
         // Create content with very short second heading
@@ -597,11 +602,11 @@ mod tests {
     #[test]
     fn test_bounds_checking_edge_case() {
         // Test case that specifically targets the bounds checking fix
-        // Create a heading where col + self.config.level would exceed line length
+        // Create a heading where col + self.config.level.as_usize() would exceed line length
         let rule = MD025SingleTitle::default();
 
         // Create content where the second heading is just "#" (length 1)
-        // col will be 0, self.config.level is 1, so col + self.config.level = 1
+        // col will be 0, self.config.level.as_usize() is 1, so col + self.config.level.as_usize() = 1
         // This should not exceed bounds for "#" but tests the edge case
         let content = "# First Title\n#";
         let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
