@@ -2,26 +2,27 @@
 ///
 /// See [docs/md026.md](../../docs/md026.md) for full documentation, configuration, and examples.
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
-use crate::utils::range_utils::calculate_match_range;
-use lazy_static::lazy_static;
+use crate::utils::range_utils::{LineIndex, calculate_match_range};
 use regex::Regex;
 use std::collections::HashMap;
 use std::ops::Range;
+use std::sync::LazyLock;
 use std::sync::RwLock;
 
 mod md026_config;
 use md026_config::{DEFAULT_PUNCTUATION, MD026Config};
 
-lazy_static! {
-    // Optimized single regex for all ATX heading types (normal, closed, indented 1-3 spaces)
-    static ref ATX_HEADING_UNIFIED: Regex = Regex::new(r"^( {0,3})(#{1,6})(\s+)(.+?)(\s+#{1,6})?$").unwrap();
+// Optimized single regex for all ATX heading types (normal, closed, indented 1-3 spaces)
+static ATX_HEADING_UNIFIED: LazyLock<Regex> =
+    LazyLock::new(|| Regex::new(r"^( {0,3})(#{1,6})(\s+)(.+?)(\s+#{1,6})?$").unwrap());
 
-    // Fast check patterns for early returns - match defaults
-    static ref QUICK_PUNCTUATION_CHECK: Regex = Regex::new(&format!(r"[{}]", regex::escape(DEFAULT_PUNCTUATION))).unwrap();
+// Fast check patterns for early returns - match defaults
+static QUICK_PUNCTUATION_CHECK: LazyLock<Regex> =
+    LazyLock::new(|| Regex::new(&format!(r"[{}]", regex::escape(DEFAULT_PUNCTUATION))).unwrap());
 
-    // Regex cache for punctuation patterns
-    static ref PUNCTUATION_REGEX_CACHE: RwLock<HashMap<String, Regex>> = RwLock::new(HashMap::new());
-}
+// Regex cache for punctuation patterns
+static PUNCTUATION_REGEX_CACHE: LazyLock<RwLock<HashMap<String, Regex>>> =
+    LazyLock::new(|| RwLock::new(HashMap::new()));
 
 /// Rule MD026: Trailing punctuation in heading
 #[derive(Clone, Default)]
@@ -71,23 +72,15 @@ impl MD026NoTrailingPunctuation {
     }
 
     #[inline]
-    fn get_line_byte_range(&self, content: &str, line_num: usize) -> Range<usize> {
-        let mut start_pos = 0;
+    fn get_line_byte_range(&self, content: &str, line_num: usize, line_index: &LineIndex) -> Range<usize> {
+        let start_pos = line_index.get_line_start_byte(line_num).unwrap_or(content.len());
 
-        for (idx, line) in content.lines().enumerate() {
-            if idx + 1 == line_num {
-                return Range {
-                    start: start_pos,
-                    end: start_pos + line.len(),
-                };
-            }
-            // +1 for the newline character
-            start_pos += line.len() + 1;
-        }
+        // Find the line length
+        let line = content.lines().nth(line_num - 1).unwrap_or("");
 
         Range {
-            start: content.len(),
-            end: content.len(),
+            start: start_pos,
+            end: start_pos + line.len(),
         }
     }
 
@@ -165,7 +158,7 @@ impl Rule for MD026NoTrailingPunctuation {
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
         // Skip if no heading markers
-        if !ctx.content.contains('#') {
+        if !ctx.likely_has_headings() {
             return true;
         }
         // Skip if none of the configured punctuation exists
@@ -207,6 +200,9 @@ impl Rule for MD026NoTrailingPunctuation {
             Err(_) => return Ok(warnings),
         };
 
+        // Create LineIndex for correct byte position calculations across all line ending types
+        let line_index = &ctx.line_index;
+
         // Use pre-computed heading information from LintContext
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
             if let Some(heading) = &line_info.heading {
@@ -223,7 +219,7 @@ impl Rule for MD026NoTrailingPunctuation {
                 if self.has_trailing_punctuation(&text_to_check, &re) {
                     // Find the trailing punctuation
                     if let Some(punctuation_match) = re.find(&text_to_check) {
-                        let line = &line_info.content;
+                        let line = line_info.content(ctx.content);
 
                         // For ATX headings, find the punctuation position in the line
                         let punctuation_pos_in_text = punctuation_match.start();
@@ -240,7 +236,7 @@ impl Rule for MD026NoTrailingPunctuation {
 
                         let last_char = text_to_check.chars().last().unwrap_or(' ');
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             line: start_line,
                             column: start_col,
                             end_line,
@@ -248,7 +244,7 @@ impl Rule for MD026NoTrailingPunctuation {
                             message: format!("Heading '{text_to_check}' ends with punctuation '{last_char}'"),
                             severity: Severity::Warning,
                             fix: Some(Fix {
-                                range: self.get_line_byte_range(content, line_num + 1),
+                                range: self.get_line_byte_range(content, line_num + 1, line_index),
                                 replacement: if matches!(heading.style, crate::lint_context::HeadingStyle::ATX) {
                                     self.fix_atx_heading(line, &re)
                                 } else {
@@ -315,9 +311,9 @@ impl Rule for MD026NoTrailingPunctuation {
                 // Check and fix trailing punctuation
                 if self.has_trailing_punctuation(&text_to_check, &re) {
                     fixed_lines[line_num] = if matches!(heading.style, crate::lint_context::HeadingStyle::ATX) {
-                        self.fix_atx_heading(&line_info.content, &re)
+                        self.fix_atx_heading(line_info.content(ctx.content), &re)
                     } else {
-                        self.fix_setext_heading(&line_info.content, &re)
+                        self.fix_setext_heading(line_info.content(ctx.content), &re)
                     };
                 }
             }
