@@ -1,28 +1,34 @@
-use crate::utils::range_utils::{LineIndex, calculate_match_range};
+use crate::utils::range_utils::calculate_match_range;
 
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
-use lazy_static::lazy_static;
 use regex::Regex;
+use std::sync::LazyLock;
 
-lazy_static! {
-    // Pattern to match quote lines with multiple spaces after >
-    static ref BLOCKQUOTE_MULTIPLE_SPACES: Regex = Regex::new(r"^(\s*)>(\s{2,})(.*)$").unwrap();
-
-    // New patterns for detecting malformed blockquote attempts where user intent is clear
-    static ref MALFORMED_BLOCKQUOTE_PATTERNS: Vec<(Regex, &'static str)> = vec![
+// New patterns for detecting malformed blockquote attempts where user intent is clear
+static MALFORMED_BLOCKQUOTE_PATTERNS: LazyLock<Vec<(Regex, &'static str)>> = LazyLock::new(|| {
+    vec![
         // Double > without space: >>text (looks like nested but missing spaces)
-        (Regex::new(r"^(\s*)>>([^\s>].*|$)").unwrap(), "missing spaces in nested blockquote"),
-
+        (
+            Regex::new(r"^(\s*)>>([^\s>].*|$)").unwrap(),
+            "missing spaces in nested blockquote",
+        ),
         // Triple > without space: >>>text
-        (Regex::new(r"^(\s*)>>>([^\s>].*|$)").unwrap(), "missing spaces in deeply nested blockquote"),
-
+        (
+            Regex::new(r"^(\s*)>>>([^\s>].*|$)").unwrap(),
+            "missing spaces in deeply nested blockquote",
+        ),
         // Space then > then text: > >text (extra > by mistake)
-        (Regex::new(r"^(\s*)>\s+>([^\s>].*|$)").unwrap(), "extra blockquote marker"),
-
+        (
+            Regex::new(r"^(\s*)>\s+>([^\s>].*|$)").unwrap(),
+            "extra blockquote marker",
+        ),
         // Multiple spaces then >: (spaces)>text (indented blockquote without space)
-        (Regex::new(r"^(\s{4,})>([^\s].*|$)").unwrap(), "indented blockquote missing space"),
-    ];
-}
+        (
+            Regex::new(r"^(\s{4,})>([^\s].*|$)").unwrap(),
+            "indented blockquote missing space",
+        ),
+    ]
+});
 
 /// Rule MD027: No multiple spaces after blockquote symbol
 ///
@@ -61,7 +67,7 @@ impl Rule for MD027MultipleSpacesBlockquote {
                     let mut found_markers = 0;
                     let mut found_first_space = false;
 
-                    for (i, ch) in line_info.content.char_indices() {
+                    for (i, ch) in line_info.content(ctx.content).char_indices() {
                         if found_markers < blockquote.nesting_level {
                             if ch == '>' {
                                 found_markers += 1;
@@ -77,17 +83,21 @@ impl Rule for MD027MultipleSpacesBlockquote {
                     }
 
                     // Count how many extra spaces/tabs there are
-                    let extra_spaces_bytes = line_info.content[byte_pos..]
+                    let extra_spaces_bytes = line_info.content(ctx.content)[byte_pos..]
                         .chars()
                         .take_while(|&c| c == ' ' || c == '\t')
                         .fold(0, |acc, ch| acc + ch.len_utf8());
 
                     if extra_spaces_bytes > 0 {
-                        let (start_line, start_col, end_line, end_col) =
-                            calculate_match_range(line_num, &line_info.content, byte_pos, extra_spaces_bytes);
+                        let (start_line, start_col, end_line, end_col) = calculate_match_range(
+                            line_num,
+                            line_info.content(ctx.content),
+                            byte_pos,
+                            extra_spaces_bytes,
+                        );
 
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             line: start_line,
                             column: start_col,
                             end_line,
@@ -96,9 +106,8 @@ impl Rule for MD027MultipleSpacesBlockquote {
                             severity: Severity::Warning,
                             fix: Some(Fix {
                                 range: {
-                                    let line_index = LineIndex::new(ctx.content.to_string());
-                                    let start_byte = line_index.line_col_to_byte_range(line_num, start_col).start;
-                                    let end_byte = line_index.line_col_to_byte_range(line_num, end_col).start;
+                                    let start_byte = ctx.line_index.line_col_to_byte_range(line_num, start_col).start;
+                                    let end_byte = ctx.line_index.line_col_to_byte_range(line_num, end_col).start;
                                     start_byte..end_byte
                                 },
                                 replacement: "".to_string(), // Remove the extra spaces
@@ -108,13 +117,13 @@ impl Rule for MD027MultipleSpacesBlockquote {
                 }
             } else {
                 // Part 2: Check for malformed blockquote attempts on non-blockquote lines
-                let malformed_attempts = self.detect_malformed_blockquote_attempts(&line_info.content);
+                let malformed_attempts = self.detect_malformed_blockquote_attempts(line_info.content(ctx.content));
                 for (start, len, fixed_line, description) in malformed_attempts {
                     let (start_line, start_col, end_line, end_col) =
-                        calculate_match_range(line_num, &line_info.content, start, len);
+                        calculate_match_range(line_num, line_info.content(ctx.content), start, len);
 
                     warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         line: start_line,
                         column: start_col,
                         end_line,
@@ -122,10 +131,7 @@ impl Rule for MD027MultipleSpacesBlockquote {
                         message: format!("Malformed quote: {description}"),
                         severity: Severity::Warning,
                         fix: Some(Fix {
-                            range: {
-                                let line_index = LineIndex::new(ctx.content.to_string());
-                                line_index.line_col_to_byte_range(line_num, 1)
-                            },
+                            range: ctx.line_index.line_col_to_byte_range(line_num, 1),
                             replacement: fixed_line,
                         }),
                     });
@@ -157,17 +163,17 @@ impl Rule for MD027MultipleSpacesBlockquote {
                     };
                     result.push(fixed_line);
                 } else {
-                    result.push(line_info.content.clone());
+                    result.push(line_info.content(ctx.content).to_string());
                 }
             } else {
                 // Check for malformed blockquote attempts
-                let malformed_attempts = self.detect_malformed_blockquote_attempts(&line_info.content);
+                let malformed_attempts = self.detect_malformed_blockquote_attempts(line_info.content(ctx.content));
                 if !malformed_attempts.is_empty() {
                     // Use the first fix (there should only be one per line)
                     let (_, _, fixed_line, _) = &malformed_attempts[0];
                     result.push(fixed_line.clone());
                 } else {
-                    result.push(line_info.content.clone());
+                    result.push(line_info.content(ctx.content).to_string());
                 }
             }
         }
@@ -189,7 +195,7 @@ impl Rule for MD027MultipleSpacesBlockquote {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        ctx.content.is_empty() || !ctx.content.contains('>')
+        ctx.content.is_empty() || !ctx.likely_has_blockquotes()
     }
 }
 
