@@ -190,7 +190,7 @@ impl Rule for MD029OrderedListPrefix {
         let mut fixes: Vec<&Fix> = Vec::new();
         for warning in &warnings {
             // Skip MD029-style warnings (lazy continuation indentation)
-            if warning.rule_name == Some("MD029-style") {
+            if warning.rule_name.as_deref() == Some("MD029-style") {
                 continue;
             }
             if let Some(ref fix) = warning.fix {
@@ -234,10 +234,7 @@ impl Rule for MD029OrderedListPrefix {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        let content = ctx.content;
-        content.is_empty()
-            || !content.contains('1')
-            || (!content.contains("1.") && !content.contains("2.") && !content.contains("0."))
+        ctx.content.is_empty() || !ctx.likely_has_lists()
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -295,7 +292,7 @@ impl MD029OrderedListPrefix {
                 }
 
                 // Skip code fence lines
-                let trimmed = line_info.content.trim();
+                let trimmed = line_info.content(ctx.content).trim();
                 if trimmed.starts_with("```") || trimmed.starts_with("~~~") {
                     continue;
                 }
@@ -306,12 +303,12 @@ impl MD029OrderedListPrefix {
                 }
 
                 // Check if this is a lazy continuation (0-2 spaces)
-                if line_info.indent <= 2 && !line_info.content.trim().is_empty() {
+                if line_info.indent <= 2 && !line_info.content(ctx.content).trim().is_empty() {
                     // This is a lazy continuation - add a style warning
                     let col = line_info.indent + 1;
 
                     warnings.push(LintWarning {
-                        rule_name: Some("MD029-style"),
+                        rule_name: Some("MD029-style".to_string()),
                         message: "List continuation should be indented (lazy continuation detected)".to_string(),
                         line: line_num,
                         column: col,
@@ -328,8 +325,9 @@ impl MD029OrderedListPrefix {
         }
     }
 
-    /// Check if blocks are separated only by unindented list items
-    /// This helps detect the pattern: 1. item / - sub / 1. item (should be 2.)
+    /// Check if blocks are separated only by list items or properly indented list continuation content
+    /// This helps detect the pattern: 1. item / - nested sub / 1. item (should be 2.)
+    /// Now also allows indented nested lists and content that's properly indented for list continuation
     fn has_only_unindented_lists_between(
         &self,
         ctx: &crate::lint_context::LintContext,
@@ -340,21 +338,73 @@ impl MD029OrderedListPrefix {
             return false;
         }
 
+        // Calculate minimum continuation indent from the previous block's last item
+        let min_continuation_indent =
+            if let Some(prev_block) = ctx.list_blocks.iter().find(|block| block.end_line == end_line) {
+                if let Some(&last_item_line) = prev_block.item_lines.last() {
+                    if let Some(line_info) = ctx.line_info(last_item_line) {
+                        if let Some(list_item) = &line_info.list_item {
+                            if list_item.is_ordered {
+                                list_item.marker.len() + 1 // Add 1 for space after ordered markers
+                            } else {
+                                2 // Unordered lists need at least 2 spaces
+                            }
+                        } else {
+                            3 // Fallback
+                        }
+                    } else {
+                        3 // Fallback
+                    }
+                } else {
+                    3 // Fallback
+                }
+            } else {
+                3 // Fallback
+            };
+
         for line_num in (end_line + 1)..start_line {
             if let Some(line_info) = ctx.line_info(line_num) {
-                let trimmed = line_info.content.trim();
+                let trimmed = line_info.content(ctx.content).trim();
 
                 // Skip empty lines
                 if trimmed.is_empty() {
                     continue;
                 }
 
-                // If it's an unindented list item (column 0), that's what we're looking for
-                if line_info.list_item.is_some() && line_info.indent == 0 {
+                // Allow any list item (both unindented and properly indented nested lists)
+                if line_info.list_item.is_some() {
+                    // Check if nested list has sufficient indentation to be continuation
+                    if line_info.indent >= min_continuation_indent {
+                        continue; // Properly indented nested list
+                    }
+                    // Unindented or under-indented list item breaks continuity
+                    return false;
+                }
+
+                // Allow fence markers that are properly indented
+                if trimmed.starts_with("```") || trimmed.starts_with("~~~") {
+                    if line_info.indent >= min_continuation_indent {
+                        continue; // Properly indented fence marker
+                    }
+                    // Under-indented fence marker breaks continuity
+                    return false;
+                }
+
+                // Allow code blocks that are properly indented
+                if line_info.in_code_block {
+                    if line_info.indent >= min_continuation_indent {
+                        continue; // Properly indented code block
+                    }
+                    // Under-indented code block breaks continuity
+                    return false;
+                }
+
+                // Allow other indented text that's part of list continuation
+                if line_info.indent >= min_continuation_indent {
                     continue;
                 }
 
-                // Any other non-empty content means it's not just unindented lists
+                // Any other content (unindented or under-indented) breaks continuity
                 return false;
             }
         }
@@ -373,6 +423,30 @@ impl MD029OrderedListPrefix {
             return false;
         }
 
+        // Calculate minimum continuation indent from the previous block's last item
+        let min_continuation_indent =
+            if let Some(prev_block) = ctx.list_blocks.iter().find(|block| block.end_line == end_line) {
+                if let Some(&last_item_line) = prev_block.item_lines.last() {
+                    if let Some(line_info) = ctx.line_info(last_item_line) {
+                        if let Some(list_item) = &line_info.list_item {
+                            if list_item.is_ordered {
+                                list_item.marker.len() + 1 // Add 1 for space after ordered markers
+                            } else {
+                                2 // Unordered lists need at least 2 spaces
+                            }
+                        } else {
+                            3 // Fallback
+                        }
+                    } else {
+                        3 // Fallback
+                    }
+                } else {
+                    3 // Fallback
+                }
+            } else {
+                3 // Fallback
+            };
+
         for line_num in (end_line + 1)..start_line {
             if let Some(line_info) = ctx.line_info(line_num) {
                 // Skip empty lines
@@ -380,19 +454,47 @@ impl MD029OrderedListPrefix {
                     continue;
                 }
 
-                // Skip lines in code blocks
-                if line_info.in_code_block {
-                    continue;
-                }
-
                 // If there's any heading, the lists are not continuous
                 if line_info.heading.is_some() {
                     return false;
                 }
 
-                // If there's any other non-empty content, be conservative and separate
-                let trimmed = line_info.content.trim();
-                if !trimmed.is_empty() && !trimmed.starts_with("```") && !trimmed.starts_with("~~~") {
+                let trimmed = line_info.content(ctx.content).trim();
+
+                // Allow list items if properly indented
+                if line_info.list_item.is_some() {
+                    if line_info.indent >= min_continuation_indent {
+                        continue; // Properly indented nested list
+                    }
+                    // Under-indented list breaks continuity
+                    return false;
+                }
+
+                // Allow fence markers if properly indented
+                if trimmed.starts_with("```") || trimmed.starts_with("~~~") {
+                    if line_info.indent >= min_continuation_indent {
+                        continue; // Properly indented fence
+                    }
+                    // Under-indented fence breaks continuity
+                    return false;
+                }
+
+                // Allow code blocks if properly indented
+                if line_info.in_code_block {
+                    if line_info.indent >= min_continuation_indent {
+                        continue; // Properly indented code block
+                    }
+                    // Under-indented code block breaks continuity
+                    return false;
+                }
+
+                // Allow other indented text that's part of list continuation
+                if line_info.indent >= min_continuation_indent {
+                    continue;
+                }
+
+                // Any other unindented or under-indented content breaks continuity
+                if !trimmed.is_empty() {
                     return false;
                 }
             }
@@ -438,7 +540,7 @@ impl MD029OrderedListPrefix {
 
         for line_num in (end_line + 1)..start_line {
             if let Some(line_info) = ctx.line_info(line_num) {
-                let trimmed = line_info.content.trim();
+                let trimmed = line_info.content(ctx.content).trim();
 
                 // Skip empty lines
                 if trimmed.is_empty() {
@@ -610,7 +712,7 @@ impl MD029OrderedListPrefix {
                         };
 
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             message: format!(
                                 "Ordered list item number {actual_num} does not match style (expected {expected_num})"
                             ),
