@@ -21,10 +21,14 @@ impl MD030ListMarkerSpace {
     pub fn new(ul_single: usize, ul_multi: usize, ol_single: usize, ol_multi: usize) -> Self {
         Self {
             config: MD030Config {
-                ul_single,
-                ul_multi,
-                ol_single,
-                ol_multi,
+                ul_single: crate::types::PositiveUsize::new(ul_single)
+                    .unwrap_or(crate::types::PositiveUsize::from_const(1)),
+                ul_multi: crate::types::PositiveUsize::new(ul_multi)
+                    .unwrap_or(crate::types::PositiveUsize::from_const(1)),
+                ol_single: crate::types::PositiveUsize::new(ol_single)
+                    .unwrap_or(crate::types::PositiveUsize::from_const(1)),
+                ol_multi: crate::types::PositiveUsize::new(ol_multi)
+                    .unwrap_or(crate::types::PositiveUsize::from_const(1)),
             },
         }
     }
@@ -35,10 +39,10 @@ impl MD030ListMarkerSpace {
 
     pub fn get_expected_spaces(&self, list_type: ListType, is_multi: bool) -> usize {
         match (list_type, is_multi) {
-            (ListType::Unordered, false) => self.config.ul_single,
-            (ListType::Unordered, true) => self.config.ul_multi,
-            (ListType::Ordered, false) => self.config.ol_single,
-            (ListType::Ordered, true) => self.config.ol_multi,
+            (ListType::Unordered, false) => self.config.ul_single.get(),
+            (ListType::Unordered, true) => self.config.ul_multi.get(),
+            (ListType::Ordered, false) => self.config.ol_single.get(),
+            (ListType::Ordered, true) => self.config.ol_multi.get(),
         }
     }
 }
@@ -68,6 +72,7 @@ impl Rule for MD030ListMarkerSpace {
             }
         }
 
+        // Collect lines once instead of in every is_multi_line_list_item call
         let lines: Vec<&str> = ctx.content.lines().collect();
         let mut in_blockquote = false;
 
@@ -105,7 +110,7 @@ impl Rule for MD030ListMarkerSpace {
                 let actual_spaces = list_info.content_column.saturating_sub(marker_end);
 
                 // Determine if this is a multi-line list item
-                let is_multi_line = self.is_multi_line_list_item(ctx, line_num);
+                let is_multi_line = self.is_multi_line_list_item(ctx, line_num, &lines);
                 let expected_spaces = self.get_expected_spaces(list_type, is_multi_line);
 
                 // Check for tabs in the spacing
@@ -147,7 +152,7 @@ impl Rule for MD030ListMarkerSpace {
                         format!("Spaces after list markers (Expected: {expected_spaces}; Actual: {actual_spaces})");
 
                     warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         severity: Severity::Warning,
                         line: start_line,
                         column: start_col,
@@ -171,7 +176,7 @@ impl Rule for MD030ListMarkerSpace {
             return true;
         }
 
-        // Fast byte-level check for list markers
+        // Fast byte-level check for list markers (including ordered lists)
         let bytes = ctx.content.as_bytes();
         !bytes.contains(&b'*')
             && !bytes.contains(&b'-')
@@ -250,7 +255,7 @@ impl Rule for MD030ListMarkerSpace {
             }
 
             // Try to fix list marker spacing
-            let is_multi_line = self.is_multi_line_list_item(ctx, line_num);
+            let is_multi_line = self.is_multi_line_list_item(ctx, line_num, &lines);
             if let Some(fixed_line) = self.try_fix_list_marker_spacing_with_context(line, is_multi_line) {
                 result_lines.push(fixed_line);
             } else {
@@ -270,7 +275,7 @@ impl Rule for MD030ListMarkerSpace {
 
 impl MD030ListMarkerSpace {
     /// Check if a list item is multi-line (spans multiple lines or contains nested content)
-    fn is_multi_line_list_item(&self, ctx: &crate::lint_context::LintContext, line_num: usize) -> bool {
+    fn is_multi_line_list_item(&self, ctx: &crate::lint_context::LintContext, line_num: usize, lines: &[&str]) -> bool {
         // Get the current list item info
         let current_line_info = match ctx.line_info(line_num) {
             Some(info) if info.list_item.is_some() => info,
@@ -278,7 +283,6 @@ impl MD030ListMarkerSpace {
         };
 
         let current_list = current_line_info.list_item.as_ref().unwrap();
-        let lines: Vec<&str> = ctx.content.lines().collect();
 
         // Check subsequent lines to see if they are continuation of this list item
         for next_line_num in (line_num + 1)..=lines.len() {
@@ -333,9 +337,9 @@ impl MD030ListMarkerSpace {
                     if !content.is_empty() {
                         // Use appropriate configuration based on whether it's multi-line
                         let spaces = if is_multi_line {
-                            " ".repeat(self.config.ul_multi)
+                            " ".repeat(self.config.ul_multi.get())
                         } else {
-                            " ".repeat(self.config.ul_single)
+                            " ".repeat(self.config.ul_single.get())
                         };
                         return Some(format!("{indent}{marker}{spaces}{content}"));
                     }
@@ -358,9 +362,9 @@ impl MD030ListMarkerSpace {
                     if !content.is_empty() {
                         // Use appropriate configuration based on whether it's multi-line
                         let spaces = if is_multi_line {
-                            " ".repeat(self.config.ol_multi)
+                            " ".repeat(self.config.ol_multi.get())
                         } else {
-                            " ".repeat(self.config.ol_single)
+                            " ".repeat(self.config.ol_single.get())
                         };
                         return Some(format!("{indent}{before_dot}.{spaces}{content}"));
                     }
