@@ -1,14 +1,10 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::range_utils::{LineIndex, calculate_line_range};
 use crate::utils::regex_cache::BLOCKQUOTE_PREFIX_RE;
-use lazy_static::lazy_static;
 use regex::Regex;
-
-lazy_static! {
-    static ref BLANK_LINE_RE: Regex = Regex::new(r"^\s*$").unwrap();
-    // Detects ordered list items starting with a number other than 1
-    static ref ORDERED_LIST_NON_ONE_RE: Regex = Regex::new(r"^\s*([2-9]|\d{2,})\.\s").unwrap();
-}
+use std::sync::LazyLock;
+// Detects ordered list items starting with a number other than 1
+static ORDERED_LIST_NON_ONE_RE: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^\s*([2-9]|\d{2,})\.\s").unwrap());
 
 /// Rule MD032: Lists should be surrounded by blank lines
 ///
@@ -80,67 +76,34 @@ lazy_static! {
 /// - Efficient list item detection
 /// - Pre-computation of code block lines to avoid redundant processing
 #[derive(Debug, Clone, Default)]
-pub struct MD032BlanksAroundLists {
-    /// Allow lists to follow headings without blank lines
-    pub allow_after_headings: bool,
-    /// Allow lists to follow content ending with colons without blank lines
-    pub allow_after_colons: bool,
-}
+pub struct MD032BlanksAroundLists;
 
 impl MD032BlanksAroundLists {
-    pub fn strict() -> Self {
-        Self {
-            allow_after_headings: false,
-            allow_after_colons: false,
-        }
-    }
-
     /// Check if a blank line should be required before a list based on the previous line context
     fn should_require_blank_line_before(
-        &self,
-        prev_line: &str,
         ctx: &crate::lint_context::LintContext,
         prev_line_num: usize,
         current_line_num: usize,
     ) -> bool {
-        let trimmed_prev = prev_line.trim();
-
         // Always require blank lines after code blocks, front matter, etc.
-        if ctx.is_in_code_block(prev_line_num) || ctx.is_in_front_matter(prev_line_num) {
+        if ctx
+            .line_info(prev_line_num)
+            .is_some_and(|info| info.in_code_block || info.in_front_matter)
+        {
             return true;
         }
 
         // Always allow nested lists (lists indented within other list items)
-        if self.is_nested_list(ctx, prev_line_num, current_line_num) {
+        if Self::is_nested_list(ctx, prev_line_num, current_line_num) {
             return false;
         }
 
-        // Allow lists after headings if configured (now false by default)
-        if self.allow_after_headings && self.is_heading_line_from_context(ctx, prev_line_num - 1) {
-            return false;
-        }
-
-        // Allow lists after content ending with colons if configured (now false by default)
-        if self.allow_after_colons && trimmed_prev.ends_with(':') {
-            return false;
-        }
-
-        // Default: require blank line (matching markdownlint's stricter behavior)
+        // Default: require blank line (matching markdownlint's behavior)
         true
     }
 
-    /// Check if a line is a heading using cached LintContext info
-    fn is_heading_line_from_context(&self, ctx: &crate::lint_context::LintContext, line_idx: usize) -> bool {
-        if line_idx < ctx.lines.len() {
-            ctx.lines[line_idx].heading.is_some()
-        } else {
-            false
-        }
-    }
-
     /// Check if the current list is nested within another list item
     fn is_nested_list(
-        &self,
         ctx: &crate::lint_context::LintContext,
         prev_line_num: usize,    // 1-indexed
         current_line_num: usize, // 1-indexed
@@ -178,21 +141,38 @@ impl MD032BlanksAroundLists {
 
             for &item_line in &block.item_lines {
                 if prev_item_line > 0 {
-                    // Check if there's a fenced code block between prev_item_line and item_line
-                    let mut has_code_fence = false;
+                    // Check if there's a standalone code fence between prev_item_line and item_line
+                    // A code fence that's indented as part of a list item should NOT split the list
+                    let mut has_standalone_code_fence = false;
+
+                    // Calculate minimum indentation for list item content
+                    let min_indent_for_content = if block.is_ordered {
+                        // For ordered lists, content should be indented at least to align with text after marker
+                        // e.g., "1. " = 3 chars, so content should be indented 3+ spaces
+                        3 // Minimum for "1. "
+                    } else {
+                        // For unordered lists, content should be indented at least 2 spaces
+                        2 // For "- " or "* "
+                    };
+
                     for check_line in (prev_item_line + 1)..item_line {
                         if check_line - 1 < ctx.lines.len() {
                             let line = &ctx.lines[check_line - 1];
+                            let line_content = line.content(ctx.content);
                             if line.in_code_block
-                                && (line.content.trim().starts_with("```") || line.content.trim().starts_with("~~~"))
+                                && (line_content.trim().starts_with("```") || line_content.trim().starts_with("~~~"))
                             {
-                                has_code_fence = true;
-                                break;
+                                // Check if this code fence is indented as part of the list item
+                                // If it's indented enough to be part of the list item, it shouldn't split
+                                if line.indent < min_indent_for_content {
+                                    has_standalone_code_fence = true;
+                                    break;
+                                }
                             }
                         }
                     }
 
-                    if has_code_fence {
+                    if has_standalone_code_fence {
                         // End current segment before this item
                         segments.push((current_start, prev_item_line));
                         current_start = item_line;
@@ -218,8 +198,9 @@ impl MD032BlanksAroundLists {
                     for check_line in (seg_end + 1)..next_start {
                         if check_line - 1 < ctx.lines.len() {
                             let line = &ctx.lines[check_line - 1];
+                            let line_content = line.content(ctx.content);
                             if line.in_code_block
-                                && (line.content.trim().starts_with("```") || line.content.trim().starts_with("~~~"))
+                                && (line_content.trim().starts_with("```") || line_content.trim().starts_with("~~~"))
                             {
                                 found_fence = true;
                                 break;
@@ -303,7 +284,10 @@ impl MD032BlanksAroundLists {
             }
 
             // Skip if in code block or front matter
-            if ctx.is_in_code_block(line_num) || ctx.is_in_front_matter(line_num) {
+            if ctx
+                .line_info(line_num)
+                .is_some_and(|info| info.in_code_block || info.in_front_matter)
+            {
                 continue;
             }
 
@@ -313,7 +297,9 @@ impl MD032BlanksAroundLists {
                 if line_idx > 0 {
                     let prev_line = lines[line_idx - 1];
                     let prev_is_blank = is_blank_in_context(prev_line);
-                    let prev_excluded = ctx.is_in_code_block(line_idx) || ctx.is_in_front_matter(line_idx);
+                    let prev_excluded = ctx
+                        .line_info(line_idx)
+                        .is_some_and(|info| info.in_code_block || info.in_front_matter);
 
                     if !prev_is_blank && !prev_excluded {
                         // This ordered list item starting with non-1 needs a blank line before it
@@ -325,7 +311,7 @@ impl MD032BlanksAroundLists {
                             end_line,
                             end_column: end_col,
                             severity: Severity::Error,
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             message: "Ordered list starting with non-1 should be preceded by blank line".to_string(),
                             fix: Some(Fix {
                                 range: line_index.line_col_to_byte_range_with_length(line_num, 1, 0),
@@ -342,8 +328,9 @@ impl MD032BlanksAroundLists {
                 let prev_line_actual_idx_0 = start_line - 2;
                 let prev_line_actual_idx_1 = start_line - 1;
                 let prev_line_str = lines[prev_line_actual_idx_0];
-                let is_prev_excluded =
-                    ctx.is_in_code_block(prev_line_actual_idx_1) || ctx.is_in_front_matter(prev_line_actual_idx_1);
+                let is_prev_excluded = ctx
+                    .line_info(prev_line_actual_idx_1)
+                    .is_some_and(|info| info.in_code_block || info.in_front_matter);
                 let prev_prefix = BLOCKQUOTE_PREFIX_RE
                     .find(prev_line_str)
                     .map_or(String::new(), |m| m.as_str().to_string());
@@ -352,8 +339,7 @@ impl MD032BlanksAroundLists {
 
                 // Only require blank lines for content in the same context (same blockquote level)
                 // and when the context actually requires it
-                let should_require =
-                    self.should_require_blank_line_before(prev_line_str, ctx, prev_line_actual_idx_1, start_line);
+                let should_require = Self::should_require_blank_line_before(ctx, prev_line_actual_idx_1, start_line);
                 if !is_prev_excluded && !prev_is_blank && prefixes_match && should_require {
                     // Calculate precise character range for the entire list line that needs a blank line before it
                     let (start_line, start_col, end_line, end_col) =
@@ -365,7 +351,7 @@ impl MD032BlanksAroundLists {
                         end_line,
                         end_column: end_col,
                         severity: Severity::Error,
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         message: "List should be preceded by blank line".to_string(),
                         fix: Some(Fix {
                             range: line_index.line_col_to_byte_range_with_length(start_line, 1, 0),
@@ -381,7 +367,7 @@ impl MD032BlanksAroundLists {
                 let next_line_str = lines[next_line_idx_0];
                 // Check if next line is excluded - front matter or indented code blocks within lists
                 // We want blank lines before standalone code blocks, but not within list items
-                let is_next_excluded = ctx.is_in_front_matter(next_line_idx_1)
+                let is_next_excluded = ctx.line_info(next_line_idx_1).is_some_and(|info| info.in_front_matter)
                     || (next_line_idx_0 < ctx.lines.len()
                         && ctx.lines[next_line_idx_0].in_code_block
                         && ctx.lines[next_line_idx_0].indent >= 2);
@@ -403,7 +389,7 @@ impl MD032BlanksAroundLists {
                         end_line: end_line_last,
                         end_column: end_col_last,
                         severity: Severity::Error,
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         message: "List should be followed by blank line".to_string(),
                         fix: Some(Fix {
                             range: line_index.line_col_to_byte_range_with_length(end_line + 1, 1, 0),
@@ -429,7 +415,7 @@ impl Rule for MD032BlanksAroundLists {
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
         let lines: Vec<&str> = content.lines().collect();
-        let line_index = LineIndex::new(content.to_string());
+        let line_index = &ctx.line_index;
 
         // Early return for empty content
         if lines.is_empty() {
@@ -442,7 +428,7 @@ impl Rule for MD032BlanksAroundLists {
             return Ok(Vec::new());
         }
 
-        self.perform_checks(ctx, &lines, &list_blocks, &line_index)
+        self.perform_checks(ctx, &lines, &list_blocks, line_index)
     }
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
@@ -450,7 +436,12 @@ impl Rule for MD032BlanksAroundLists {
     }
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        ctx.content.is_empty() || ctx.list_blocks.is_empty()
+        // Fast path: check if document likely has lists
+        if ctx.content.is_empty() || !ctx.likely_has_lists() {
+            return true;
+        }
+        // Verify list blocks actually exist
+        ctx.list_blocks.is_empty()
     }
 
     fn category(&self) -> RuleCategory {
@@ -461,33 +452,11 @@ impl Rule for MD032BlanksAroundLists {
         self
     }
 
-    fn default_config_section(&self) -> Option<(String, toml::Value)> {
-        let mut map = toml::map::Map::new();
-        map.insert(
-            "allow_after_headings".to_string(),
-            toml::Value::Boolean(self.allow_after_headings),
-        );
-        map.insert(
-            "allow_after_colons".to_string(),
-            toml::Value::Boolean(self.allow_after_colons),
-        );
-        Some((self.name().to_string(), toml::Value::Table(map)))
-    }
-
-    fn from_config(config: &crate::config::Config) -> Box<dyn Rule>
+    fn from_config(_config: &crate::config::Config) -> Box<dyn Rule>
     where
         Self: Sized,
     {
-        let allow_after_headings =
-            crate::config::get_rule_config_value::<bool>(config, "MD032", "allow_after_headings").unwrap_or(false); // Match markdownlint's stricter behavior
-
-        let allow_after_colons =
-            crate::config::get_rule_config_value::<bool>(config, "MD032", "allow_after_colons").unwrap_or(false); // Match markdownlint's stricter behavior
-
-        Box::new(MD032BlanksAroundLists {
-            allow_after_headings,
-            allow_after_colons,
-        })
+        Box::new(MD032BlanksAroundLists)
     }
 }
 
@@ -513,18 +482,14 @@ impl MD032BlanksAroundLists {
             if start_line > 1 {
                 let prev_line_actual_idx_0 = start_line - 2;
                 let prev_line_actual_idx_1 = start_line - 1;
-                let is_prev_excluded =
-                    ctx.is_in_code_block(prev_line_actual_idx_1) || ctx.is_in_front_matter(prev_line_actual_idx_1);
+                let is_prev_excluded = ctx
+                    .line_info(prev_line_actual_idx_1)
+                    .is_some_and(|info| info.in_code_block || info.in_front_matter);
                 let prev_prefix = BLOCKQUOTE_PREFIX_RE
                     .find(lines[prev_line_actual_idx_0])
                     .map_or(String::new(), |m| m.as_str().to_string());
 
-                let should_require = self.should_require_blank_line_before(
-                    lines[prev_line_actual_idx_0],
-                    ctx,
-                    prev_line_actual_idx_1,
-                    start_line,
-                );
+                let should_require = Self::should_require_blank_line_before(ctx, prev_line_actual_idx_1, start_line);
                 if !is_prev_excluded
                     && !is_blank_in_context(lines[prev_line_actual_idx_0])
                     && prev_prefix == *prefix
@@ -541,13 +506,20 @@ impl MD032BlanksAroundLists {
                 let line_after_block_content_str = lines[after_block_line_idx_0];
                 // Check if next line is excluded - in code block, front matter, or starts an indented code block
                 // Only exclude code fence lines if they're indented (part of list content)
-                let is_line_after_excluded = ctx.is_in_code_block(after_block_line_idx_1)
-                    || ctx.is_in_front_matter(after_block_line_idx_1)
+                let is_line_after_excluded = ctx
+                    .line_info(after_block_line_idx_1)
+                    .is_some_and(|info| info.in_code_block || info.in_front_matter)
                     || (after_block_line_idx_0 < ctx.lines.len()
                         && ctx.lines[after_block_line_idx_0].in_code_block
                         && ctx.lines[after_block_line_idx_0].indent >= 2
-                        && (ctx.lines[after_block_line_idx_0].content.trim().starts_with("```")
-                            || ctx.lines[after_block_line_idx_0].content.trim().starts_with("~~~")));
+                        && (ctx.lines[after_block_line_idx_0]
+                            .content(ctx.content)
+                            .trim()
+                            .starts_with("```")
+                            || ctx.lines[after_block_line_idx_0]
+                                .content(ctx.content)
+                                .trim()
+                                .starts_with("~~~")));
                 let after_prefix = BLOCKQUOTE_PREFIX_RE
                     .find(line_after_block_content_str)
                     .map_or(String::new(), |m| m.as_str().to_string());
@@ -602,13 +574,13 @@ mod tests {
     use crate::rule::Rule;
 
     fn lint(content: &str) -> Vec<LintWarning> {
-        let rule = MD032BlanksAroundLists::default();
+        let rule = MD032BlanksAroundLists;
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         rule.check(&ctx).expect("Lint check failed")
     }
 
     fn fix(content: &str) -> String {
-        let rule = MD032BlanksAroundLists::default();
+        let rule = MD032BlanksAroundLists;
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         rule.fix(&ctx).expect("Lint fix failed")
     }
@@ -1178,18 +1150,19 @@ mod tests {
     }
 
     #[test]
-    fn test_fix_with_windows_line_endings() {
-        let content = "Text\r\n- Item 1\r\n- Item 2\r\nText";
+    fn test_fix_with_normalized_line_endings() {
+        // In production, content is normalized to LF at I/O boundary
+        // Unit tests should use LF input to reflect actual runtime behavior
+        let content = "Text\n- Item 1\n- Item 2\nText";
         let warnings = lint(content);
-        assert_eq!(warnings.len(), 2, "Should detect issues with Windows line endings");
+        assert_eq!(warnings.len(), 2, "Should detect issues with normalized line endings");
 
         // Test that warnings have fixes
         check_warnings_have_fixes(content);
 
         let fixed_content = fix(content);
-        // Note: Our fix uses \n, which is standard for Rust string processing
         let expected = "Text\n\n- Item 1\n- Item 2\n\nText";
-        assert_eq!(fixed_content, expected, "Fix should handle Windows line endings");
+        assert_eq!(fixed_content, expected, "Fix should work with normalized LF content");
     }
 
     #[test]
