@@ -3,22 +3,16 @@
 //!
 //! See [docs/md033.md](../../docs/md033.md) for full documentation, configuration, and examples.
 
-use crate::rule::{LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
+use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::kramdown_utils::{is_kramdown_block_attribute, is_kramdown_extension};
 use crate::utils::range_utils::calculate_html_tag_range;
 use crate::utils::regex_cache::*;
-use lazy_static::lazy_static;
-use regex::Regex;
 use std::collections::HashSet;
+use std::sync::LazyLock;
 
 mod md033_config;
 use md033_config::MD033Config;
 
-lazy_static! {
-    // HTML/Markdown comment pattern (specific to MD033)
-    static ref HTML_COMMENT_PATTERN: Regex = Regex::new(r"<!--.*?-->").unwrap();
-}
-
 #[derive(Clone)]
 pub struct MD033NoInlineHtml {
     config: MD033Config,
@@ -164,6 +158,50 @@ impl MD033NoInlineHtml {
             || content.starts_with("mailto:")
     }
 
+    /// Calculate fix to remove HTML tags while keeping content
+    ///
+    /// For self-closing tags like `<br/>`, returns a single fix to remove the tag.
+    /// For paired tags like `<span>text</span>`, returns the replacement text (just the content).
+    ///
+    /// Returns (range, replacement_text) where range is the bytes to replace
+    /// and replacement_text is what to put there (content without tags, or empty for self-closing).
+    fn calculate_fix(
+        &self,
+        content: &str,
+        opening_tag: &str,
+        tag_byte_start: usize,
+    ) -> Option<(std::ops::Range<usize>, String)> {
+        // Check if it's a self-closing tag (ends with />)
+        if opening_tag.ends_with("/>") {
+            return Some((tag_byte_start..tag_byte_start + opening_tag.len(), String::new()));
+        }
+
+        // Extract tag name from opening tag (e.g., "<div>" -> "div", "<span class='x'>" -> "span")
+        let tag_name = opening_tag
+            .trim_start_matches('<')
+            .split(|c: char| c.is_whitespace() || c == '>' || c == '/')
+            .next()?
+            .to_lowercase();
+
+        // Build the closing tag pattern
+        let closing_tag = format!("</{tag_name}>");
+
+        // Search for the closing tag after the opening tag
+        let search_start = tag_byte_start + opening_tag.len();
+        if let Some(closing_pos) = content[search_start..].find(&closing_tag) {
+            let closing_byte_start = search_start + closing_pos;
+            let closing_byte_end = closing_byte_start + closing_tag.len();
+
+            // Extract the content between tags
+            let inner_content = &content[search_start..closing_byte_start];
+
+            return Some((tag_byte_start..closing_byte_end, inner_content.to_string()));
+        }
+
+        // If no closing tag found, just remove the opening tag
+        Some((tag_byte_start..tag_byte_start + opening_tag.len(), String::new()))
+    }
+
     /// Find HTML tags that span multiple lines
     fn find_multiline_html_tags(
         &self,
@@ -178,9 +216,8 @@ impl MD033NoInlineHtml {
         }
 
         // Simple approach: use regex to find patterns like <tagname and then look for closing >
-        lazy_static::lazy_static! {
-            static ref INCOMPLETE_TAG_START: regex::Regex = regex::Regex::new(r"(?i)<[a-zA-Z][^>]*$").unwrap();
-        }
+        static INCOMPLETE_TAG_START: LazyLock<regex::Regex> =
+            LazyLock::new(|| regex::Regex::new(r"(?i)<[a-zA-Z][^>]*$").unwrap());
 
         let lines: Vec<&str> = content.lines().collect();
 
@@ -188,7 +225,7 @@ impl MD033NoInlineHtml {
             let line_num = i + 1;
 
             // Skip code blocks and empty lines
-            if line.trim().is_empty() || ctx.is_in_code_block(line_num) {
+            if line.trim().is_empty() || ctx.line_info(line_num).is_some_and(|info| info.in_code_block) {
                 continue;
             }
 
@@ -218,7 +255,7 @@ impl MD033NoInlineHtml {
                     let next_line_num = j + 1;
 
                     // Stop if we hit a code block
-                    if ctx.is_in_code_block(next_line_num) {
+                    if ctx.line_info(next_line_num).is_some_and(|info| info.in_code_block) {
                         break;
                     }
 
@@ -246,7 +283,7 @@ impl MD033NoInlineHtml {
                             && !self.is_url_in_angle_brackets(final_tag)
                             && !self.is_tag_allowed(final_tag)
                             && !skip_mkdocs_markdown
-                            && HTML_TAG_FINDER.is_match(final_tag)
+                            && HTML_OPENING_TAG_FINDER.is_match(final_tag)
                         {
                             // Check for duplicates (avoid flagging the same position twice)
                             let already_warned =
@@ -260,12 +297,12 @@ impl MD033NoInlineHtml {
                                     incomplete_match.len(),
                                 );
                                 warnings.push(LintWarning {
-                                    rule_name: Some(self.name()),
+                                    rule_name: Some(self.name().to_string()),
                                     line: start_line,
                                     column: start_col,
                                     end_line,
                                     end_column: end_col,
-                                    message: format!("HTML tag found: {final_tag} (use Markdown syntax instead)"),
+                                    message: format!("HTML tag found: {final_tag}"),
                                     severity: Severity::Warning,
                                     fix: None,
                                 });
@@ -291,7 +328,7 @@ impl Rule for MD033NoInlineHtml {
         let content = ctx.content;
 
         // Early return: if no HTML tags at all, skip processing
-        if content.is_empty() || !has_html_tags(content) {
+        if content.is_empty() || !ctx.likely_has_html() {
             return Ok(Vec::new());
         }
 
@@ -341,7 +378,7 @@ impl Rule for MD033NoInlineHtml {
             if line.trim().is_empty() {
                 continue;
             }
-            if ctx.is_in_code_block(line_num) {
+            if ctx.line_info(line_num).is_some_and(|info| info.in_code_block) {
                 continue;
             }
             // Skip lines that are indented code blocks (4+ spaces or tab) per CommonMark spec
@@ -363,15 +400,43 @@ impl Rule for MD033NoInlineHtml {
                 continue;
             }
 
-            // Find all HTML tags in the line using regex
-            for tag_match in HTML_TAG_FINDER.find_iter(line) {
+            // Find all HTML opening tags in the line using regex
+            for tag_match in HTML_OPENING_TAG_FINDER.find_iter(line) {
                 let tag = tag_match.as_str();
 
-                // Skip HTML comments
+                // Calculate byte offset for the tag in the entire content
+                let line_byte_offset: usize = content
+                    .lines()
+                    .take(line_num - 1)
+                    .map(|l| l.len() + 1) // +1 for newline
+                    .sum();
+                let tag_byte_start = line_byte_offset + tag_match.start();
+
+                // Skip HTML tags inside HTML comments
+                if ctx.is_in_html_comment(tag_byte_start) {
+                    continue;
+                }
+
+                // Skip HTML comments themselves
                 if self.is_html_comment(tag) {
                     continue;
                 }
 
+                // Skip JSX components in MDX files (e.g., <Chart />, <MyComponent>)
+                // JSX components start with uppercase letter
+                if ctx.flavor.supports_jsx() {
+                    // Extract tag name (remove angle brackets, slashes, and attributes)
+                    let tag_clean = tag.trim_start_matches('<').trim_start_matches('/');
+                    let tag_name = tag_clean
+                        .split(|c: char| c.is_whitespace() || c == '>' || c == '/')
+                        .next()
+                        .unwrap_or("");
+
+                    if tag_name.chars().next().is_some_and(|c| c.is_uppercase()) {
+                        continue;
+                    }
+                }
+
                 // Skip likely programming type annotations
                 if self.is_likely_type_annotation(tag) {
                     continue;
@@ -406,15 +471,21 @@ impl Rule for MD033NoInlineHtml {
                 // Report each HTML tag individually (true markdownlint compatibility)
                 let (start_line, start_col, end_line, end_col) =
                     calculate_html_tag_range(line_num, line, tag_match.start(), tag_match.len());
+
+                // Calculate fix to remove HTML tags but keep content
+                let fix = self
+                    .calculate_fix(content, tag, tag_byte_start)
+                    .map(|(range, replacement)| Fix { range, replacement });
+
                 warnings.push(LintWarning {
-                    rule_name: Some(self.name()),
+                    rule_name: Some(self.name().to_string()),
                     line: start_line,
                     column: start_col,
                     end_line,
                     end_column: end_col,
-                    message: format!("Inline HTML found: {tag} (use Markdown syntax instead)"),
+                    message: format!("Inline HTML found: {tag}"),
                     severity: Severity::Warning,
-                    fix: None,
+                    fix,
                 });
             }
         }
@@ -441,8 +512,7 @@ impl Rule for MD033NoInlineHtml {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        let content = ctx.content;
-        content.is_empty() || !has_html_tags(content)
+        ctx.content.is_empty() || !ctx.likely_has_html()
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -478,10 +548,9 @@ mod tests {
         let content = "<div>Some content</div>";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        // Reports one warning per HTML tag (true markdownlint compatibility)
-        assert_eq!(result.len(), 2); // <div> and </div>
+        // Only reports opening tags, not closing tags
+        assert_eq!(result.len(), 1); // Only <div>, not </div>
         assert!(result[0].message.starts_with("Inline HTML found: <div>"));
-        assert!(result[1].message.starts_with("Inline HTML found: </div>"));
     }
 
     #[test]
@@ -490,24 +559,10 @@ mod tests {
         let content = "<DiV>Some <B>content</B></dIv>";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        // Reports one warning per HTML tag (true markdownlint compatibility)
-        assert_eq!(result.len(), 4); // <DiV>, <B>, </B>, </dIv>
-        assert_eq!(
-            result[0].message,
-            "Inline HTML found: <DiV> (use Markdown syntax instead)"
-        );
-        assert_eq!(
-            result[1].message,
-            "Inline HTML found: <B> (use Markdown syntax instead)"
-        );
-        assert_eq!(
-            result[2].message,
-            "Inline HTML found: </B> (use Markdown syntax instead)"
-        );
-        assert_eq!(
-            result[3].message,
-            "Inline HTML found: </dIv> (use Markdown syntax instead)"
-        );
+        // Only reports opening tags, not closing tags
+        assert_eq!(result.len(), 2); // <DiV>, <B> (not </B>, </dIv>)
+        assert_eq!(result[0].message, "Inline HTML found: <DiV>");
+        assert_eq!(result[1].message, "Inline HTML found: <B>");
     }
 
     #[test]
@@ -516,30 +571,16 @@ mod tests {
         let content = "<div>Allowed</div><p>Not allowed</p><br/>";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        // Only warnings for non-allowed tags (<p> and </p>, div and br are allowed)
-        assert_eq!(result.len(), 2);
-        assert_eq!(
-            result[0].message,
-            "Inline HTML found: <p> (use Markdown syntax instead)"
-        );
-        assert_eq!(
-            result[1].message,
-            "Inline HTML found: </p> (use Markdown syntax instead)"
-        );
+        // Only warnings for non-allowed opening tags (<p> only, div and br are allowed)
+        assert_eq!(result.len(), 1);
+        assert_eq!(result[0].message, "Inline HTML found: <p>");
 
         // Test case-insensitivity of allowed tags
         let content2 = "<DIV>Allowed</DIV><P>Not allowed</P><BR/>";
         let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard);
         let result2 = rule.check(&ctx2).unwrap();
-        assert_eq!(result2.len(), 2); // <P> and </P> flagged
-        assert_eq!(
-            result2[0].message,
-            "Inline HTML found: <P> (use Markdown syntax instead)"
-        );
-        assert_eq!(
-            result2[1].message,
-            "Inline HTML found: </P> (use Markdown syntax instead)"
-        );
+        assert_eq!(result2.len(), 1); // Only <P> flagged
+        assert_eq!(result2[0].message, "Inline HTML found: <P>");
     }
 
     #[test]
@@ -548,16 +589,9 @@ mod tests {
         let content = "<!-- This is a comment --> <p>Not a comment</p>";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        // Should detect warnings for HTML tags (comments are skipped)
-        assert_eq!(result.len(), 2); // <p> and </p>
-        assert_eq!(
-            result[0].message,
-            "Inline HTML found: <p> (use Markdown syntax instead)"
-        );
-        assert_eq!(
-            result[1].message,
-            "Inline HTML found: </p> (use Markdown syntax instead)"
-        );
+        // Should detect warnings for HTML opening tags (comments are skipped, closing tags not reported)
+        assert_eq!(result.len(), 1); // Only <p>
+        assert_eq!(result[0].message, "Inline HTML found: <p>");
     }
 
     #[test]
@@ -568,24 +602,14 @@ mod tests {
         let result = rule.check(&ctx).unwrap();
         // The <div> in the URL should be detected as HTML (not skipped)
         assert_eq!(result.len(), 1);
-        assert_eq!(
-            result[0].message,
-            "Inline HTML found: <div> (use Markdown syntax instead)"
-        );
+        assert_eq!(result[0].message, "Inline HTML found: <div>");
 
         let content2 = "[Link <a>text</a>](url)";
         let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard);
         let result2 = rule.check(&ctx2).unwrap();
-        // Reports one warning per HTML tag (true markdownlint compatibility)
-        assert_eq!(result2.len(), 2); // <a> and </a>
-        assert_eq!(
-            result2[0].message,
-            "Inline HTML found: <a> (use Markdown syntax instead)"
-        );
-        assert_eq!(
-            result2[1].message,
-            "Inline HTML found: </a> (use Markdown syntax instead)"
-        );
+        // Only reports opening tags
+        assert_eq!(result2.len(), 1); // Only <a>
+        assert_eq!(result2[0].message, "Inline HTML found: <a>");
     }
 
     #[test]
@@ -604,16 +628,9 @@ mod tests {
         let content = "```html\n<div>Code</div>\n```\n<div>Not code</div>";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        // Reports one warning per HTML tag (true markdownlint compatibility)
-        assert_eq!(result.len(), 2); // <div> and </div> outside code block
-        assert_eq!(
-            result[0].message,
-            "Inline HTML found: <div> (use Markdown syntax instead)"
-        );
-        assert_eq!(
-            result[1].message,
-            "Inline HTML found: </div> (use Markdown syntax instead)"
-        );
+        // Only reports opening tags outside code block
+        assert_eq!(result.len(), 1); // Only <div> outside code block
+        assert_eq!(result[0].message, "Inline HTML found: <div>");
     }
 
     #[test]
@@ -624,9 +641,123 @@ mod tests {
         let result = rule.check(&ctx).unwrap();
         // Should detect <br/> outside code span, but not tags inside code span
         assert_eq!(result.len(), 1);
-        assert_eq!(
-            result[0].message,
-            "Inline HTML found: <br/> (use Markdown syntax instead)"
-        );
+        assert_eq!(result[0].message, "Inline HTML found: <br/>");
+    }
+
+    #[test]
+    fn test_md033_issue_90_code_span_with_diff_block() {
+        // Test for issue #90: inline code span followed by diff code block
+        let rule = MD033NoInlineHtml::default();
+        let content = r#"# Heading
+
+`<env>`
+
+```diff
+- this
++ that
+```"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        // Should NOT detect <env> as HTML since it's inside backticks
+        assert_eq!(result.len(), 0, "Should not report HTML tags inside code spans");
+    }
+
+    #[test]
+    fn test_md033_multiple_code_spans_with_angle_brackets() {
+        // Test multiple code spans on same line
+        let rule = MD033NoInlineHtml::default();
+        let content = "`<one>` and `<two>` and `<three>` are all code spans";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 0, "Should not report HTML tags inside any code spans");
+    }
+
+    #[test]
+    fn test_md033_nested_angle_brackets_in_code_span() {
+        // Test nested angle brackets
+        let rule = MD033NoInlineHtml::default();
+        let content = "Text with `<<nested>>` brackets";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 0, "Should handle nested angle brackets in code spans");
+    }
+
+    #[test]
+    fn test_md033_code_span_at_end_before_code_block() {
+        // Test code span at end of line before code block
+        let rule = MD033NoInlineHtml::default();
+        let content = "Testing `<test>`\n```\ncode here\n```";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 0, "Should handle code span before code block");
+    }
+
+    #[test]
+    fn test_md033_quick_fix_inline_tag() {
+        // Test Quick Fix for inline HTML tags - keeps content, removes tags
+        let rule = MD033NoInlineHtml::default();
+        let content = "This has <span>inline text</span> that should keep content.";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        assert_eq!(result.len(), 1, "Should find one HTML tag");
+        assert!(result[0].fix.is_some(), "Should have a fix");
+
+        let fix = result[0].fix.as_ref().unwrap();
+        assert_eq!(&content[fix.range.clone()], "<span>inline text</span>");
+        assert_eq!(fix.replacement, "inline text");
+    }
+
+    #[test]
+    fn test_md033_quick_fix_multiline_tag() {
+        // Test Quick Fix for multiline HTML tags - keeps content
+        let rule = MD033NoInlineHtml::default();
+        let content = "<div>\nBlock content\n</div>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        assert_eq!(result.len(), 1, "Should find one HTML tag");
+        assert!(result[0].fix.is_some(), "Should have a fix");
+
+        let fix = result[0].fix.as_ref().unwrap();
+        assert_eq!(&content[fix.range.clone()], "<div>\nBlock content\n</div>");
+        assert_eq!(fix.replacement, "\nBlock content\n");
+    }
+
+    #[test]
+    fn test_md033_quick_fix_self_closing_tag() {
+        // Test Quick Fix for self-closing tags - removes tag (no content)
+        let rule = MD033NoInlineHtml::default();
+        let content = "Self-closing: <br/>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        assert_eq!(result.len(), 1, "Should find one HTML tag");
+        assert!(result[0].fix.is_some(), "Should have a fix");
+
+        let fix = result[0].fix.as_ref().unwrap();
+        assert_eq!(&content[fix.range.clone()], "<br/>");
+        assert_eq!(fix.replacement, "");
+    }
+
+    #[test]
+    fn test_md033_quick_fix_multiple_tags() {
+        // Test Quick Fix with multiple HTML tags - keeps content for both
+        let rule = MD033NoInlineHtml::default();
+        let content = "<span>first</span> and <strong>second</strong>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        assert_eq!(result.len(), 2, "Should find two HTML tags");
+        assert!(result[0].fix.is_some(), "First tag should have a fix");
+        assert!(result[1].fix.is_some(), "Second tag should have a fix");
+
+        let fix1 = result[0].fix.as_ref().unwrap();
+        assert_eq!(&content[fix1.range.clone()], "<span>first</span>");
+        assert_eq!(fix1.replacement, "first");
+
+        let fix2 = result[1].fix.as_ref().unwrap();
+        assert_eq!(&content[fix2.range.clone()], "<strong>second</strong>");
+        assert_eq!(fix2.replacement, "second");
     }
 }
