@@ -3,7 +3,7 @@
 //!
 //! See [docs/md035.md](../../docs/md035.md) for full documentation, configuration, and examples.
 
-use crate::utils::range_utils::{LineIndex, calculate_line_range};
+use crate::utils::range_utils::calculate_line_range;
 
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
 use crate::utils::regex_cache::{
@@ -58,15 +58,15 @@ impl MD035HRStyle {
         (is_dash_line || is_equals_line) && prev_line_has_content
     }
 
-    /// Find the most prevalent HR style in the document (excluding setext headings and code blocks)
+    /// Find the most prevalent HR style in the document (excluding setext headings, code blocks, and frontmatter)
     fn most_prevalent_hr_style(lines: &[&str], ctx: &crate::lint_context::LintContext) -> Option<String> {
         use std::collections::HashMap;
         let mut counts: HashMap<&str, usize> = HashMap::new();
         let mut order: Vec<&str> = Vec::new();
         for (i, line) in lines.iter().enumerate() {
-            // Skip if this line is in a code block
-            if let Some(line_info) = ctx.line_info(i + 1)
-                && line_info.in_code_block
+            // Skip if this line is in frontmatter or a code block (using pre-computed LineInfo)
+            if let Some(line_info) = ctx.lines.get(i)
+                && (line_info.in_front_matter || line_info.in_code_block)
             {
                 continue;
             }
@@ -104,7 +104,7 @@ impl Rule for MD035HRStyle {
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
 
         let mut warnings = Vec::new();
         let lines: Vec<&str> = content.lines().collect();
@@ -117,9 +117,9 @@ impl Rule for MD035HRStyle {
         };
 
         for (i, line) in lines.iter().enumerate() {
-            // Skip if this line is in a code block or code span
-            if let Some(line_info) = ctx.line_info(i + 1)
-                && line_info.in_code_block
+            // Skip if this line is in frontmatter or a code block (using pre-computed LineInfo)
+            if let Some(line_info) = ctx.lines.get(i)
+                && (line_info.in_front_matter || line_info.in_code_block)
             {
                 continue;
             }
@@ -139,7 +139,7 @@ impl Rule for MD035HRStyle {
                     let (start_line, start_col, end_line, end_col) = calculate_line_range(i + 1, line);
 
                     warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         line: start_line,
                         column: start_col,
                         end_line,
@@ -164,7 +164,7 @@ impl Rule for MD035HRStyle {
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
 
         let mut result = Vec::new();
         let lines: Vec<&str> = content.lines().collect();
@@ -177,9 +177,9 @@ impl Rule for MD035HRStyle {
         };
 
         for (i, line) in lines.iter().enumerate() {
-            // Skip if this line is in a code block or code span
-            if let Some(line_info) = ctx.line_info(i + 1)
-                && line_info.in_code_block
+            // Skip if this line is in frontmatter or a code block (using pre-computed LineInfo)
+            if let Some(line_info) = ctx.lines.get(i)
+                && (line_info.in_front_matter || line_info.in_code_block)
             {
                 result.push(line.to_string());
                 continue;
@@ -200,7 +200,12 @@ impl Rule for MD035HRStyle {
             }
         }
 
-        Ok(result.join("\n"))
+        let mut fixed = result.join("\n");
+        // Preserve trailing newline if original content had one
+        if content.ends_with('\n') && !fixed.ends_with('\n') {
+            fixed.push('\n');
+        }
+        Ok(fixed)
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -209,8 +214,8 @@ impl Rule for MD035HRStyle {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        ctx.content.is_empty()
-            || (!ctx.content.contains("---") && !ctx.content.contains("***") && !ctx.content.contains("___"))
+        // HR can use -, *, or _
+        ctx.content.is_empty() || (!ctx.has_char('-') && !ctx.has_char('*') && !ctx.has_char('_'))
     }
 
     fn default_config_section(&self) -> Option<(String, toml::Value)> {
