@@ -1,6 +1,7 @@
 /// Rule MD037: No spaces around emphasis markers
 ///
 /// See [docs/md037.md](../../docs/md037.md) for full documentation, configuration, and examples.
+use crate::filtered_lines::FilteredLinesExt;
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::emphasis_utils::{
     EmphasisSpan, find_emphasis_markers, find_emphasis_spans, has_doc_patterns, replace_inline_code,
@@ -8,15 +9,6 @@ use crate::utils::emphasis_utils::{
 use crate::utils::kramdown_utils::has_span_ial;
 use crate::utils::regex_cache::UNORDERED_LIST_MARKER_REGEX;
 use crate::utils::skip_context::{is_in_html_comment, is_in_math_context, is_in_table_cell};
-use lazy_static::lazy_static;
-use regex::Regex;
-
-lazy_static! {
-    // Reference definition pattern - matches [ref]: url "title"
-    static ref REF_DEF_REGEX: Regex = Regex::new(
-        r#"(?m)^[ ]{0,3}\[([^\]]+)\]:\s*([^\s]+)(?:\s+(?:"([^"]*)"|'([^']*)'))?$"#
-    ).unwrap();
-}
 
 /// Check if an emphasis span has spacing issues that should be flagged
 #[inline]
@@ -51,14 +43,8 @@ impl MD037NoSpaceInEmphasis {
             }
         }
 
-        // Check reference definitions [ref]: url "title" using regex pattern
-        for m in REF_DEF_REGEX.find_iter(ctx.content) {
-            if m.start() <= byte_pos && byte_pos < m.end() {
-                return true;
-            }
-        }
-
-        false
+        // Check reference definitions [ref]: url "title" using pre-computed data (O(1) vs O(n))
+        ctx.is_in_reference_def(byte_pos)
     }
 }
 
@@ -80,30 +66,28 @@ impl Rule for MD037NoSpaceInEmphasis {
             return Ok(vec![]);
         }
 
+        // Create LineIndex for correct byte position calculations across all line ending types
+        let line_index = &ctx.line_index;
+
         let mut warnings = Vec::new();
 
-        // Process the content line by line
-        for (line_num, line) in content.lines().enumerate() {
-            // Skip if in code block or front matter
-            if ctx.is_in_code_block(line_num + 1) || ctx.is_in_front_matter(line_num + 1) {
-                continue;
-            }
-
+        // Process content lines, automatically skipping front matter and code blocks
+        for line in ctx.filtered_lines().skip_front_matter().skip_code_blocks() {
             // Skip if the line doesn't contain any emphasis markers
-            if !line.contains('*') && !line.contains('_') {
+            if !line.content.contains('*') && !line.content.contains('_') {
                 continue;
             }
 
             // Check for emphasis issues on the original line
-            self.check_line_for_emphasis_issues_fast(line, line_num + 1, &mut warnings);
+            self.check_line_for_emphasis_issues_fast(line.content, line.line_num, &mut warnings);
         }
 
         // Filter out warnings for emphasis markers that are inside links, HTML comments, or math
         let mut filtered_warnings = Vec::new();
-        let mut line_start_pos = 0;
 
-        for (line_idx, line) in content.lines().enumerate() {
+        for (line_idx, _line) in content.lines().enumerate() {
             let line_num = line_idx + 1;
+            let line_start_pos = line_index.get_line_start_byte(line_num).unwrap_or(0);
 
             // Find warnings for this line
             for warning in &warnings {
@@ -121,8 +105,6 @@ impl Rule for MD037NoSpaceInEmphasis {
                     }
                 }
             }
-
-            line_start_pos += line.len() + 1; // +1 for newline
         }
 
         Ok(filtered_warnings)
@@ -145,13 +127,8 @@ impl Rule for MD037NoSpaceInEmphasis {
             return Ok(content.to_string());
         }
 
-        // Get all line positions to make it easier to apply fixes by warning
-        let mut line_positions = Vec::new();
-        let mut pos = 0;
-        for line in content.lines() {
-            line_positions.push(pos);
-            pos += line.len() + 1; // +1 for the newline
-        }
+        // Create LineIndex for correct byte position calculations across all line ending types
+        let line_index = &ctx.line_index;
 
         // Apply fixes
         let mut result = content.to_string();
@@ -164,7 +141,7 @@ impl Rule for MD037NoSpaceInEmphasis {
         for warning in sorted_warnings {
             if let Some(fix) = &warning.fix {
                 // Calculate the absolute position in the file
-                let line_start = line_positions.get(warning.line - 1).copied().unwrap_or(0);
+                let line_start = line_index.get_line_start_byte(warning.line).unwrap_or(0);
                 let abs_start = line_start + warning.column - 1;
                 let abs_end = abs_start + (fix.range.end - fix.range.start);
 
@@ -192,8 +169,7 @@ impl Rule for MD037NoSpaceInEmphasis {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        let content = ctx.content;
-        content.is_empty() || (!content.contains('*') && !content.contains('_'))
+        ctx.content.is_empty() || !ctx.likely_has_emphasis()
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -328,7 +304,7 @@ impl MD037NoSpaceInEmphasis {
                 let fixed_text = format!("{marker_str}{trimmed_content}{marker_str}");
 
                 let warning = LintWarning {
-                    rule_name: Some(self.name()),
+                    rule_name: Some(self.name().to_string()),
                     message: format!("Spaces inside emphasis markers: {full_text:?}"),
                     line: line_num,
                     column: offset + full_start + 1, // +1 because columns are 1-indexed
