@@ -24,109 +24,14 @@ use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, S
 ///
 /// Note: Code spans containing backticks (e.g., `` `backticks` inside ``) are not flagged
 /// to avoid breaking nested backtick structures used to display backticks in documentation.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Default)]
 pub struct MD038NoSpaceInCode {
     pub enabled: bool,
-    /// Allow leading/trailing spaces in code spans when they improve readability
-    pub allow_intentional_spaces: bool,
-    /// Allow spaces around single characters (e.g., ` y ` for visibility)
-    pub allow_single_char_spaces: bool,
-    /// Allow spaces in command examples (heuristic: contains common shell indicators)
-    pub allow_command_spaces: bool,
-}
-
-impl Default for MD038NoSpaceInCode {
-    fn default() -> Self {
-        Self::new()
-    }
 }
 
 impl MD038NoSpaceInCode {
     pub fn new() -> Self {
-        Self {
-            enabled: true,
-            allow_intentional_spaces: true, // More lenient by default
-            allow_single_char_spaces: true,
-            allow_command_spaces: true,
-        }
-    }
-
-    pub fn strict() -> Self {
-        Self {
-            enabled: true,
-            allow_intentional_spaces: false,
-            allow_single_char_spaces: false,
-            allow_command_spaces: false,
-        }
-    }
-
-    /// Determine if spaces in a code span should be allowed based on content heuristics
-    fn should_allow_spaces(&self, code_content: &str, trimmed: &str) -> bool {
-        // If intentional spaces are globally allowed, apply heuristics
-        if self.allow_intentional_spaces {
-            // Allow single character with spaces for visibility (e.g., ` y `, ` * `)
-            if self.allow_single_char_spaces && trimmed.len() == 1 {
-                return true;
-            }
-
-            // Allow command examples with spaces
-            if self.allow_command_spaces && self.looks_like_command(trimmed) {
-                return true;
-            }
-
-            // Allow spaces around variable references or file patterns
-            if self.looks_like_variable_or_pattern(trimmed) {
-                return true;
-            }
-
-            // Allow if spaces improve readability for complex content
-            if self.spaces_improve_readability(code_content, trimmed) {
-                return true;
-            }
-        }
-
-        false
-    }
-
-    /// Check if content looks like a shell command that benefits from spaces
-    fn looks_like_command(&self, content: &str) -> bool {
-        // Common command patterns - check case-insensitive prefixes
-        const COMMAND_PREFIXES: &[&str] = &[
-            "git ", "npm ", "cargo ", "docker ", "kubectl ", "pip ", "yarn ", "sudo ", "chmod ", "chown ", "ls ",
-            "cd ", "mkdir ", "rm ", "cp ", "mv ", "cat ", "grep ", "find ", "awk ", "sed ", "rumdl ",
-        ];
-
-        // Check if content starts with any command (case-insensitive)
-        // Use iterator with early return to avoid allocating lowercase string unless needed
-        let needs_lowercase_check = COMMAND_PREFIXES.iter().any(|&cmd| {
-            content.len() >= cmd.len() && content.as_bytes()[..cmd.len()].eq_ignore_ascii_case(cmd.as_bytes())
-        });
-
-        needs_lowercase_check
-            || content.contains(" -") // Commands with flags
-            || content.contains(" --") // Commands with long flags
-    }
-
-    /// Check if content looks like a variable reference or file pattern
-    fn looks_like_variable_or_pattern(&self, content: &str) -> bool {
-        // Variable patterns: $VAR, ${VAR}, %VAR%, etc.
-        content.starts_with('$')
-            || content.starts_with('%') && content.ends_with('%')
-            || (content.contains("*") && content.len() > 3) // File patterns like *.txt (must be substantial)
-            || (content.contains("?") && content.len() > 3 && content.contains("."))
-        // File patterns like file?.txt
-    }
-
-    /// Check if spaces improve readability for complex content
-    fn spaces_improve_readability(&self, _code_content: &str, trimmed: &str) -> bool {
-        // Complex content that benefits from spacing - be more conservative
-        trimmed.len() >= 20 // Only longer content might benefit from spacing
-            || trimmed.contains("://") // URLs
-            || trimmed.contains("->") // Arrows or operators
-            || trimmed.contains("=>") // Lambda arrows
-            || trimmed.contains("&&") || trimmed.contains("||") // Boolean operators
-            || (trimmed.chars().filter(|c| c.is_ascii_punctuation()).count() as f64 / trimmed.len() as f64) > 0.4
-        // Higher punctuation density threshold
+        Self { enabled: true }
     }
 
     /// Check if a code span is likely part of a nested backtick structure
@@ -155,7 +60,7 @@ impl MD038NoSpaceInCode {
             return false;
         }
 
-        let line_content = &ctx.lines[line_idx].content;
+        let line_content = &ctx.lines[line_idx].content(ctx.content);
 
         // For each pair of adjacent code spans, check what's between them
         for (_, other_span) in &same_line_spans {
@@ -224,19 +129,24 @@ impl Rule for MD038NoSpaceInCode {
                     continue;
                 }
 
+                // Skip inline R code in Quarto/RMarkdown: `r expression`
+                // This is a legitimate pattern where space is required after 'r'
+                if ctx.flavor == crate::config::MarkdownFlavor::Quarto
+                    && trimmed.starts_with('r')
+                    && trimmed.len() > 1
+                    && trimmed.chars().nth(1).is_some_and(|c| c.is_whitespace())
+                {
+                    continue;
+                }
+
                 // Check if this might be part of a nested backtick structure
                 // by looking for other code spans nearby that might indicate nesting
                 if self.is_likely_nested_backticks(ctx, i) {
                     continue;
                 }
 
-                // Check if spaces are allowed in this context
-                if self.should_allow_spaces(code_content, trimmed) {
-                    continue;
-                }
-
                 warnings.push(LintWarning {
-                    rule_name: Some(self.name()),
+                    rule_name: Some(self.name().to_string()),
                     line: code_span.line,
                     column: code_span.start_col + 1, // Convert to 1-indexed
                     end_line: code_span.line,
@@ -295,49 +205,18 @@ impl Rule for MD038NoSpaceInCode {
 
     /// Check if content is likely to have code spans
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        !ctx.content.contains('`')
+        !ctx.likely_has_code()
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
         self
     }
 
-    fn default_config_section(&self) -> Option<(String, toml::Value)> {
-        let mut map = toml::map::Map::new();
-        map.insert(
-            "allow_intentional_spaces".to_string(),
-            toml::Value::Boolean(self.allow_intentional_spaces),
-        );
-        map.insert(
-            "allow_single_char_spaces".to_string(),
-            toml::Value::Boolean(self.allow_single_char_spaces),
-        );
-        map.insert(
-            "allow_command_spaces".to_string(),
-            toml::Value::Boolean(self.allow_command_spaces),
-        );
-        Some((self.name().to_string(), toml::Value::Table(map)))
-    }
-
-    fn from_config(config: &crate::config::Config) -> Box<dyn Rule>
+    fn from_config(_config: &crate::config::Config) -> Box<dyn Rule>
     where
         Self: Sized,
     {
-        let allow_intentional_spaces =
-            crate::config::get_rule_config_value::<bool>(config, "MD038", "allow_intentional_spaces").unwrap_or(true); // Default to true for better UX
-
-        let allow_single_char_spaces =
-            crate::config::get_rule_config_value::<bool>(config, "MD038", "allow_single_char_spaces").unwrap_or(true);
-
-        let allow_command_spaces =
-            crate::config::get_rule_config_value::<bool>(config, "MD038", "allow_command_spaces").unwrap_or(true);
-
-        Box::new(MD038NoSpaceInCode {
-            enabled: true,
-            allow_intentional_spaces,
-            allow_single_char_spaces,
-            allow_command_spaces,
-        })
+        Box::new(MD038NoSpaceInCode { enabled: true })
     }
 }
 
@@ -375,18 +254,11 @@ mod tests {
             "This is `code` in a sentence.",
             "This is a `longer code span` in a sentence.",
             "This is `code with internal spaces` which is fine.",
-            "This is`` code with double backticks`` which is also fine.",
             "Code span at `end of line`",
             "`Start of line` code span",
             "Multiple `code spans` in `one line` are fine",
             "Code span with `symbols: !@#$%^&*()`",
             "Empty code span `` is technically valid",
-            // New cases that should be allowed with lenient settings
-            "Type ` y ` to confirm.",                       // Single character with spaces
-            "Use ` git commit -m \"message\" ` to commit.", // Command with spaces
-            "The variable ` $HOME ` contains home path.",   // Variable reference
-            "The pattern ` *.txt ` matches text files.",    // File pattern
-            "URL example ` https://example.com/very/long/path?query=value&more=params ` here.", // Complex long URL
         ];
         for case in valid_cases {
             let ctx = crate::lint_context::LintContext::new(case, crate::config::MarkdownFlavor::Standard);
@@ -398,29 +270,16 @@ mod tests {
     #[test]
     fn test_md038_invalid() {
         let rule = MD038NoSpaceInCode::new();
-        // Cases that should still be flagged even with lenient settings
+        // All spaces should be flagged (matching markdownlint behavior)
         let invalid_cases = vec![
-            "This is ` random word ` with unnecessary spaces.", // Not a command/variable/single char
-            "Text with ` plain text ` should be flagged.",      // Just plain text with spaces
-            "Code with ` just code ` here.",                    // Simple code with spaces
-            "Multiple ` word ` spans with ` text ` in one line.", // Multiple simple cases
-        ];
-        for case in invalid_cases {
-            let ctx = crate::lint_context::LintContext::new(case, crate::config::MarkdownFlavor::Standard);
-            let result = rule.check(&ctx).unwrap();
-            assert!(!result.is_empty(), "Invalid case should have warnings: {case}");
-        }
-    }
-
-    #[test]
-    fn test_md038_strict_mode() {
-        let rule = MD038NoSpaceInCode::strict();
-        // In strict mode, ALL spaces should be flagged
-        let invalid_cases = vec![
-            "Type ` y ` to confirm.",                       // Single character with spaces
-            "Use ` git commit -m \"message\" ` to commit.", // Command with spaces
-            "The variable ` $HOME ` contains home path.",   // Variable reference
-            "The pattern ` *.txt ` matches text files.",    // File pattern
+            "Type ` y ` to confirm.",
+            "Use ` git commit -m \"message\" ` to commit.",
+            "The variable ` $HOME ` contains home path.",
+            "The pattern ` *.txt ` matches text files.",
+            "This is ` random word ` with unnecessary spaces.",
+            "Text with ` plain text ` should be flagged.",
+            "Code with ` just code ` here.",
+            "Multiple ` word ` spans with ` text ` in one line.",
             "This is ` code` with leading space.",
             "This is `code ` with trailing space.",
             "This is ` code ` with both leading and trailing space.",
@@ -428,7 +287,7 @@ mod tests {
         for case in invalid_cases {
             let ctx = crate::lint_context::LintContext::new(case, crate::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
-            assert!(!result.is_empty(), "Strict mode should flag all spaces: {case}");
+            assert!(!result.is_empty(), "Invalid case should have warnings: {case}");
         }
     }
 
@@ -489,15 +348,41 @@ mod tests {
 
     #[test]
     fn test_nested_backtick_detection() {
-        let rule = MD038NoSpaceInCode::strict();
+        let rule = MD038NoSpaceInCode::new();
 
-        // In strict mode, should_allow_spaces returns false, but the check method
-        // will skip code spans with backticks anyway
-        assert!(!rule.should_allow_spaces(" plain text ", "plain text"));
+        // Test that code spans with backticks are skipped
+        let content = "Code with `` `backticks` inside `` should not be flagged";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Code spans with backticks should be skipped");
+    }
 
-        // Test with lenient mode
-        let lenient_rule = MD038NoSpaceInCode::new();
-        assert!(lenient_rule.should_allow_spaces(" y ", "y")); // Single char
-        assert!(!lenient_rule.should_allow_spaces(" plain text ", "plain text"));
+    #[test]
+    fn test_quarto_inline_r_code() {
+        // Test that Quarto-specific R code exception works
+        let rule = MD038NoSpaceInCode::new();
+
+        // Test inline R code - should NOT trigger warning in Quarto flavor
+        // The key pattern is "r " followed by code
+        let content = r#"The result is `r nchar("test")` which equals 4."#;
+
+        // Quarto flavor should allow R code
+        let ctx_quarto = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Quarto);
+        let result_quarto = rule.check(&ctx_quarto).unwrap();
+        assert!(
+            result_quarto.is_empty(),
+            "Quarto inline R code should not trigger warnings. Got {} warnings",
+            result_quarto.len()
+        );
+
+        // Test that other code with spaces still gets flagged in Quarto
+        let content_other = "This has ` plain text ` with spaces.";
+        let ctx_other = crate::lint_context::LintContext::new(content_other, crate::config::MarkdownFlavor::Quarto);
+        let result_other = rule.check(&ctx_other).unwrap();
+        assert_eq!(
+            result_other.len(),
+            1,
+            "Quarto should still flag non-R code spans with improper spaces"
+        );
     }
 }
