@@ -1,15 +1,8 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
-use lazy_static::lazy_static;
-use regex::Regex;
+use crate::utils::regex_cache::get_cached_regex;
 
-lazy_static! {
-    // Pre-compiled regex patterns for performance - using DOTALL flag to match newlines
-    static ref LINK_PATTERN: Regex = Regex::new(r"(?s)!?\[([^\]]*)\]\(([^)]*)\)").unwrap();
-
-    // Fast check patterns - simple string-based checks are faster than complex regex
-    static ref WHITESPACE_CHECK: Regex = Regex::new(r"^\s+|\s+$").unwrap();
-    static ref ALL_WHITESPACE: Regex = Regex::new(r"^\s*$").unwrap();
-}
+// Regex patterns
+const ALL_WHITESPACE_STR: &str = r"^\s*$";
 
 /// Rule MD039: No space inside link text
 ///
@@ -28,12 +21,6 @@ impl MD039NoSpaceInLinks {
         Self
     }
 
-    /// Optimized fast check to see if content has any potential links or images
-    #[inline]
-    fn has_links_or_images(&self, content: &str) -> bool {
-        LINK_PATTERN.is_match(content)
-    }
-
     #[inline]
     fn trim_link_text_preserve_escapes(text: &str) -> &str {
         // Optimized trimming that preserves escapes
@@ -98,8 +85,7 @@ impl Rule for MD039NoSpaceInLinks {
     }
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        let content = ctx.content;
-        content.is_empty() || !self.has_links_or_images(content)
+        ctx.content.is_empty() || !ctx.likely_has_links_or_images()
     }
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
@@ -112,6 +98,11 @@ impl Rule for MD039NoSpaceInLinks {
                 continue;
             }
 
+            // Skip links inside Jinja templates
+            if ctx.is_in_jinja_range(link.byte_offset) {
+                continue;
+            }
+
             // Fast check if trimming is needed
             if !self.needs_trimming(&link.text) {
                 continue;
@@ -120,11 +111,14 @@ impl Rule for MD039NoSpaceInLinks {
             // Optimized unescaping for whitespace check
             let unescaped = self.unescape_fast(&link.text);
 
-            let needs_warning = if ALL_WHITESPACE.is_match(&unescaped) {
+            let needs_warning = if get_cached_regex(ALL_WHITESPACE_STR)
+                .map(|re| re.is_match(&unescaped))
+                .unwrap_or(false)
+            {
                 true
             } else {
                 let trimmed = link.text.trim_matches(|c: char| c.is_whitespace());
-                link.text.as_str() != trimmed
+                link.text.as_ref() != trimmed
             };
 
             if needs_warning {
@@ -138,7 +132,10 @@ impl Rule for MD039NoSpaceInLinks {
                     format!("({})", link.url)
                 };
 
-                let fixed = if ALL_WHITESPACE.is_match(&unescaped) {
+                let fixed = if get_cached_regex(ALL_WHITESPACE_STR)
+                    .map(|re| re.is_match(&unescaped))
+                    .unwrap_or(false)
+                {
                     format!("[]{url}")
                 } else {
                     let trimmed = Self::trim_link_text_preserve_escapes(&link.text);
@@ -146,7 +143,7 @@ impl Rule for MD039NoSpaceInLinks {
                 };
 
                 warnings.push(LintWarning {
-                    rule_name: Some(self.name()),
+                    rule_name: Some(self.name().to_string()),
                     line: link.line,
                     column: link.start_col + 1, // Convert to 1-indexed
                     end_line: link.line,
@@ -168,6 +165,11 @@ impl Rule for MD039NoSpaceInLinks {
                 continue;
             }
 
+            // Skip images inside Jinja templates
+            if ctx.is_in_jinja_range(image.byte_offset) {
+                continue;
+            }
+
             // Fast check if trimming is needed
             if !self.needs_trimming(&image.alt_text) {
                 continue;
@@ -176,11 +178,14 @@ impl Rule for MD039NoSpaceInLinks {
             // Optimized unescaping for whitespace check
             let unescaped = self.unescape_fast(&image.alt_text);
 
-            let needs_warning = if ALL_WHITESPACE.is_match(&unescaped) {
+            let needs_warning = if get_cached_regex(ALL_WHITESPACE_STR)
+                .map(|re| re.is_match(&unescaped))
+                .unwrap_or(false)
+            {
                 true
             } else {
                 let trimmed = image.alt_text.trim_matches(|c: char| c.is_whitespace());
-                image.alt_text.as_str() != trimmed
+                image.alt_text.as_ref() != trimmed
             };
 
             if needs_warning {
@@ -194,7 +199,10 @@ impl Rule for MD039NoSpaceInLinks {
                     format!("({})", image.url)
                 };
 
-                let fixed = if ALL_WHITESPACE.is_match(&unescaped) {
+                let fixed = if get_cached_regex(ALL_WHITESPACE_STR)
+                    .map(|re| re.is_match(&unescaped))
+                    .unwrap_or(false)
+                {
                     format!("![]{url}")
                 } else {
                     let trimmed = Self::trim_link_text_preserve_escapes(&image.alt_text);
@@ -202,7 +210,7 @@ impl Rule for MD039NoSpaceInLinks {
                 };
 
                 warnings.push(LintWarning {
-                    rule_name: Some(self.name()),
+                    rule_name: Some(self.name().to_string()),
                     line: image.line,
                     column: image.start_col + 1, // Convert to 1-indexed
                     end_line: image.line,
@@ -231,17 +239,25 @@ impl Rule for MD039NoSpaceInLinks {
                 continue;
             }
 
+            // Skip links inside Jinja templates
+            if ctx.is_in_jinja_range(link.byte_offset) {
+                continue;
+            }
+
             if !self.needs_trimming(&link.text) {
                 continue;
             }
 
             let unescaped = self.unescape_fast(&link.text);
 
-            let needs_fix = if ALL_WHITESPACE.is_match(&unescaped) {
+            let needs_fix = if get_cached_regex(ALL_WHITESPACE_STR)
+                .map(|re| re.is_match(&unescaped))
+                .unwrap_or(false)
+            {
                 true
             } else {
                 let trimmed = link.text.trim_matches(|c: char| c.is_whitespace());
-                link.text.as_str() != trimmed
+                link.text.as_ref() != trimmed
             };
 
             if needs_fix {
@@ -255,7 +271,10 @@ impl Rule for MD039NoSpaceInLinks {
                     format!("({})", link.url)
                 };
 
-                let replacement = if ALL_WHITESPACE.is_match(&unescaped) {
+                let replacement = if get_cached_regex(ALL_WHITESPACE_STR)
+                    .map(|re| re.is_match(&unescaped))
+                    .unwrap_or(false)
+                {
                     format!("[]{url_part}")
                 } else {
                     let trimmed = Self::trim_link_text_preserve_escapes(&link.text);
@@ -273,17 +292,25 @@ impl Rule for MD039NoSpaceInLinks {
                 continue;
             }
 
+            // Skip images inside Jinja templates
+            if ctx.is_in_jinja_range(image.byte_offset) {
+                continue;
+            }
+
             if !self.needs_trimming(&image.alt_text) {
                 continue;
             }
 
             let unescaped = self.unescape_fast(&image.alt_text);
 
-            let needs_fix = if ALL_WHITESPACE.is_match(&unescaped) {
+            let needs_fix = if get_cached_regex(ALL_WHITESPACE_STR)
+                .map(|re| re.is_match(&unescaped))
+                .unwrap_or(false)
+            {
                 true
             } else {
                 let trimmed = image.alt_text.trim_matches(|c: char| c.is_whitespace());
-                image.alt_text.as_str() != trimmed
+                image.alt_text.as_ref() != trimmed
             };
 
             if needs_fix {
@@ -297,7 +324,10 @@ impl Rule for MD039NoSpaceInLinks {
                     format!("({})", image.url)
                 };
 
-                let replacement = if ALL_WHITESPACE.is_match(&unescaped) {
+                let replacement = if get_cached_regex(ALL_WHITESPACE_STR)
+                    .map(|re| re.is_match(&unescaped))
+                    .unwrap_or(false)
+                {
                     format!("![]{url_part}")
                 } else {
                     let trimmed = Self::trim_link_text_preserve_escapes(&image.alt_text);
