@@ -1,5 +1,5 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
-use crate::utils::range_utils::{LineIndex, calculate_line_range};
+use crate::utils::range_utils::calculate_line_range;
 
 /// Rule MD040: Fenced code blocks should have a language
 ///
@@ -19,7 +19,7 @@ impl Rule for MD040FencedCodeLanguage {
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
 
         let mut warnings = Vec::new();
 
@@ -98,12 +98,18 @@ impl Rule for MD040FencedCodeLanguage {
                     let has_title_only =
                         ctx.flavor == crate::config::MarkdownFlavor::MkDocs && after_fence.starts_with("title=");
 
-                    if after_fence.is_empty() || has_title_only {
+                    // Check for Quarto/RMarkdown code chunk syntax: {language} or {language, options}
+                    // Examples: ```{python}, ```{r}, ```{r, echo=FALSE}
+                    let has_quarto_syntax = ctx.flavor == crate::config::MarkdownFlavor::Quarto
+                        && after_fence.starts_with('{')
+                        && after_fence.contains('}');
+
+                    if (after_fence.is_empty() || has_title_only) && !has_quarto_syntax {
                         // Calculate precise character range for the entire fence line that needs a language
                         let (start_line, start_col, end_line, end_col) = calculate_line_range(i + 1, line);
 
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             line: start_line,
                             column: start_col,
                             end_line,
@@ -138,7 +144,7 @@ impl Rule for MD040FencedCodeLanguage {
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
 
         let mut result = String::new();
         let mut in_code_block = false;
@@ -149,50 +155,10 @@ impl Rule for MD040FencedCodeLanguage {
 
         let lines: Vec<&str> = content.lines().collect();
 
-        // Helper function to check if we're in a nested context
-        let is_in_nested_context = |line_idx: usize| -> bool {
-            // Look for blockquote or list context above this line
-            for i in (0..line_idx).rev() {
-                let line = lines.get(i).unwrap_or(&"");
-                let trimmed = line.trim();
-
-                // If we hit a blank line, check if context continues
-                if trimmed.is_empty() {
-                    continue;
-                }
-
-                // Check for blockquote markers
-                if line.trim_start().starts_with('>') {
-                    return true;
-                }
-
-                // Check for list markers with sufficient indentation
-                if line.len() - line.trim_start().len() >= 2 {
-                    let after_indent = line.trim_start();
-                    if after_indent.starts_with("- ")
-                        || after_indent.starts_with("* ")
-                        || after_indent.starts_with("+ ")
-                        || (after_indent.len() > 2
-                            && after_indent.as_bytes().first().is_some_and(|&b| b.is_ascii_digit())
-                            && after_indent.as_bytes().get(1) == Some(&b'.')
-                            && after_indent.as_bytes().get(2) == Some(&b' '))
-                    {
-                        return true;
-                    }
-                }
-
-                // If we find content that's not indented, we're not in nested context
-                if line.starts_with(|c: char| !c.is_whitespace()) {
-                    break;
-                }
-            }
-            false
-        };
-
         // Pre-compute disabled state to avoid O(n²) complexity
         let mut is_disabled = false;
 
-        for (i, line) in lines.iter().enumerate() {
+        for line in lines.iter() {
             let trimmed = line.trim();
 
             // Update disabled state incrementally
@@ -278,28 +244,19 @@ impl Rule for MD040FencedCodeLanguage {
                     let has_title_only =
                         ctx.flavor == crate::config::MarkdownFlavor::MkDocs && after_fence.starts_with("title=");
 
-                    if after_fence.is_empty() || has_title_only {
-                        // Decide whether to preserve indentation based on context
-                        let should_preserve_indent = is_in_nested_context(i);
+                    // Check for Quarto/RMarkdown code chunk syntax: {language} or {language, options}
+                    let has_quarto_syntax = ctx.flavor == crate::config::MarkdownFlavor::Quarto
+                        && after_fence.starts_with('{')
+                        && after_fence.contains('}');
 
-                        if should_preserve_indent {
-                            // Preserve indentation for nested contexts
-                            original_indent = line_indent;
-                            if has_title_only {
-                                // Insert language before title attribute
-                                result.push_str(&format!("{original_indent}{fence_marker}text {after_fence}\n"));
-                            } else {
-                                result.push_str(&format!("{original_indent}{fence_marker}text\n"));
-                            }
+                    if (after_fence.is_empty() || has_title_only) && !has_quarto_syntax {
+                        // Always preserve the original indentation - adding a language tag should not change indentation
+                        original_indent = line_indent;
+                        if has_title_only {
+                            // Insert language before title attribute
+                            result.push_str(&format!("{original_indent}{fence_marker}text {after_fence}\n"));
                         } else {
-                            // Remove indentation for standalone code blocks
-                            original_indent = String::new();
-                            if has_title_only {
-                                // Insert language before title attribute
-                                result.push_str(&format!("{fence_marker}text {after_fence}\n"));
-                            } else {
-                                result.push_str(&format!("{fence_marker}text\n"));
-                            }
+                            result.push_str(&format!("{original_indent}{fence_marker}text\n"));
                         }
                         fence_needs_language = true;
                     } else {
@@ -339,8 +296,7 @@ impl Rule for MD040FencedCodeLanguage {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        let content = ctx.content;
-        content.is_empty() || (!content.contains("```") && !content.contains("~~~"))
+        ctx.content.is_empty() || (!ctx.likely_has_code() && !ctx.has_char('~'))
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -627,13 +583,67 @@ another block without
   ```
 "#;
         let fixed = run_fix(content).unwrap();
-        // The implementation appears to remove indentation for standalone blocks
-        // but preserve it for nested contexts. This test case seems to be treating
-        // it as a standalone block.
-        assert!(fixed.contains("```text"));
+        // Should preserve indentation for list items
+        assert!(fixed.contains("  ```text"));
         assert!(fixed.contains("  indented code block"));
     }
 
+    #[test]
+    fn test_fix_preserves_indentation_numbered_list() {
+        // Test case from issue #122
+        let content = r#"1. Step 1
+
+    ```
+    foo
+    bar
+    ```
+"#;
+        let fixed = run_fix(content).unwrap();
+        // Should preserve 4-space indentation for numbered list content
+        assert!(fixed.contains("    ```text"));
+        assert!(fixed.contains("    foo"));
+        assert!(fixed.contains("    bar"));
+        // Should not remove indentation
+        assert!(!fixed.contains("\n```text\n"));
+    }
+
+    #[test]
+    fn test_fix_preserves_all_indentation() {
+        let content = r#"# Test
+
+Top-level code block:
+```
+top level
+```
+
+1. List item
+
+    ```
+    nested in list
+    ```
+
+Indented by 2 spaces:
+  ```
+  content
+  ```
+"#;
+        let fixed = run_fix(content).unwrap();
+
+        // All indentation should be preserved exactly as-is
+        assert!(
+            fixed.contains("```text\ntop level"),
+            "Top-level code block indentation preserved"
+        );
+        assert!(
+            fixed.contains("    ```text\n    nested in list"),
+            "List item code block indentation preserved"
+        );
+        assert!(
+            fixed.contains("  ```text\n  content"),
+            "2-space indented code block indentation preserved"
+        );
+    }
+
     #[test]
     fn test_fix_with_tilde_fences() {
         let content = r#"# Test
@@ -807,4 +817,58 @@ console.log(`template string with backticks`);
         let ctx = LintContext::new("", crate::config::MarkdownFlavor::Standard);
         assert!(rule.should_skip(&ctx));
     }
+
+    #[test]
+    fn test_quarto_code_chunk_syntax() {
+        let rule = MD040FencedCodeLanguage;
+
+        // Test Quarto {r} syntax - should NOT trigger warning
+        let content = r#"# Test
+
+```{r}
+x <- 1
+```
+
+```{python}
+x = 1
+```
+
+```{r, echo=FALSE}
+plot(x)
+```
+"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Quarto);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Quarto code chunks with {{language}} syntax should not trigger warnings"
+        );
+
+        // Test that missing language DOES trigger warning for Quarto
+        let content_no_lang = r#"# Test
+
+```
+code without language
+```
+"#;
+        let ctx = LintContext::new(content_no_lang, crate::config::MarkdownFlavor::Quarto);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Quarto files without language should trigger warning");
+
+        // Test that standard flavor still requires standard language syntax
+        let content_standard = r#"# Test
+
+```{python}
+code
+```
+"#;
+        let ctx = LintContext::new(content_standard, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        // In standard flavor, {python} is considered "after_fence" content, so it's valid
+        // The fence marker is "```" and after_fence is "{python}", which is non-empty
+        assert!(
+            result.is_empty(),
+            "Standard flavor should accept any non-empty after_fence content"
+        );
+    }
 }
