@@ -1,11 +1,50 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::mkdocs_patterns::is_mkdocs_auto_reference;
+use pulldown_cmark::LinkType;
 
 /// Rule MD042: No empty links
 ///
 /// See [docs/md042.md](../../docs/md042.md) for full documentation, configuration, and examples.
 ///
 /// This rule is triggered when a link has no content (text) or destination (URL).
+///
+/// # MkDocs Support
+///
+/// When `flavor = "mkdocs"` is configured, this rule recognizes two types of valid MkDocs patterns:
+///
+/// ## 1. Auto-References (via mkdocs-autorefs / mkdocstrings)
+///
+/// Backtick-wrapped Python identifiers used for cross-referencing:
+/// ```markdown
+/// [`module.Class`][]     // Python class reference
+/// [`str`][]              // Built-in type reference
+/// [`api.function`][]     // Function reference
+/// ```
+///
+/// **References:**
+/// - [mkdocs-autorefs](https://mkdocstrings.github.io/autorefs/)
+/// - [mkdocstrings](https://mkdocstrings.github.io/)
+///
+/// ## 2. Paragraph Anchors (via Python-Markdown attr_list extension)
+///
+/// Empty links combined with attributes to create anchor points:
+/// ```markdown
+/// [](){ #my-anchor }              // Basic anchor
+/// [](){ #anchor .class }          // Anchor with CSS class
+/// [](){: #anchor }                // With colon (canonical attr_list syntax)
+/// [](){ .class1 .class2 }         // Classes only
+/// ```
+///
+/// This syntax combines:
+/// - Empty link `[]()` → creates `<a href=""></a>`
+/// - attr_list syntax `{ #id }` → adds attributes to preceding element
+/// - Result: `<a href="" id="my-anchor"></a>`
+///
+/// **References:**
+/// - [Python-Markdown attr_list](https://python-markdown.github.io/extensions/attr_list/)
+/// - [MkDocs discussion](https://github.com/mkdocs/mkdocs/discussions/3754)
+///
+/// **Implementation:** See [`is_mkdocs_attribute_anchor`](Self::is_mkdocs_attribute_anchor)
 #[derive(Clone, Default)]
 pub struct MD042NoEmptyLinks {}
 
@@ -13,6 +52,80 @@ impl MD042NoEmptyLinks {
     pub fn new() -> Self {
         Self {}
     }
+
+    /// Strip surrounding backticks from a string
+    /// Used for MkDocs auto-reference detection where `module.Class` should be treated as module.Class
+    fn strip_backticks(s: &str) -> &str {
+        s.trim_start_matches('`').trim_end_matches('`')
+    }
+
+    /// Check if a string is a valid Python identifier
+    /// Python identifiers can contain alphanumeric characters and underscores, but cannot start with a digit
+    fn is_valid_python_identifier(s: &str) -> bool {
+        if s.is_empty() {
+            return false;
+        }
+
+        let first_char = s.chars().next().unwrap();
+        if !first_char.is_ascii_alphabetic() && first_char != '_' {
+            return false;
+        }
+
+        s.chars().all(|c| c.is_ascii_alphanumeric() || c == '_')
+    }
+
+    /// Check if an empty link is followed by MkDocs attribute syntax
+    /// Pattern: []() followed by { #anchor } or { #anchor .class }
+    ///
+    /// This validates the Python-Markdown attr_list extension syntax when applied to empty links.
+    /// Empty links `[]()` combined with attributes like `{ #anchor }` create anchor points in
+    /// documentation, as documented by mkdocs-autorefs and the attr_list extension.
+    fn is_mkdocs_attribute_anchor(content: &str, link_end: usize) -> bool {
+        // UTF-8 safety: Validate byte position is at character boundary
+        if !content.is_char_boundary(link_end) {
+            return false;
+        }
+
+        // Get the content after the link
+        if let Some(rest) = content.get(link_end..) {
+            // Trim whitespace and check if it starts with {
+            // Note: trim_start() removes all whitespace including newlines
+            // This is intentionally permissive to match real-world MkDocs usage
+            let trimmed = rest.trim_start();
+
+            // Check for opening brace (with optional colon per attr_list spec)
+            let stripped = if let Some(s) = trimmed.strip_prefix("{:") {
+                s
+            } else if let Some(s) = trimmed.strip_prefix('{') {
+                s
+            } else {
+                return false;
+            };
+
+            // Look for closing brace
+            if let Some(end_brace) = stripped.find('}') {
+                // DoS prevention: Limit attribute section length
+                if end_brace > 500 {
+                    return false;
+                }
+
+                let attrs = stripped[..end_brace].trim();
+
+                // Empty attributes should not be considered valid
+                if attrs.is_empty() {
+                    return false;
+                }
+
+                // Check if it contains an anchor (starts with #) or class (starts with .)
+                // Valid patterns: { #anchor }, { #anchor .class }, { .class #anchor }
+                // At least one attribute starting with # or . is required
+                return attrs
+                    .split_whitespace()
+                    .any(|part| part.starts_with('#') || part.starts_with('.'));
+            }
+        }
+        false
+    }
 }
 
 impl Rule for MD042NoEmptyLinks {
@@ -32,77 +145,139 @@ impl Rule for MD042NoEmptyLinks {
 
         // Use centralized link parsing from LintContext
         for link in &ctx.links {
+            // Skip links inside Jinja templates
+            if ctx.is_in_jinja_range(link.byte_offset) {
+                continue;
+            }
+
+            // Skip links inside HTML tags (e.g., <a href="...?p[images][0]=...">)
+            // Check if the link's byte position falls within any HTML tag range
+            let in_html_tag = ctx
+                .html_tags()
+                .iter()
+                .any(|html_tag| html_tag.byte_offset <= link.byte_offset && link.byte_offset < html_tag.byte_end);
+            if in_html_tag {
+                continue;
+            }
+
             // For reference links, resolve the URL
             let effective_url = if link.is_reference {
                 if let Some(ref_id) = &link.reference_id {
-                    ctx.get_reference_url(ref_id).unwrap_or("").to_string()
+                    ctx.get_reference_url(ref_id.as_ref()).unwrap_or("").to_string()
                 } else {
                     String::new()
                 }
             } else {
-                link.url.clone()
+                link.url.to_string()
             };
 
             // For MkDocs mode, check if this looks like an auto-reference
             // Note: We check both the reference_id AND the text since shorthand references
             // like [class.Name][] use the text as the implicit reference
+            // Also strip backticks since MkDocs resolves `module.Class` as module.Class
             if mkdocs_mode && link.is_reference {
-                // Check the reference_id if present
-                if let Some(ref_id) = &link.reference_id
-                    && is_mkdocs_auto_reference(ref_id)
-                {
-                    continue;
+                // Check the reference_id if present (strip backticks first)
+                if let Some(ref_id) = &link.reference_id {
+                    let stripped_ref = Self::strip_backticks(ref_id);
+                    // Accept if it matches MkDocs patterns OR if it's a backtick-wrapped valid identifier
+                    // Backticks indicate code/type reference (like `str`, `int`, `MyClass`)
+                    if is_mkdocs_auto_reference(stripped_ref)
+                        || (ref_id != stripped_ref && Self::is_valid_python_identifier(stripped_ref))
+                    {
+                        continue;
+                    }
                 }
-                // Also check the link text itself for shorthand references
-                if is_mkdocs_auto_reference(&link.text) {
+                // Also check the link text itself for shorthand references (strip backticks)
+                let stripped_text = Self::strip_backticks(&link.text);
+                // Accept if it matches MkDocs patterns OR if it's a backtick-wrapped valid identifier
+                if is_mkdocs_auto_reference(stripped_text)
+                    || (link.text.as_ref() != stripped_text && Self::is_valid_python_identifier(stripped_text))
+                {
                     continue;
                 }
             }
 
+            // Skip autolinks (like <https://example.com>)
+            // Autolinks are valid CommonMark syntax: <URL> where text field is empty but URL is the display
+            // Detect by checking if source markdown is wrapped in < and >
+            let link_markdown = &ctx.content[link.byte_offset..link.byte_end];
+            if link_markdown.starts_with('<') && link_markdown.ends_with('>') {
+                continue;
+            }
+
+            // Skip Obsidian block references (wiki-links with #^ pattern)
+            // Examples: [[#^block-id]] or [[Note#^block-id]]
+            // These are valid Obsidian syntax where the display text is auto-generated from the referenced block
+            if matches!(link.link_type, LinkType::WikiLink { .. })
+                && link.text.trim().is_empty()
+                && link.url.contains("#^")
+            {
+                continue;
+            }
+
             // Check for empty links
             if link.text.trim().is_empty() || effective_url.trim().is_empty() {
-                let replacement = if link.text.trim().is_empty() && effective_url.trim().is_empty() {
-                    "[Link text](https://example.com)".to_string()
-                } else if link.text.trim().is_empty() {
-                    if link.is_reference {
-                        format!("[Link text]{}", &ctx.content[link.byte_offset + 1..link.byte_end])
-                    } else {
-                        format!("[Link text]({effective_url})")
-                    }
-                } else if link.is_reference {
-                    // Keep the reference format
-                    let ref_part = &ctx.content[link.byte_offset + link.text.len() + 2..link.byte_end];
-                    format!("[{}]{}", link.text, ref_part)
-                } else {
-                    format!("[{}](https://example.com)", link.text)
-                };
+                // In MkDocs mode, check if this is an attribute anchor: []() followed by { #anchor }
+                if mkdocs_mode
+                    && link.text.trim().is_empty()
+                    && effective_url.trim().is_empty()
+                    && Self::is_mkdocs_attribute_anchor(ctx.content, link.byte_end)
+                {
+                    // This is a valid MkDocs attribute anchor, skip it
+                    continue;
+                }
 
-                // Format the link as it appears in the source
-                let link_display = if link.is_reference {
-                    if let Some(ref_id) = &link.reference_id {
-                        if ref_id.is_empty() {
-                            format!("[{}][]", link.text)
+                // Determine if we can provide a meaningful fix
+                let replacement = if link.text.trim().is_empty() {
+                    // Empty text - can we fix it?
+                    if !effective_url.trim().is_empty() {
+                        // Has URL but no text - add placeholder text
+                        if link.is_reference {
+                            Some(format!(
+                                "[Link text]{}",
+                                &ctx.content[link.byte_offset + 1..link.byte_end]
+                            ))
                         } else {
-                            format!("[{}][{}]", link.text, ref_id)
+                            Some(format!("[Link text]({effective_url})"))
                         }
                     } else {
-                        format!("[{}]", link.text)
+                        // Both empty - can't meaningfully auto-fix
+                        None
                     }
+                } else if link.is_reference {
+                    // Reference links with text but no/empty reference - keep the format
+                    let ref_part = &ctx.content[link.byte_offset + link.text.len() + 2..link.byte_end];
+                    Some(format!("[{}]{}", link.text, ref_part))
                 } else {
-                    format!("[{}]({})", link.text, link.url)
+                    // URL is empty, but text is not
+                    // Check if the link text looks like a URL - if so, use it as the destination
+                    let text_is_url = link.text.starts_with("http://")
+                        || link.text.starts_with("https://")
+                        || link.text.starts_with("ftp://")
+                        || link.text.starts_with("ftps://");
+
+                    if text_is_url {
+                        Some(format!("[{}]({})", link.text, link.text))
+                    } else {
+                        // Text is not a URL - can't meaningfully auto-fix
+                        None
+                    }
                 };
 
+                // Extract the exact link text from the source
+                let link_display = &ctx.content[link.byte_offset..link.byte_end];
+
                 warnings.push(LintWarning {
-                    rule_name: Some(self.name()),
+                    rule_name: Some(self.name().to_string()),
                     message: format!("Empty link found: {link_display}"),
                     line: link.line,
                     column: link.start_col + 1, // Convert to 1-indexed
                     end_line: link.line,
                     end_column: link.end_col + 1, // Convert to 1-indexed
                     severity: Severity::Warning,
-                    fix: Some(Fix {
+                    fix: replacement.map(|r| Fix {
                         range: link.byte_offset..link.byte_end,
-                        replacement,
+                        replacement: r,
                     }),
                 });
             }
@@ -146,8 +321,7 @@ impl Rule for MD042NoEmptyLinks {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        let content = ctx.content;
-        content.is_empty() || !content.contains('[')
+        ctx.content.is_empty() || !ctx.likely_has_links_or_images()
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -442,24 +616,34 @@ mod tests {
 
     #[test]
     fn test_fix_suggestions() {
-        let ctx = LintContext::new("[](https://example.com)", crate::config::MarkdownFlavor::Standard);
         let rule = MD042NoEmptyLinks::new();
+
+        // Case 1: Empty text, has URL - fixable (add placeholder text)
+        let ctx = LintContext::new("[](https://example.com)", crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        assert!(result[0].fix.is_some());
+        assert!(result[0].fix.is_some(), "Empty text with URL should be fixable");
         let fix = result[0].fix.as_ref().unwrap();
         assert_eq!(fix.replacement, "[Link text](https://example.com)");
 
+        // Case 2: Non-URL text, empty URL - NOT fixable (can't guess the URL)
         let ctx = LintContext::new("[text]()", crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        assert!(result[0].fix.is_some());
-        let fix = result[0].fix.as_ref().unwrap();
-        assert_eq!(fix.replacement, "[text](https://example.com)");
+        assert!(
+            result[0].fix.is_none(),
+            "Non-URL text with empty URL should NOT be fixable"
+        );
 
+        // Case 3: URL text, empty URL - fixable (use text as URL)
+        let ctx = LintContext::new("[https://example.com]()", crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result[0].fix.is_some(), "URL text with empty URL should be fixable");
+        let fix = result[0].fix.as_ref().unwrap();
+        assert_eq!(fix.replacement, "[https://example.com](https://example.com)");
+
+        // Case 4: Both empty - NOT fixable (can't guess either)
         let ctx = LintContext::new("[]()", crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        assert!(result[0].fix.is_some());
-        let fix = result[0].fix.as_ref().unwrap();
-        assert_eq!(fix.replacement, "[Link text](https://example.com)");
+        assert!(result[0].fix.is_none(), "Both empty should NOT be fixable");
     }
 
     #[test]
@@ -539,4 +723,67 @@ UnboundLocalError: cannot access local variable 'calls' where it is not associat
             "Should not flag reference links as empty when code blocks contain tildes (issue #29). Got: {result:?}"
         );
     }
+
+    #[test]
+    fn test_link_with_inline_code_in_text() {
+        // Links with inline code in the text should NOT be flagged as empty
+        let ctx = LintContext::new(
+            "[`#[derive(Serialize, Deserialize)`](https://serde.rs/derive.html)",
+            crate::config::MarkdownFlavor::Standard,
+        );
+        let rule = MD042NoEmptyLinks::new();
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Links with inline code should not be flagged as empty. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_mkdocs_backtick_wrapped_references() {
+        // Test for issue #97 - backtick-wrapped references should be recognized as MkDocs auto-references
+        let rule = MD042NoEmptyLinks::new();
+
+        // Module.Class pattern with backticks
+        let ctx = LintContext::new("[`module.Class`][]", crate::config::MarkdownFlavor::MkDocs);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should not flag [`module.Class`][] as empty in MkDocs mode (issue #97). Got: {result:?}"
+        );
+
+        // Reference with explicit ID
+        let ctx = LintContext::new("[`module.Class`][ref]", crate::config::MarkdownFlavor::MkDocs);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should not flag [`module.Class`][ref] as empty in MkDocs mode (issue #97). Got: {result:?}"
+        );
+
+        // Path-like reference with backticks
+        let ctx = LintContext::new("[`api/endpoint`][]", crate::config::MarkdownFlavor::MkDocs);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should not flag [`api/endpoint`][] as empty in MkDocs mode (issue #97). Got: {result:?}"
+        );
+
+        // Should still flag in standard mode
+        let ctx = LintContext::new("[`module.Class`][]", crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(
+            result.len(),
+            1,
+            "Should flag [`module.Class`][] as empty in Standard mode (no auto-refs). Got: {result:?}"
+        );
+
+        // Should still flag truly empty links even in MkDocs mode
+        let ctx = LintContext::new("[][]", crate::config::MarkdownFlavor::MkDocs);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(
+            result.len(),
+            1,
+            "Should still flag [][] as empty in MkDocs mode. Got: {result:?}"
+        );
+    }
 }
