@@ -1,23 +1,20 @@
 use crate::utils::fast_hash;
-use crate::utils::range_utils::LineIndex;
 use crate::utils::regex_cache::{escape_regex, get_cached_fancy_regex};
 
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
 use fancy_regex::Regex;
-use lazy_static::lazy_static;
 use std::collections::HashMap;
+use std::sync::LazyLock;
 use std::sync::{Arc, Mutex};
 
 mod md044_config;
 use md044_config::MD044Config;
 
-lazy_static! {
-    static ref HTML_COMMENT_REGEX: Regex = Regex::new(r"<!--([\s\S]*?)-->").unwrap();
-    // Reference definition pattern - matches [ref]: url "title"
-    static ref REF_DEF_REGEX: regex::Regex = regex::Regex::new(
-        r#"(?m)^[ ]{0,3}\[([^\]]+)\]:\s*([^\s]+)(?:\s+(?:"([^"]*)"|'([^']*)'))?$"#
-    ).unwrap();
-}
+static HTML_COMMENT_REGEX: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"<!--([\s\S]*?)-->").unwrap());
+// Reference definition pattern - matches [ref]: url "title"
+static REF_DEF_REGEX: LazyLock<regex::Regex> = LazyLock::new(|| {
+    regex::Regex::new(r#"(?m)^[ ]{0,3}\[([^\]]+)\]:\s*([^\s]+)(?:\s+(?:"([^"]*)"|'([^']*)'))?$"#).unwrap()
+});
 
 type WarningPosition = (usize, usize, String); // (line, column, found_name)
 
@@ -43,7 +40,7 @@ type WarningPosition = (usize, usize, String); // (line, column, found_name)
 /// ```yaml
 /// MD044:
 ///   names: []                # List of proper names to check for correct capitalization
-///   code_blocks_excluded: true  # Whether to exclude code blocks from checking
+///   code-blocks: false       # Whether to check code blocks (default: false)
 /// ```
 ///
 /// Example configuration:
@@ -51,7 +48,7 @@ type WarningPosition = (usize, usize, String); // (line, column, found_name)
 /// ```yaml
 /// MD044:
 ///   names: ["JavaScript", "Node.js", "TypeScript"]
-///   code_blocks_excluded: true
+///   code-blocks: true
 /// ```
 ///
 /// ## Performance Optimizations
@@ -67,7 +64,7 @@ type WarningPosition = (usize, usize, String); // (line, column, found_name)
 ///
 /// - **Word Boundaries**: Only matches complete words, not substrings within other words
 /// - **Case Sensitivity**: Properly handles case-specific matching
-/// - **Code Blocks**: Optionally excludes code blocks where capitalization may be intentionally different
+/// - **Code Blocks**: Optionally checks code blocks (controlled by code-blocks setting)
 /// - **Markdown Formatting**: Handles proper names within Markdown formatting elements
 ///
 /// ## Fix Behavior
@@ -89,6 +86,7 @@ impl MD044ProperNames {
         let config = MD044Config {
             names,
             code_blocks,
+            html_elements: true, // Default to checking HTML elements
             html_comments: true, // Default to checking HTML comments
         };
         let combined_pattern = Self::create_combined_pattern(&config);
@@ -209,7 +207,7 @@ impl MD044ProperNames {
         let hash = fast_hash(content);
         {
             // Use a separate scope for borrowing to minimize lock time
-            let cache = self.content_cache.lock().unwrap();
+            let cache = self.content_cache.lock().expect("MD044 content cache mutex poisoned");
             if let Some(cached) = cache.get(&hash) {
                 return cached.clone();
             }
@@ -229,7 +227,7 @@ impl MD044ProperNames {
         // Use ctx.lines for better performance
         for (line_idx, line_info) in ctx.lines.iter().enumerate() {
             let line_num = line_idx + 1;
-            let line = &line_info.content;
+            let line = line_info.content(ctx.content);
 
             // Skip code fence lines (```language or ~~~language)
             let trimmed = line.trim_start();
@@ -237,8 +235,13 @@ impl MD044ProperNames {
                 continue;
             }
 
-            // Skip if in code block
-            if self.config.code_blocks && line_info.in_code_block {
+            // Skip if in code block (when code_blocks = false)
+            if !self.config.code_blocks && line_info.in_code_block {
+                continue;
+            }
+
+            // Skip if in HTML block (when html_elements = false)
+            if !self.config.html_elements && line_info.in_html_block {
                 continue;
             }
 
@@ -300,8 +303,8 @@ impl MD044ProperNames {
                             continue; // Not at word boundary
                         }
 
-                        // Skip if in inline code when code_blocks is true
-                        if self.config.code_blocks {
+                        // Skip if in inline code when code_blocks is false
+                        if !self.config.code_blocks {
                             let byte_pos = line_info.byte_offset + cap.start();
                             if ctx.is_in_code_block_or_span(byte_pos) {
                                 continue;
@@ -330,7 +333,10 @@ impl MD044ProperNames {
         }
 
         // Store in cache
-        self.content_cache.lock().unwrap().insert(hash, violations.clone());
+        self.content_cache
+            .lock()
+            .expect("MD044 content cache mutex poisoned")
+            .insert(hash, violations.clone());
         violations
     }
 
@@ -488,14 +494,14 @@ impl Rule for MD044ProperNames {
             return Ok(Vec::new());
         }
 
-        let line_index = LineIndex::new(content.to_string());
+        let line_index = &ctx.line_index;
         let violations = self.find_name_violations(content, ctx);
 
         let warnings = violations
             .into_iter()
             .filter_map(|(line, column, found_name)| {
                 self.get_proper_name_for(&found_name).map(|proper_name| LintWarning {
-                    rule_name: Some(self.name()),
+                    rule_name: Some(self.name().to_string()),
                     line,
                     column,
                     end_line: line,
@@ -547,7 +553,7 @@ impl Rule for MD044ProperNames {
 
             if let Some(line_violations) = violations_by_line.get(&line_num) {
                 // This line has violations, fix them
-                let mut fixed_line = line_info.content.clone();
+                let mut fixed_line = line_info.content(ctx.content).to_string();
 
                 for (col_num, found_name) in line_violations {
                     if let Some(proper_name) = self.get_proper_name_for(found_name) {
@@ -566,7 +572,7 @@ impl Rule for MD044ProperNames {
                 fixed_lines.push(fixed_line);
             } else {
                 // No violations on this line, keep it as is
-                fixed_lines.push(line_info.content.clone());
+                fixed_lines.push(line_info.content(ctx.content).to_string());
             }
         }
 
@@ -658,13 +664,13 @@ mod tests {
     }
 
     #[test]
-    fn test_names_in_code_blocks_ignored() {
+    fn test_names_in_code_blocks_checked_by_default() {
         let rule = MD044ProperNames::new(vec!["JavaScript".to_string()], true);
 
         let content = r#"Here is some text with JavaScript.
 
 ```javascript
-// This javascript should be ignored
+// This javascript should be checked
 const lang = "javascript";
 ```
 
@@ -673,16 +679,17 @@ But this javascript should be flagged."#;
         let ctx = create_context(content);
         let result = rule.check(&ctx).unwrap();
 
-        assert_eq!(result.len(), 1, "Should only flag javascript outside code blocks");
-        assert_eq!(result[0].line, 8);
-        assert_eq!(result[0].message, "Proper name 'javascript' should be 'JavaScript'");
+        assert_eq!(result.len(), 3, "Should flag javascript inside and outside code blocks");
+        assert_eq!(result[0].line, 4);
+        assert_eq!(result[1].line, 5);
+        assert_eq!(result[2].line, 8);
     }
 
     #[test]
-    fn test_names_in_code_blocks_not_ignored_when_disabled() {
+    fn test_names_in_code_blocks_ignored_when_disabled() {
         let rule = MD044ProperNames::new(
             vec!["JavaScript".to_string()],
-            false, // code_blocks = false means check inside code blocks
+            false, // code_blocks = false means skip code blocks
         );
 
         let content = r#"```
@@ -694,22 +701,23 @@ javascript in code block
 
         assert_eq!(
             result.len(),
-            1,
-            "Should flag javascript in code blocks when code_blocks is false"
+            0,
+            "Should not flag javascript in code blocks when code_blocks is false"
         );
     }
 
     #[test]
-    fn test_names_in_inline_code_ignored() {
+    fn test_names_in_inline_code_checked_by_default() {
         let rule = MD044ProperNames::new(vec!["JavaScript".to_string()], true);
 
         let content = "This is `javascript` in inline code and javascript outside.";
         let ctx = create_context(content);
         let result = rule.check(&ctx).unwrap();
 
-        // When code_blocks=true, inline code should be excluded
-        assert_eq!(result.len(), 1, "Should only flag javascript outside inline code");
-        assert_eq!(result[0].column, 41); // javascript outside
+        // When code_blocks=true, inline code should be checked
+        assert_eq!(result.len(), 2, "Should flag javascript inside and outside inline code");
+        assert_eq!(result[0].column, 10); // javascript in inline code
+        assert_eq!(result[1].column, 41); // javascript outside
     }
 
     #[test]
@@ -747,6 +755,7 @@ javascript in code block
         let config = MD044Config {
             names: vec!["GitHub".to_string(), "GitLab".to_string(), "DevOps".to_string()],
             code_blocks: true,
+            html_elements: true,
             html_comments: true,
         };
         let rule = MD044ProperNames::from_config_struct(config);
@@ -839,7 +848,7 @@ javascript in code block
     }
 
     #[test]
-    fn test_fix_preserves_code_blocks() {
+    fn test_fix_checks_code_blocks_by_default() {
         let rule = MD044ProperNames::new(vec!["JavaScript".to_string()], true);
 
         let content = r#"I love javascript.
@@ -856,7 +865,7 @@ More javascript here."#;
         let expected = r#"I love JavaScript.
 
 ```
-const lang = "javascript";
+const lang = "JavaScript";
 ```
 
 More JavaScript here."#;
@@ -886,7 +895,7 @@ Third line with RUST and PYTHON."#;
     fn test_default_config() {
         let config = MD044Config::default();
         assert!(config.names.is_empty());
-        assert!(config.code_blocks);
+        assert!(!config.code_blocks); // Default is false (skip code blocks)
     }
 
     #[test]
@@ -949,7 +958,8 @@ Third line with RUST and PYTHON."#;
     fn test_html_comments_not_checked_when_disabled() {
         let config = MD044Config {
             names: vec!["JavaScript".to_string()],
-            code_blocks: true,
+            code_blocks: true,    // Check code blocks
+            html_elements: true,  // Check HTML elements
             html_comments: false, // Don't check HTML comments
         };
         let rule = MD044ProperNames::from_config_struct(config);
@@ -970,7 +980,8 @@ More javascript outside."#;
     fn test_html_comments_checked_when_enabled() {
         let config = MD044Config {
             names: vec!["JavaScript".to_string()],
-            code_blocks: true,
+            code_blocks: true,   // Check code blocks
+            html_elements: true, // Check HTML elements
             html_comments: true, // Check HTML comments
         };
         let rule = MD044ProperNames::from_config_struct(config);
@@ -993,8 +1004,9 @@ More javascript outside."#;
     fn test_multiline_html_comments() {
         let config = MD044Config {
             names: vec!["Python".to_string(), "JavaScript".to_string()],
-            code_blocks: true,
-            html_comments: false,
+            code_blocks: true,    // Check code blocks
+            html_elements: true,  // Check HTML elements
+            html_comments: false, // Don't check HTML comments
         };
         let rule = MD044ProperNames::from_config_struct(config);
 
@@ -1018,8 +1030,9 @@ More javascript outside."#;
     fn test_fix_preserves_html_comments_when_disabled() {
         let config = MD044Config {
             names: vec!["JavaScript".to_string()],
-            code_blocks: true,
-            html_comments: false,
+            code_blocks: true,    // Check code blocks
+            html_elements: true,  // Check HTML elements
+            html_comments: false, // Don't check HTML comments
         };
         let rule = MD044ProperNames::from_config_struct(config);
 
