@@ -86,7 +86,7 @@ impl Rule for MD045NoAltText {
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
         // Skip if no image syntax present
-        !ctx.content.contains("![")
+        !ctx.likely_has_links_or_images()
     }
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
@@ -112,7 +112,7 @@ impl Rule for MD045NoAltText {
                 };
 
                 warnings.push(LintWarning {
-                    rule_name: Some(self.name()),
+                    rule_name: Some(self.name().to_string()),
                     line: image.line,
                     column: image.start_col + 1, // Convert to 1-indexed
                     end_line: image.line,
@@ -428,7 +428,8 @@ mod tests {
     #[test]
     fn test_image_with_spaces_in_url() {
         let rule = MD045NoAltText::new();
-        let content = "![](my image.jpg)";
+        // Use angle bracket syntax for URLs with spaces (CommonMark spec)
+        let content = "![](<my image.jpg>)";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
