@@ -1,18 +1,5 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
 
-/// Detect the line ending style used in the content
-fn detect_line_ending(content: &str) -> &'static str {
-    // Check for CRLF first (more specific than LF)
-    if content.contains("\r\n") {
-        "\r\n"
-    } else if content.contains('\n') {
-        "\n"
-    } else {
-        // Default to LF for empty or single-line files
-        "\n"
-    }
-}
-
 /// Rule MD047: File should end with a single newline
 ///
 /// See [docs/md047.md](../../docs/md047.md) for full documentation, configuration, and examples.
@@ -29,6 +16,11 @@ impl Rule for MD047SingleTrailingNewline {
         "Files should end with a single newline character"
     }
 
+    fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
+        // Skip empty files - they don't need trailing newlines
+        ctx.content.is_empty()
+    }
+
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
         let mut warnings = Vec::new();
@@ -38,17 +30,15 @@ impl Rule for MD047SingleTrailingNewline {
             return Ok(warnings);
         }
 
-        // Detect the line ending style used in the document
-        let line_ending = detect_line_ending(content);
-
-        // Check if file ends with newline (supporting both LF and CRLF)
+        // Content has been normalized to LF at I/O boundary
+        // Check if file ends with newline
         let has_trailing_newline = content.ends_with('\n');
 
         // Check for missing trailing newline
         if !has_trailing_newline {
             let lines = &ctx.lines;
             let last_line_num = lines.len();
-            let last_line_content = lines.last().map(|s| s.content.as_str()).unwrap_or("");
+            let last_line_content = lines.last().map(|s| s.content(content)).unwrap_or("");
 
             // Calculate precise character range for the end of file
             // For missing newline, highlight the end of the last line
@@ -60,7 +50,7 @@ impl Rule for MD047SingleTrailingNewline {
             );
 
             warnings.push(LintWarning {
-                rule_name: Some(self.name()),
+                rule_name: Some(self.name().to_string()),
                 message: String::from("File should end with a single newline character"),
                 line: start_line,
                 column: start_col,
@@ -70,8 +60,8 @@ impl Rule for MD047SingleTrailingNewline {
                 fix: Some(Fix {
                     // For missing newline, insert at the end of the file
                     range: content.len()..content.len(),
-                    // Add newline using the detected line ending style
-                    replacement: line_ending.to_string(),
+                    // Always add LF - will be converted to CRLF at I/O boundary if needed
+                    replacement: "\n".to_string(),
                 }),
             });
         }
@@ -87,9 +77,7 @@ impl Rule for MD047SingleTrailingNewline {
             return Ok(String::new());
         }
 
-        // Detect the line ending style used in the document
-        let line_ending = detect_line_ending(content);
-
+        // Content has been normalized to LF at I/O boundary
         // Check if file already ends with a newline
         let has_trailing_newline = content.ends_with('\n');
 
@@ -97,10 +85,10 @@ impl Rule for MD047SingleTrailingNewline {
             return Ok(content.to_string());
         }
 
-        // Content doesn't end with newline, add one using detected style
-        let mut result = String::with_capacity(content.len() + line_ending.len());
+        // Content doesn't end with newline, add LF (will be converted at I/O boundary if needed)
+        let mut result = String::with_capacity(content.len() + 1);
         result.push_str(content);
-        result.push_str(line_ending);
+        result.push('\n');
         Ok(result)
     }
 
@@ -152,39 +140,19 @@ mod tests {
     }
 
     #[test]
-    fn test_crlf_line_ending_preservation() {
+    fn test_normalized_lf_content() {
+        // In production, content is normalized to LF before rules see it
+        // This test reflects the actual runtime behavior
         let rule = MD047SingleTrailingNewline;
-        // Content with CRLF line endings but missing final newline
-        let content = "Line 1\r\nLine 2";
+        let content = "Line 1\nLine 2";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
 
         let fixed = rule.fix(&ctx).unwrap();
-        // Should preserve CRLF style
-        assert_eq!(fixed, "Line 1\r\nLine 2\r\n");
-        assert!(fixed.ends_with("\r\n"), "Should end with CRLF");
-    }
-
-    #[test]
-    fn test_crlf_multiple_newlines() {
-        // Should not trigger when file has CRLF trailing newlines
-        let rule = MD047SingleTrailingNewline;
-        let content = "Line 1\r\nLine 2\r\n\r\n\r\n";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
-        let result = rule.check(&ctx).unwrap();
-        assert!(result.is_empty());
-    }
-
-    #[test]
-    fn test_detect_line_ending() {
-        assert_eq!(detect_line_ending("Line 1\nLine 2"), "\n");
-        assert_eq!(detect_line_ending("Line 1\r\nLine 2"), "\r\n");
-        assert_eq!(detect_line_ending("Single line"), "\n");
-        assert_eq!(detect_line_ending(""), "\n");
-
-        // Mixed line endings should detect CRLF (first match wins)
-        assert_eq!(detect_line_ending("Line 1\r\nLine 2\nLine 3"), "\r\n");
+        // Rule always adds LF - I/O boundary converts to CRLF if needed
+        assert_eq!(fixed, "Line 1\nLine 2\n");
+        assert!(fixed.ends_with('\n'), "Should end with LF");
     }
 
     #[test]
