@@ -1,6 +1,6 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
 use crate::rules::code_fence_utils::CodeFenceStyle;
-use crate::utils::range_utils::{LineIndex, calculate_match_range};
+use crate::utils::range_utils::calculate_match_range;
 use toml;
 
 mod md048_config;
@@ -26,7 +26,10 @@ impl MD048CodeFenceStyle {
     }
 
     fn detect_style(&self, ctx: &crate::lint_context::LintContext) -> Option<CodeFenceStyle> {
-        // Find the first code fence by looking for opening fences
+        // Count occurrences of each fence style (prevalence-based approach)
+        let mut backtick_count = 0;
+        let mut tilde_count = 0;
+        let mut in_code_block = false;
 
         for line in ctx.content.lines() {
             let trimmed = line.trim_start();
@@ -35,15 +38,30 @@ impl MD048CodeFenceStyle {
             if trimmed.starts_with("```") || trimmed.starts_with("~~~") {
                 let fence_char = if trimmed.starts_with("```") { '`' } else { '~' };
 
-                // This is an opening fence - return its style immediately
-                if fence_char == '`' {
-                    return Some(CodeFenceStyle::Backtick);
+                if !in_code_block {
+                    // Opening fence - count it
+                    if fence_char == '`' {
+                        backtick_count += 1;
+                    } else {
+                        tilde_count += 1;
+                    }
+                    in_code_block = true;
                 } else {
-                    return Some(CodeFenceStyle::Tilde);
+                    // Potential closing fence - exit code block
+                    in_code_block = false;
                 }
             }
         }
-        None
+
+        // Use the most prevalent style
+        // In case of a tie, prefer backticks (more common, widely supported)
+        if backtick_count >= tilde_count && backtick_count > 0 {
+            Some(CodeFenceStyle::Backtick)
+        } else if tilde_count > 0 {
+            Some(CodeFenceStyle::Tilde)
+        } else {
+            None
+        }
     }
 }
 
@@ -58,7 +76,7 @@ impl Rule for MD048CodeFenceStyle {
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
 
         let mut warnings = Vec::new();
 
@@ -96,7 +114,7 @@ impl Rule for MD048CodeFenceStyle {
                             calculate_match_range(line_num + 1, line, fence_start, fence_end - fence_start);
 
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             message: "Code fence style: use ~~~ instead of ```".to_string(),
                             line: start_line,
                             column: start_col,
@@ -118,7 +136,7 @@ impl Rule for MD048CodeFenceStyle {
                             calculate_match_range(line_num + 1, line, fence_start, fence_end - fence_start);
 
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             message: "Code fence style: use ``` instead of ~~~".to_string(),
                             line: start_line,
                             column: start_col,
@@ -144,7 +162,7 @@ impl Rule for MD048CodeFenceStyle {
                             calculate_match_range(line_num + 1, line, fence_start, fence_end - fence_start);
 
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             message: "Code fence style: use ~~~ instead of ```".to_string(),
                             line: start_line,
                             column: start_col,
@@ -166,7 +184,7 @@ impl Rule for MD048CodeFenceStyle {
                             calculate_match_range(line_num + 1, line, fence_start, fence_end - fence_start);
 
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             message: "Code fence style: use ``` instead of ~~~".to_string(),
                             line: start_line,
                             column: start_col,
@@ -193,7 +211,7 @@ impl Rule for MD048CodeFenceStyle {
     /// Check if this rule should be skipped for performance
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
         // Skip if content is empty or has no code fence markers
-        ctx.content.is_empty() || (!ctx.content.contains("```") && !ctx.content.contains("~~~"))
+        ctx.content.is_empty() || (!ctx.likely_has_code() && !ctx.has_char('~'))
     }
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
@@ -354,26 +372,28 @@ mod tests {
     }
 
     #[test]
-    fn test_consistent_style_first_backtick() {
+    fn test_consistent_style_tie_prefers_backtick() {
         let rule = MD048CodeFenceStyle::new(CodeFenceStyle::Consistent);
+        // One backtick fence and one tilde fence - tie should prefer backticks
         let content = "```\ncode\n```\n\n~~~\nmore code\n~~~";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
-        // First fence is backtick, so tildes should be flagged
+        // Backticks win due to tie-breaker, so tildes should be flagged
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].line, 5);
         assert_eq!(result[1].line, 7);
     }
 
     #[test]
-    fn test_consistent_style_first_tilde() {
+    fn test_consistent_style_tilde_most_prevalent() {
         let rule = MD048CodeFenceStyle::new(CodeFenceStyle::Consistent);
-        let content = "~~~\ncode\n~~~\n\n```\nmore code\n```";
+        // Two tilde fences and one backtick fence - tildes are most prevalent
+        let content = "~~~\ncode\n~~~\n\n```\nmore code\n```\n\n~~~\neven more\n~~~";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
-        // First fence is tilde, so backticks should be flagged
+        // Tildes are most prevalent, so backticks should be flagged
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].line, 5);
         assert_eq!(result[1].line, 7);
