@@ -1,17 +1,12 @@
-use crate::utils::range_utils::{LineIndex, calculate_match_range};
+use crate::utils::range_utils::calculate_match_range;
 use crate::utils::regex_cache::{BOLD_ASTERISK_REGEX, BOLD_UNDERSCORE_REGEX};
 
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
 use crate::rules::strong_style::StrongStyle;
-use lazy_static::lazy_static;
-use regex::Regex;
+use crate::utils::regex_cache::get_cached_regex;
 
-lazy_static! {
-    // Reference definition pattern - matches [ref]: url "title"
-    static ref REF_DEF_REGEX: Regex = Regex::new(
-        r#"(?m)^[ ]{0,3}\[([^\]]+)\]:\s*([^\s]+)(?:\s+(?:"([^"]*)"|'([^']*)'))?$"#
-    ).unwrap();
-}
+// Reference definition pattern
+const REF_DEF_REGEX_STR: &str = r#"(?m)^[ ]{0,3}\[([^\]]+)\]:\s*([^\s]+)(?:\s+(?:"([^"]*)"|'([^']*)'))?$"#;
 
 mod md050_config;
 use md050_config::MD050Config;
@@ -54,9 +49,11 @@ impl MD050StrongStyle {
         }
 
         // Check reference definitions [ref]: url "title" using regex pattern
-        for m in REF_DEF_REGEX.find_iter(ctx.content) {
-            if m.start() <= byte_pos && byte_pos < m.end() {
-                return true;
+        if let Ok(re) = get_cached_regex(REF_DEF_REGEX_STR) {
+            for m in re.find_iter(ctx.content) {
+                if m.start() <= byte_pos && byte_pos < m.end() {
+                    return true;
+                }
             }
         }
 
@@ -116,8 +113,8 @@ impl MD050StrongStyle {
     fn detect_style(&self, ctx: &crate::lint_context::LintContext) -> Option<StrongStyle> {
         let content = ctx.content;
 
-        // Find the first occurrence of either style that's not in a code block, link, HTML tag, or front matter
-        let mut first_asterisk = None;
+        // Count how many times each marker appears (prevalence-based approach)
+        let mut asterisk_count = 0;
         for m in BOLD_ASTERISK_REGEX.find_iter(content) {
             // Skip matches in front matter
             let (line_num, _) = ctx.offset_to_line_col(m.start());
@@ -132,12 +129,11 @@ impl MD050StrongStyle {
                 && !self.is_in_html_tag(ctx, m.start())
                 && !self.is_in_html_code_content(ctx, m.start())
             {
-                first_asterisk = Some(m);
-                break;
+                asterisk_count += 1;
             }
         }
 
-        let mut first_underscore = None;
+        let mut underscore_count = 0;
         for m in BOLD_UNDERSCORE_REGEX.find_iter(content) {
             // Skip matches in front matter
             let (line_num, _) = ctx.offset_to_line_col(m.start());
@@ -152,23 +148,23 @@ impl MD050StrongStyle {
                 && !self.is_in_html_tag(ctx, m.start())
                 && !self.is_in_html_code_content(ctx, m.start())
             {
-                first_underscore = Some(m);
-                break;
+                underscore_count += 1;
             }
         }
 
-        match (first_asterisk, first_underscore) {
-            (Some(a), Some(u)) => {
-                // Whichever pattern appears first determines the style
-                if a.start() < u.start() {
+        match (asterisk_count, underscore_count) {
+            (0, 0) => None,
+            (_, 0) => Some(StrongStyle::Asterisk),
+            (0, _) => Some(StrongStyle::Underscore),
+            (a, u) => {
+                // Use the most prevalent marker as the target style
+                // In case of a tie, prefer asterisk (matches CommonMark recommendation)
+                if a >= u {
                     Some(StrongStyle::Asterisk)
                 } else {
                     Some(StrongStyle::Underscore)
                 }
             }
-            (Some(_), None) => Some(StrongStyle::Asterisk),
-            (None, Some(_)) => Some(StrongStyle::Underscore),
-            (None, None) => None,
         }
     }
 
@@ -203,7 +199,7 @@ impl Rule for MD050StrongStyle {
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let line_index = &ctx.line_index;
 
         let mut warnings = Vec::new();
 
@@ -222,18 +218,16 @@ impl Rule for MD050StrongStyle {
             }
         };
 
-        // Track byte position for each line
-        let mut byte_pos = 0;
-
         for (line_num, line) in content.lines().enumerate() {
             // Skip if this line is in front matter
             if let Some(line_info) = ctx.line_info(line_num + 1)
                 && line_info.in_front_matter
             {
-                byte_pos += line.len() + 1; // +1 for newline
                 continue;
             }
 
+            let byte_pos = line_index.get_line_start_byte(line_num + 1).unwrap_or(0);
+
             for m in strong_regex.find_iter(line) {
                 // Calculate the byte position of this match in the document
                 let match_byte_pos = byte_pos + m.start();
@@ -277,7 +271,7 @@ impl Rule for MD050StrongStyle {
                         calculate_match_range(line_num + 1, line, m.start(), m.len());
 
                     warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         line: start_line,
                         column: start_col,
                         end_line,
@@ -285,7 +279,7 @@ impl Rule for MD050StrongStyle {
                         message: message.to_string(),
                         severity: Severity::Warning,
                         fix: Some(Fix {
-                            range: _line_index.line_col_to_byte_range(line_num + 1, m.start() + 1),
+                            range: line_index.line_col_to_byte_range(line_num + 1, m.start() + 1),
                             replacement: match target_style {
                                 StrongStyle::Asterisk => format!("**{text}**"),
                                 StrongStyle::Underscore => format!("__{text}__"),
@@ -299,9 +293,6 @@ impl Rule for MD050StrongStyle {
                     });
                 }
             }
-
-            // Update byte position for next line
-            byte_pos += line.len() + 1; // +1 for newline
         }
 
         Ok(warnings)
@@ -368,7 +359,8 @@ impl Rule for MD050StrongStyle {
 
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        ctx.content.is_empty() || (!ctx.content.contains("**") && !ctx.content.contains("__"))
+        // Strong uses double markers, but likely_has_emphasis checks for count > 1
+        ctx.content.is_empty() || !ctx.likely_has_emphasis()
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -466,18 +458,19 @@ mod tests {
     }
 
     #[test]
-    fn test_consistent_style_first_underscore() {
+    fn test_consistent_style_tie_prefers_asterisk() {
         let rule = MD050StrongStyle::new(StrongStyle::Consistent);
         let content = "First __strong__ then **also strong**.";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
-        // First strong is __, so ** should be flagged
+        // Equal counts (1 vs 1), so prefer asterisks per CommonMark recommendation
+        // The __ should be flagged to change to **
         assert_eq!(result.len(), 1);
         assert!(
             result[0]
                 .message
-                .contains("Strong emphasis should use __ instead of **")
+                .contains("Strong emphasis should use ** instead of __")
         );
     }
 
