@@ -2,41 +2,43 @@ use crate::rule::{LintError, LintResult, LintWarning, Rule, Severity};
 use crate::utils::mkdocs_patterns::is_mkdocs_auto_reference;
 use crate::utils::range_utils::calculate_match_range;
 use crate::utils::regex_cache::{HTML_COMMENT_PATTERN, SHORTCUT_REF_REGEX};
-use crate::utils::skip_context::{is_in_front_matter, is_in_math_context, is_in_table_cell};
-use lazy_static::lazy_static;
+use crate::utils::skip_context::{is_in_math_context, is_in_table_cell};
 use regex::Regex;
 use std::collections::{HashMap, HashSet};
+use std::sync::LazyLock;
 
-lazy_static! {
-    // Pattern to match reference definitions [ref]: url
-    // Note: \S* instead of \S+ to allow empty definitions like [ref]:
-    // The capturing group handles nested brackets to support cases like [`union[t, none]`]:
-    static ref REF_REGEX: Regex = Regex::new(r"^\s*\[((?:[^\[\]\\]|\\.|\[[^\]]*\])*)\]:\s*.*").unwrap();
+// Pattern to match reference definitions [ref]: url
+// Note: \S* instead of \S+ to allow empty definitions like [ref]:
+// The capturing group handles nested brackets to support cases like [`union[t, none]`]:
+static REF_REGEX: LazyLock<Regex> =
+    LazyLock::new(|| Regex::new(r"^\s*\[((?:[^\[\]\\]|\\.|\[[^\]]*\])*)\]:\s*.*").unwrap());
 
-    // Pattern for list items to exclude from reference checks (standard regex is fine)
-    static ref LIST_ITEM_REGEX: Regex = Regex::new(r"^\s*[-*+]\s+(?:\[[xX\s]\]\s+)?").unwrap();
+// Pattern for list items to exclude from reference checks (standard regex is fine)
+static LIST_ITEM_REGEX: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^\s*[-*+]\s+(?:\[[xX\s]\]\s+)?").unwrap());
 
-    // Pattern for code blocks (standard regex is fine)
-    static ref FENCED_CODE_START: Regex = Regex::new(r"^(\s*)(`{3,}|~{3,})").unwrap();
+// Pattern for code blocks (standard regex is fine)
+static FENCED_CODE_START: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^(\s*)(`{3,}|~{3,})").unwrap());
 
-    // Pattern for output example sections (standard regex is fine)
-    static ref OUTPUT_EXAMPLE_START: Regex = Regex::new(r"^#+\s*(?:Output|Example|Output Style|Output Format)\s*$").unwrap();
+// Pattern for output example sections (standard regex is fine)
+static OUTPUT_EXAMPLE_START: LazyLock<Regex> =
+    LazyLock::new(|| Regex::new(r"^#+\s*(?:Output|Example|Output Style|Output Format)\s*$").unwrap());
 
-    // Pattern for GitHub alerts/callouts in blockquotes (e.g., > [!NOTE], > [!TIP], etc.)
-    // Extended to include additional common alert types
-    static ref GITHUB_ALERT_REGEX: Regex = Regex::new(r"^\s*>\s*\[!(NOTE|TIP|IMPORTANT|WARNING|CAUTION|INFO|SUCCESS|FAILURE|DANGER|BUG|EXAMPLE|QUOTE)\]").unwrap();
+// Pattern for GitHub alerts/callouts in blockquotes (e.g., > [!NOTE], > [!TIP], etc.)
+// Extended to include additional common alert types
+static GITHUB_ALERT_REGEX: LazyLock<Regex> = LazyLock::new(|| {
+    Regex::new(r"^\s*>\s*\[!(NOTE|TIP|IMPORTANT|WARNING|CAUTION|INFO|SUCCESS|FAILURE|DANGER|BUG|EXAMPLE|QUOTE)\]")
+        .unwrap()
+});
 
-    // Pattern to detect URLs that may contain brackets (IPv6, API endpoints, etc.)
-    // This pattern specifically looks for:
-    // - IPv6 addresses: https://[::1] or https://[2001:db8::1]
-    // - IPv6 with zone IDs: https://[fe80::1%eth0]
-    // - IPv6 mixed notation: https://[::ffff:192.0.2.1]
-    // - API paths with array notation: https://api.example.com/users[0]
-    // But NOT markdown reference links that happen to follow URLs
-    static ref URL_WITH_BRACKETS: Regex = Regex::new(
-        r"https?://(?:\[[0-9a-fA-F:.%]+\]|[^\s\[\]]+/[^\s]*\[\d+\])"
-    ).unwrap();
-}
+// Pattern to detect URLs that may contain brackets (IPv6, API endpoints, etc.)
+// This pattern specifically looks for:
+// - IPv6 addresses: https://[::1] or https://[2001:db8::1]
+// - IPv6 with zone IDs: https://[fe80::1%eth0]
+// - IPv6 mixed notation: https://[::ffff:192.0.2.1]
+// - API paths with array notation: https://api.example.com/users[0]
+// But NOT markdown reference links that happen to follow URLs
+static URL_WITH_BRACKETS: LazyLock<Regex> =
+    LazyLock::new(|| Regex::new(r"https?://(?:\[[0-9a-fA-F:.%]+\]|[^\s\[\]]+/[^\s]*\[\d+\])").unwrap());
 
 /// Rule MD052: Reference links and images should use reference style
 ///
@@ -51,9 +53,34 @@ impl MD052ReferenceLinkImages {
         Self {}
     }
 
-    /// Check if a pattern is likely NOT a markdown reference
-    /// Returns true if this pattern should be skipped
-    fn is_likely_not_reference(text: &str) -> bool {
+    /// Strip surrounding backticks from a string
+    /// Used for MkDocs auto-reference detection where `module.Class` should be treated as module.Class
+    fn strip_backticks(s: &str) -> &str {
+        s.trim_start_matches('`').trim_end_matches('`')
+    }
+
+    /// Check if a string is a valid Python identifier
+    /// Used for MkDocs auto-reference detection where single-word backtick-wrapped identifiers
+    /// like `str`, `int`, etc. should be accepted as valid auto-references
+    fn is_valid_python_identifier(s: &str) -> bool {
+        if s.is_empty() {
+            return false;
+        }
+        let first_char = s.chars().next().unwrap();
+        if !first_char.is_ascii_alphabetic() && first_char != '_' {
+            return false;
+        }
+        s.chars().all(|c| c.is_ascii_alphanumeric() || c == '_')
+    }
+
+    /// Check if text matches a known non-reference pattern that should be skipped.
+    ///
+    /// These are deterministic patterns from markdown extensions or code examples,
+    /// not heuristics. Returns true for:
+    /// - Markdown extensions: [^footnote], [@citation], [!alert], [TOC]
+    /// - Programming syntax: [T], [null], [i32], ["string"]
+    /// - Descriptive text: [default: value], [0-9]
+    fn is_known_non_reference_pattern(text: &str) -> bool {
         // Skip numeric patterns (array indices, ranges)
         if text.chars().all(|c| c.is_ascii_digit()) {
             return true;
@@ -65,8 +92,14 @@ impl MD052ReferenceLinkImages {
         }
 
         // Skip patterns that look like config sections [tool.something], [section.subsection]
-        // But not if they contain other non-alphanumeric chars like hyphens or underscores
-        if text.contains('.') && !text.contains(' ') && !text.contains('-') && !text.contains('_') {
+        // But not if they contain other non-alphanumeric chars like hyphens, underscores, or backticks
+        // Backticks indicate intentional code formatting in a reference name (e.g., [`module.Class`])
+        if text.contains('.')
+            && !text.contains(' ')
+            && !text.contains('-')
+            && !text.contains('_')
+            && !text.contains('`')
+        {
             // Config sections typically have dots, no spaces, and only alphanumeric + dots
             return true;
         }
@@ -138,16 +171,66 @@ impl MD052ReferenceLinkImages {
             return true;
         }
 
+        // Skip footnote syntax like [^1], [^note], etc.
+        // Footnotes start with ^ and are a common markdown extension
+        if text.starts_with('^') {
+            return true;
+        }
+
+        // Skip Pandoc/RMarkdown/Quarto citation syntax like [@citation-key]
+        // Citations in these formats start with @ inside brackets
+        if text.starts_with('@') {
+            return true;
+        }
+
+        // Skip table of contents markers like [TOC]
+        // Used by Python-Markdown and other processors
+        if text == "TOC" {
+            return true;
+        }
+
         // Skip single uppercase letters (likely type parameters) like [T], [U], [K], [V]
         if text.len() == 1 && text.chars().all(|c| c.is_ascii_uppercase()) {
             return true;
         }
 
-        // Skip common programming type names and short identifiers
+        // Skip common programming type names, literals, and short identifiers
         // that are likely not markdown references
         let common_non_refs = [
-            "object", "Object", "any", "Any", "inv", "void", "bool", "int", "float", "str", "char", "i8", "i16", "i32",
-            "i64", "i128", "isize", "u8", "u16", "u32", "u64", "u128", "usize", "f32", "f64",
+            // Programming types
+            "object",
+            "Object",
+            "any",
+            "Any",
+            "inv",
+            "void",
+            "bool",
+            "int",
+            "float",
+            "str",
+            "char",
+            "i8",
+            "i16",
+            "i32",
+            "i64",
+            "i128",
+            "isize",
+            "u8",
+            "u16",
+            "u32",
+            "u64",
+            "u128",
+            "usize",
+            "f32",
+            "f64",
+            // JavaScript/JSON literals (excluding "undefined" which is too ambiguous)
+            "null",
+            "true",
+            "false",
+            "NaN",
+            "Infinity",
+            // Common JavaScript output patterns
+            "object Object",
         ];
 
         if common_non_refs.contains(&text) {
@@ -273,6 +356,11 @@ impl MD052ReferenceLinkImages {
                 continue; // Skip inline links
             }
 
+            // Skip links inside Jinja templates
+            if ctx.is_in_jinja_range(link.byte_offset) {
+                continue;
+            }
+
             // Skip links inside code spans
             if Self::is_in_code_span(link.line, link.start_col, &code_spans) {
                 continue;
@@ -298,17 +386,30 @@ impl MD052ReferenceLinkImages {
                 continue;
             }
 
-            // Skip links inside frontmatter (convert from 1-based to 0-based line numbers)
-            if is_in_front_matter(content, link.line.saturating_sub(1)) {
+            // Skip links inside frontmatter
+            if ctx.line_info(link.line).is_some_and(|info| info.in_front_matter) {
                 continue;
             }
 
             if let Some(ref_id) = &link.reference_id {
                 let reference_lower = ref_id.to_lowercase();
 
+                // Skip known non-reference patterns (markdown extensions, code examples)
+                if Self::is_known_non_reference_pattern(ref_id) {
+                    continue;
+                }
+
                 // Skip MkDocs auto-references if in MkDocs mode
                 // Check both the reference_id and the link text for shorthand references
-                if mkdocs_mode && (is_mkdocs_auto_reference(ref_id) || is_mkdocs_auto_reference(&link.text)) {
+                // Strip backticks since MkDocs resolves `module.Class` as module.Class
+                let stripped_ref = Self::strip_backticks(ref_id);
+                let stripped_text = Self::strip_backticks(&link.text);
+                if mkdocs_mode
+                    && (is_mkdocs_auto_reference(stripped_ref)
+                        || is_mkdocs_auto_reference(stripped_text)
+                        || (ref_id != stripped_ref && Self::is_valid_python_identifier(stripped_ref))
+                        || (link.text.as_ref() != stripped_text && Self::is_valid_python_identifier(stripped_text)))
+                {
                     continue;
                 }
 
@@ -316,7 +417,7 @@ impl MD052ReferenceLinkImages {
                 if !references.contains(&reference_lower) && !reported_refs.contains_key(&reference_lower) {
                     // Check if the line is in an example section or list item
                     if let Some(line_info) = ctx.line_info(link.line) {
-                        if OUTPUT_EXAMPLE_START.is_match(&line_info.content) {
+                        if OUTPUT_EXAMPLE_START.is_match(line_info.content(ctx.content)) {
                             in_example_section = true;
                             continue;
                         }
@@ -326,19 +427,19 @@ impl MD052ReferenceLinkImages {
                         }
 
                         // Skip list items
-                        if LIST_ITEM_REGEX.is_match(&line_info.content) {
+                        if LIST_ITEM_REGEX.is_match(line_info.content(ctx.content)) {
                             continue;
                         }
 
                         // Skip lines that are HTML content
-                        let trimmed = line_info.content.trim_start();
+                        let trimmed = line_info.content(ctx.content).trim_start();
                         if trimmed.starts_with('<') {
                             continue;
                         }
                     }
 
                     let match_len = link.byte_end - link.byte_offset;
-                    undefined.push((link.line - 1, link.start_col, match_len, ref_id.clone()));
+                    undefined.push((link.line - 1, link.start_col, match_len, ref_id.to_string()));
                     reported_refs.insert(reference_lower, true);
                 }
             }
@@ -350,6 +451,11 @@ impl MD052ReferenceLinkImages {
                 continue; // Skip inline images
             }
 
+            // Skip images inside Jinja templates
+            if ctx.is_in_jinja_range(image.byte_offset) {
+                continue;
+            }
+
             // Skip images inside code spans
             if Self::is_in_code_span(image.line, image.start_col, &code_spans) {
                 continue;
@@ -375,17 +481,30 @@ impl MD052ReferenceLinkImages {
                 continue;
             }
 
-            // Skip images inside frontmatter (convert from 1-based to 0-based line numbers)
-            if is_in_front_matter(content, image.line.saturating_sub(1)) {
+            // Skip images inside frontmatter
+            if ctx.line_info(image.line).is_some_and(|info| info.in_front_matter) {
                 continue;
             }
 
             if let Some(ref_id) = &image.reference_id {
                 let reference_lower = ref_id.to_lowercase();
 
+                // Skip known non-reference patterns (markdown extensions, code examples)
+                if Self::is_known_non_reference_pattern(ref_id) {
+                    continue;
+                }
+
                 // Skip MkDocs auto-references if in MkDocs mode
                 // Check both the reference_id and the alt text for shorthand references
-                if mkdocs_mode && (is_mkdocs_auto_reference(ref_id) || is_mkdocs_auto_reference(&image.alt_text)) {
+                // Strip backticks since MkDocs resolves `module.Class` as module.Class
+                let stripped_ref = Self::strip_backticks(ref_id);
+                let stripped_alt = Self::strip_backticks(&image.alt_text);
+                if mkdocs_mode
+                    && (is_mkdocs_auto_reference(stripped_ref)
+                        || is_mkdocs_auto_reference(stripped_alt)
+                        || (ref_id != stripped_ref && Self::is_valid_python_identifier(stripped_ref))
+                        || (image.alt_text.as_ref() != stripped_alt && Self::is_valid_python_identifier(stripped_alt)))
+                {
                     continue;
                 }
 
@@ -393,7 +512,7 @@ impl MD052ReferenceLinkImages {
                 if !references.contains(&reference_lower) && !reported_refs.contains_key(&reference_lower) {
                     // Check if the line is in an example section or list item
                     if let Some(line_info) = ctx.line_info(image.line) {
-                        if OUTPUT_EXAMPLE_START.is_match(&line_info.content) {
+                        if OUTPUT_EXAMPLE_START.is_match(line_info.content(ctx.content)) {
                             in_example_section = true;
                             continue;
                         }
@@ -403,19 +522,19 @@ impl MD052ReferenceLinkImages {
                         }
 
                         // Skip list items
-                        if LIST_ITEM_REGEX.is_match(&line_info.content) {
+                        if LIST_ITEM_REGEX.is_match(line_info.content(ctx.content)) {
                             continue;
                         }
 
                         // Skip lines that are HTML content
-                        let trimmed = line_info.content.trim_start();
+                        let trimmed = line_info.content(ctx.content).trim_start();
                         if trimmed.starts_with('<') {
                             continue;
                         }
                     }
 
                     let match_len = image.byte_end - image.byte_offset;
-                    undefined.push((image.line - 1, image.start_col, match_len, ref_id.clone()));
+                    undefined.push((image.line - 1, image.start_col, match_len, ref_id.to_string()));
                     reported_refs.insert(reference_lower, true);
                 }
             }
@@ -443,8 +562,8 @@ impl MD052ReferenceLinkImages {
         in_example_section = false; // Reset for line-by-line processing
 
         for (line_num, line) in lines.iter().enumerate() {
-            // Skip lines in frontmatter (line_num is already 0-based)
-            if is_in_front_matter(content, line_num) {
+            // Skip lines in frontmatter (convert 0-based to 1-based for line_info)
+            if ctx.line_info(line_num + 1).is_some_and(|info| info.in_front_matter) {
                 continue;
             }
 
@@ -556,11 +675,22 @@ impl MD052ReferenceLinkImages {
                             continue;
                         }
 
+                        // Skip Pandoc/RMarkdown inline footnotes: ^[text]
+                        // Check if there's a ^ immediately before the opening bracket
+                        if bracket_start > 0 {
+                            // bracket_start is a byte offset, so we need to check the byte before
+                            if let Some(byte) = line.as_bytes().get(bracket_start.saturating_sub(1))
+                                && *byte == b'^'
+                            {
+                                continue; // This is an inline footnote, skip it
+                            }
+                        }
+
                         let reference = ref_match.as_str();
                         let reference_lower = reference.to_lowercase();
 
-                        // Skip patterns that are likely not markdown references
-                        if Self::is_likely_not_reference(reference) {
+                        // Skip known non-reference patterns (markdown extensions, code examples)
+                        if Self::is_known_non_reference_pattern(reference) {
                             continue;
                         }
 
@@ -596,7 +726,12 @@ impl MD052ReferenceLinkImages {
                         }
 
                         // Skip MkDocs auto-references if in MkDocs mode
-                        if mkdocs_mode && is_mkdocs_auto_reference(reference) {
+                        // Strip backticks since MkDocs resolves `module.Class` as module.Class
+                        let stripped_ref = Self::strip_backticks(reference);
+                        if mkdocs_mode
+                            && (is_mkdocs_auto_reference(stripped_ref)
+                                || (reference != stripped_ref && Self::is_valid_python_identifier(stripped_ref)))
+                        {
                             continue;
                         }
 
@@ -614,6 +749,19 @@ impl MD052ReferenceLinkImages {
                             let line_start_byte = ctx.line_offsets[line_num];
                             let byte_pos = line_start_byte + col;
 
+                            // Skip if inside Jinja template
+                            if ctx.is_in_jinja_range(byte_pos) {
+                                continue;
+                            }
+
+                            // Skip if inside code block
+                            if crate::utils::code_block_utils::CodeBlockUtils::is_in_code_block(
+                                &ctx.code_blocks,
+                                byte_pos,
+                            ) {
+                                continue;
+                            }
+
                             // Skip if inside HTML comment
                             if Self::is_in_html_comment(content, byte_pos) {
                                 continue;
@@ -732,33 +880,11 @@ impl Rule for MD052ReferenceLinkImages {
         let content = ctx.content;
         let mut warnings = Vec::new();
 
-        // OPTIMIZATION: Early exit if no reference-style links/images exist
-        // Check if there are any reference-style links or images in the document
-        let has_reference_links = ctx.links.iter().any(|l| l.is_reference);
-        let has_reference_images = ctx.images.iter().any(|i| i.is_reference);
-
-        // Quick check: If document contains no brackets at all, nothing to check
+        // OPTIMIZATION: Early exit if no brackets at all
         if !content.contains('[') {
             return Ok(warnings);
         }
 
-        // Quick check for reference definitions
-        let has_reference_definitions = content.contains("]:");
-
-        // If we have no reference links/images AND no reference definitions,
-        // then check if we might have shortcut references [text]
-        if !has_reference_links && !has_reference_images && !has_reference_definitions {
-            // Only do expensive shortcut checking if we have brackets but no links/images/refs
-            // This handles the case where all brackets are inline links [text](url)
-            let all_brackets_are_inline = ctx.links.iter().all(|l| !l.is_reference)
-                && ctx.images.iter().all(|i| !i.is_reference)
-                && ctx.links.len() + ctx.images.len() > 0;
-
-            if all_brackets_are_inline {
-                return Ok(warnings); // All brackets accounted for as inline links/images
-            }
-        }
-
         // Check if we're in MkDocs mode from the context
         let mkdocs_mode = ctx.flavor == crate::config::MarkdownFlavor::MkDocs;
 
@@ -776,7 +902,7 @@ impl Rule for MD052ReferenceLinkImages {
                 calculate_match_range(line_num + 1, line_content, col, match_len);
 
             warnings.push(LintWarning {
-                rule_name: Some(self.name()),
+                rule_name: Some(self.name().to_string()),
                 line: start_line,
                 column: start_col,
                 end_line,
@@ -792,8 +918,8 @@ impl Rule for MD052ReferenceLinkImages {
 
     /// Check if this rule should be skipped for performance
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        // Skip if content is empty or has no reference-style links/images
-        ctx.content.is_empty() || (!ctx.content.contains("](") && !ctx.content.contains("]["))
+        // Skip if content is empty or has no links/images
+        ctx.content.is_empty() || !ctx.likely_has_links_or_images()
     }
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
@@ -1337,6 +1463,57 @@ Regular [undefined] reference outside snippet markers."#;
         );
     }
 
+    #[test]
+    fn test_pandoc_citations_not_flagged() {
+        // Test that Pandoc/RMarkdown/Quarto citation syntax is not flagged
+        let rule = MD052ReferenceLinkImages::new();
+
+        let content = r#"# Research Paper
+
+We are using the **bookdown** package [@R-bookdown] in this sample book.
+This was built on top of R Markdown and **knitr** [@xie2015].
+
+Multiple citations [@citation1; @citation2; @citation3] are also supported.
+
+Regular [undefined] reference should still be flagged.
+"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should only flag the undefined reference, not the citations
+        assert_eq!(
+            result.len(),
+            1,
+            "Should only flag the undefined reference, not Pandoc citations"
+        );
+        assert!(result[0].message.contains("undefined"));
+    }
+
+    #[test]
+    fn test_pandoc_inline_footnotes_not_flagged() {
+        // Test that Pandoc inline footnote syntax is not flagged
+        let rule = MD052ReferenceLinkImages::new();
+
+        let content = r#"# Math Document
+
+You can use math in footnotes like this^[where we mention $p = \frac{a}{b}$].
+
+Another footnote^[with some text and a [link](https://example.com)].
+
+But this [reference] without ^ should be flagged.
+"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should only flag the reference without ^
+        assert_eq!(
+            result.len(),
+            1,
+            "Should only flag the regular reference, not inline footnotes"
+        );
+        assert!(result[0].message.contains("reference"));
+    }
+
     #[test]
     fn test_github_alerts_not_flagged() {
         // Test for issue #60 - GitHub alerts should not be flagged as undefined references
