@@ -5,24 +5,19 @@
 
 use crate::rule::{LintError, LintResult, LintWarning, Rule, Severity};
 use crate::utils::range_utils::calculate_match_range;
-use lazy_static::lazy_static;
 use regex::Regex;
-use serde::{Deserialize, Serialize};
+use std::sync::LazyLock;
 
 mod md054_config;
 use md054_config::MD054Config;
 
-lazy_static! {
-    // Updated regex patterns that work with Unicode characters
-    static ref AUTOLINK_RE: Regex = Regex::new(r"<([^<>]+)>").unwrap();
-    static ref INLINE_RE: Regex = Regex::new(r"\[([^\]]+)\]\(([^)]+)\)").unwrap();
-    static ref URL_INLINE_RE: Regex = Regex::new(r"\[([^\]]+)\]\(([^)]+)\)").unwrap();
-    static ref SHORTCUT_RE: Regex = Regex::new(r"\[([^\]]+)\]").unwrap();
-    static ref COLLAPSED_RE: Regex = Regex::new(r"\[([^\]]+)\]\[\]").unwrap();
-    static ref FULL_RE: Regex = Regex::new(r"\[([^\]]+)\]\[([^\]]+)\]").unwrap();
-    static ref CODE_BLOCK_DELIMITER: Regex = Regex::new(r"^(```|~~~)").unwrap();
-    static ref REFERENCE_DEF_RE: Regex = Regex::new(r"^\s*\[([^\]]+)\]:\s+(.+)$").unwrap();
-}
+// Updated regex patterns that work with Unicode characters
+static AUTOLINK_RE: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"<([^<>]+)>").unwrap());
+static INLINE_RE: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"\[([^\]]+)\]\(([^)]+)\)").unwrap());
+static SHORTCUT_RE: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"\[([^\]]+)\]").unwrap());
+static COLLAPSED_RE: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"\[([^\]]+)\]\[\]").unwrap());
+static FULL_RE: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"\[([^\]]+)\]\[([^\]]+)\]").unwrap());
+static REFERENCE_DEF_RE: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^\s*\[([^\]]+)\]:\s+(.+)$").unwrap());
 
 /// Rule MD054: Link and image style should be consistent
 ///
@@ -68,16 +63,6 @@ lazy_static! {
 /// styles have different advantages (e.g., inline links are self-contained, reference links
 /// keep the content cleaner), but mixing styles can create confusion.
 ///
-#[derive(Debug, Eq, PartialEq, Hash, Serialize, Deserialize, Clone)]
-pub enum LinkImageStyle {
-    Autolink,
-    Inline,
-    UrlInline,
-    Shortcut,
-    Collapsed,
-    Full,
-}
-
 #[derive(Debug, Default, Clone)]
 pub struct MD054LinkImageStyle {
     config: MD054Config,
@@ -149,7 +134,7 @@ impl Rule for MD054LinkImageStyle {
 
         for (line_num, line) in lines.iter().enumerate() {
             // Skip code blocks and reference definitions early
-            if ctx.is_in_code_block(line_num + 1) {
+            if ctx.line_info(line_num + 1).is_some_and(|info| info.in_code_block) {
                 continue;
             }
             if REFERENCE_DEF_RE.is_match(line) {
@@ -253,18 +238,18 @@ impl Rule for MD054LinkImageStyle {
             for m in filtered_matches {
                 let match_start_char = line[..m.start].chars().count();
 
-                if !ctx.is_in_code_span(line_num + 1, match_start_char + 1) && !self.is_style_allowed(m.style) {
+                if !ctx.is_in_code_span(line_num + 1, match_start_char) && !self.is_style_allowed(m.style) {
                     let match_len = line[m.start..m.end].chars().count();
                     let (start_line, start_col, end_line, end_col) =
                         calculate_match_range(line_num + 1, line, match_start_char, match_len);
 
                     warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         line: start_line,
                         column: start_col,
                         end_line,
                         end_column: end_col,
-                        message: format!("Link/image style '{}' is not consistent with document", m.style),
+                        message: format!("Link/image style '{}' is not allowed", m.style),
                         severity: Severity::Warning,
                         fix: None,
                     });
@@ -285,6 +270,10 @@ impl Rule for MD054LinkImageStyle {
         crate::rule::FixCapability::Unfixable
     }
 
+    fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
+        ctx.content.is_empty() || !ctx.likely_has_links_or_images()
+    }
+
     fn as_any(&self) -> &dyn std::any::Any {
         self
     }
