@@ -1,5 +1,5 @@
 use crate::rule::{LintError, LintResult, LintWarning, Rule, Severity};
-use crate::utils::range_utils::{LineIndex, calculate_line_range};
+use crate::utils::range_utils::calculate_line_range;
 use crate::utils::table_utils::TableUtils;
 
 mod md055_config;
@@ -94,68 +94,80 @@ impl MD055TablePipeStyle {
     }
 
     /// Fix a table row to match the target style
+    /// Uses surgical fixes: only adds/removes pipes, preserves all user formatting
     fn fix_table_row(&self, line: &str, target_style: &str) -> String {
         let trimmed = line.trim();
         if !trimmed.contains('|') {
             return line.to_string();
         }
 
-        // Check if this is a delimiter row (contains dashes)
-        let is_delimiter_row = trimmed.contains('-')
-            && trimmed
-                .chars()
-                .all(|c| c == '-' || c == ':' || c == '|' || c.is_whitespace());
+        let has_leading = trimmed.starts_with('|');
+        let has_trailing = trimmed.ends_with('|');
 
-        // Split the line by pipes to get the content
-        let parts: Vec<&str> = trimmed.split('|').collect();
-        let mut content_parts = Vec::new();
-
-        // Extract the actual content (skip empty leading/trailing parts)
-        let start_idx = if parts.first().is_some_and(|p| p.trim().is_empty()) {
-            1
-        } else {
-            0
-        };
-        let end_idx = if parts.last().is_some_and(|p| p.trim().is_empty()) {
-            if !parts.is_empty() { parts.len() - 1 } else { 0 }
-        } else {
-            parts.len()
-        };
-
-        for part in parts.iter().take(end_idx).skip(start_idx) {
-            // Trim each part to remove extra spaces, but preserve the content
-            content_parts.push(part.trim());
-        }
-
-        // Rebuild the line with the target style
         match target_style {
             "leading_and_trailing" => {
-                if is_delimiter_row {
-                    format!("| {} |", content_parts.join("|"))
-                } else {
-                    format!("| {} |", content_parts.join(" | "))
+                let mut result = trimmed.to_string();
+
+                // Add leading pipe if missing
+                if !has_leading {
+                    result = format!("| {result}");
                 }
-            }
-            "leading_only" => {
-                if is_delimiter_row {
-                    format!("| {}", content_parts.join("|"))
-                } else {
-                    format!("| {}", content_parts.join(" | "))
-                }
-            }
-            "trailing_only" => {
-                if is_delimiter_row {
-                    format!("{} |", content_parts.join("|"))
-                } else {
-                    format!("{} |", content_parts.join(" | "))
+
+                // Add trailing pipe if missing
+                if !has_trailing {
+                    result = format!("{result} |");
                 }
+
+                result
             }
             "no_leading_or_trailing" => {
-                if is_delimiter_row {
-                    content_parts.join("|")
-                } else {
-                    content_parts.join(" | ")
+                let mut result = trimmed;
+
+                // Remove leading pipe if present
+                if has_leading {
+                    result = result.strip_prefix('|').unwrap_or(result);
+                    result = result.trim_start();
                 }
+
+                // Remove trailing pipe if present
+                if has_trailing {
+                    result = result.strip_suffix('|').unwrap_or(result);
+                    result = result.trim_end();
+                }
+
+                result.to_string()
+            }
+            "leading_only" => {
+                let mut result = trimmed.to_string();
+
+                // Add leading pipe if missing
+                if !has_leading {
+                    result = format!("| {result}");
+                }
+
+                // Remove trailing pipe if present
+                if has_trailing {
+                    result = result.strip_suffix('|').unwrap_or(&result).trim_end().to_string();
+                }
+
+                result
+            }
+            "trailing_only" => {
+                let mut result = trimmed;
+
+                // Remove leading pipe if present
+                if has_leading {
+                    result = result.strip_prefix('|').unwrap_or(result).trim_start();
+                }
+
+                let mut result = result.to_string();
+
+                // Add trailing pipe if missing
+                if !has_trailing {
+                    result = format!("{result} |");
+                }
+
+                result
             }
             _ => line.to_string(),
         }
@@ -172,19 +184,16 @@ impl Rule for MD055TablePipeStyle {
     }
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        // Skip if no pipe characters present (no tables)
-        !ctx.content.contains('|')
+        // Skip if no tables present (uses cached pipe count)
+        !ctx.likely_has_tables()
     }
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
-        let line_index = LineIndex::new(content.to_string());
+        let line_index = &ctx.line_index;
         let mut warnings = Vec::new();
 
-        // Early return for empty content or content without tables
-        if content.is_empty() || !content.contains('|') {
-            return Ok(Vec::new());
-        }
+        // Early return handled by should_skip()
 
         let lines: Vec<&str> = content.lines().collect();
 
@@ -199,27 +208,63 @@ impl Rule for MD055TablePipeStyle {
             }
         };
 
-        // Use shared table detection for better performance
-        let table_blocks = TableUtils::find_table_blocks(content, ctx);
+        // Use pre-computed table blocks from context
+        let table_blocks = &ctx.table_blocks;
 
         // Process each table block
         for table_block in table_blocks {
             let mut table_style = None;
 
             // First pass: determine the table's style for "consistent" mode
+            // Count all rows to determine most prevalent style (prevalence-based approach)
             if configured_style == "consistent" {
-                // Check header row first
+                let mut leading_and_trailing_count = 0;
+                let mut no_leading_or_trailing_count = 0;
+                let mut leading_only_count = 0;
+                let mut trailing_only_count = 0;
+
+                // Count style of header row
                 if let Some(style) = TableUtils::determine_pipe_style(lines[table_block.header_line]) {
-                    table_style = Some(style);
-                } else {
-                    // Check content rows if header doesn't have a clear style
-                    for &line_idx in &table_block.content_lines {
-                        if let Some(style) = TableUtils::determine_pipe_style(lines[line_idx]) {
-                            table_style = Some(style);
-                            break;
+                    match style {
+                        "leading_and_trailing" => leading_and_trailing_count += 1,
+                        "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
+                        "leading_only" => leading_only_count += 1,
+                        "trailing_only" => trailing_only_count += 1,
+                        _ => {}
+                    }
+                }
+
+                // Count style of content rows
+                for &line_idx in &table_block.content_lines {
+                    if let Some(style) = TableUtils::determine_pipe_style(lines[line_idx]) {
+                        match style {
+                            "leading_and_trailing" => leading_and_trailing_count += 1,
+                            "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
+                            "leading_only" => leading_only_count += 1,
+                            "trailing_only" => trailing_only_count += 1,
+                            _ => {}
                         }
                     }
                 }
+
+                // Determine most prevalent style
+                // In case of tie, prefer leading_and_trailing (most common, widely supported)
+                let max_count = leading_and_trailing_count
+                    .max(no_leading_or_trailing_count)
+                    .max(leading_only_count)
+                    .max(trailing_only_count);
+
+                if max_count > 0 {
+                    if leading_and_trailing_count == max_count {
+                        table_style = Some("leading_and_trailing");
+                    } else if no_leading_or_trailing_count == max_count {
+                        table_style = Some("no_leading_or_trailing");
+                    } else if leading_only_count == max_count {
+                        table_style = Some("leading_only");
+                    } else if trailing_only_count == max_count {
+                        table_style = Some("trailing_only");
+                    }
+                }
             }
 
             // Determine target style for this table
@@ -256,7 +301,7 @@ impl Rule for MD055TablePipeStyle {
 
                         let fixed_line = self.fix_table_row(line, target_style);
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             severity: Severity::Warning,
                             message,
                             line: start_line,
@@ -295,8 +340,8 @@ impl Rule for MD055TablePipeStyle {
             }
         };
 
-        // Use shared table detection for better performance
-        let table_blocks = TableUtils::find_table_blocks(content, ctx);
+        // Use pre-computed table blocks from context
+        let table_blocks = &ctx.table_blocks;
 
         // Create a copy of lines that we can modify
         let mut result_lines = lines.iter().map(|&s| s.to_string()).collect::<Vec<String>>();
@@ -306,19 +351,55 @@ impl Rule for MD055TablePipeStyle {
             let mut table_style = None;
 
             // First pass: determine the table's style for "consistent" mode
+            // Count all rows to determine most prevalent style (prevalence-based approach)
             if configured_style == "consistent" {
-                // Check header row first
+                let mut leading_and_trailing_count = 0;
+                let mut no_leading_or_trailing_count = 0;
+                let mut leading_only_count = 0;
+                let mut trailing_only_count = 0;
+
+                // Count style of header row
                 if let Some(style) = TableUtils::determine_pipe_style(lines[table_block.header_line]) {
-                    table_style = Some(style);
-                } else {
-                    // Check content rows if header doesn't have a clear style
-                    for &line_idx in &table_block.content_lines {
-                        if let Some(style) = TableUtils::determine_pipe_style(lines[line_idx]) {
-                            table_style = Some(style);
-                            break;
+                    match style {
+                        "leading_and_trailing" => leading_and_trailing_count += 1,
+                        "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
+                        "leading_only" => leading_only_count += 1,
+                        "trailing_only" => trailing_only_count += 1,
+                        _ => {}
+                    }
+                }
+
+                // Count style of content rows
+                for &line_idx in &table_block.content_lines {
+                    if let Some(style) = TableUtils::determine_pipe_style(lines[line_idx]) {
+                        match style {
+                            "leading_and_trailing" => leading_and_trailing_count += 1,
+                            "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
+                            "leading_only" => leading_only_count += 1,
+                            "trailing_only" => trailing_only_count += 1,
+                            _ => {}
                         }
                     }
                 }
+
+                // Determine most prevalent style
+                // In case of tie, prefer leading_and_trailing (most common, widely supported)
+                let max_count = leading_and_trailing_count
+                    .max(no_leading_or_trailing_count)
+                    .max(leading_only_count)
+                    .max(trailing_only_count);
+
+                if max_count > 0 {
+                    if leading_and_trailing_count == max_count {
+                        table_style = Some("leading_and_trailing");
+                    } else if no_leading_or_trailing_count == max_count {
+                        table_style = Some("no_leading_or_trailing");
+                    } else if leading_only_count == max_count {
+                        table_style = Some("leading_only");
+                    } else if trailing_only_count == max_count {
+                        table_style = Some("trailing_only");
+                    }
+                }
             }
 
             // Determine target style for this table
@@ -340,7 +421,12 @@ impl Rule for MD055TablePipeStyle {
             }
         }
 
-        Ok(result_lines.join("\n"))
+        let mut fixed = result_lines.join("\n");
+        // Preserve trailing newline if original content had one
+        if content.ends_with('\n') && !fixed.ends_with('\n') {
+            fixed.push('\n');
+        }
+        Ok(fixed)
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -378,7 +464,8 @@ mod tests {
         let result = rule.fix(&ctx).unwrap();
 
         // With the fixed implementation, the delimiter row should have pipes removed
-        let expected = "Header 1 | Header 2 | Header 3\n----------|----------|----------\nData 1 | Data 2 | Data 3";
+        // Spacing is preserved from original input
+        let expected = "Header 1 | Header 2 | Header 3\n----------|----------|----------\nData 1   | Data 2   | Data 3";
 
         assert_eq!(result, expected);
 
@@ -398,12 +485,9 @@ mod tests {
         let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.fix(&ctx).unwrap();
 
-        // Output the actual result for debugging
-        log::info!("Actual leading_and_trailing result:\n{}", result.replace('\n', "\\n"));
-
-        // The delimiter row should have pipes added with spacing as in the implementation
-        let expected =
-            "| Header 1 | Header 2 | Header 3 |\n| ----------|----------|---------- |\n| Data 1 | Data 2 | Data 3 |";
+        // The delimiter row should have pipes added
+        // Spacing is preserved from original input
+        let expected = "| Header 1 | Header 2 | Header 3 |\n| ----------|----------|---------- |\n| Data 1   | Data 2   | Data 3 |";
 
         assert_eq!(result, expected);
     }
@@ -438,8 +522,9 @@ mod tests {
         let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.fix(&ctx).unwrap();
 
-        // The table should be fixed, with delimiter row pipes properly removed
-        let expected = "# Table Example\n\nHere's a table with leading and trailing pipes:\n\nHeader 1 | Header 2 | Header 3\n----------|----------|----------\nData 1 | Data 2 | Data 3\nData 4 | Data 5 | Data 6\n\nMore content after the table.";
+        // The table should be fixed, with pipes removed
+        // Spacing is preserved from original input
+        let expected = "# Table Example\n\nHere's a table with leading and trailing pipes:\n\nHeader 1 | Header 2 | Header 3\n----------|----------|----------\nData 1   | Data 2   | Data 3\nData 4   | Data 5   | Data 6\n\nMore content after the table.";
 
         assert_eq!(result, expected);
 
@@ -463,14 +548,10 @@ mod tests {
         let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.fix(&ctx).unwrap();
 
-        // Output the actual result for debugging
-        log::info!("Actual result with invalid style:\n{}", result.replace('\n', "\\n"));
+        // Should default to "leading_and_trailing"
+        // Already has leading and trailing pipes, so no changes needed - spacing is preserved
+        let expected = "| Header 1 | Header 2 | Header 3 |\n|----------|----------|----------|\n| Data 1   | Data 2   | Data 3   |";
 
-        // Should default to "leading_and_trailing" and fix any inconsistencies with that style
-        let expected =
-            "| Header 1 | Header 2 | Header 3 |\n| ----------|----------|---------- |\n| Data 1 | Data 2 | Data 3 |";
-
-        // Should match the expected output after processing with the default style
         assert_eq!(result, expected);
 
         // Now check a content that needs actual modification
@@ -479,8 +560,8 @@ mod tests {
         let result = rule.fix(&ctx2).unwrap();
 
         // Should add pipes to match the default "leading_and_trailing" style
-        let expected =
-            "| Header 1 | Header 2 | Header 3 |\n| ----------|----------|---------- |\n| Data 1 | Data 2 | Data 3 |";
+        // Spacing is preserved from original input
+        let expected = "| Header 1 | Header 2 | Header 3 |\n| ----------|----------|---------- |\n| Data 1   | Data 2   | Data 3 |";
         assert_eq!(result, expected);
 
         // Check that warning messages also work with the fallback style
