@@ -5,62 +5,54 @@
 
 use crate::rule::{LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::element_cache::ElementCache;
-use lazy_static::lazy_static;
 use regex::Regex;
 use std::collections::HashMap;
 use std::env;
 use std::path::{Path, PathBuf};
+use std::sync::LazyLock;
 use std::sync::{Arc, Mutex};
 
 mod md057_config;
 use md057_config::MD057Config;
 
 // Thread-safe cache for file existence checks to avoid redundant filesystem operations
-lazy_static! {
-    static ref FILE_EXISTENCE_CACHE: Arc<Mutex<HashMap<PathBuf, bool>>> = Arc::new(Mutex::new(HashMap::new()));
-}
+static FILE_EXISTENCE_CACHE: LazyLock<Arc<Mutex<HashMap<PathBuf, bool>>>> =
+    LazyLock::new(|| Arc::new(Mutex::new(HashMap::new())));
 
 // Reset the file existence cache (typically between rule runs)
 fn reset_file_existence_cache() {
-    let mut cache = FILE_EXISTENCE_CACHE.lock().unwrap();
+    let mut cache = FILE_EXISTENCE_CACHE
+        .lock()
+        .expect("File existence cache mutex poisoned");
     cache.clear();
 }
 
 // Check if a file exists with caching
 fn file_exists_with_cache(path: &Path) -> bool {
-    let mut cache = FILE_EXISTENCE_CACHE.lock().unwrap();
+    let mut cache = FILE_EXISTENCE_CACHE
+        .lock()
+        .expect("File existence cache mutex poisoned");
     *cache.entry(path.to_path_buf()).or_insert_with(|| path.exists())
 }
 
-lazy_static! {
-    // Regex to match the start of a link - simplified for performance
-    static ref LINK_START_REGEX: Regex =
-        Regex::new(r"!?\[[^\]]*\]").unwrap();
+// Regex to match the start of a link - simplified for performance
+static LINK_START_REGEX: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"!?\[[^\]]*\]").unwrap());
 
-    /// Regex to extract the URL from a markdown link
-    /// Format: `](URL)` or `](URL "title")`
-    static ref URL_EXTRACT_REGEX: Regex =
-        Regex::new("\\]\\(\\s*<?([^>\\)\\s#]+)(#[^)\\s]*)?\\s*(?:\"[^\"]*\")?\\s*>?\\s*\\)").unwrap();
+/// Regex to extract the URL from a markdown link
+/// Format: `](URL)` or `](URL "title")`
+static URL_EXTRACT_REGEX: LazyLock<Regex> =
+    LazyLock::new(|| Regex::new("\\]\\(\\s*<?([^>\\)\\s#]+)(#[^)\\s]*)?\\s*(?:\"[^\"]*\")?\\s*>?\\s*\\)").unwrap());
 
-    /// Regex to detect code fence blocks
-    static ref CODE_FENCE_REGEX: Regex =
-        Regex::new(r"^( {0,3})(`{3,}|~{3,})").unwrap();
+/// Regex to detect protocol and domain for external links
+static PROTOCOL_DOMAIN_REGEX: LazyLock<Regex> =
+    LazyLock::new(|| Regex::new(r"^(https?://|ftp://|mailto:|www\.)").unwrap());
 
-    /// Regex to detect protocol and domain for external links
-    static ref PROTOCOL_DOMAIN_REGEX: Regex =
-        Regex::new(r"^(https?://|ftp://|mailto:|www\.)").unwrap();
+/// Regex to detect media file types
+static MEDIA_FILE_REGEX: LazyLock<Regex> =
+    LazyLock::new(|| Regex::new(r"\.(jpg|jpeg|png|gif|bmp|svg|webp|tiff|mp3|mp4|avi|mov|webm|wav|ogg|pdf)$").unwrap());
 
-    /// Regex to detect media file types
-    static ref MEDIA_FILE_REGEX: Regex =
-        Regex::new(r"\.(jpg|jpeg|png|gif|bmp|svg|webp|tiff|mp3|mp4|avi|mov|webm|wav|ogg|pdf)$").unwrap();
-
-    /// Regex to detect fragment-only links
-    static ref FRAGMENT_ONLY_REGEX: Regex =
-        Regex::new(r"^#").unwrap();
-
-    // Current working directory
-    static ref CURRENT_DIR: PathBuf = env::current_dir().unwrap_or_else(|_| PathBuf::from("."));
-}
+// Current working directory
+static CURRENT_DIR: LazyLock<PathBuf> = LazyLock::new(|| env::current_dir().unwrap_or_else(|_| PathBuf::from(".")));
 
 /// Rule MD057: Existing relative links should point to valid files or directories.
 #[derive(Debug, Default, Clone)]
@@ -86,7 +78,7 @@ impl MD057ExistingRelativeLinks {
             Some(path.to_path_buf())
         };
 
-        *self.base_path.lock().unwrap() = dir_path;
+        *self.base_path.lock().expect("Base path mutex poisoned") = dir_path;
         self
     }
 
@@ -182,7 +174,7 @@ impl MD057ExistingRelativeLinks {
             // Check if the file exists (with caching to avoid filesystem calls)
             if !file_exists_with_cache(&resolved_path) {
                 warnings.push(LintWarning {
-                    rule_name: Some(self.name()),
+                    rule_name: Some(self.name().to_string()),
                     line: line_num,
                     column,
                     end_line: line_num,
@@ -210,8 +202,7 @@ impl Rule for MD057ExistingRelativeLinks {
     }
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        let content = ctx.content;
-        content.is_empty() || !content.contains('[') || !content.contains("](")
+        ctx.content.is_empty() || !ctx.likely_has_links_or_images()
     }
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
@@ -234,7 +225,7 @@ impl Rule for MD057ExistingRelativeLinks {
 
         // Cache base path lookup to avoid repeated mutex operations
         let base_path = {
-            let base_path_guard = self.base_path.lock().unwrap();
+            let base_path_guard = self.base_path.lock().expect("Base path mutex poisoned");
             if base_path_guard.is_some() {
                 base_path_guard.clone()
             } else {
@@ -266,16 +257,8 @@ impl Rule for MD057ExistingRelativeLinks {
 
         // Use LintContext links instead of expensive regex parsing
         if !ctx.links.is_empty() {
-            // Pre-compute line positions for efficient absolute position calculation
-            let mut line_positions = Vec::new();
-            let mut pos = 0;
-            line_positions.push(0);
-            for ch in content.chars() {
-                pos += ch.len_utf8();
-                if ch == '\n' {
-                    line_positions.push(pos);
-                }
-            }
+            // Use LineIndex for correct position calculation across all line ending types
+            let line_index = &ctx.line_index;
 
             // Create element cache once for all links
             let element_cache = ElementCache::new(content);
@@ -301,13 +284,9 @@ impl Rule for MD057ExistingRelativeLinks {
                     let start_pos = link_match.start();
                     let end_pos = link_match.end();
 
-                    // Calculate absolute position efficiently using pre-computed positions
-                    let absolute_start_pos = if line_idx < line_positions.len() {
-                        line_positions[line_idx] + start_pos
-                    } else {
-                        // Fallback for edge cases
-                        content.lines().take(line_idx).map(|l| l.len() + 1).sum::<usize>() + start_pos
-                    };
+                    // Calculate absolute position using LineIndex
+                    let line_start_byte = line_index.get_line_start_byte(line_idx + 1).unwrap_or(0);
+                    let absolute_start_pos = line_start_byte + start_pos;
 
                     // Skip if this link is in a code span
                     if element_cache.is_in_code_span(absolute_start_pos) {
