@@ -1,8 +1,6 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
 use crate::rule_config_serde::RuleConfig;
 use crate::utils::kramdown_utils::is_kramdown_block_attribute;
-use crate::utils::range_utils::LineIndex;
-use crate::utils::table_utils::TableUtils;
 use serde::{Deserialize, Serialize};
 
 /// Rule MD058: Blanks around tables
@@ -101,13 +99,13 @@ impl Rule for MD058BlanksAroundTables {
     }
 
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        // Skip if no pipe characters present (no tables)
-        !ctx.content.contains('|')
+        // Skip if no tables present
+        !ctx.likely_has_tables()
     }
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
         let mut warnings = Vec::new();
 
         // Early return for empty content or content without tables
@@ -117,8 +115,8 @@ impl Rule for MD058BlanksAroundTables {
 
         let lines: Vec<&str> = content.lines().collect();
 
-        // Use shared table detection for better performance
-        let table_blocks = TableUtils::find_table_blocks(content, ctx);
+        // Use pre-computed table blocks from context
+        let table_blocks = &ctx.table_blocks;
 
         for table_block in table_blocks {
             // Check for sufficient blank lines before table
@@ -133,7 +131,7 @@ impl Rule for MD058BlanksAroundTables {
                     };
 
                     warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
+                        rule_name: Some(self.name().to_string()),
                         message,
                         line: table_block.start_line + 1,
                         column: 1,
@@ -169,7 +167,7 @@ impl Rule for MD058BlanksAroundTables {
                         };
 
                         warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
+                            rule_name: Some(self.name().to_string()),
                             message,
                             line: table_block.end_line + 1,
                             column: lines[table_block.end_line].len() + 1,
@@ -194,7 +192,7 @@ impl Rule for MD058BlanksAroundTables {
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let content = ctx.content;
-        let _line_index = LineIndex::new(content.to_string());
+        let _line_index = &ctx.line_index;
 
         let mut warnings = self.check(ctx)?;
         if warnings.is_empty() {
@@ -300,6 +298,7 @@ impl Rule for MD058BlanksAroundTables {
 mod tests {
     use super::*;
     use crate::lint_context::LintContext;
+    use crate::utils::table_utils::TableUtils;
 
     #[test]
     fn test_table_with_blanks() {
@@ -664,8 +663,11 @@ Text after.";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
-        // Single column tables are not detected by table_utils (requires 2+ columns)
-        assert_eq!(result.len(), 0);
+        // Single column tables ARE now detected (fixed to support 1+ columns)
+        // Expects 2 warnings: missing blank before and after table
+        assert_eq!(result.len(), 2);
+        assert!(result[0].message.contains("before"));
+        assert!(result[1].message.contains("after"));
     }
 
     #[test]
