@@ -1,8 +1,7 @@
 //!
 //! Utility functions for detecting and handling code blocks and code spans in Markdown for rumdl.
 
-use lazy_static::lazy_static;
-use regex::Regex;
+use crate::rules::blockquote_utils::BlockquoteUtils;
 
 /// Classification of code blocks relative to list contexts
 #[derive(Debug, Clone, PartialEq, Eq)]
@@ -15,11 +14,6 @@ pub enum CodeBlockContext {
     Adjacent,
 }
 
-lazy_static! {
-    static ref CODE_BLOCK_PATTERN: Regex = Regex::new(r"^(```|~~~)").unwrap();
-    static ref CODE_SPAN_PATTERN: Regex = Regex::new(r"`+").unwrap();
-}
-
 /// Utility functions for detecting and handling code blocks in Markdown
 pub struct CodeBlockUtils;
 
@@ -44,7 +38,15 @@ impl CodeBlockUtils {
         // Find fenced code blocks
         for (i, line) in lines.iter().enumerate() {
             let line_start = line_positions[i];
-            let trimmed = line.trim_start();
+
+            // Strip ALL blockquote prefixes to properly detect fenced code blocks inside blockquotes
+            // This handles nested blockquotes by recursively stripping '>' markers
+            let mut line_without_blockquote = line.to_string();
+            while BlockquoteUtils::is_blockquote(&line_without_blockquote) {
+                line_without_blockquote = BlockquoteUtils::extract_content(&line_without_blockquote);
+            }
+
+            let trimmed = line_without_blockquote.trim_start();
 
             // Check if this line could be a code fence
             if trimmed.starts_with("```") || trimmed.starts_with("~~~") {
@@ -77,8 +79,15 @@ impl CodeBlockUtils {
         // Find indented code blocks (4+ spaces or tab at start of line)
         // According to CommonMark, indented code blocks must be preceded by a blank line
         // (unless they're at the start of the document or after a block-level element)
+        //
+        // IMPORTANT: We must handle list contexts correctly:
+        // - At document level: 4 spaces + blank line before = code block
+        // - In a list context: 4 spaces = continuation paragraph (NOT a code block)
+        // - In a list context: 8+ spaces (depending on list marker) = code block
         let mut in_indented_block = false;
         let mut indented_block_start = 0;
+        let mut in_list_context = false;
+        let mut list_continuation_indent: usize = 0;
 
         for (line_idx, line) in lines.iter().enumerate() {
             let line_start = if line_idx < line_positions.len() {
@@ -87,29 +96,128 @@ impl CodeBlockUtils {
                 0
             };
 
-            // Check if this line is indented code
-            let is_indented = line.starts_with("    ") || line.starts_with("\t");
+            // Strip ALL blockquote prefixes to properly detect indented code blocks inside blockquotes
+            let mut line_without_blockquote = line.to_string();
+            while BlockquoteUtils::is_blockquote(&line_without_blockquote) {
+                line_without_blockquote = BlockquoteUtils::extract_content(&line_without_blockquote);
+            }
+
+            // Calculate the indent level
+            let indent_level = line_without_blockquote.len() - line_without_blockquote.trim_start().len();
+            let is_indented = line_without_blockquote.starts_with("    ") || line_without_blockquote.starts_with("\t");
 
             // Check if this looks like a list item (has list marker after indentation)
-            let trimmed = line.trim_start();
-            let is_list_item = trimmed.starts_with("- ")
-                || trimmed.starts_with("* ")
-                || trimmed.starts_with("+ ")
-                || trimmed.chars().next().is_some_and(|c| c.is_numeric())
-                    && trimmed.chars().nth(1).is_some_and(|c| c == '.' || c == ')');
+            let trimmed = line_without_blockquote.trim_start();
 
-            // Check if previous line was blank
-            let prev_blank = line_idx > 0 && lines[line_idx - 1].trim().is_empty();
+            // Check for ordered list marker: 1-9 digits followed by . or )
+            // Must be followed by at least one space
+            let is_ordered_list = {
+                let mut chars = trimmed.chars();
+                let first_char = chars.next();
+                if !first_char.is_some_and(|c| c.is_numeric()) {
+                    false
+                } else {
+                    // Find delimiter position (. or ))
+                    let delimiter_char_pos = trimmed.chars().position(|c| c == '.' || c == ')');
+                    match delimiter_char_pos {
+                        Some(char_pos) if char_pos > 0 => {
+                            // Convert character position to byte position for slicing
+                            let byte_pos = trimmed.char_indices().nth(char_pos).map(|(i, _)| i);
+                            if let Some(byte_pos) = byte_pos {
+                                // All chars before delimiter must be digits
+                                let all_digits = trimmed[..byte_pos].chars().all(|c| c.is_numeric());
+                                // Must be followed by space or tab
+                                let has_space =
+                                    trimmed.chars().nth(char_pos + 1).is_some_and(|c| c == ' ' || c == '\t');
+                                all_digits && has_space
+                            } else {
+                                false
+                            }
+                        }
+                        _ => false,
+                    }
+                }
+            };
 
-            if is_indented && !line.trim().is_empty() && !is_list_item {
-                if !in_indented_block {
-                    // Only start an indented code block if preceded by a blank line
-                    if prev_blank {
+            let is_list_item =
+                trimmed.starts_with("- ") || trimmed.starts_with("* ") || trimmed.starts_with("+ ") || is_ordered_list;
+
+            // Check if previous line was blank (after stripping blockquote markers)
+            let prev_line_without_blockquote = if line_idx > 0 {
+                let mut prev = lines[line_idx - 1].to_string();
+                while BlockquoteUtils::is_blockquote(&prev) {
+                    prev = BlockquoteUtils::extract_content(&prev);
+                }
+                prev
+            } else {
+                String::new()
+            };
+            let prev_blank = line_idx > 0 && prev_line_without_blockquote.trim().is_empty();
+
+            // Update list context tracking
+            if is_list_item {
+                // We're starting or continuing a list
+                in_list_context = true;
+
+                // Calculate continuation indent per CommonMark spec:
+                // "The spaces of indentation after the list marker determine how much
+                // relative indentation is needed. The first continuation block must be
+                // indented to the column of the first character other than a space after the marker."
+
+                let marker_column = indent_level;
+                let marker_width =
+                    if trimmed.starts_with("- ") || trimmed.starts_with("* ") || trimmed.starts_with("+ ") {
+                        1 // Single character marker (-, *, +)
+                    } else {
+                        // Ordered list marker: count digits + delimiter (. or ))
+                        trimmed.chars().take_while(|c| c.is_numeric()).count() + 1
+                    };
+
+                // Count actual spaces/tabs after marker (CommonMark allows 1-4 spaces)
+                // Find the first non-space character after the marker
+                let after_marker = &trimmed[marker_width..];
+                let spaces_after_marker = after_marker.chars().take_while(|c| *c == ' ' || *c == '\t').count();
+
+                // Continuation indent = marker column + marker width + actual spaces
+                // This is the column where the first content character appears
+                list_continuation_indent = marker_column + marker_width + spaces_after_marker;
+            } else if in_list_context
+                && !line_without_blockquote.trim().is_empty()
+                && indent_level < list_continuation_indent
+            {
+                // Outdented non-empty line ends the list context
+                in_list_context = false;
+                list_continuation_indent = 0;
+            }
+
+            // Determine if this indented line is:
+            // 1. A list continuation paragraph (indent >= continuation_indent, < continuation_indent + 4)
+            // 2. A code block within a list (indent >= continuation_indent + 4)
+            // 3. A document-level code block (not in list context)
+
+            let is_list_continuation_paragraph = in_list_context
+                && indent_level >= list_continuation_indent
+                && indent_level < (list_continuation_indent + 4);
+
+            let is_code_block_in_list = in_list_context && indent_level >= (list_continuation_indent + 4);
+
+            // Handle indented code blocks
+            if is_indented && !line_without_blockquote.trim().is_empty() && !is_list_item {
+                if is_code_block_in_list {
+                    // Code block within list (CommonMark Example 270, 273, 274)
+                    // Requires continuation_indent + 4 spaces, and must have blank line before
+                    if !in_indented_block && prev_blank {
+                        in_indented_block = true;
+                        indented_block_start = line_start;
+                    }
+                } else if !is_list_continuation_paragraph {
+                    // Document-level indented code block (not in list)
+                    if !in_indented_block && prev_blank {
                         in_indented_block = true;
                         indented_block_start = line_start;
                     }
-                    // Otherwise, this is just an indented line, not a code block
                 }
+                // If is_list_continuation_paragraph, don't treat as code block
             } else if in_indented_block {
                 // End of indented code block
                 let block_end = if line_idx > 0 && line_idx - 1 < line_positions.len() {
@@ -212,6 +320,7 @@ impl CodeBlockUtils {
     /// Calculate minimum indentation required for code block to continue a list
     /// Based on the most recent list item's marker width
     pub fn calculate_min_continuation_indent(
+        content: &str,
         lines: &[crate::lint_context::LineInfo],
         current_line_idx: usize,
     ) -> usize {
@@ -228,7 +337,7 @@ impl CodeBlockUtils {
                 }
 
                 // Stop at structural separators that would break list context
-                if line_info.heading.is_some() || Self::is_structural_separator(&line_info.content) {
+                if line_info.heading.is_some() || Self::is_structural_separator(line_info.content(content)) {
                     break;
                 }
             }
