@@ -1,21 +1,22 @@
 use fancy_regex::Regex as FancyRegex;
-use lazy_static::lazy_static;
 use regex::Regex;
+use std::sync::LazyLock;
 use std::sync::{Arc, Mutex};
 
-lazy_static! {
-    // Efficient regex patterns
-    static ref CODE_BLOCK_START_REGEX: Regex = Regex::new(r"^(\s*)(```|~~~)(.*)$").unwrap();
-    static ref CODE_BLOCK_END_REGEX: Regex = Regex::new(r"^(\s*)(```|~~~)\s*$").unwrap();
-    static ref INDENTED_CODE_BLOCK_REGEX: Regex = Regex::new(r"^(\s{4,})(.+)$").unwrap();
+// Efficient regex patterns
+static CODE_BLOCK_START_REGEX: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^(\s*)(```|~~~)(.*)$").unwrap());
+static INDENTED_CODE_BLOCK_REGEX: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^(\s{4,})(.+)$").unwrap());
 
-    // List detection patterns
-    static ref UNORDERED_LIST_REGEX: FancyRegex = FancyRegex::new(r"^(?P<indent>[ \t]*)(?P<marker>[*+-])(?P<after>[ \t]*)(?P<content>.*)$").unwrap();
-    static ref ORDERED_LIST_REGEX: FancyRegex = FancyRegex::new(r"^(?P<indent>[ \t]*)(?P<marker>\d+\.)(?P<after>[ \t]*)(?P<content>.*)$").unwrap();
+// List detection patterns
+static UNORDERED_LIST_REGEX: LazyLock<FancyRegex> = LazyLock::new(|| {
+    FancyRegex::new(r"^(?P<indent>[ \t]*)(?P<marker>[*+-])(?P<after>[ \t]*)(?P<content>.*)$").unwrap()
+});
+static ORDERED_LIST_REGEX: LazyLock<FancyRegex> = LazyLock::new(|| {
+    FancyRegex::new(r"^(?P<indent>[ \t]*)(?P<marker>\d+\.)(?P<after>[ \t]*)(?P<content>.*)$").unwrap()
+});
 
-    // Inline code span pattern
-    static ref CODE_SPAN_REGEX: Regex = Regex::new(r"`+").unwrap();
-}
+// Inline code span pattern
+static CODE_SPAN_REGEX: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"`+").unwrap());
 
 /// Represents a range in the document with start and end positions
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
@@ -449,7 +450,12 @@ impl ElementCache {
                     "*" => ListMarkerType::Asterisk,
                     "+" => ListMarkerType::Plus,
                     "-" => ListMarkerType::Minus,
-                    _ => unreachable!(),
+                    other => {
+                        // This should never happen due to regex validation,
+                        // but default to dash if it does
+                        eprintln!("Warning: Unexpected list marker '{other}', defaulting to dash");
+                        ListMarkerType::Minus
+                    }
                 };
                 let nesting_level = self.calculate_nesting_level(indentation, blockquote_depth, prev_items);
                 // Find parent: most recent previous item with lower nesting_level and same blockquote depth
@@ -517,15 +523,13 @@ impl ElementCache {
 }
 
 // Global cache for sharing across threads
-lazy_static! {
-    static ref ELEMENT_CACHE: Arc<Mutex<Option<ElementCache>>> = Arc::new(Mutex::new(None));
-}
+static ELEMENT_CACHE: LazyLock<Arc<Mutex<Option<ElementCache>>>> = LazyLock::new(|| Arc::new(Mutex::new(None)));
 
 /// Get or create element cache for document content
 pub fn get_element_cache(content: &str) -> ElementCache {
     // Try to get existing cache
     {
-        let cache_guard = ELEMENT_CACHE.lock().unwrap();
+        let cache_guard = ELEMENT_CACHE.lock().expect("Element cache mutex poisoned");
 
         // If cache exists and content matches, return it
         if let Some(existing_cache) = &*cache_guard
@@ -541,7 +545,7 @@ pub fn get_element_cache(content: &str) -> ElementCache {
 
     // Store in global cache
     {
-        let mut cache_guard = ELEMENT_CACHE.lock().unwrap();
+        let mut cache_guard = ELEMENT_CACHE.lock().expect("Element cache mutex poisoned");
         *cache_guard = Some(new_cache.clone());
     }
 
@@ -550,7 +554,7 @@ pub fn get_element_cache(content: &str) -> ElementCache {
 
 /// Reset the element cache
 pub fn reset_element_cache() {
-    let mut cache_guard = ELEMENT_CACHE.lock().unwrap();
+    let mut cache_guard = ELEMENT_CACHE.lock().expect("Element cache mutex poisoned");
     *cache_guard = None;
 }
 
