@@ -57,14 +57,17 @@ impl TableUtils {
             }
         }
 
-        // All non-empty parts must be valid (no newlines) for the row to be valid
-        if total_non_empty_parts == 0 {
+        // Check if all non-empty parts are valid (no newlines)
+        if total_non_empty_parts > 0 && valid_parts != total_non_empty_parts {
+            // Some cells contain newlines, not a valid table row
             return false;
         }
 
-        if valid_parts != total_non_empty_parts {
-            // Some cells contain newlines, not a valid table row
-            return false;
+        // GFM allows tables with all empty cells (e.g., |||)
+        // These are valid if they have proper table formatting (leading and trailing pipes)
+        if total_non_empty_parts == 0 {
+            // Empty cells are only valid with proper pipe formatting
+            return trimmed.starts_with('|') && trimmed.ends_with('|') && parts.len() >= 3;
         }
 
         // GFM allows single-column tables, so >= 1 valid part is enough
@@ -88,6 +91,7 @@ impl TableUtils {
         // Split by pipes and check each part
         let parts: Vec<&str> = trimmed.split('|').collect();
         let mut valid_delimiter_parts = 0;
+        let mut total_non_empty_parts = 0;
 
         for part in &parts {
             let part_trimmed = part.trim();
@@ -95,17 +99,26 @@ impl TableUtils {
                 continue; // Skip empty parts from leading/trailing pipes
             }
 
+            total_non_empty_parts += 1;
+
             // Check if this part looks like a delimiter (contains dashes and optionally colons)
             if part_trimmed.chars().all(|c| c == '-' || c == ':' || c.is_whitespace()) && part_trimmed.contains('-') {
                 valid_delimiter_parts += 1;
             }
         }
 
-        valid_delimiter_parts >= 2
+        // All non-empty parts must be valid delimiters, and there must be at least one
+        total_non_empty_parts > 0 && valid_delimiter_parts == total_non_empty_parts
     }
 
     /// Find all table blocks in the content with optimized detection
-    pub fn find_table_blocks(content: &str, ctx: &crate::lint_context::LintContext) -> Vec<TableBlock> {
+    /// This version accepts code_blocks and code_spans directly for use during LintContext construction
+    pub fn find_table_blocks_with_code_info(
+        content: &str,
+        code_blocks: &[(usize, usize)],
+        code_spans: &[crate::lint_context::CodeSpan],
+        html_comment_ranges: &[crate::utils::skip_context::ByteRange],
+    ) -> Vec<TableBlock> {
         let lines: Vec<&str> = content.lines().collect();
         let mut tables = Vec::new();
         let mut i = 0;
@@ -119,9 +132,18 @@ impl TableUtils {
         }
 
         while i < lines.len() {
-            // Skip lines in code blocks using cached code blocks from context
+            // Skip lines in code blocks, code spans, or HTML comments
             let line_start = line_positions[i];
-            if ctx.is_in_code_block_or_span(line_start) {
+            let in_code =
+                crate::utils::code_block_utils::CodeBlockUtils::is_in_code_block_or_span(code_blocks, line_start)
+                    || code_spans
+                        .iter()
+                        .any(|span| line_start >= span.byte_offset && line_start < span.byte_end);
+            let in_html_comment = html_comment_ranges
+                .iter()
+                .any(|range| line_start >= range.start && line_start < range.end);
+
+            if in_code || in_html_comment {
                 i += 1;
                 continue;
             }
@@ -174,6 +196,12 @@ impl TableUtils {
         tables
     }
 
+    /// Find all table blocks in the content with optimized detection
+    /// This is a backward-compatible wrapper that accepts LintContext
+    pub fn find_table_blocks(content: &str, ctx: &crate::lint_context::LintContext) -> Vec<TableBlock> {
+        Self::find_table_blocks_with_code_info(content, &ctx.code_blocks, &ctx.code_spans(), ctx.html_comment_ranges())
+    }
+
     /// Count the number of cells in a table row
     pub fn count_cells(row: &str) -> usize {
         let trimmed = row.trim();
@@ -183,8 +211,8 @@ impl TableUtils {
             return 0;
         }
 
-        // Users shouldn't have to escape pipes in regex patterns, etc.
-        let masked_row = Self::mask_pipes_in_inline_code(trimmed);
+        // Users shouldn't have to escape pipes in regex patterns, inline code, etc.
+        let masked_row = Self::mask_pipes_for_table_parsing(trimmed);
 
         // Handle case with leading/trailing pipes
         let mut cell_count = 0;
@@ -208,7 +236,7 @@ impl TableUtils {
     }
 
     /// Mask pipes inside inline code blocks with a placeholder character
-    fn mask_pipes_in_inline_code(text: &str) -> String {
+    pub fn mask_pipes_in_inline_code(text: &str) -> String {
         let mut result = String::new();
         let chars: Vec<char> = text.chars().collect();
         let mut i = 0;
@@ -275,6 +303,44 @@ impl TableUtils {
         result
     }
 
+    /// Mask both inline code pipes AND escaped pipes for accurate table cell parsing
+    ///
+    /// This function combines two types of masking:
+    /// 1. Pipes inside inline code blocks (between backticks) → masked as '_'
+    /// 2. Escaped pipes `\|` → masked as `\_` (backslash + underscore)
+    ///
+    /// This allows `split('|')` to correctly identify cell boundaries without
+    /// accidentally splitting on:
+    /// - Literal pipes inside code: `| a | b |` → treated as single cell
+    /// - Escaped pipes: `a \| b` → treated as single cell containing literal pipe
+    ///
+    /// The original text is reconstructed from byte offsets, so these masks only
+    /// affect where we split, not the actual cell content.
+    pub fn mask_pipes_for_table_parsing(text: &str) -> String {
+        // First pass: mask inline code pipes
+        let after_code_masking = Self::mask_pipes_in_inline_code(text);
+
+        // Second pass: mask escaped pipes
+        let mut result = String::new();
+        let chars: Vec<char> = after_code_masking.chars().collect();
+        let mut i = 0;
+
+        while i < chars.len() {
+            if i + 1 < chars.len() && chars[i] == '\\' && chars[i + 1] == '|' {
+                // Found escaped pipe: \|
+                // Replace with \_ to keep same byte length while preventing split
+                result.push('\\');
+                result.push('_'); // Mask the pipe
+                i += 2;
+            } else {
+                result.push(chars[i]);
+                i += 1;
+            }
+        }
+
+        result
+    }
+
     /// Determine the pipe style of a table row
     pub fn determine_pipe_style(line: &str) -> Option<&'static str> {
         let trimmed = line.trim();
@@ -336,6 +402,11 @@ mod tests {
 
         // Cells with newlines
         assert!(!TableUtils::is_potential_table_row("| Cell with\nnewline | Other |"));
+
+        // Empty cells (Issue #129)
+        assert!(TableUtils::is_potential_table_row("|||")); // Two empty cells
+        assert!(TableUtils::is_potential_table_row("||||")); // Three empty cells
+        assert!(TableUtils::is_potential_table_row("| | |")); // Two empty cells with spaces
     }
 
     #[test]
