@@ -3,6 +3,7 @@
 //! This module implements text wrapping/reflow functionality that preserves
 //! Markdown elements like links, emphasis, code spans, etc.
 
+use crate::utils::is_definition_list_item;
 use crate::utils::regex_cache::{
     DISPLAY_MATH_REGEX, EMOJI_SHORTCODE_REGEX, FOOTNOTE_REF_REGEX, HTML_ENTITY_REGEX, HTML_TAG_PATTERN,
     INLINE_IMAGE_FANCY_REGEX, INLINE_LINK_FANCY_REGEX, INLINE_MATH_REGEX, REF_IMAGE_REGEX, REF_LINK_REGEX,
@@ -37,7 +38,7 @@ impl Default for ReflowOptions {
 fn is_sentence_boundary(text: &str, pos: usize) -> bool {
     let chars: Vec<char> = text.chars().collect();
 
-    if pos + 2 >= chars.len() {
+    if pos + 1 >= chars.len() {
         return false;
     }
 
@@ -47,13 +48,24 @@ fn is_sentence_boundary(text: &str, pos: usize) -> bool {
         return false;
     }
 
-    // Must be followed by a space
+    // Must be followed by at least one space
     if chars[pos + 1] != ' ' {
         return false;
     }
 
-    // Next character after space must be uppercase (new sentence indicator)
-    if !chars[pos + 2].is_uppercase() {
+    // Skip all whitespace after the punctuation to find the start of the next sentence
+    let mut next_char_pos = pos + 2;
+    while next_char_pos < chars.len() && chars[next_char_pos].is_whitespace() {
+        next_char_pos += 1;
+    }
+
+    // Check if we reached the end of the string
+    if next_char_pos >= chars.len() {
+        return false;
+    }
+
+    // Next character after space(s) must be uppercase (new sentence indicator)
+    if !chars[next_char_pos].is_uppercase() {
         return false;
     }
 
@@ -71,11 +83,11 @@ fn is_sentence_boundary(text: &str, pos: usize) -> bool {
         }
 
         // Check for decimal numbers (e.g., "3.14")
-        if pos > 0 && chars[pos - 1].is_numeric() && pos + 2 < chars.len() && chars[pos + 2].is_numeric() {
+        // Make sure to check if next_char_pos is within bounds
+        if pos > 0 && chars[pos - 1].is_numeric() && next_char_pos < chars.len() && chars[next_char_pos].is_numeric() {
             return false;
         }
     }
-
     true
 }
 
@@ -95,7 +107,6 @@ pub fn split_into_sentences(text: &str) -> Vec<String> {
                 chars.next();
                 pos += 1;
             }
-
             sentences.push(current_sentence.trim().to_string());
             current_sentence.clear();
         }
@@ -107,7 +118,6 @@ pub fn split_into_sentences(text: &str) -> Vec<String> {
     if !current_sentence.trim().is_empty() {
         sentences.push(current_sentence.trim().to_string());
     }
-
     sentences
 }
 
@@ -163,7 +173,47 @@ fn is_numbered_list_item(line: &str) -> bool {
     false
 }
 
-/// Reflow a single line of markdown text to fit within the specified line length
+/// Check if a line ends with a hard break (either two spaces or backslash)
+///
+/// CommonMark supports two formats for hard line breaks:
+/// 1. Two or more trailing spaces
+/// 2. A backslash at the end of the line
+fn has_hard_break(line: &str) -> bool {
+    let line = line.strip_suffix('\r').unwrap_or(line);
+    line.ends_with("  ") || line.ends_with('\\')
+}
+
+/// Trim trailing whitespace while preserving hard breaks (two trailing spaces or backslash)
+///
+/// Hard breaks in Markdown can be indicated by:
+/// 1. Two trailing spaces before a newline (traditional)
+/// 2. A backslash at the end of the line (mdformat style)
+fn trim_preserving_hard_break(s: &str) -> String {
+    // Strip trailing \r from CRLF line endings first to handle Windows files
+    let s = s.strip_suffix('\r').unwrap_or(s);
+
+    // Check for backslash hard break (mdformat style)
+    if s.ends_with('\\') {
+        // Preserve the backslash exactly as-is
+        return s.to_string();
+    }
+
+    // Check if there are at least 2 trailing spaces (traditional hard break)
+    if s.ends_with("  ") {
+        // Find the position where non-space content ends
+        let content_end = s.trim_end().len();
+        if content_end == 0 {
+            // String is all whitespace
+            return String::new();
+        }
+        // Preserve exactly 2 trailing spaces for hard break
+        format!("{}  ", &s[..content_end])
+    } else {
+        // No hard break, just trim all trailing whitespace
+        s.trim_end().to_string()
+    }
+}
+
 pub fn reflow_line(line: &str, options: &ReflowOptions) -> Vec<String> {
     // For sentence-per-line mode, always process regardless of length
     if options.sentence_per_line {
@@ -381,10 +431,21 @@ fn parse_markdown_elements(text: &str) -> Vec<Element> {
         }
 
         // Check for HTML tags - <tag> </tag> <tag/>
+        // But exclude autolinks like <https://...> or <mailto:...>
         if let Ok(Some(m)) = HTML_TAG_PATTERN.find(remaining)
             && earliest_match.as_ref().is_none_or(|(start, _, _)| m.start() < *start)
         {
-            earliest_match = Some((m.start(), "html_tag", m));
+            // Check if this is an autolink (starts with protocol or mailto:)
+            let matched_text = &remaining[m.start()..m.end()];
+            let is_autolink = matched_text.starts_with("<http://")
+                || matched_text.starts_with("<https://")
+                || matched_text.starts_with("<mailto:")
+                || matched_text.starts_with("<ftp://")
+                || matched_text.starts_with("<ftps://");
+
+            if !is_autolink {
+                earliest_match = Some((m.start(), "html_tag", m));
+            }
         }
 
         // Find earliest non-link special characters
@@ -651,7 +712,7 @@ fn reflow_elements_sentence_per_line(elements: &[Element]) -> Vec<String> {
     let mut lines = Vec::new();
     let mut current_line = String::new();
 
-    for element in elements {
+    for element in elements.iter() {
         let element_str = format!("{element}");
 
         // For text elements, split into sentences
@@ -665,10 +726,67 @@ fn reflow_elements_sentence_per_line(elements: &[Element]) -> Vec<String> {
                 for (i, sentence) in sentences.iter().enumerate() {
                     if i == 0 {
                         // First sentence might continue from previous elements
-                        lines.push(sentence.to_string());
+                        // But check if it ends with an abbreviation
+                        let trimmed = sentence.trim();
+                        let ends_with_sentence_punct =
+                            trimmed.ends_with('.') || trimmed.ends_with('!') || trimmed.ends_with('?');
+                        let ends_with_abbreviation = if ends_with_sentence_punct {
+                            // Strip the final punctuation before checking abbreviations
+                            let without_punct = trimmed
+                                .trim_end_matches('.')
+                                .trim_end_matches('!')
+                                .trim_end_matches('?');
+                            let ignored_words = [
+                                "ie", "i.e", "eg", "e.g", "etc", "ex", "vs", "Mr", "Mrs", "Dr", "Ms", "Prof", "Sr",
+                                "Jr",
+                            ];
+                            ignored_words
+                                .iter()
+                                .any(|word| without_punct.to_lowercase().ends_with(&word.to_lowercase()))
+                        } else {
+                            false
+                        };
+
+                        if ends_with_abbreviation {
+                            // Don't emit yet - this sentence ends with abbreviation, continue accumulating
+                            current_line = sentence.to_string();
+                        } else {
+                            // Normal case - emit the first sentence
+                            lines.push(sentence.to_string());
+                            current_line.clear();
+                        }
                     } else if i == sentences.len() - 1 {
-                        // Last sentence might continue to next elements
-                        current_line = sentence.to_string();
+                        // Last sentence: check if it's complete or incomplete
+                        let trimmed = sentence.trim();
+                        let ends_with_sentence_punct =
+                            trimmed.ends_with('.') || trimmed.ends_with('!') || trimmed.ends_with('?');
+
+                        // Check if it ends with an abbreviation
+                        let ends_with_abbreviation = if ends_with_sentence_punct {
+                            // Strip the final punctuation before checking abbreviations
+                            let without_punct = trimmed
+                                .trim_end_matches('.')
+                                .trim_end_matches('!')
+                                .trim_end_matches('?');
+                            let ignored_words = [
+                                "ie", "i.e", "eg", "e.g", "etc", "ex", "vs", "Mr", "Mrs", "Dr", "Ms", "Prof", "Sr",
+                                "Jr",
+                            ];
+                            ignored_words
+                                .iter()
+                                .any(|word| without_punct.to_lowercase().ends_with(&word.to_lowercase()))
+                        } else {
+                            false
+                        };
+
+                        if ends_with_sentence_punct && !ends_with_abbreviation {
+                            // Complete sentence - emit it immediately
+                            lines.push(sentence.to_string());
+                            current_line.clear();
+                        } else {
+                            // Incomplete sentence - save for next iteration
+                            current_line = sentence.to_string();
+                        }
                     } else {
                         // Complete sentences in the middle
                         lines.push(sentence.to_string());
@@ -696,7 +814,6 @@ fn reflow_elements_sentence_per_line(elements: &[Element]) -> Vec<String> {
     if !current_line.is_empty() {
         lines.push(current_line.trim().to_string());
     }
-
     lines
 }
 
@@ -876,7 +993,8 @@ pub fn reflow_markdown(content: &str, options: &ReflowOptions) -> String {
             let marker = &line[indent..marker_end];
 
             // Collect all content for this list item (including continuation lines)
-            let mut list_content = vec![line[content_start..].to_string()];
+            // Preserve hard breaks (2 trailing spaces) while trimming excessive whitespace
+            let mut list_content = vec![trim_preserving_hard_break(&line[content_start..])];
             i += 1;
 
             // Collect continuation lines (indented lines that are part of this list item)
@@ -900,6 +1018,7 @@ pub fn reflow_markdown(content: &str, options: &ReflowOptions) -> String {
                     || (next_trimmed.starts_with('+')
                         && (next_trimmed.len() == 1 || next_trimmed.chars().nth(1) == Some(' ')))
                     || is_numbered_list_item(next_trimmed)
+                    || is_definition_list_item(next_trimmed)
                 {
                     break;
                 }
@@ -907,9 +1026,10 @@ pub fn reflow_markdown(content: &str, options: &ReflowOptions) -> String {
                 // Check if this line is indented (continuation of list item)
                 let next_indent = next_line.len() - next_line.trim_start().len();
                 if next_indent >= content_start {
-                    // This is a continuation line - add its content (trim only leading space)
-                    // We need to preserve trailing spaces for hard breaks
-                    list_content.push(next_line.trim_start().to_string());
+                    // This is a continuation line - add its content
+                    // Preserve hard breaks while trimming excessive whitespace
+                    let trimmed_start = next_line.trim_start();
+                    list_content.push(trim_preserving_hard_break(trimmed_start));
                     i += 1;
                 } else {
                     // Not indented enough, not part of this list item
@@ -917,11 +1037,20 @@ pub fn reflow_markdown(content: &str, options: &ReflowOptions) -> String {
                 }
             }
 
-            // Join all the content with spaces (if preserve_breaks is false)
+            // Join content, but respect hard breaks (lines ending with 2 spaces or backslash)
+            // Hard breaks should prevent joining with the next line
             let combined_content = if options.preserve_breaks {
                 list_content[0].clone()
             } else {
-                list_content.join(" ")
+                // Check if any lines have hard breaks - if so, preserve the structure
+                let has_hard_breaks = list_content.iter().any(|line| has_hard_break(line));
+                if has_hard_breaks {
+                    // Don't join lines with hard breaks - keep them separate with newlines
+                    list_content.join("\n")
+                } else {
+                    // No hard breaks, safe to join with spaces
+                    list_content.join(" ")
+                }
             };
 
             // Calculate the proper indentation for continuation lines
@@ -964,6 +1093,13 @@ pub fn reflow_markdown(content: &str, options: &ReflowOptions) -> String {
             continue;
         }
 
+        // Preserve definition list items (extended markdown)
+        if is_definition_list_item(trimmed) {
+            result.push(line.to_string());
+            i += 1;
+            continue;
+        }
+
         // Check if this is a single line that doesn't need processing
         let mut is_single_line_paragraph = true;
         if i + 1 < lines.len() {
@@ -1007,17 +1143,25 @@ pub fn reflow_markdown(content: &str, options: &ReflowOptions) -> String {
         // If preserve_breaks is true, treat each line separately
         if options.preserve_breaks {
             // Don't collect consecutive lines - just reflow this single line
-            let has_hard_break = line.ends_with("  ");
+            let hard_break_type = if line.strip_suffix('\r').unwrap_or(line).ends_with('\\') {
+                Some("\\")
+            } else if line.ends_with("  ") {
+                Some("  ")
+            } else {
+                None
+            };
             let reflowed = reflow_line(line, options);
 
-            // Preserve hard breaks (two trailing spaces)
-            if has_hard_break && !reflowed.is_empty() {
-                let mut reflowed_with_break = reflowed;
-                let last_idx = reflowed_with_break.len() - 1;
-                if !reflowed_with_break[last_idx].ends_with("  ") {
-                    reflowed_with_break[last_idx].push_str("  ");
+            // Preserve hard breaks (two trailing spaces or backslash)
+            if let Some(break_marker) = hard_break_type {
+                if !reflowed.is_empty() {
+                    let mut reflowed_with_break = reflowed;
+                    let last_idx = reflowed_with_break.len() - 1;
+                    if !has_hard_break(&reflowed_with_break[last_idx]) {
+                        reflowed_with_break[last_idx].push_str(break_marker);
+                    }
+                    result.extend(reflowed_with_break);
                 }
-                result.extend(reflowed_with_break);
             } else {
                 result.extend(reflowed);
             }
@@ -1050,12 +1194,13 @@ pub fn reflow_markdown(content: &str, options: &ReflowOptions) -> String {
                     || (next_trimmed.starts_with('+')
                         && (next_trimmed.len() == 1 || next_trimmed.chars().nth(1) == Some(' ')))
                     || is_numbered_list_item(next_trimmed)
+                    || is_definition_list_item(next_trimmed)
                 {
                     break;
                 }
 
-                // Check if previous line ends with hard break (two spaces)
-                if prev_line.ends_with("  ") {
+                // Check if previous line ends with hard break (two spaces or backslash)
+                if has_hard_break(prev_line) {
                     // Start a new part after hard break
                     paragraph_parts.push(current_part.join(" "));
                     current_part = vec![next_line];
@@ -1080,10 +1225,11 @@ pub fn reflow_markdown(content: &str, options: &ReflowOptions) -> String {
                 let reflowed = reflow_line(part, options);
                 result.extend(reflowed);
 
-                // Preserve hard break by ensuring last line of part ends with two spaces
+                // Preserve hard break by ensuring last line of part ends with hard break marker
+                // Use two spaces as the default hard break format for reflows
                 if j < paragraph_parts.len() - 1 && !result.is_empty() {
                     let last_idx = result.len() - 1;
-                    if !result[last_idx].ends_with("  ") {
+                    if !has_hard_break(&result[last_idx]) {
                         result[last_idx].push_str("  ");
                     }
                 }
@@ -1100,10 +1246,231 @@ pub fn reflow_markdown(content: &str, options: &ReflowOptions) -> String {
     }
 }
 
+/// Information about a reflowed paragraph
+#[derive(Debug, Clone)]
+pub struct ParagraphReflow {
+    /// Starting byte offset of the paragraph in the original content
+    pub start_byte: usize,
+    /// Ending byte offset of the paragraph in the original content
+    pub end_byte: usize,
+    /// The reflowed text for this paragraph
+    pub reflowed_text: String,
+}
+
+/// Reflow a single paragraph at the specified line number
+///
+/// This function finds the paragraph containing the given line number,
+/// reflows it according to the specified line length, and returns
+/// information about the paragraph location and its reflowed text.
+///
+/// # Arguments
+///
+/// * `content` - The full document content
+/// * `line_number` - The 1-based line number within the paragraph to reflow
+/// * `line_length` - The target line length for reflowing
+///
+/// # Returns
+///
+/// Returns `Some(ParagraphReflow)` if a paragraph was found and reflowed,
+/// or `None` if the line number is out of bounds or the content at that
+/// line shouldn't be reflowed (e.g., code blocks, headings, etc.)
+pub fn reflow_paragraph_at_line(content: &str, line_number: usize, line_length: usize) -> Option<ParagraphReflow> {
+    if line_number == 0 {
+        return None;
+    }
+
+    let lines: Vec<&str> = content.lines().collect();
+
+    // Check if line number is valid (1-based)
+    if line_number > lines.len() {
+        return None;
+    }
+
+    let target_idx = line_number - 1; // Convert to 0-based
+    let target_line = lines[target_idx];
+    let trimmed = target_line.trim();
+
+    // Don't reflow special blocks
+    if trimmed.is_empty()
+        || trimmed.starts_with('#')
+        || trimmed.starts_with("```")
+        || trimmed.starts_with("~~~")
+        || target_line.starts_with("    ")
+        || target_line.starts_with('\t')
+        || trimmed.starts_with('>')
+        || trimmed.contains('|') // Tables
+        || (trimmed.starts_with('[') && target_line.contains("]:")) // Reference definitions
+        || is_horizontal_rule(trimmed)
+        || ((trimmed.starts_with('-') || trimmed.starts_with('*') || trimmed.starts_with('+'))
+            && !is_horizontal_rule(trimmed)
+            && (trimmed.len() == 1 || trimmed.chars().nth(1) == Some(' ')))
+        || is_numbered_list_item(trimmed)
+        || is_definition_list_item(trimmed)
+    {
+        return None;
+    }
+
+    // Find paragraph start - scan backward until blank line or special block
+    let mut para_start = target_idx;
+    while para_start > 0 {
+        let prev_idx = para_start - 1;
+        let prev_line = lines[prev_idx];
+        let prev_trimmed = prev_line.trim();
+
+        // Stop at blank line or special blocks
+        if prev_trimmed.is_empty()
+            || prev_trimmed.starts_with('#')
+            || prev_trimmed.starts_with("```")
+            || prev_trimmed.starts_with("~~~")
+            || prev_line.starts_with("    ")
+            || prev_line.starts_with('\t')
+            || prev_trimmed.starts_with('>')
+            || prev_trimmed.contains('|')
+            || (prev_trimmed.starts_with('[') && prev_line.contains("]:"))
+            || is_horizontal_rule(prev_trimmed)
+            || ((prev_trimmed.starts_with('-') || prev_trimmed.starts_with('*') || prev_trimmed.starts_with('+'))
+                && !is_horizontal_rule(prev_trimmed)
+                && (prev_trimmed.len() == 1 || prev_trimmed.chars().nth(1) == Some(' ')))
+            || is_numbered_list_item(prev_trimmed)
+            || is_definition_list_item(prev_trimmed)
+        {
+            break;
+        }
+
+        para_start = prev_idx;
+    }
+
+    // Find paragraph end - scan forward until blank line or special block
+    let mut para_end = target_idx;
+    while para_end + 1 < lines.len() {
+        let next_idx = para_end + 1;
+        let next_line = lines[next_idx];
+        let next_trimmed = next_line.trim();
+
+        // Stop at blank line or special blocks
+        if next_trimmed.is_empty()
+            || next_trimmed.starts_with('#')
+            || next_trimmed.starts_with("```")
+            || next_trimmed.starts_with("~~~")
+            || next_line.starts_with("    ")
+            || next_line.starts_with('\t')
+            || next_trimmed.starts_with('>')
+            || next_trimmed.contains('|')
+            || (next_trimmed.starts_with('[') && next_line.contains("]:"))
+            || is_horizontal_rule(next_trimmed)
+            || ((next_trimmed.starts_with('-') || next_trimmed.starts_with('*') || next_trimmed.starts_with('+'))
+                && !is_horizontal_rule(next_trimmed)
+                && (next_trimmed.len() == 1 || next_trimmed.chars().nth(1) == Some(' ')))
+            || is_numbered_list_item(next_trimmed)
+            || is_definition_list_item(next_trimmed)
+        {
+            break;
+        }
+
+        para_end = next_idx;
+    }
+
+    // Extract paragraph lines
+    let paragraph_lines = &lines[para_start..=para_end];
+
+    // Calculate byte offsets
+    let mut start_byte = 0;
+    for line in lines.iter().take(para_start) {
+        start_byte += line.len() + 1; // +1 for newline
+    }
+
+    let mut end_byte = start_byte;
+    for line in paragraph_lines.iter() {
+        end_byte += line.len() + 1; // +1 for newline
+    }
+
+    // Track whether the byte range includes a trailing newline
+    // (it doesn't if this is the last line and the file doesn't end with newline)
+    let includes_trailing_newline = para_end != lines.len() - 1 || content.ends_with('\n');
+
+    // Adjust end_byte if the last line doesn't have a newline
+    if !includes_trailing_newline {
+        end_byte -= 1;
+    }
+
+    // Join paragraph lines and reflow
+    let paragraph_text = paragraph_lines.join("\n");
+
+    // Create reflow options
+    let options = ReflowOptions {
+        line_length,
+        break_on_sentences: true,
+        preserve_breaks: false,
+        sentence_per_line: false,
+    };
+
+    // Reflow the paragraph using reflow_markdown to handle it properly
+    let reflowed = reflow_markdown(&paragraph_text, &options);
+
+    // Ensure reflowed text matches whether the byte range includes a trailing newline
+    // This is critical: if the range includes a newline, the replacement must too,
+    // otherwise the next line will get appended to the reflowed paragraph
+    let reflowed_text = if includes_trailing_newline {
+        // Range includes newline - ensure reflowed text has one
+        if reflowed.ends_with('\n') {
+            reflowed
+        } else {
+            format!("{reflowed}\n")
+        }
+    } else {
+        // Range doesn't include newline - ensure reflowed text doesn't have one
+        if reflowed.ends_with('\n') {
+            reflowed.trim_end_matches('\n').to_string()
+        } else {
+            reflowed
+        }
+    };
+
+    Some(ParagraphReflow {
+        start_byte,
+        end_byte,
+        reflowed_text,
+    })
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
 
+    #[test]
+    fn test_list_item_trailing_whitespace_removal() {
+        // Test for issue #76 - hard breaks (2 trailing spaces) should be preserved
+        // and prevent reflowing
+        let input = "1. First line with trailing spaces   \n    Second line with trailing spaces  \n    Third line\n";
+
+        let options = ReflowOptions {
+            line_length: 999999,
+            break_on_sentences: true, // MD013 uses true by default
+            preserve_breaks: false,
+            sentence_per_line: false,
+        };
+
+        let result = reflow_markdown(input, &options);
+
+        // Should not contain 3+ consecutive spaces (which would indicate
+        // trailing whitespace became mid-line whitespace)
+        assert!(
+            !result.contains("   "),
+            "Result should not contain 3+ consecutive spaces: {result:?}"
+        );
+
+        // Hard breaks should be preserved (exactly 2 trailing spaces)
+        assert!(result.contains("  \n"), "Hard breaks should be preserved: {result:?}");
+
+        // Should NOT be reflowed into a single line because hard breaks are present
+        // The content should maintain its line structure
+        assert!(
+            result.lines().count() >= 2,
+            "Should have multiple lines (not reflowed due to hard breaks), got: {}",
+            result.lines().count()
+        );
+    }
+
     #[test]
     fn test_reflow_simple_text() {
         let options = ReflowOptions {
@@ -1321,6 +1688,19 @@ mod tests {
         assert_eq!(result[2], "And a statement.");
     }
 
+    #[test]
+    fn test_split_sentences_issue_124() {
+        // Test the actual text from issue #124
+        let text = "If you are sure that all data structures exposed in a `PyModule` are thread-safe, then pass `gil_used = false` as a parameter to the `pymodule` procedural macro declaring the module or call `PyModule::gil_used` on a `PyModule` instance.  For example:";
+
+        let sentences = split_into_sentences(text);
+
+        // This should detect 2 sentences:
+        // 1. "If you are sure ... on a `PyModule` instance."
+        // 2. "For example:"
+        assert_eq!(sentences.len(), 2, "Should detect 2 sentences in the text");
+    }
+
     #[test]
     fn test_reference_link_edge_cases() {
         let options = ReflowOptions {
@@ -1575,4 +1955,144 @@ mod tests {
             "Bullet lists should preserve markers and indent continuations with 2 spaces.\nExpected:\n{expected}\nGot:\n{result}"
         );
     }
+
+    #[test]
+    fn test_ie_abbreviation_split_debug() {
+        let input = "This results in extracting directly from the input object, i.e. `obj.extract()`, rather than trying to access an item or attribute.";
+
+        let options = ReflowOptions {
+            line_length: 80,
+            break_on_sentences: true,
+            preserve_breaks: false,
+            sentence_per_line: true,
+        };
+
+        let result = reflow_line(input, &options);
+
+        // Should be 1 sentence, not split after "i.e."
+        assert_eq!(result.len(), 1, "Should not split after i.e. abbreviation");
+    }
+
+    #[test]
+    fn test_ie_abbreviation_paragraph() {
+        // Test the full paragraph from the file that's causing the issue
+        let input = "The `pyo3(transparent)` attribute can be used on structs with exactly one field.\nThis results in extracting directly from the input object, i.e. `obj.extract()`, rather than trying to access an item or attribute.\nThis behaviour is enabled per default for newtype structs and tuple-variants with a single field.";
+
+        let options = ReflowOptions {
+            line_length: 80,
+            break_on_sentences: true,
+            preserve_breaks: false,
+            sentence_per_line: true,
+        };
+
+        let result = reflow_markdown(input, &options);
+
+        // Should be 3 sentences, not 4 (shouldn't split after "i.e.")
+        let line_count = result.lines().count();
+        assert_eq!(line_count, 3, "Should have 3 sentences, not {line_count}");
+
+        // Verify the second line contains the full sentence
+        let lines: Vec<&str> = result.lines().collect();
+        assert!(lines.len() >= 2, "Should have at least 2 lines");
+        assert!(lines[1].contains("i.e."), "Second line should contain 'i.e.'");
+        assert!(
+            lines[1].contains("`obj.extract()`"),
+            "Second line should contain the code span"
+        );
+        assert!(
+            lines[1].contains("attribute."),
+            "Second line should end with 'attribute.'"
+        );
+    }
+
+    #[test]
+    fn test_definition_list_preservation() {
+        let options = ReflowOptions {
+            line_length: 80,
+            break_on_sentences: true,
+            preserve_breaks: false,
+            sentence_per_line: true,
+        };
+
+        let content = "Term\n: Definition text here.";
+        let result = reflow_markdown(content, &options);
+
+        // Should NOT join into "Term : Definition text here."
+        assert_eq!(result, "Term\n: Definition text here.");
+    }
+
+    #[test]
+    fn test_definition_list_multiline() {
+        let options = ReflowOptions {
+            line_length: 80,
+            break_on_sentences: true,
+            preserve_breaks: false,
+            sentence_per_line: true,
+        };
+
+        let content = "Term\n: First sentence of definition. Second sentence.";
+        let result = reflow_markdown(content, &options);
+
+        // Term line should stay separate
+        assert!(result.starts_with("Term\n"));
+        // Definition list item (line starting with ": ") should be preserved as-is
+        // We don't split sentences within definition list items
+        assert!(result.contains("\n: First sentence of definition. Second sentence."));
+    }
+
+    #[test]
+    fn test_definition_list_multiple() {
+        let options = ReflowOptions {
+            line_length: 80,
+            sentence_per_line: true,
+            ..Default::default()
+        };
+
+        let content = "Term 1\n: Definition 1\n: Another definition for term 1\n\nTerm 2\n: Definition 2";
+        let result = reflow_markdown(content, &options);
+
+        // All definition lines should preserve ": " at start
+        assert!(result.lines().filter(|l| l.trim_start().starts_with(": ")).count() >= 3);
+    }
+
+    #[test]
+    fn test_definition_list_with_paragraphs() {
+        let options = ReflowOptions {
+            line_length: 0, // No line length constraint
+            break_on_sentences: true,
+            preserve_breaks: false,
+            sentence_per_line: true,
+        };
+
+        let content = "Regular paragraph. With multiple sentences.\n\nTerm\n: Definition.\n\nAnother paragraph.";
+        let result = reflow_markdown(content, &options);
+
+        // Paragraph should be reflowed (sentences on separate lines)
+        assert!(result.contains("Regular paragraph."));
+        assert!(result.contains("\nWith multiple sentences."));
+        // Definition list should be preserved
+        assert!(result.contains("Term\n: Definition."));
+        // Another paragraph should be preserved (single sentence, stays as is)
+        assert!(result.contains("Another paragraph."));
+    }
+
+    #[test]
+    fn test_definition_list_edge_cases() {
+        let options = ReflowOptions::default();
+
+        // Indented definition
+        let content1 = "Term\n  : Indented definition";
+        let result1 = reflow_markdown(content1, &options);
+        assert!(result1.contains("\n  : Indented definition"));
+
+        // Multiple spaces after colon
+        let content2 = "Term\n:   Definition";
+        let result2 = reflow_markdown(content2, &options);
+        assert!(result2.contains("\n:   Definition"));
+
+        // Tab after colon
+        let content3 = "Term\n:\tDefinition";
+        let result3 = reflow_markdown(content3, &options);
+        assert!(result3.contains("\n:\tDefinition"));
+    }
 }
