@@ -192,11 +192,9 @@ pub fn extract_highlighted_text(content: &str, warning: &LintWarning) -> String
 pub fn create_rule_by_name(rule_name: &str) -> Option<Box<dyn Rule>> {
     match rule_name {
         "MD001" => Some(Box::new(MD001HeadingIncrement)),
-        "MD002" => Some(Box::new(MD002FirstHeadingH1::new(1))),
         "MD003" => Some(Box::new(MD003HeadingStyle::new(HeadingStyle::Consistent))),
         "MD004" => Some(Box::new(MD004UnorderedListStyle::new(UnorderedListStyle::Consistent))),
         "MD005" => Some(Box::new(MD005ListIndent::default())),
-        "MD006" => Some(Box::new(MD006StartBullets)),
         "MD007" => Some(Box::new(MD007ULIndent::new(2))),
         "MD009" => Some(Box::new(MD009TrailingSpaces::new(2, false))),
         "MD010" => Some(Box::new(MD010NoHardTabs::new(4))),
@@ -216,7 +214,7 @@ pub fn create_rule_by_name(rule_name: &str) -> Option<Box<dyn Rule>> {
         "MD028" => Some(Box::new(MD028NoBlanksBlockquote)),
         "MD030" => Some(Box::new(MD030ListMarkerSpace::new(1, 1, 1, 1))),
         "MD031" => Some(Box::new(MD031BlanksAroundFences::default())),
-        "MD032" => Some(Box::new(MD032BlanksAroundLists::default())),
+        "MD032" => Some(Box::new(MD032BlanksAroundLists)),
         "MD033" => Some(Box::new(MD033NoInlineHtml::new())),
         "MD034" => Some(Box::new(MD034NoBareUrls)),
         "MD035" => Some(Box::new(MD035HRStyle::new("consistent".to_string()))),
@@ -267,7 +265,7 @@ mod tests {
     fn test_extract_highlighted_text_single_line() {
         let content = "This is a test line";
         let warning = LintWarning {
-            rule_name: Some("TEST"),
+            rule_name: Some("TEST".to_string()),
             line: 1,
             column: 6,
             end_line: 1,
@@ -285,7 +283,7 @@ mod tests {
     fn test_extract_highlighted_text_multi_line() {
         let content = "Line 1\nLine 2\nLine 3";
         let warning = LintWarning {
-            rule_name: Some("TEST"),
+            rule_name: Some("TEST".to_string()),
             line: 1,
             column: 6,
             end_line: 2,
