@@ -1,6 +1,7 @@
 use rumdl_lib::config::Config; // Ensure Config is imported
 use rumdl_lib::config::RuleRegistry;
 use rumdl_lib::rules::*;
+use serial_test::serial;
 use std::fs;
 use tempfile::tempdir; // For temporary directory // Add back env import // Ensure SourcedConfig is imported
 
@@ -179,7 +180,10 @@ style = "asterisk"
         .expect("Linting should succeed");
 
     // Verify no MD013 warnings because line_length is set to 150
-    let md013_warnings = warnings.iter().filter(|w| w.rule_name == Some("MD013")).count();
+    let md013_warnings = warnings
+        .iter()
+        .filter(|w| w.rule_name.as_deref() == Some("MD013"))
+        .count();
 
     assert_eq!(
         md013_warnings, 0,
@@ -309,11 +313,11 @@ style = "dash"
     .unwrap();
 
     assert!(
-        warnings_short.iter().all(|w| w.rule_name != Some("MD013")),
+        warnings_short.iter().all(|w| w.rule_name.as_deref() != Some("MD013")),
         "MD013 should not trigger for short line with config"
     );
     assert!(
-        warnings_long.iter().any(|w| w.rule_name == Some("MD013")),
+        warnings_long.iter().any(|w| w.rule_name.as_deref() == Some("MD013")),
         "MD013 should trigger for long line with config"
     );
 
@@ -381,16 +385,25 @@ unknown_global = true"#;
     fs::write(&config_path, config_content).unwrap();
     let sourced =
         rumdl_lib::config::SourcedConfig::load_with_discovery(Some(config_path.to_str().unwrap()), None, true)
-            .expect("config should load successfully"); // Use load
-    let rules = rumdl_lib::all_rules(&rumdl_lib::config::Config::default()); // Use all_rules instead of get_rules
+            .expect("config should load successfully");
+    let rules = rumdl_lib::all_rules(&rumdl_lib::config::Config::default());
     let registry = RuleRegistry::from_rules(&rules);
-    let warnings = rumdl_lib::config::validate_config_sourced(&sourced, &registry); // Use validate_config_sourced
-    // It seems unknown global keys are not yet tracked properly. Adjust test or implementation.
-    // For now, let's expect 0 warnings related to global keys until tracking is implemented/fixed.
+    let warnings = rumdl_lib::config::validate_config_sourced(&sourced, &registry);
+
+    // Should detect the unknown global key "unknown_global"
     let global_warnings = warnings.iter().filter(|w| w.rule.is_none()).count();
     assert_eq!(
-        global_warnings, 0,
-        "Expected 0 unknown global option warnings (check implementation)"
+        global_warnings, 1,
+        "Expected 1 unknown global option warning for 'unknown_global'"
+    );
+
+    // Verify the warning message contains "unknown_global" or "unknown-global"
+    let has_unknown_key_warning = warnings
+        .iter()
+        .any(|w| w.message.contains("unknown_global") || w.message.contains("unknown-global"));
+    assert!(
+        has_unknown_key_warning,
+        "Expected warning about unknown_global, got: {warnings:?}"
     );
 }
 
@@ -584,7 +597,7 @@ invalid_key =
             "Error should mention TOML parsing: {error_msg}"
         );
         assert!(
-            error_msg.contains("invalid string"),
+            error_msg.contains("string values must be quoted") || error_msg.contains("invalid string"),
             "Error should describe the specific issue: {error_msg}"
         );
     }
@@ -885,11 +898,10 @@ line-length:
 }
 
 #[test]
+#[serial(cwd)]
 fn test_user_configuration_discovery() {
     use std::env;
 
-    // Save original env vars
-    let original_xdg = env::var("XDG_CONFIG_HOME").ok();
     let original_dir = env::current_dir().unwrap();
 
     // Create temporary directories
@@ -901,11 +913,6 @@ fn test_user_configuration_discovery() {
     fs::create_dir_all(&project_dir).unwrap();
     fs::create_dir_all(&rumdl_config_dir).unwrap();
 
-    // Set XDG_CONFIG_HOME to our temp config dir
-    unsafe {
-        env::set_var("XDG_CONFIG_HOME", &config_dir);
-    }
-
     // Create user config file
     let user_config_path = rumdl_config_dir.join("rumdl.toml");
     let user_config_content = r#"
@@ -922,8 +929,9 @@ indent = 4
     env::set_current_dir(&project_dir).unwrap();
 
     // Test that user config is loaded when no project config exists
-    let sourced =
-        rumdl_lib::config::SourcedConfig::load_with_discovery(None, None, false).expect("Should load user config");
+    // Pass the config_dir directly instead of setting XDG_CONFIG_HOME
+    let sourced = rumdl_lib::config::SourcedConfig::load_with_discovery_impl(None, None, false, Some(&config_dir))
+        .expect("Should load user config");
 
     let config: Config = sourced.into();
 
@@ -955,7 +963,8 @@ indent = 2
 
     // Test that project config takes precedence over user config
     let sourced_with_project =
-        rumdl_lib::config::SourcedConfig::load_with_discovery(None, None, false).expect("Should load project config");
+        rumdl_lib::config::SourcedConfig::load_with_discovery_impl(None, None, false, Some(&config_dir))
+            .expect("Should load project config");
 
     let config_with_project: Config = sourced_with_project.into();
 
@@ -973,18 +982,13 @@ indent = 2
 
     // Restore original environment
     env::set_current_dir(original_dir).unwrap();
-    match original_xdg {
-        Some(val) => unsafe { env::set_var("XDG_CONFIG_HOME", val) },
-        None => unsafe { env::remove_var("XDG_CONFIG_HOME") },
-    }
 }
 
 #[test]
+#[serial(cwd)]
 fn test_user_configuration_file_precedence() {
     use std::env;
 
-    // Save original env vars
-    let original_xdg = env::var("XDG_CONFIG_HOME").ok();
     let original_dir = env::current_dir().unwrap();
 
     // Create temporary directories
@@ -996,11 +1000,6 @@ fn test_user_configuration_file_precedence() {
     fs::create_dir_all(&project_dir).unwrap();
     fs::create_dir_all(&rumdl_config_dir).unwrap();
 
-    // Set XDG_CONFIG_HOME to our temp config dir
-    unsafe {
-        env::set_var("XDG_CONFIG_HOME", &config_dir);
-    }
-
     // Create multiple user config files to test precedence
     // .rumdl.toml (highest precedence)
     let dot_rumdl_path = rumdl_config_dir.join(".rumdl.toml");
@@ -1032,9 +1031,9 @@ line-length = 99"#,
     // Change to project directory (which has no config)
     env::set_current_dir(&project_dir).unwrap();
 
-    // Test that .rumdl.toml is loaded first
-    let sourced =
-        rumdl_lib::config::SourcedConfig::load_with_discovery(None, None, false).expect("Should load user config");
+    // Test that .rumdl.toml is loaded first - pass config_dir directly
+    let sourced = rumdl_lib::config::SourcedConfig::load_with_discovery_impl(None, None, false, Some(&config_dir))
+        .expect("Should load user config");
 
     let config: Config = sourced.into();
     assert_eq!(
@@ -1045,8 +1044,8 @@ line-length = 99"#,
     // Remove .rumdl.toml and test again
     fs::remove_file(&dot_rumdl_path).unwrap();
 
-    let sourced2 =
-        rumdl_lib::config::SourcedConfig::load_with_discovery(None, None, false).expect("Should load user config");
+    let sourced2 = rumdl_lib::config::SourcedConfig::load_with_discovery_impl(None, None, false, Some(&config_dir))
+        .expect("Should load user config");
 
     let config2: Config = sourced2.into();
     assert_eq!(
@@ -1057,8 +1056,8 @@ line-length = 99"#,
     // Remove rumdl.toml and test again
     fs::remove_file(&rumdl_path).unwrap();
 
-    let sourced3 =
-        rumdl_lib::config::SourcedConfig::load_with_discovery(None, None, false).expect("Should load user config");
+    let sourced3 = rumdl_lib::config::SourcedConfig::load_with_discovery_impl(None, None, false, Some(&config_dir))
+        .expect("Should load user config");
 
     let config3: Config = sourced3.into();
     assert_eq!(
@@ -1068,8 +1067,4 @@ line-length = 99"#,
 
     // Restore original environment
     env::set_current_dir(original_dir).unwrap();
-    match original_xdg {
-        Some(val) => unsafe { env::set_var("XDG_CONFIG_HOME", val) },
-        None => unsafe { env::remove_var("XDG_CONFIG_HOME") },
-    }
 }
