@@ -218,13 +218,20 @@ fn test_md039_whitespace_only_links() {
 
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 4, "Should detect whitespace-only links");
+    // CommonMark-compliant: [\n\n\n](url3) is NOT a valid link (blank lines break syntax)
+    // Valid links: [   ](url1), [\t\t\t](url2), [ \t\n ](url4)
+    assert_eq!(
+        result.len(),
+        3,
+        "Should detect 3 CommonMark-compliant whitespace-only links"
+    );
 
     // These should be trimmed to empty
     let fixed = rule.fix(&ctx).unwrap();
     assert!(fixed.contains("[](url1)"));
     assert!(fixed.contains("[](url2)"));
-    assert!(fixed.contains("[](url3)"));
+    // [\n\n\n](url3) is not a link, so it remains unchanged
+    assert!(fixed.contains("[\n\n\n](url3)"));
     assert!(fixed.contains("[](url4)"));
 }
 
@@ -401,10 +408,11 @@ fn test_md042_empty_url_variations() {
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 5, "Should detect all empty URL variations");
 
-    // Verify fix suggestions
+    // Verify that non-URL text with empty URLs are NOT fixable
+    // (we can't guess what the URL should be)
     let fixed = rule.fix(&ctx).unwrap();
-    assert!(fixed.contains("[Click here](https://example.com)"));
-    assert!(!fixed.contains("[Click here]()"));
+    // Content should remain unchanged since these are not fixable
+    assert_eq!(fixed, content);
 }
 
 #[test]
@@ -422,10 +430,11 @@ fn test_md042_both_empty() {
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 4, "Should detect all double-empty variations");
 
-    // Verify fix
+    // Verify that both empty text and URL are NOT fixable
+    // (we can't guess either the text or the URL)
     let fixed = rule.fix(&ctx).unwrap();
-    assert!(fixed.contains("[Link text](https://example.com)"));
-    assert!(!fixed.contains("[]()"));
+    // Content should remain unchanged since these are not fixable
+    assert_eq!(fixed, content);
 }
 
 #[test]
@@ -545,16 +554,28 @@ fn test_md042_nested_links() {
     let rule = MD042NoEmptyLinks::new();
 
     // Test 10: Nested link-like structures
+    // With ENABLE_WIKILINKS: [[text]] is parsed as a wiki-link
+    // [[Double brackets]](url) becomes a wiki-link with empty text pointing to "Double brackets"
+    // The trailing (url) is just plain text, not part of the link
     let content = "\
 [Link [with] brackets](url)
 [Link (with) parens](url)
 [[Double brackets]](url)
-[](url [not a link])";
+[](url)";
 
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    // Last one has empty text
-    assert!(!result.is_empty(), "Should detect empty text in last link");
+
+    // With wiki-links enabled, we get 2 empty links:
+    // 1. [[Double brackets]] - wiki-link with empty text
+    // 2. [](url) - explicit empty link
+    assert_eq!(
+        result.len(),
+        2,
+        "Should detect empty text in wiki-link and regular empty link"
+    );
+    assert!(result.iter().any(|w| w.message.contains("[[Double brackets")));
+    assert!(result.iter().any(|w| w.message.contains("[](url)")));
 }
 
 #[test]
@@ -592,10 +613,18 @@ Another [ spaced link ](  )";
     let step3 = md042.fix(&ctx2).unwrap();
     let ctx_final = LintContext::new(&step3, rumdl_lib::config::MarkdownFlavor::Standard);
 
-    // All issues should be resolved
+    // MD034 and MD039 issues should be resolved
     assert!(md034.check(&ctx_final).unwrap().is_empty());
     assert!(md039.check(&ctx_final).unwrap().is_empty());
-    assert!(md042.check(&ctx_final).unwrap().is_empty());
+
+    // MD042: The empty links []() and [spaced link](  ) cannot be auto-fixed
+    // because they have no content to infer a URL from (empty text/whitespace-only URL)
+    let md042_remaining = md042.check(&ctx_final).unwrap();
+    assert_eq!(md042_remaining.len(), 2, "Two unfixable empty links should remain");
+
+    // Verify the unfixable links are correctly identified
+    assert!(md042_remaining[0].message.contains("Empty link found"));
+    assert!(md042_remaining[1].message.contains("Empty link found"));
 }
 
 #[test]
