@@ -1,12 +1,12 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::MD018NoMissingSpaceAtx;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD018NoMissingSpaceAtx;
 
 #[test]
 fn test_valid_atx_headings() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "# Heading 1\n## Heading 2\n### Heading 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -15,7 +15,7 @@ fn test_valid_atx_headings() {
 fn test_invalid_atx_headings() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "#Heading 1\n## Heading 2\n###Heading 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     assert_eq!(result[0].line, 1);
@@ -26,7 +26,7 @@ fn test_invalid_atx_headings() {
 fn test_mixed_atx_headings() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "# Heading 1\n##Heading 2\n### Heading 3\n####Heading 4";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
 }
@@ -35,7 +35,7 @@ fn test_mixed_atx_headings() {
 fn test_code_block() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "```markdown\n#Not a heading\n##Also not a heading\n```\n# Real Heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -44,7 +44,7 @@ fn test_code_block() {
 fn test_fix_atx_headings() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "#Heading 1\n## Heading 2\n###Heading 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "# Heading 1\n## Heading 2\n### Heading 3");
 }
@@ -53,7 +53,7 @@ fn test_fix_atx_headings() {
 fn test_fix_mixed_atx_headings() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "# Heading 1\n##Heading 2\n### Heading 3\n####Heading 4";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "# Heading 1\n## Heading 2\n### Heading 3\n#### Heading 4");
 }
@@ -62,7 +62,7 @@ fn test_fix_mixed_atx_headings() {
 fn test_preserve_code_blocks() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "# Real Heading\n```\n#Not a heading\n```\n# Another Heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "# Real Heading\n```\n#Not a heading\n```\n# Another Heading");
 }
@@ -71,7 +71,7 @@ fn test_preserve_code_blocks() {
 fn test_heading_with_multiple_hashes() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "######Heading 6";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].message, "No space after ###### in heading");
@@ -83,7 +83,7 @@ fn test_heading_with_multiple_hashes() {
 fn test_not_a_heading() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "This is #not a heading\nAnd this is also #not a heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -92,7 +92,7 @@ fn test_not_a_heading() {
 fn test_closed_atx_headings() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "#Heading 1 #\n##Heading 2 ##\n###Heading 3 ###";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3);
     let fixed = rule.fix(&ctx).unwrap();
@@ -103,7 +103,7 @@ fn test_closed_atx_headings() {
 fn test_multiple_spaces() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "# Heading with extra space\n#  Another heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -112,7 +112,7 @@ fn test_multiple_spaces() {
 fn test_empty_headings() {
     let rule = MD018NoMissingSpaceAtx::new();
     let content = "#\n##\n###";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -123,7 +123,7 @@ fn test_emoji_hashtags() {
 
     // Test emoji hashtag patterns that should NOT be detected as headings
     let content = "#️⃣ Emoji hashtag\n#⃣ Another variant\n##️⃣ Double emoji\n# Regular heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Accept that emojis with spaces after them might be detected as headings
@@ -135,7 +135,7 @@ fn test_emoji_hashtags() {
 
     // Test with missing space after regular heading but emoji hashtags present
     let content = "#️⃣ Emoji\n#Missing space\n#⃣ Another emoji";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Find the warning for line 2
@@ -152,7 +152,7 @@ fn test_hashtag_vs_heading() {
 
     // Test hashtags that should NOT be detected as headings
     let content = "#tag\n#123\n#abc123\n# Real Heading\n##RealHeadingNoSpace";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // The rule should skip lowercase hashtags but detect the uppercase heading without space
