@@ -74,7 +74,7 @@ fn test_line_index() {
     let content = r#"1. First item
 2. Second item
 3. Third item"#;
-    let index = LineIndex::new(content.to_string());
+    let index = LineIndex::new(content);
 
     // The byte range should be calculated based on the actual content
     // Line 2, Column 1 corresponds to the beginning of "2. Second item" which is at index 14
@@ -464,11 +464,17 @@ second line of second item"#;
     );
 
     // Check for lazy continuation warnings
-    let lazy_warnings = result.iter().filter(|w| w.rule_name == Some("MD029-style")).count();
+    let lazy_warnings = result
+        .iter()
+        .filter(|w| w.rule_name.as_deref() == Some("MD029-style"))
+        .count();
     assert_eq!(lazy_warnings, 2, "Should have 2 lazy continuation warnings");
 
     // Check for numbering warning
-    let numbering_warnings = result.iter().filter(|w| w.rule_name == Some("MD029")).count();
+    let numbering_warnings = result
+        .iter()
+        .filter(|w| w.rule_name.as_deref() == Some("MD029"))
+        .count();
     assert_eq!(numbering_warnings, 1, "Should have 1 numbering warning");
 }
 
@@ -724,7 +730,10 @@ lazy line
     let result = rule.check(&ctx).unwrap();
 
     // Should detect lazy continuations (0 and 2 space lines)
-    let lazy_warnings = result.iter().filter(|w| w.rule_name == Some("MD029-style")).count();
+    let lazy_warnings = result
+        .iter()
+        .filter(|w| w.rule_name.as_deref() == Some("MD029-style"))
+        .count();
     // Note: Only line 2 is detected as lazy continuation because it's within the list block.
     // Line 5 has 2 spaces but it's after line 4 which starts a new list, so it's not
     // considered part of the list block and thus not checked for lazy continuation.
@@ -860,7 +869,7 @@ fn test_md029_nested_ordered_lists_bug() {
             println!(
                 "  Line {}: '{}' - marker: '{}', column: {}, ordered: {}",
                 line_num,
-                line_info.content.trim(),
+                line_info.content(ctx.content).trim(),
                 list_item.marker,
                 list_item.marker_column,
                 list_item.is_ordered
