@@ -4,7 +4,7 @@ use rumdl_lib::rules::MD032BlanksAroundLists;
 
 #[test]
 fn test_valid_lists() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Some text\n\n* Item 1\n* Item 2\n\nMore text";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -13,7 +13,7 @@ fn test_valid_lists() {
 
 #[test]
 fn test_missing_blank_line_before() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Some text\n* Item 1\n* Item 2\n\nMore text";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -22,7 +22,7 @@ fn test_missing_blank_line_before() {
 
 #[test]
 fn test_missing_blank_line_after() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Some text\n\n* Item 1\n* Item 2\nMore text";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -31,7 +31,7 @@ fn test_missing_blank_line_after() {
 
 #[test]
 fn test_fix_missing_blank_lines() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Text\n* Item 1\n* Item 2\nMore text";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
@@ -44,7 +44,7 @@ fn test_fix_missing_blank_lines() {
 #[test]
 fn test_emphasis_not_list_marker_simple() {
     // Test simple emphasis pattern that should NOT be detected as a list marker
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "*Emphasis text*\n- List item\n- Another item";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -63,7 +63,7 @@ fn test_emphasis_not_list_marker_simple() {
 #[test]
 fn test_emphasis_not_list_marker_multiple_stars() {
     // Test various emphasis patterns that should NOT be detected as lists
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content =
         "**Bold text here**\n*Italic text*\n***Bold italic***\n\n- Actual list item\n- Another item\n\nMore text";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
@@ -79,7 +79,7 @@ fn test_emphasis_not_list_marker_multiple_stars() {
 #[test]
 fn test_emphasis_followed_by_list_needs_blank() {
     // This is the exact case from the parity corpus that was failing
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "**Problem: Permission errors**\n- On Windows: Run as administrator";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -99,7 +99,7 @@ fn test_emphasis_followed_by_list_needs_blank() {
 #[test]
 fn test_nested_lists_issue_33() {
     // Test for GitHub issue #33 - Nested lists should not require blank lines between levels
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "## Heading\n\n1. List item 1\n   - sub list 1.1\n   - sub list 1.2\n1. List item 2\n   - sub list 2.1\n\nThat was a nice list.";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -116,7 +116,7 @@ fn test_nested_lists_issue_33() {
 #[test]
 fn test_blockquote_numbers_issue_32() {
     // Test for GitHub issue #32 - Lines starting with numbers in blockquotes should not be detected as lists
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "> The following versions are vulnerable:\n>   all versions 9 and before\n>   10.5 - 10.6\n>   11.1 - 11.2\n> Other information";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -133,7 +133,7 @@ fn test_blockquote_numbers_issue_32() {
 #[test]
 fn test_emphasis_patterns_not_lists() {
     // Test various emphasis patterns that contain * or + characters
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "**API Parameters**\n*userId (string) - The user ID*\n\n+ This is a real list item\n+ Another real item\n\nMore text";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -145,7 +145,7 @@ fn test_emphasis_patterns_not_lists() {
 #[test]
 fn test_heading_emphasis_not_list() {
     // Test heading with emphasis that was causing false positives
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "## **Section Title**\n\nSome content\n\n- Real list item\n- Another item";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -156,7 +156,7 @@ fn test_heading_emphasis_not_list() {
 
 #[test]
 fn test_multiple_lists() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Text\n* List 1\n* List 1\nText\n1. List 2\n2. List 2\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -172,7 +172,7 @@ fn test_multiple_lists() {
 #[test]
 fn test_nested_lists() {
     // Nested lists should not require blank lines between parent and child items
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Text\n* Item 1\n  * Nested 1\n  * Nested 2\n* Item 2\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -190,7 +190,7 @@ fn test_nested_lists() {
 #[test]
 fn test_nested_lists_with_strict_mode() {
     // Even in strict mode, nested lists are a standard Markdown pattern and shouldn't require blank lines
-    let rule = MD032BlanksAroundLists::strict();
+    let rule = MD032BlanksAroundLists;
     let content = "Text\n\n* Item 1\n  * Nested 1\n  * Nested 2\n* Item 2\n\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -204,7 +204,7 @@ fn test_nested_lists_with_strict_mode() {
 #[test]
 fn test_deeply_nested_lists() {
     // Test multiple levels of nesting
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "## Section\n\n* Level 1\n  * Level 2\n    * Level 3\n      * Level 4\n  * Back to Level 2\n* Back to Level 1\n\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -215,7 +215,7 @@ fn test_deeply_nested_lists() {
 #[test]
 fn test_nested_ordered_lists() {
     // Test nested ordered lists
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "## Section\n\n1. First item\n   1. Sub item 1.1\n   2. Sub item 1.2\n2. Second item\n   1. Sub item 2.1\n\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -225,7 +225,7 @@ fn test_nested_ordered_lists() {
 #[test]
 fn test_mixed_nested_list_types() {
     // Test mixing ordered and unordered lists in nesting
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "## Section\n\n1. Ordered item\n   - Unordered sub-item\n   - Another unordered sub-item\n2. Another ordered item\n   * Different unordered marker\n\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -234,7 +234,7 @@ fn test_mixed_nested_list_types() {
 
 #[test]
 fn test_mixed_list_types() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Text\n* Unordered\n* List\nText\n1. Ordered\n2. List\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -249,7 +249,7 @@ fn test_mixed_list_types() {
 
 #[test]
 fn test_list_with_content() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Text\n* Item 1\n  Content\n* Item 2\n  More content\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
@@ -288,7 +288,7 @@ fn test_list_with_content() {
 
 #[test]
 fn test_list_at_start() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "* Item 1\n* Item 2\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -300,7 +300,7 @@ fn test_list_at_start() {
 
 #[test]
 fn test_list_at_end() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Text\n* Item 1\n* Item 2";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -312,7 +312,7 @@ fn test_list_at_end() {
 
 #[test]
 fn test_multiple_blank_lines() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Text\n\n\n* Item 1\n* Item 2\n\n\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -321,7 +321,7 @@ fn test_multiple_blank_lines() {
 
 #[test]
 fn test_list_with_blank_lines() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "Text\n\n* Item 1\n\n* Item 2\n\nText";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -330,7 +330,7 @@ fn test_list_with_blank_lines() {
 
 #[test]
 fn test_md032_toc_false_positive() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = r#"
 ## Table of Contents
 
@@ -353,7 +353,7 @@ fn test_md032_toc_false_positive() {
 
 #[test]
 fn test_list_followed_by_heading_invalid() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "* Item 1\n* Item 2\n## Next Section";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -363,7 +363,7 @@ fn test_list_followed_by_heading_invalid() {
 
 #[test]
 fn test_list_followed_by_code_block_invalid() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "* Item 1\n* Item 2\n```\ncode\n```";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -373,7 +373,7 @@ fn test_list_followed_by_code_block_invalid() {
 
 #[test]
 fn test_list_followed_by_blank_then_code_block_valid() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
     let content = "* Item 1\n* Item 2\n\n```\ncode\n```";
     let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
@@ -382,53 +382,9 @@ fn test_list_followed_by_blank_then_code_block_valid() {
 
 // New tests for lenient behavior
 
-#[test]
-fn test_allow_list_after_heading() {
-    // Default is now strict (false) to match markdownlint
-    let rule = MD032BlanksAroundLists {
-        allow_after_headings: true,
-        ..Default::default()
-    };
-
-    // Test cases that should NOT be flagged with lenient settings
-    let valid_cases = vec![
-        "# Items to consider:\n* Item 1\n* Item 2\n\nMore text",
-        "## Steps:\n1. First step\n2. Second step\n\nFollowing text",
-        "### Features\n- Feature A\n- Feature B\n\nDescription",
-    ];
-
-    for case in valid_cases {
-        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard);
-        let result = rule.check(&ctx).unwrap();
-        assert!(result.is_empty(), "Should not flag lists after headings in: {case}");
-    }
-}
-
-#[test]
-fn test_allow_list_after_colon() {
-    // Default is now strict (false) to match markdownlint
-    let rule = MD032BlanksAroundLists {
-        allow_after_colons: true,
-        ..Default::default()
-    };
-
-    // Test cases that should NOT be flagged with lenient settings
-    let valid_cases = vec![
-        "Here are the steps:\n1. First step\n2. Second step\n\nFollowing text",
-        "Items to consider:\n* Item 1\n* Item 2\n\nMore text",
-        "The following options are available:\n- Option A\n- Option B\n\nDescription",
-    ];
-
-    for case in valid_cases {
-        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard);
-        let result = rule.check(&ctx).unwrap();
-        assert!(result.is_empty(), "Should not flag lists after colons in: {case}");
-    }
-}
-
 #[test]
 fn test_strict_mode_flags_all() {
-    let rule = MD032BlanksAroundLists::strict(); // All allowances disabled
+    let rule = MD032BlanksAroundLists; // All allowances disabled
 
     // Even valid cases should be flagged in strict mode
     let cases = vec![
@@ -445,7 +401,7 @@ fn test_strict_mode_flags_all() {
 
 #[test]
 fn test_still_flags_inappropriate_cases() {
-    let rule = MD032BlanksAroundLists::default();
+    let rule = MD032BlanksAroundLists;
 
     // These should still be flagged even with lenient settings
     let invalid_cases = vec![
