@@ -20,7 +20,7 @@ fn test_bare_urls() {
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1, "Bare URLs should be flagged");
     assert_eq!(result[0].line, 1);
-    assert_eq!(result[0].rule_name, Some("MD034"));
+    assert_eq!(result[0].rule_name.as_deref(), Some("MD034"));
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "This is a bare URL: <https://example.com/foobar>");
 }
@@ -639,3 +639,151 @@ fn test_mixed_multiline_links_and_bare_urls() {
         "Should not modify the second multi-line markdown link"
     );
 }
+
+#[test]
+fn test_issue_104_url_in_empty_link() {
+    // Issue #104: URL in link text with empty URL part [url]()
+    // This is the pattern from issue #104: [https://github.com/pfeif/hx-complete-generator]()
+    // The URL is in the link text with empty URL part
+    let rule = MD034NoBareUrls;
+    let content = "check it out in its new repository at [https://github.com/pfeif/hx-complete-generator]().";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // The URL in [url]() should NOT be flagged because it's part of a markdown link construct
+    // (even though the link is empty/invalid, it's still a link construct that should be handled by MD042)
+    assert_eq!(
+        result.len(),
+        0,
+        "URL in [url]() link text should not be flagged as bare URL. This is MD042 territory. Found {} warnings: {:#?}",
+        result.len(),
+        result
+    );
+}
+
+#[test]
+fn test_issue_104_url_in_empty_bracket_link() {
+    // Issue #104: Similar pattern with [url][]
+    let rule = MD034NoBareUrls;
+    let content = "Visit [https://www.google.com][] for more info.";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should not be flagged - it's part of a markdown link reference construct
+    assert_eq!(
+        result.len(),
+        0,
+        "URL in [url][] should not be flagged as bare URL. Found {} warnings: {:#?}",
+        result.len(),
+        result
+    );
+}
+
+#[test]
+fn test_issue_104_full_paragraph_not_corrupted() {
+    // Issue #104: Full regression test with the actual paragraph from the bug report
+    // This tests that after MD042 fixes the empty link, MD034 doesn't corrupt the text
+    let rule = MD034NoBareUrls;
+
+    // This is what the content looks like AFTER MD042 has fixed the empty link
+    // MD042 now intelligently uses the URL from the text as the destination
+    let content_after_md042 = "I've never been one to implement hacky solutions because life is just easier\nwhen everything gets done \"by the book.\" So, if you're reading this and want to\nsee the code that creates this extension and prevents me from pouring needless\nhours into meticulously maintaining the files by hand, I welcome you to check it\nout in its new repository at [https://github.com/pfeif/hx-complete-generator](https://github.com/pfeif/hx-complete-generator).";
+
+    let ctx = LintContext::new(content_after_md042, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // MD034 should NOT flag the URL because it's properly in a markdown link now
+    assert_eq!(
+        result.len(),
+        0,
+        "After MD042 fixes empty link, MD034 should not flag the URL. Found {} warnings: {:#?}",
+        result.len(),
+        result
+    );
+
+    // Verify MD034 fix produces exactly the expected output (no modifications)
+    let fixed = rule.fix(&ctx).unwrap();
+    assert_eq!(
+        fixed, content_after_md042,
+        "MD034 should not modify content that has properly formatted links"
+    );
+}
+
+// Issue #116: URLs in front matter should not be flagged
+#[test]
+fn test_urls_in_yaml_front_matter() {
+    let rule = MD034NoBareUrls;
+    let content = "---\nurl: http://example.com\ntitle: Test\n---\n\n# Content";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+    assert!(result.is_empty(), "URLs in YAML front matter should not be flagged");
+}
+
+#[test]
+fn test_urls_in_toml_front_matter() {
+    let rule = MD034NoBareUrls;
+    let content = "+++\nurl = \"http://example.com\"\ntitle = \"Test\"\n+++\n\n# Content";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+    assert!(result.is_empty(), "URLs in TOML front matter should not be flagged");
+}
+
+#[test]
+fn test_urls_in_json_front_matter() {
+    let rule = MD034NoBareUrls;
+    let content = "{\n\"url\": \"http://example.com\",\n\"title\": \"Test\"\n}\n\n# Content";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+    assert!(result.is_empty(), "URLs in JSON front matter should not be flagged");
+}
+
+#[test]
+fn test_bare_url_after_front_matter() {
+    let rule = MD034NoBareUrls;
+    let content = "---\nurl: http://example.com\n---\n\nVisit http://bare-url.com";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+    assert_eq!(result.len(), 1, "Bare URL after front matter should be flagged");
+    assert!(result[0].message.contains("http://bare-url.com"));
+
+    let fixed = rule.fix(&ctx).unwrap();
+    assert!(
+        fixed.contains("<http://bare-url.com>"),
+        "Bare URL should be wrapped in angle brackets"
+    );
+    assert!(
+        fixed.contains("url: http://example.com"),
+        "URL in front matter should remain unchanged"
+    );
+}
+
+#[test]
+fn test_email_in_front_matter() {
+    let rule = MD034NoBareUrls;
+    let content = "---\nauthor_email: user@example.com\ncontact: admin@test.org\n---\n\n# Content";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+    assert!(result.is_empty(), "Emails in front matter should not be flagged");
+}
+
+#[test]
+fn test_multiple_urls_in_front_matter() {
+    let rule = MD034NoBareUrls;
+    let content = "---\nurl: http://example.com\nrepository: https://github.com/user/repo\nwebsite: ftp://files.example.org\n---\n\n# Content";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+    assert!(result.is_empty(), "Multiple URLs in front matter should not be flagged");
+}
+
+#[test]
+fn test_issue_116_exact_reproduction() {
+    // This is the exact test case from issue #116
+    let rule = MD034NoBareUrls;
+    let content = "---\nurl: http://example.com\n---\n\n# Repro";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+    assert!(
+        result.is_empty(),
+        "Issue #116: URL in front matter should not be flagged"
+    );
+}
