@@ -1,12 +1,12 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::MD037NoSpaceInEmphasis;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD037NoSpaceInEmphasis;
 
 #[test]
 fn test_valid_emphasis() {
     let rule = MD037NoSpaceInEmphasis;
     let content = "*text* and **text** and _text_ and __text__";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -15,7 +15,7 @@ fn test_valid_emphasis() {
 fn test_spaces_inside_asterisk_emphasis() {
     let rule = MD037NoSpaceInEmphasis;
     let content = "* text * and *text * and * text*";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3); // All three emphasis spans have spacing issues
 }
@@ -24,7 +24,7 @@ fn test_spaces_inside_asterisk_emphasis() {
 fn test_spaces_inside_double_asterisk() {
     let rule = MD037NoSpaceInEmphasis;
     let content = "** text ** and **text ** and ** text**";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3); // All three have spacing issues
 }
@@ -33,7 +33,7 @@ fn test_spaces_inside_double_asterisk() {
 fn test_spaces_inside_underscore_emphasis() {
     let rule = MD037NoSpaceInEmphasis;
     let content = "_ text _ and _text _ and _ text_";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3);
 }
@@ -42,7 +42,7 @@ fn test_spaces_inside_underscore_emphasis() {
 fn test_spaces_inside_double_underscore() {
     let rule = MD037NoSpaceInEmphasis;
     let content = "__ text __ and __text __ and __ text__";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3); // All three emphasis spans have spacing issues
 }
@@ -51,7 +51,7 @@ fn test_spaces_inside_double_underscore() {
 fn test_emphasis_in_code_block() {
     let rule = MD037NoSpaceInEmphasis;
     let content = "```\n* text *\n```\n* text *";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // The emphasis inside the code block should be ignored, but the one outside should be flagged
     assert_eq!(result.len(), 1);
@@ -61,7 +61,7 @@ fn test_emphasis_in_code_block() {
 fn test_multiple_emphasis_on_line() {
     let rule = MD037NoSpaceInEmphasis;
     let content = "* text * and _ text _ in one line";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2); // Both emphasis spans have spacing issues
 }
@@ -70,7 +70,7 @@ fn test_multiple_emphasis_on_line() {
 fn test_mixed_emphasis() {
     let rule = MD037NoSpaceInEmphasis;
     let content = "* text * and ** text ** mixed";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2); // Both emphasis spans have spacing issues
 }
@@ -79,7 +79,7 @@ fn test_mixed_emphasis() {
 fn test_emphasis_with_punctuation() {
     let rule = MD037NoSpaceInEmphasis;
     let content = "* text! * and * text? * here";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2); // Both emphasis spans have spacing issues
 }
@@ -90,25 +90,25 @@ fn test_code_span_handling() {
 
     // Test code spans containing emphasis-like content
     let content = "Use `*text*` as emphasis and `**text**` as strong emphasis";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Test nested backticks with different counts
     let content = "This is ``code with ` inside`` and `code with *asterisks*`";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Test code spans at start and end of line
     let content = "`*text*` at start and at end `*more text*`";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Test mixed code spans and emphasis in same line
     let content = "Code `let x = 1;` and *emphasis* and more code `let y = 2;`";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -119,25 +119,25 @@ fn test_emphasis_edge_cases() {
 
     // Test emphasis next to punctuation
     let content = "*text*.and **text**!";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Test emphasis at line boundaries
     let content = "*text*\n*text*";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Test emphasis mixed with code spans on the same line
     let content = "*emphasis* with `code` and *more emphasis*";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Test complex mixed content
     let content = "**strong _with emph_** and `code *with* asterisks`";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -148,25 +148,25 @@ fn test_fix_preserves_structure_emphasis() {
 
     // Verify emphasis fix preserves code blocks
     let content = "* bad emphasis * and ```\n* text *\n```\n* more bad *";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    let fixed_ctx = LintContext::new(&fixed);
+    let fixed_ctx = LintContext::new(&fixed, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&fixed_ctx).unwrap();
     assert!(result.is_empty()); // Fixed content should have no warnings
 
     // Verify preservation of complex content
     let content = "`code` with * bad * and **bad ** emphasis";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    let fixed_ctx = LintContext::new(&fixed);
+    let fixed_ctx = LintContext::new(&fixed, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&fixed_ctx).unwrap();
     assert!(result.is_empty()); // Fixed content should have no warnings
 
     // Test multiple emphasis fixes on the same line
     let content = "* test * and ** strong ** emphasis";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    let fixed_ctx = LintContext::new(&fixed);
+    let fixed_ctx = LintContext::new(&fixed, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&fixed_ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -177,7 +177,7 @@ fn test_nested_emphasis() {
 
     // Display results instead of asserting
     let content = "**This is *nested* emphasis**";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     println!("Nested emphasis test - expected 1 issue, found {} issues", result.len());
     for warning in &result {
@@ -195,7 +195,7 @@ fn test_emphasis_in_lists() {
 
     // Display results for valid list items
     let content = "- Item with *emphasis*\n- Item with **strong**";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     println!("\nValid list items - expected 0 issues, found {} issues", result.len());
     for warning in &result {
@@ -207,7 +207,7 @@ fn test_emphasis_in_lists() {
 
     // Display results for invalid list items
     let content = "- Item with * emphasis *\n- Item with ** strong **";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     println!("\nInvalid list items - expected 1 issue, found {} issues", result.len());
     for warning in &result {
@@ -226,13 +226,13 @@ fn test_emphasis_with_special_characters() {
 
     // Valid emphasis with special characters
     let content = "*Special: !@#$%^&*()* and **More: []{}<>\"'**";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Invalid emphasis with special characters
     let content = "* Special: !@#$%^&() * and ** More: []{}<>\"' **";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2); // Both emphasis spans have spacing issues
 }
@@ -243,13 +243,13 @@ fn test_emphasis_near_html() {
 
     // Valid emphasis near HTML
     let content = "<div>*Emphasis*</div> and **Strong** <span>text</span>";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Invalid emphasis near HTML
     let content = "<div>* Emphasis *</div> and ** Strong ** <span>text</span>";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2); // Both emphasis spans have spacing issues
 }
@@ -260,7 +260,7 @@ fn test_emphasis_with_multiple_spaces() {
 
     // Emphasis with multiple spaces - these SHOULD be flagged
     let content = "*   multiple spaces   * and **    more spaces    **";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2); // Both emphasis spans have spacing issues
 }
@@ -271,7 +271,7 @@ fn test_non_emphasis_asterisks() {
 
     // Asterisks that aren't emphasis
     let content = "* Not emphasis\n* Also not emphasis\n2 * 3 = 6";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(
         result.len(),
@@ -281,7 +281,7 @@ fn test_non_emphasis_asterisks() {
 
     // Mix of emphasis and non-emphasis
     let content = "* List item with *emphasis*\n* List item with *incorrect * emphasis";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(
         result.len(),
@@ -296,7 +296,7 @@ fn test_emphasis_at_boundaries() {
 
     // Emphasis at word boundaries
     let content = "Text * emphasis * more text";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
 }
@@ -307,13 +307,13 @@ fn test_emphasis_in_blockquotes() {
 
     // Valid emphasis in blockquotes
     let content = "> This is a *emphasized* text in a blockquote\n> And **strong** text too";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Invalid emphasis in blockquotes
     let content = "> This is a * emphasized * text in a blockquote\n> And ** strong ** text too";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2); // Both emphasis spans have spacing issues
 }
@@ -326,7 +326,7 @@ fn test_md037_in_text_code_block() {
 README.md:24:5: [MD037] Spaces inside emphasis markers: "* incorrect *" [*]
 ```
 "#;
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -348,7 +348,7 @@ fn test_false_positive_punctuation_after_emphasis() {
     ];
 
     for content in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Print results for debugging
@@ -382,7 +382,7 @@ fn test_false_positive_nested_emphasis() {
     ];
 
     for content in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Print results for debugging
@@ -416,7 +416,7 @@ fn test_false_positive_multiple_emphasis_same_line() {
     ];
 
     for content in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Print results for debugging
@@ -451,7 +451,7 @@ fn test_true_positive_spaces_in_emphasis() {
     ];
 
     for (content, expected_warnings) in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Print results for debugging
@@ -497,7 +497,7 @@ fn test_emphasis_boundary_detection() {
     ];
 
     for (content, expected_warnings) in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         println!(
@@ -535,7 +535,7 @@ fn test_math_expressions_not_flagged() {
     ];
 
     for content in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         println!("Testing math expression: {content}");
