@@ -662,3 +662,182 @@ fn test_issue_81_toml_code_block_not_parsed() {
         "Should not flag [[bin]] in TOML code block as undefined reference (issue #81)"
     );
 }
+
+#[test]
+fn test_mkdocs_backtick_wrapped_auto_references() {
+    // Test for issue #97 - backtick-wrapped references should be recognized as MkDocs auto-references
+    let rule = MD052ReferenceLinkImages::new();
+
+    // Module.Class pattern with backticks
+    let content = "[`module.Class`][]";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let result = rule.check(&ctx).unwrap();
+    assert!(
+        result.is_empty(),
+        "Should not flag [`module.Class`][] as undefined reference in MkDocs mode (issue #97). Got: {result:?}"
+    );
+
+    // Reference with explicit ID
+    let content = "[`module.Class`][ref]";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let result = rule.check(&ctx).unwrap();
+    assert!(
+        result.is_empty(),
+        "Should not flag [`module.Class`][ref] as undefined reference in MkDocs mode (issue #97). Got: {result:?}"
+    );
+
+    // Path-like reference with backticks
+    let content = "[`api/endpoint`][]";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let result = rule.check(&ctx).unwrap();
+    assert!(
+        result.is_empty(),
+        "Should not flag [`api/endpoint`][] as undefined reference in MkDocs mode (issue #97). Got: {result:?}"
+    );
+
+    // Multiple backtick-wrapped references
+    let content = "See [`module.func`][], [`package.Class`][], and [`api/endpoint`][] for details.";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let result = rule.check(&ctx).unwrap();
+    assert!(
+        result.is_empty(),
+        "Should not flag multiple backtick-wrapped auto-references in MkDocs mode (issue #97). Got: {result:?}"
+    );
+
+    // Should still flag in standard mode (no MkDocs auto-references)
+    let content = "[`module.Class`][]";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+    assert_eq!(
+        result.len(),
+        1,
+        "Should flag [`module.Class`][] as undefined reference in Standard mode (no auto-refs). Got: {result:?}"
+    );
+
+    // Should still flag truly undefined references even in MkDocs mode
+    let content = "[undefined_reference][]";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let result = rule.check(&ctx).unwrap();
+    assert_eq!(
+        result.len(),
+        1,
+        "Should still flag [undefined_reference][] as undefined in MkDocs mode. Got: {result:?}"
+    );
+
+    // Backtick-wrapped images should also work
+    let content = "![`module.Class`][]";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let result = rule.check(&ctx).unwrap();
+    assert!(
+        result.is_empty(),
+        "Should not flag backtick-wrapped image references in MkDocs mode (issue #97). Got: {result:?}"
+    );
+
+    // Single-word backtick-wrapped identifiers should also work (the actual issue #97 example)
+    let content = "[`str`][]";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let result = rule.check(&ctx).unwrap();
+    assert!(
+        result.is_empty(),
+        "Should not flag [`str`][] as undefined reference in MkDocs mode (issue #97 example). Got: {result:?}"
+    );
+
+    // Multiple single-word backtick-wrapped identifiers
+    let content = "See [`str`][], [`int`][], and [`bool`][] for details.";
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let result = rule.check(&ctx).unwrap();
+    assert!(
+        result.is_empty(),
+        "Should not flag single-word backtick-wrapped identifiers in MkDocs mode (issue #97). Got: {result:?}"
+    );
+
+    // Note: [str][] without backticks is treated as an empty link by MD042, not a reference.
+    // MD052 only checks reference links, so it doesn't flag this pattern.
+    // This is correct behavior - if users want MkDocs auto-references, they should use backticks: [`str`][]
+}
+
+#[test]
+fn test_issue_114_code_block_in_quote() {
+    // Test for issue #114 - code block in quote creates false positives for MD052
+    let rule = MD052ReferenceLinkImages::new();
+
+    let content = r#"```rust
+#[derive(Debug)]
+struct Ok;
+```
+
+> ```rust
+> #[derive(Debug)]
+> struct NotOk;
+> ```
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should not flag [derive(Debug)] inside code blocks, even if they're in block quotes
+    assert_eq!(
+        result.len(),
+        0,
+        "Should not flag [derive(Debug)] inside code blocks (even in block quotes) as undefined references. Got: {result:?}"
+    );
+}
+
+#[test]
+fn test_code_block_in_quote_various_patterns() {
+    // Test various bracket patterns in code blocks inside block quotes
+    let rule = MD052ReferenceLinkImages::new();
+
+    let content = r#"Regular code block:
+```rust
+let x = vec![1, 2, 3];
+```
+
+> Code block in quote:
+> ```rust
+> let y = vec![4, 5, 6];
+> #[derive(Debug)]
+> struct Foo;
+> ```
+
+> Another blockquote
+> ```python
+> data = {"key": [1, 2, 3]}
+> ```
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should not flag any of these as undefined references
+    assert_eq!(
+        result.len(),
+        0,
+        "Should not flag brackets inside code blocks within blockquotes. Got: {result:?}"
+    );
+}
+
+#[test]
+fn test_actual_reference_in_quote_outside_code() {
+    // Make sure we still catch actual undefined references in blockquotes
+    let rule = MD052ReferenceLinkImages::new();
+
+    let content = r#"> This is a [reference] in a blockquote
+>
+> ```rust
+> #[derive(Debug)]
+> struct Foo;
+> ```
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should flag [reference] but not [derive(Debug)]
+    assert_eq!(
+        result.len(),
+        1,
+        "Should flag [reference] but not code block content. Got: {result:?}"
+    );
+    assert!(result[0].message.contains("reference"));
+}
